@@ -8,14 +8,14 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_QSCORE_ADAPTER_H_
-#define _GB2_QSCORE_ADAPTER_H_
+#ifndef _U2_QSCORE_ADAPTER_H_
+#define _U2_QSCORE_ADAPTER_H_
 
-#include <datatype/MAlignment.h>
-#include <core_api/Task.h>
+#include <U2Core/MAlignment.h>
+#include <U2Core/Task.h>
 
-namespace GB2 {
+namespace U2 {
 	extern double QScore(const MAlignment& maTest, const MAlignment& maRef, TaskStateInfo& ti);
 }
 
-#endif //_GB2_QSCORE_ADAPTER_H_
+#endif //_U2_QSCORE_ADAPTER_H_
