@@ -13,30 +13,30 @@
 
 #include "AnnotatorTests.h"
 
-#include <util_algorithm/GAutoDeleteList.h>
-#include <util_gui/GUIUtils.h>
-#include <util_ov_annotated_dna/AnnotatedDNAView.h>
-#include <util_ov_annotated_dna/ADVConstants.h>
-#include <util_ov_annotated_dna/ADVUtils.h>
-#include <gobjects/AnnotationTableObject.h>
+#include <U2Core/GAutoDeleteList.h>
+#include <U2Gui/GUIUtils.h>
+#include <U2View/AnnotatedDNAView.h>
+#include <U2View/ADVConstants.h>
+#include <U2View/ADVUtils.h>
+#include <U2Core/AnnotationTableObject.h>
 
 #include <QtGui/QMenu>
 #include <QtGui/QMessageBox>
 
-#include <test_framework/xmltest/XMLTestFormat.h>
-#include <test_framework/GTest.h>
-#include <test_framework/GTestFrameworkComponents.h>
+#include <U2Test/XMLTestFormat.h>
+#include <U2Test/GTest.h>
+#include <U2Test/GTestFrameworkComponents.h>
 
-#include <core_api/AppContext.h>
+#include <U2Core/AppContext.h>
 
 #include "CollocationWorker.h"
 
-namespace GB2 {
+namespace U2 {
 
 
-extern "C" Q_DECL_EXPORT Plugin* GB2_PLUGIN_INIT_FUNC() {
+extern "C" Q_DECL_EXPORT Plugin* U2_PLUGIN_INIT_FUNC() {
     AnnotatorPlugin * plug = new AnnotatorPlugin();
-	return plug;
+    return plug;
 }
 
 AnnotatorPlugin::AnnotatorPlugin() : Plugin(tr("dna_annotator_plugin"), tr("dna_annotator_plugin_desc")), viewCtx(NULL)
@@ -47,20 +47,20 @@ AnnotatorPlugin::AnnotatorPlugin() : Plugin(tr("dna_annotator_plugin"), tr("dna_
     }
     LocalWorkflow::CollocationWorkerFactory::init();
 
-	//Annotator test
-	GTestFormatRegistry* tfr = AppContext::getTestFramework()->getTestFormatRegistry();
-	XMLTestFormat *xmlTestFormat = qobject_cast<XMLTestFormat*>(tfr->findFormat("XML"));
-	assert(xmlTestFormat!=NULL);
-	
+    //Annotator test
+    GTestFormatRegistry* tfr = AppContext::getTestFramework()->getTestFormatRegistry();
+    XMLTestFormat *xmlTestFormat = qobject_cast<XMLTestFormat*>(tfr->findFormat("XML"));
+    assert(xmlTestFormat!=NULL);
+
     GAutoDeleteList<XMLTestFactory>* l = new GAutoDeleteList<XMLTestFactory>(this);
     l->qlist = AnnotatorTests::createTestFactories();
 
 
-	foreach(XMLTestFactory* f, l->qlist) { 
-		bool res = xmlTestFormat->registerTestFactory(f);
-		Q_UNUSED(res);
-		assert(res);
-	}
+    foreach(XMLTestFactory* f, l->qlist) {
+        bool res = xmlTestFormat->registerTestFactory(f);
+        Q_UNUSED(res);
+        assert(res);
+    }
 }
 
 AnnotatorViewContext::AnnotatorViewContext(QObject* p) : GObjectViewWindowContext(p, ANNOTATED_DNA_VIEW_FACTORY_ID) {
@@ -69,7 +69,7 @@ AnnotatorViewContext::AnnotatorViewContext(QObject* p) : GObjectViewWindowContex
 
 void AnnotatorViewContext::initViewContext(GObjectView* v) {
     AnnotatedDNAView* av = qobject_cast<AnnotatedDNAView*>(v);
-    ADVGlobalAction* a = new ADVGlobalAction(av, QIcon(":annotator/images/regions.png"), tr("find_annotation_collocations"), 30);
+    ADVGlobalAction* a = new ADVGlobalAction(av, QIcon(":annotator/images/regions.png"), tr("Find annotated regions..."), 30);
     connect(a, SIGNAL(triggered()), SLOT(sl_showCollocationDialog()));
 }
 
@@ -100,9 +100,9 @@ void AnnotatorViewContext::sl_showCollocationDialog() {
 }
 
 QList<XMLTestFactory*> AnnotatorTests::createTestFactories() {
-	QList<XMLTestFactory*> res;
-	res.append(GTest_AnnotatorSearch::createFactory());
-	return res;
+    QList<XMLTestFactory*> res;
+    res.append(GTest_AnnotatorSearch::createFactory());
+    return res;
 }
 
 }//namespace
