@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -8,17 +8,17 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_ANNOTATION_COLLOCATOR_PLUGIN_H_
-#define _GB2_ANNOTATION_COLLOCATOR_PLUGIN_H_
+#ifndef _U2_ANNOTATION_COLLOCATOR_PLUGIN_H_
+#define _U2_ANNOTATION_COLLOCATOR_PLUGIN_H_
 
-#include <core_api/PluginModel.h>
-#include <core_api/ObjectViewModel.h>
+#include <U2Core/PluginModel.h>
+#include <U2Gui/ObjectViewModel.h>
 
 #include <QtCore/QMap>
 #include <QtGui/QAction>
 
 
-namespace GB2 {
+namespace U2 {
 
 class XMLTestFactory;
 
@@ -41,13 +41,11 @@ protected slots:
 
 protected:
     virtual void initViewContext(GObjectView* view);
-    virtual void buildMenu(GObjectView* v, QMenu* m);
-
 };
 
 class AnnotatorTests {
 public:
-	static QList<XMLTestFactory*> createTestFactories();
+    static QList<XMLTestFactory*> createTestFactories();
 };
 
 } //namespace
