@@ -8,14 +8,16 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_ANNOTATOR_WORKER_H_
-#define _GB2_ANNOTATOR_WORKER_H_
+#ifndef _U2_ANNOTATOR_WORKER_H_
+#define _U2_ANNOTATOR_WORKER_H_
 
-#include <workflow_library/LocalDomain.h>
-#include <workflow_support/WorkflowUtils.h>
+#include <QtCore/QSet>
+
+#include <U2Lang/LocalDomain.h>
+#include <U2Lang/WorkflowUtils.h>
 #include "CollocationsSearchAlgorithm.h"
 
-namespace GB2 {
+namespace U2 {
 
 namespace LocalWorkflow {
 
@@ -61,6 +63,6 @@ public:
 };
 
 }//Workflow namespace
-}//GB2 namespace
+}//U2 namespace
 
 #endif
