@@ -8,15 +8,15 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_COLLOCATION_DIALOG_CONTROLLER_H_
-#define _GB2_COLLOCATION_DIALOG_CONTROLLER_H_
+#ifndef _U2_COLLOCATION_DIALOG_CONTROLLER_H_
+#define _U2_COLLOCATION_DIALOG_CONTROLLER_H_
 
 #include "CollocationsSearchAlgorithm.h"
 
 #include <ui/ui_FindAnnotationCollocationsDialog.h>
-#include <core_api/Task.h>
-#include <core_api/LRegion.h>
-#include <datatype/AnnotationData.h>
+#include <U2Core/Task.h>
+#include <U2Core/LRegion.h>
+#include <U2Core/AnnotationData.h>
 //#include "gobjects/AnnotationTableObject.h"
 
 #include <QtCore/QTimer>
@@ -24,7 +24,7 @@
 #include <QtGui/QDialog>
 #include <QtGui/QToolButton>
 
-namespace GB2 {
+namespace U2 {
 
 class ADVSequenceObjectContext;
 class CollocationSearchTask;
@@ -76,7 +76,7 @@ public:
 class CollocationSearchTask : public Task , public CollocationsAlgorithmListener{
     Q_OBJECT
 public:
-	CollocationSearchTask(const QList<AnnotationTableObject*> &table, const QSet<QString>& names, const CollocationsAlgorithmSettings& cfg);
+    CollocationSearchTask(const QList<AnnotationTableObject*> &table, const QSet<QString>& names, const CollocationsAlgorithmSettings& cfg);
     CollocationSearchTask(const QList<SharedAnnotationData> &table, const QSet<QString>& names, const CollocationsAlgorithmSettings& cfg);
     void run();
 
