@@ -8,13 +8,13 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_COLLOCATION_SEARCH_ALGORITHM_H_
-#define _GB2_COLLOCATION_SEARCH_ALGORITHM_H_
+#ifndef _U2_COLLOCATION_SEARCH_ALGORITHM_H_
+#define _U2_COLLOCATION_SEARCH_ALGORITHM_H_
 
-#include <core_api/Task.h>
-#include <core_api/LRegion.h>
+#include <U2Core/Task.h>
+#include <U2Core/LRegion.h>
 
-namespace GB2 {
+namespace U2 {
 
 class CollocationsAlgorithmListener {
 public:
@@ -35,13 +35,13 @@ class CollocationsAlgorithmSettings;
 
 class CollocationsAlgorithm {
 public:
-	enum SearchType {NormalSearch, PartialSearch};
-	static void find(const QList<CollocationsAlgorithmItem>& items, TaskStateInfo& si, 
-		CollocationsAlgorithmListener* l, const CollocationsAlgorithmSettings& cfg);
+    enum SearchType {NormalSearch, PartialSearch};
+    static void find(const QList<CollocationsAlgorithmItem>& items, TaskStateInfo& si,
+        CollocationsAlgorithmListener* l, const CollocationsAlgorithmSettings& cfg);
 private:
     static void findN(const QList<CollocationsAlgorithmItem>& items, TaskStateInfo& si, 
                     CollocationsAlgorithmListener* l, const LRegion& searchRegion, int distance);
-	static void findP(const QList<CollocationsAlgorithmItem>& items, TaskStateInfo& si, 
+    static void findP(const QList<CollocationsAlgorithmItem>& items, TaskStateInfo& si,
                     CollocationsAlgorithmListener* l, const LRegion& searchRegion, int distance);
 
 };
@@ -55,7 +55,7 @@ public:
 };
 
 
-} //namespace GB2
+} //namespace U2
 #endif
 
 
