@@ -11,17 +11,17 @@
 #include <QtOpenGL>
 #include <time.h>
 
-#include <datatype/BioStruct3D.h>
-#include <document_format/PDBFormat.h>
+#include <U2Core/BioStruct3D.h>
+#include <U2Formats/PDBFormat.h>
 
 #include "GraphicUtils.h"
 #include "BioStruct3DGLWidget.h"
 #include "BioStruct3DColorScheme.h"
 #include "BallAndStickGLRenderer.h"
 
-#include <core_api/Log.h>
+#include <U2Core/Log.h>
 
-namespace GB2 { 
+namespace U2 { 
 
 const QString BallAndStickGLRenderer::ID(QObject::tr("Ball-and-stick"));
 unsigned int DisplayLists::bigDL = -1;
@@ -34,13 +34,13 @@ void BallAndStickGLRenderer::drawBioStruct3D(  )
 
 void BallAndStickGLRenderer::drawAtomsAndBonds()
 {
-	glCallList(bigDL);
+    glCallList(bigDL);
 }
 
 BallAndStickGLRenderer::BallAndStickGLRenderer( const BioStruct3D& struc, const BioStruct3DColorScheme* s )
     : BioStruct3DGLRenderer(struc,s)
 {
-	bigDL = DisplayLists::getBigDisplayList();
+    bigDL = DisplayLists::getBigDisplayList();
 }
 
 void BallAndStickGLRenderer::updateColorScheme()
