@@ -8,13 +8,13 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_BIOSTRUCT3D_BALLANDSTICK_RENDERER_H_
-#define _GB2_BIOSTRUCT3D_BALLANDSTICK_RENDERER_H_
+#ifndef _U2_BIOSTRUCT3D_BALLANDSTICK_RENDERER_H_
+#define _U2_BIOSTRUCT3D_BALLANDSTICK_RENDERER_H_
 
 #include "BioStruct3DGLRender.h"
 #include <QtOpenGL>
 
-namespace GB2 { 
+namespace U2 { 
 
 class BallAndStickGLRenderer : public BioStruct3DGLRenderer {
 
@@ -37,4 +37,4 @@ public:
 
 } //namespace
 
-#endif // _GB2_BIOSTRUCT3D_BALLANDSTICK_RENDERER_H_
+#endif // _U2_BIOSTRUCT3D_BALLANDSTICK_RENDERER_H_
