@@ -15,7 +15,7 @@
 #include "BioStruct3DGLWidget.h"
 
 
-namespace GB2 { 
+namespace U2 { 
 
 
 ///////////////////////////////////////////////////////////////////////////////////////////
@@ -48,16 +48,24 @@ const QString BioStruct3DColorSchemeFactory::defaultFactoryName()
 // BioStruct3DColorScheme
 
 BioStruct3DColorScheme::BioStruct3DColorScheme(const BioStruct3DGLWidget* widget) : 
-    glWidget(widget), defaultAtomColor(0.25f, 0.25f, 0.25f), selectionColor(1.0f, 1.0f, 0)
+    glWidget(widget), defaultAtomColor(0.25f, 0.25f, 0.25f), selectionColor(1.0f, 1.0f, 0), unselectedShading(0.0)
 {
-    
 }
 
 Color4f BioStruct3DColorScheme::getAtomColor(const SharedAtom& atom) const {
-   if (isInSelection(atom))
-       return selectionColor;
-   else
-       return getSchemeAtomColor(atom);
+    Color4f c;
+
+    if (isInSelection(atom)) {
+        c = selectionColor;
+    }
+    else {
+        c = getSchemeAtomColor(atom);
+        if (!selection.isEmpty() && unselectedShading > 0.0) {  // dim unselected
+            c[3] *= (1.0 - unselectedShading);
+        }
+    }
+
+    return c;
 }
 
 void BioStruct3DColorScheme::setSelectionColor(QColor color)
@@ -65,60 +73,67 @@ void BioStruct3DColorScheme::setSelectionColor(QColor color)
     this->selectionColor=color;
 }
 
-void BioStruct3DColorScheme::updateSelectionRegion(int chainId, const QList<LRegion>& added, const QList<LRegion>& removed)
+void BioStruct3DColorScheme::setUnselectedShadingLevel(float shading)
 {
-        // Residues in chain could start from any number
-        int residueStartId = glWidget->getBioStruct3D().moleculeMap.value(chainId)->residueMap.begin().key();
-        
-        foreach( const LRegion region, removed) {
-            int startPos = region.startPos;
-            int endPos = region.endPos();
-            for (int i = startPos; i < endPos; ++i) {
-                int residueId = residueStartId + i;
-                removeFromSelection(chainId, residueId);
-            }
-        }
-        
-        foreach( const LRegion region, added) {
-            int startPos = region.startPos;
-            int endPos = region.endPos();
-            for (int i = startPos; i < endPos; ++i) {
-                int residueId = residueStartId + i;
-                addToSelection(chainId, residueId);
-            }
-        }
-        
-    
+    assert(shading >= 0.0 && shading <= 1.0);
+    unselectedShading = shading;
 }
 
-void BioStruct3DColorScheme::addToSelection( int chainId, int residueId )
+void BioStruct3DColorScheme::updateSelectionRegion(int chainId, const QList<LRegion>& added, const QList<LRegion>& removed)
 {
-    //TODO: optimize this
-    //qDebug("added to selection (%d, %d)", chainId, residueId );
+    // Residues in chain could start from any number
+    int residueStartId = glWidget->getBioStruct3D().moleculeMap.value(chainId)->residueMap.begin().key();
+
+    foreach( const LRegion region, removed) {
+        int startPos = region.startPos;
+        int endPos = region.endPos();
+        for (int i = startPos; i < endPos; ++i) {
+            int residueId = residueStartId + i;
+            removeFromSelection(chainId, residueId);
+        }
+    }
+
+    foreach( const LRegion region, added) {
+        int startPos = region.startPos;
+        int endPos = region.endPos();
+        for (int i = startPos; i < endPos; ++i) {
+            int residueId = residueStartId + i;
+            addToSelection(chainId, residueId);
+        }
+    }
+}
+
+void BioStruct3DColorScheme::addToSelection(int chainId, int residueId)
+{
+    /*    //TODO: optimize this
     if (!curSelection.contains(SelectionId(chainId,residueId))) {
         curSelection.append(SelectionId(chainId, residueId));
     }
+
     //qSort(curSelection);
+    */
+    if (!selection.contains(chainId, residueId)) {
+        selection.insert(chainId, residueId);
+    }
 }
 
-void BioStruct3DColorScheme::removeFromSelection( int chainId, int residueId )
+void BioStruct3DColorScheme::removeFromSelection(int chainId, int residueId)
 {
-    curSelection.removeOne(QPair<int,int>(chainId, residueId)); 
-    //QLinkedList< QPair<int,int> >::iterator i = curSelection.begin();  
-//    QLinkedList< QPair<int,int> >::iterator i = qBinaryFind(curSelection.begin(), curSelection.end(), QPair<int,int> (chainId, residueId));
-//     if (i != curSelection.end()) {
-//         curSelection.erase(i);
-//     }
+    selection.remove(chainId, residueId);
+    /*curSelection.removeOne(QPair<int,int>(chainId, residueId));*/
 }
 
 bool BioStruct3DColorScheme::isInSelection( const SharedAtom& atom ) const
 {
+   /*
    QLinkedList<SelectionId>::const_iterator i;
    SelectionId selId(atom->chainIndex, atom->residueIndex);
    for ( i = curSelection.constBegin(); i != curSelection.constEnd(); ++i) {
         if ((*i) == selId)
             return true;
    }
+   */
+   return selection.contains(atom->chainIndex, atom->residueIndex);
 
 //   qBinaryFind(curSelection.begin(), curSelection.end(), QPair<int,int> (chainId, residueId) );
 //   if (i != curSelection.end()) {
@@ -139,33 +154,33 @@ Color4f BioStruct3DColorScheme::getSchemeAtomColor( const SharedAtom& atom ) con
 
 Color4f ChemicalElemColorScheme::getSchemeAtomColor( const SharedAtom& a ) const
 {
-	Color4f color;
-	if (elementColorMap.contains(a->atomicNumber)) {
-		return elementColorMap.value(a->atomicNumber);
-	} else {
-		return defaultAtomColor;
-	}
+    Color4f color;
+    if (elementColorMap.contains(a->atomicNumber)) {
+        return elementColorMap.value(a->atomicNumber);
+    } else {
+        return defaultAtomColor;
+    }
 
 }
 
 ChemicalElemColorScheme::ChemicalElemColorScheme(const BioStruct3DGLWidget* widget)
         : BioStruct3DColorScheme(widget)
 {
-	//CPK colors
+    //CPK colors
 
-	elementColorMap.insert(1, Color4f(1.0f, 1.0f, 1.0f));
-	elementColorMap.insert(6, Color4f(0.8f, 0.8f, 0.8f));
-	elementColorMap.insert(7, Color4f(0.7f, 0.7f, 1.0f));
-	elementColorMap.insert(8, Color4f(0.95f, 0.0f , 0.0f));
-	elementColorMap.insert(11, Color4f(0.0f, 0.0f , 1.0f));
-	elementColorMap.insert(12, Color4f(0.16f, 0.5f , 0.16f));
-	elementColorMap.insert(15, Color4f(1.0f, 0.63f , 0.0f));
-	elementColorMap.insert(16, Color4f(1.0f, 0.8f , 0.2f));
-	elementColorMap.insert(17, Color4f(0.0f, 1.0f , 0.0f));
-	elementColorMap.insert(20, Color4f(0.5f, 0.5f , 0.5f));
-	elementColorMap.insert(26, Color4f(1.0f, 0.63f , 0.0f));
-	elementColorMap.insert(30, Color4f(0.63f, 0.2f , 0.2f));
-	elementColorMap.insert(35, Color4f(0.63f, 0.2f , 0.2f));
+    elementColorMap.insert(1, Color4f(1.0f, 1.0f, 1.0f));
+    elementColorMap.insert(6, Color4f(0.8f, 0.8f, 0.8f));
+    elementColorMap.insert(7, Color4f(0.7f, 0.7f, 1.0f));
+    elementColorMap.insert(8, Color4f(0.95f, 0.0f , 0.0f));
+    elementColorMap.insert(11, Color4f(0.0f, 0.0f , 1.0f));
+    elementColorMap.insert(12, Color4f(0.16f, 0.5f , 0.16f));
+    elementColorMap.insert(15, Color4f(1.0f, 0.63f , 0.0f));
+    elementColorMap.insert(16, Color4f(1.0f, 0.8f , 0.2f));
+    elementColorMap.insert(17, Color4f(0.0f, 1.0f , 0.0f));
+    elementColorMap.insert(20, Color4f(0.5f, 0.5f , 0.5f));
+    elementColorMap.insert(26, Color4f(1.0f, 0.63f , 0.0f));
+    elementColorMap.insert(30, Color4f(0.63f, 0.2f , 0.2f));
+    elementColorMap.insert(35, Color4f(0.63f, 0.2f , 0.2f));
 
 }
 
@@ -175,22 +190,22 @@ ChemicalElemColorScheme::ChemicalElemColorScheme(const BioStruct3DGLWidget* widg
 
 ChainsColorScheme::ChainsColorScheme(const BioStruct3DGLWidget* widget) : BioStruct3DColorScheme(widget)
 {
-	const QMap<int, QColor> chainColors = glWidget->getChainColors();
+    const QMap<int, QColor> chainColors = glWidget->getChainColors();
     Q_ASSERT(!chainColors.empty());
     QMapIterator<int, QColor> i(chainColors);
-	while (i.hasNext()) {
-		i.next();
-		chainColorMap.insert(i.key(), Color4f(i.value()));
+    while (i.hasNext()) {
+        i.next();
+        chainColorMap.insert(i.key(), Color4f(i.value()));
     }
 }
 Color4f ChainsColorScheme::getSchemeAtomColor( const SharedAtom& atom ) const
 {
-	Color4f color;
-	if (chainColorMap.contains(atom->chainIndex)) {
-		return chainColorMap.value(atom->chainIndex);
-	} else {
-		return defaultAtomColor;
-	}
+    Color4f color;
+    if (chainColorMap.contains(atom->chainIndex)) {
+        return chainColorMap.value(atom->chainIndex);
+    } else {
+        return defaultAtomColor;
+    }
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////
@@ -205,10 +220,11 @@ SecStructColorScheme::SecStructColorScheme(const BioStruct3DGLWidget* widget) :
         secStrucColorMap.insert(i.key().toAscii(), Color4f(i.value()));
     }
 
-    foreach (SharedSecondaryStructure struc, widget->getBioStruct3D().secondaryStructures) {
+    foreach (const SharedSecondaryStructure& struc, widget->getBioStruct3D().secondaryStructures) {
         for (int index = struc->startSequenceNumber; index <= struc->endSequenceNumber; ++index ) {
             QByteArray type = BioStruct3D::getSecStructTypeName(struc->type).toAscii();
-            Q_ASSERT(secStrucColorMap.contains(type));
+            Q_ASSERT( secStrucColorMap.contains(type));
+            Q_ASSERT( struc->chainIndex != 0);
             molMap[struc->chainIndex].strucResidueTable.insert(index, type);
         }
     }
@@ -227,16 +243,18 @@ SecStructColorScheme::SecStructColorScheme(const BioStruct3DGLWidget* widget) :
 
 Color4f SecStructColorScheme::getSchemeAtomColor( const SharedAtom& atom ) const
 {
+    Color4f c = defaultAtomColor;
     int residueIndex = atom->residueIndex;
 
     if (molMap.contains(atom->chainIndex)) {
         const QHash<int, QByteArray>& residueTable = molMap.value(atom->chainIndex).strucResidueTable;
         if (residueTable.contains(residueIndex)) {
             QByteArray type = residueTable.value(residueIndex);
-            return secStrucColorMap.value(type);
+            c = secStrucColorMap.value(type);
         }    
     }
-    return defaultAtomColor;    
+
+    return c;
 }
 
 
