@@ -15,7 +15,7 @@
 #include "VanDerWaalsGLRenderer.h"
 #include "WormsGLRenderer.h"
 
-namespace GB2 { 
+namespace U2 { 
 
 #define REGISTER_FACTORY(c) \
     map.insert(c::ID, new c::Factory)
