@@ -15,23 +15,23 @@
 #include <QtGui/QImageWriter>
 #include <QtCore/QTime>
 
-#include <datatype/BioStruct3D.h>
-#include <util_ov_annotated_dna/AnnotatedDNAView.h>
-#include <util_ov_annotated_dna/ADVSequenceObjectContext.h>
-#include <gobjects/AnnotationSettings.h>
-#include <gobjects/AnnotationTableObject.h>
-#include <gobjects/DNASequenceObject.h>
-#include <gobjects/BioStruct3DObject.h>
-#include <gobjects/GObjectUtils.h>
-#include <gobjects/GObjectRelationRoles.h>
-#include <core_api/Log.h>
-#include <core_api/AppContext.h>
-#include <core_api/DocumentModel.h>
-#include <core_api/Counter.h>
-#include <molecular_geometry/MolecularSurfaceFactoryRegistry.h>
-#include <molecular_geometry/MolecularSurface.h>
-#include <selection/DNASequenceSelection.h>
-#include <selection/AnnotationSelection.h>
+#include <U2Core/BioStruct3D.h>
+#include <U2View/AnnotatedDNAView.h>
+#include <U2View/ADVSequenceObjectContext.h>
+#include <U2Core/AnnotationSettings.h>
+#include <U2Core/AnnotationTableObject.h>
+#include <U2Core/DNASequenceObject.h>
+#include <U2Core/BioStruct3DObject.h>
+#include <U2Core/GObjectUtils.h>
+#include <U2Core/GObjectRelationRoles.h>
+#include <U2Core/Log.h>
+#include <U2Core/AppContext.h>
+#include <U2Core/DocumentModel.h>
+#include <U2Core/Counter.h>
+#include <U2Algorithm/MolecularSurfaceFactoryRegistry.h>
+#include <U2Algorithm/MolecularSurface.h>
+#include <U2Core/DNASequenceSelection.h>
+#include <U2Core/AnnotationSelection.h>
 #include <time.h>
 
 #include "BioStruct3DGLWidget.h"
@@ -44,32 +44,32 @@
 
 #include "gl2ps/gl2ps.h"
 
-
 //disable "unsafe functions" deprecation warnings on MS VS
 #ifdef Q_OS_WIN
 #pragma warning(disable : 4996)
 #endif
 
 
-namespace GB2 { 
+namespace U2 { 
 
-static LogCategory log(ULOG_CAT_PLUGIN_BIOSTRUCT_3D);
-static LogCategory logPerf(ULOG_CAT_PERFORMANCE);
 int BioStruct3DGLWidget::widgetCount = 0;
 
-
 static QColor DEFAULT_BACKGROUND_COLOR = Qt::black;
 static QColor DEFAULT_SELECTION_COLOR = Qt::yellow;
 
-static QColor DEFAULT_LEFT_EYE_COLOR(0, 255, 255);
+static QColor DEFAULT_LEFT_EYE_COLOR = QColor(0, 255, 255);
 static QColor DEFAULT_RIGHT_EYE_COLOR = QColor(255, 0, 0);
 
-static int DEFAULT_RENDER_DETAIL_LEVEL = 100;
 static bool DEFAULT_ANAGLYPH = false;
+
+static int DEFAULT_RENDER_DETAIL_LEVEL = 100;
 static int DEFAULT_EYES_SHIFT = 160;
+static int DEFAULT_SHADING_LEVEL = 50;
 
 BioStruct3DGLWidget::BioStruct3DGLWidget(const BioStruct3DObject* obj, const AnnotatedDNAView* view, GLFrameManager* manager, QWidget *parent /* = 0*/)
-    : QGLWidget(parent), biostruc(obj->getBioStruct3D()), biostrucDoc(obj->getDocument()),  
+    : QGLWidget(parent),
+    biostructs( QList<const BioStruct3DObject*>() << obj ),
+    biostruc(obj->getBioStruct3D()), biostrucDoc(obj->getDocument()),
     dnaView(view), frameManager(manager), molSurface(NULL), currentModelID(obj->getBioStruct3D().pdbId), spinAngle(0), displayMenu(NULL)
 {
     BACKGROUND_COLOR_NAME = QString("BackgroundColor");
@@ -85,6 +85,7 @@ BioStruct3DGLWidget::BioStruct3DGLWidget(const BioStruct3DObject* obj, const Ann
     RIGHT_EYE_COLOR_NAME = QString("RightEyeColor");
 
     RENDER_DETAIL_LEVEL_NAME = QString("RenderDetailLevel");
+    SHADING_LEVEL_NAME = QString("Shading Unselected Regions Level");
     ANAGLYPH_NAME = QString("Anaglyph");
     EYES_SHIFT_NAME = QString("EyesShift");
 
@@ -102,13 +103,21 @@ BioStruct3DGLWidget::BioStruct3DGLWidget(const BioStruct3DObject* obj, const Ann
     backgroundColor = DEFAULT_BACKGROUND_COLOR;
     selectionColor = DEFAULT_SELECTION_COLOR;
 
-    anaglyph = DEFAULT_ANAGLYPH;
     eyesShift = DEFAULT_EYES_SHIFT;
 
+    anaglyphRenderTextureLeft = 0;
+    anaglyphRenderTextureRight = 0;
+    tempAnaglyphRenderTexture = 0;
+
+    anaglyph = DEFAULT_ANAGLYPH;
+    anaglyphAvailable = true;
+    firstResize = true;
+
     leftEyeColor = DEFAULT_LEFT_EYE_COLOR;
     rightEyeColor = DEFAULT_RIGHT_EYE_COLOR;
 
     renderDetailLevel = DEFAULT_RENDER_DETAIL_LEVEL;
+    unselectedShadingLevel = DEFAULT_SHADING_LEVEL;
 
     emptyTextureData = NULL;
 
@@ -149,11 +158,9 @@ BioStruct3DGLWidget::~BioStruct3DGLWidget()
         delete f;
     }
 
-    log.trace("Biostruct3DGLWdiget "+objectName()+" deleted");
+    uiLog.trace("Biostruct3DGLWdiget "+objectName()+" deleted");
 }
 
-
-
 void BioStruct3DGLWidget::initializeGL()
 {
     setLightPosition(Vector3D(0, 0.0, 1.0));
@@ -171,26 +178,32 @@ void BioStruct3DGLWidget::initializeGL()
     glLightfv(GL_LIGHT0, GL_DIFFUSE, light_diffuse);
     glLightfv(GL_LIGHT0, GL_SPECULAR, light_specular);
     glLightfv(GL_LIGHT0, GL_POSITION, lightPostion);
-//    glEnable(GL_NORMALIZE);
-	glEnable(GL_BLEND);                                         // Enable Blending
+    glEnable(GL_BLEND);                                         // Enable Blending
     glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
-
-	// Disable AutoTexture Coordinates
-//	glDisable(GL_TEXTURE_GEN_S);
-//	glDisable(GL_TEXTURE_GEN_T);
 }
 
 void BioStruct3DGLWidget::resizeGL(int width, int height)
 {
-	glDeleteTextures(1, &anaglyphRenderTextureLeft);
-	glDeleteTextures(1, &anaglyphRenderTextureRight);
-	glDeleteTextures(1, &tempAnaglyphRenderTexture);
+    glDeleteTextures(1, &anaglyphRenderTextureLeft);
+    glDeleteTextures(1, &anaglyphRenderTextureRight);
+    glDeleteTextures(1, &tempAnaglyphRenderTexture);
 
-    anaglyphRenderTextureLeft = getEmptyTexture(height, width);
-    anaglyphRenderTextureRight = getEmptyTexture(height, width);
+    anaglyphRenderTextureLeft = getEmptyTexture(width, height);
+    anaglyphRenderTextureRight = getEmptyTexture(width, height);
+    tempAnaglyphRenderTexture =  getEmptyTexture(width, height);
 
-    tempAnaglyphRenderTexture =  getEmptyTexture(height, width);
+    hasGlErrors();
 
+    if (firstResize && (width>0) && (height>0)) {
+        // test anaglyph mode
+        anaglyph = true;
+        draw(); // draw() checks for openGL errors and sets 'anaglyphAvailable' flag
+
+        // return anaglyph mode to the default value
+        anaglyph = DEFAULT_ANAGLYPH;
+
+        firstResize = false;
+    }
     glFrame->updateViewPort(width, height);
 }
 
@@ -266,48 +279,53 @@ void BioStruct3DGLWidget::ViewPerspective()
     glPopMatrix();                                              // Pop The Matrix
 }
 
-GLuint BioStruct3DGLWidget::getEmptyTexture(int textureHeight, int textureWidth)    // Create An Empty Texture
+GLuint BioStruct3DGLWidget::getEmptyTexture(int textureWidth, int textureHeight)    // Create An Empty Texture
 {
-    GLuint txtnumber;                                           // Texture ID
+    GLuint txtnumber;                                                    // Texture ID
 
-    glGenTextures(1, &txtnumber);                               // Create 1 Texture
-    glBindTexture(GL_TEXTURE_2D, txtnumber);                    // Bind The Texture
+    glGenTextures(1, &txtnumber);                                        // Create 1 Texture
+    glBindTexture(GL_TEXTURE_2D, txtnumber);                            // Bind The Texture
     glTexImage2D(GL_TEXTURE_2D, 0, 4, textureWidth, textureHeight, 0,
     GL_RGBA, GL_UNSIGNED_BYTE, emptyTextureData);                       // Build Texture Using Information In data
     glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_LINEAR);
     glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_LINEAR);
 
-    return txtnumber;                                           // Return The Texture ID
+    return txtnumber;                                                    // Return The Texture ID
 }
 
-void BioStruct3DGLWidget::drawTexturesAnaglypth(GLuint anaglyphRenderTextureLeft, GLuint anaglyphRenderTextureRight)                                // Draw The Image
+void BioStruct3DGLWidget::drawTexturesAnaglyph(GLuint anaglyphRenderTextureLeft, GLuint anaglyphRenderTextureRight)                                // Draw The Image
 {
     glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);      //clear color and depth buffers
     drawTexture(anaglyphRenderTextureLeft, rightEyeColor.red(), rightEyeColor.green(), rightEyeColor.blue(), 0.5f, false); // colored left image
+    if (hasGlErrors()) { return; }
 
     glBindTexture(GL_TEXTURE_2D, tempAnaglyphRenderTexture);                    // Bind To The Blur Texture
     glCopyTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA, 0, 0, width(), height(), 0);// Copy Our ViewPort To The Blur Texture (From 0,0 To 128,128... No Border)
+    if (hasGlErrors()) { return; }
 
-    glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);      //clear color and depth buffers
     drawTexture(anaglyphRenderTextureRight, leftEyeColor.red(), leftEyeColor.green(), leftEyeColor.blue(), 0.5f, false); // colored right image
-
     drawTexture(tempAnaglyphRenderTexture, 255, 255, 255, 1.0f, true);
 }
 
 void BioStruct3DGLWidget::drawTexture(GLuint anaglyphRenderTexture, int red, int green, int blue, float alpha, bool alphaOnly)                              // Draw The Blurred Image
 {
-	glEnable(GL_TEXTURE_2D);                                    // Enable 2D Texture Mapping
+    glEnable(GL_TEXTURE_2D);                                    // Enable 2D Texture Mapping
 
-    if (alphaOnly){
-        glBlendFunc(GL_ALPHA, GL_ALPHA);
-    }
-    else {
-        glBlendFunc(GL_ONE, GL_ONE);
+    GLboolean blendEnabled = glIsEnabled(GL_BLEND);
+    if (blendEnabled) {
+        if (alphaOnly){
+            glBlendFunc(GL_DST_ALPHA, GL_DST_ALPHA); // the second image is this, it has needed alpha color
+        }
+        else {
+            glBlendFunc(GL_ONE, GL_ONE);
+        }
     }
+    if (hasGlErrors()) { return; }
 
-//    glEnable(GL_BLEND);                                         // Enable Blending
     glBindTexture(GL_TEXTURE_2D, anaglyphRenderTexture);                    // Bind To The Blur Texture
+    if (hasGlErrors()) { return; }
     ViewOrtho();                                                // Switch To An Ortho View
+    if (hasGlErrors()) { return; }
 
     glColor4f((float)red/255, (float)green/255, (float)blue/255, alpha);                    // Set The Alpha Value (Starts At 0.2)
     glBegin(GL_QUADS);                                          // Begin Drawing Quads
@@ -323,22 +341,24 @@ void BioStruct3DGLWidget::drawTexture(GLuint anaglyphRenderTexture, int red, int
         glTexCoord2f(1, 1);                     // Texture Coordinate   ( 1, 1 )
         glVertex2f((float)width(), 0);                                  // Fourth Vertex    ( 640,   0 )
     glEnd();                                                    // Done Drawing Quads
+    if (hasGlErrors()) { return; }
 
     ViewPerspective();                                          // Switch To A Perspective View
+    if (hasGlErrors()) { return; }
 
     glDisable(GL_TEXTURE_2D);                                   // Disable 2D Texture Mapping
-//    glDisable(GL_BLEND);                                        // Disable Blending
     glBindTexture(GL_TEXTURE_2D,0);                             // Unbind The Blur Texture
+    if (hasGlErrors()) { return; }
 }
 
 void BioStruct3DGLWidget::drawAll()
 {
-	glEnable(GL_DEPTH_TEST);                                    // Enable Depth Testing
+    glEnable(GL_DEPTH_TEST);                                    // Enable Depth Testing
 
-	glEnable(GL_LIGHTING);
-	glEnable(GL_LIGHT0);
+    glEnable(GL_LIGHTING);
+    glEnable(GL_LIGHT0);
 
-	glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+    glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 
     Vector3D rotCenter = biostruc.getCenter();
 
@@ -352,28 +372,46 @@ void BioStruct3DGLWidget::drawAll()
 
     if(NULL != molSurface.get())
     {
-//        glEnable(GL_BLEND);
-//        glEnable(GL_BLEND);
         glEnable(GL_CULL_FACE);
         glCullFace(GL_FRONT);
         surfaceRenderer->drawSurface(*molSurface);
         glCullFace(GL_BACK);
         surfaceRenderer->drawSurface(*molSurface);
         glDisable(GL_CULL_FACE);
-//        glDisable(GL_BLEND);
     }
 
-	glDisable(GL_LIGHTING);
-	glDisable(GL_LIGHT0);
-	glDisable(GL_DEPTH_TEST);                                   // Disable Depth Testing
+    glDisable(GL_LIGHTING);
+    glDisable(GL_LIGHT0);
+    glDisable(GL_DEPTH_TEST);                                   // Disable Depth Testing
 
     clock_t t2 = clock();
-    logPerf.trace("BioStruct3D structure rendering time " + QString::number((float)( t2 - t1)/ CLOCKS_PER_SEC)+ " s");
+    perfLog.trace("BioStruct3D structure rendering time " + QString::number((float)( t2 - t1)/ CLOCKS_PER_SEC)+ " s");
 }
 
+bool BioStruct3DGLWidget::hasGlErrors() {
+
+    GLenum lastGlError = glGetError();
+
+    bool hasAnyGlError = (lastGlError != GL_NO_ERROR);
+    if (anaglyphAvailable) {
+        anaglyphAvailable = !hasAnyGlError; // don't change anaglyph mode availability if some error happened at least once
+    }
+
+    if (hasAnyGlError) {
+        uiLog.trace(
+            QString("OpenGL error: ") + QString((char*)gluErrorString(lastGlError)) +
+            QString(", returned error code ") + QString::number(lastGlError) +
+            QString(", GL_NO_ERROR = ") + QString::number(GL_NO_ERROR)
+        );
+
+        anaglyph = false;
+    }
+
+    return hasAnyGlError;
+}
+
+void BioStruct3DGLWidget::draw() {
 
-void BioStruct3DGLWidget::draw()
-{
     float eyesShift = 5*getEyesShiftMult()*glFrame->getCameraPosition().z/200;
 
     glMatrixMode(GL_MODELVIEW);
@@ -381,29 +419,39 @@ void BioStruct3DGLWidget::draw()
 
     glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);      //clear color and depth buffers
 
-    if (!anaglyph)
-    {
+    if (!anaglyph) {
         gluLookAt(0.0, 0.0, glFrame->getCameraPosition().z, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0);
         drawAll();
+        hasGlErrors();
     }
-    else
-    {
+    else {
+
         gluLookAt(eyesShift, 0.0, glFrame->getCameraPosition().z, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0);
         drawAll();
+        if (hasGlErrors()) { return; }
 
         glBindTexture(GL_TEXTURE_2D, anaglyphRenderTextureRight);                   // Bind To The Anaglyph Texture
+        if (hasGlErrors()) { return; }
         glCopyTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA, 0, 0, width(), height(), 0);// Copy Our ViewPort To The Blur Texture (From 0,0 To 128,128... No Border)
+        if (hasGlErrors()) { return; }
 
         glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
+        if (hasGlErrors()) { return; }
         glLoadIdentity();
+        if (hasGlErrors()) { return; }
 
         gluLookAt(-eyesShift, 0.0, glFrame->getCameraPosition().z, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0);
+        if (hasGlErrors()) { return; }
         drawAll();
 
-        glBindTexture(GL_TEXTURE_2D, anaglyphRenderTextureLeft);                    // Bind To The Anaglyph Texture
-        glCopyTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA, 0, 0, width(), height(), 0);// Copy Our ViewPort To The Blur Texture (From 0,0 To 128,128... No Border)
+        if (hasGlErrors()) { return; }
 
-        drawTexturesAnaglypth(anaglyphRenderTextureLeft, anaglyphRenderTextureRight);
+        glBindTexture(GL_TEXTURE_2D, anaglyphRenderTextureLeft);                    // Bind To The Anaglyph Texture
+        if (hasGlErrors()) { return; }
+        glCopyTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA, 0, 0, width(), height(), 0);// Copy Our ViewPort To The Blur Texture (From 0,0 To 128,128... No Border)
+        if (hasGlErrors()) { return; }
+
+        drawTexturesAnaglyph(anaglyphRenderTextureLeft, anaglyphRenderTextureRight);
     }
 }
 
@@ -468,6 +516,9 @@ void BioStruct3DGLWidget::createActions()
         action = new QAction(key, molSurfaceTypeActions);
         connect(action, SIGNAL(triggered()), this, SLOT(sl_showSurface()));
         action->setCheckable(true);
+        bool hasConstraints = AppContext::getMolecularSurfaceFactoryRegistry()->getSurfaceFactory(key)->hasConstraints(biostruc);
+        action->setEnabled(!hasConstraints);
+
     }
     action = new QAction(tr("Off"), molSurfaceTypeActions);
     connect(action, SIGNAL(triggered()), this, SLOT(sl_hideSurface()));
@@ -497,7 +548,6 @@ void BioStruct3DGLWidget::createActions()
         setAllModelsActiveAction = new QAction(tr("All models"), this);
         setAllModelsActiveAction->setCheckable(true);
         connect(setAllModelsActiveAction, SIGNAL(triggered()), this, SLOT(sl_setAllModelsActive()));
-        setAllModelsActiveAction->setChecked(true);
     }
 
     connect(AppContext::getTaskScheduler(), SIGNAL(si_stateChanged(Task*)), SLOT(sl_onTaskFinished(Task*)));
@@ -570,9 +620,7 @@ void BioStruct3DGLWidget::setBioStruct3DColorScheme( BioStruct3DColorScheme* clS
 {
     Q_ASSERT(clScheme != NULL);
     biostructRenderer->setColorScheme(clScheme);
-    colorScheme.reset(clScheme);
-    
-    
+    colorScheme.reset(clScheme);    
 }
 
 void BioStruct3DGLWidget::setBioStruct3DRenderer( BioStruct3DGLRenderer* r )
@@ -602,6 +650,7 @@ void BioStruct3DGLWidget::sl_selectColorScheme(QAction* action)
     colorScheme = createCustomColorScheme(schemeName);
     Q_ASSERT(colorScheme != NULL);
     colorScheme->setSelectionColor(selectionColor);
+    colorScheme->setUnselectedShadingLevel(unselectedShadingLevel/100.0);
     setBioStruct3DColorScheme(colorScheme);
     currentColorSchemeName = schemeName;
     GLFrame* frame = frameManager->getGLWidgetFrame(this);
@@ -827,29 +876,10 @@ void BioStruct3DGLWidget::sl_updateAnnimation()
         frame->makeCurrent();
         frame->rotateCamera(rotAxis, spinAngle);
         frame->updateGL();
-        //glGetFloatv( GL_MODELVIEW_MATRIX, frame->getRotationMatrix());
     }
     updateGL();
 }
 
-/*
-#define BACKGROUND_COLOR_NAME "BackgroundColor"
-#define PRODUCT_NAME "Unipro Ugene"
-#define PLUGIN_NAME "BioStruct3D Viewer Plugin"
-#define COLOR_SCHEME_NAME "ColorScheme"
-#define RENDERER_NAME "GLRenderer"
-#define OBJECT_ID_NAME "OBJECT_ID"
-
-#define SELECTION_COLOR_NAME "SelectionColor"
-
-#define LEFT_EYE_COLOR_NAME "LeftEyeColor"
-#define RIGHT_EYE_COLOR_NAME "RightEyeColor"
-
-#define RENDER_DETAIL_LEVEL_NAME "RenderDetailLevel"
-#define ANAGLYPH_NAME "Anaglyph"
-#define EYES_SHIFT_NAME "EyesShift"
-*/
-
 QVariantMap BioStruct3DGLWidget::getState()
 {
     QVariantMap state;
@@ -866,6 +896,7 @@ QVariantMap BioStruct3DGLWidget::getState()
     state[RIGHT_EYE_COLOR_NAME] = QVariant::fromValue(rightEyeColor);
 
     state[RENDER_DETAIL_LEVEL_NAME] = QVariant::fromValue(renderDetailLevel);
+    state[SHADING_LEVEL_NAME] = QVariant::fromValue(unselectedShadingLevel);
     state[ANAGLYPH_NAME] = QVariant::fromValue(anaglyph);
     state[EYES_SHIFT_NAME] = QVariant::fromValue(eyesShift);
 
@@ -892,7 +923,6 @@ void BioStruct3DGLWidget::setState( const QVariantMap& state )
     anaglyph = state.value(ANAGLYPH_NAME, DEFAULT_ANAGLYPH).value<bool>();
     eyesShift = state.value(EYES_SHIFT_NAME, DEFAULT_EYES_SHIFT).value<int>();
 
-
     QString previousColorSchemeName = currentColorSchemeName;
     QString previousGLRendererName = currentGLRendererName;
 
@@ -903,6 +933,9 @@ void BioStruct3DGLWidget::setState( const QVariantMap& state )
         setBioStruct3DColorScheme(createCustomColorScheme(currentColorSchemeName));
     }
 
+    unselectedShadingLevel = state.value(SHADING_LEVEL_NAME, DEFAULT_SHADING_LEVEL).value<int>();
+    setUnselectedShadingLevel(unselectedShadingLevel);
+
     if (previousGLRendererName!=currentGLRendererName){
         setBioStruct3DRenderer(createCustomRenderer(currentGLRendererName));
     }
@@ -936,7 +969,9 @@ void BioStruct3DGLWidget::sl_settings()
     dialog.setBackgroundColor(backgroundColor);
     dialog.setSelectionColor(selectionColor);
     dialog.setRenderDetailLevel(renderDetailLevel);
+    dialog.setShadingLevel(unselectedShadingLevel);
 
+    dialog.setAnaglyphAvailability(anaglyphAvailable);
     dialog.setAnaglyph(anaglyph);
     dialog.setEyesShift(eyesShift);
     dialog.setGlassesColorScheme(leftEyeColor, rightEyeColor);
@@ -949,6 +984,7 @@ void BioStruct3DGLWidget::sl_settings()
         selectionColor=dialog.getSelectionColor();
         colorScheme->setSelectionColor(selectionColor);
         renderDetailLevel=dialog.getRenderDetailLevel();
+        unselectedShadingLevel = dialog.getShadingLevel();
         anaglyph = dialog.getAnaglyph();
 
         eyesShift = dialog.getEyesShift();
@@ -960,7 +996,7 @@ void BioStruct3DGLWidget::sl_settings()
         setBackgroundColor(backgroundColor);
 
 //        DisplayLists::createAtomDisplayList(getRenderDetailLevel());
-		DisplayLists::createBigDisplayList(getRenderDetailLevel(), biostruc, activeModelIndexList, &(*colorScheme));
+        DisplayLists::createBigDisplayList(getRenderDetailLevel(), biostruc, activeModelIndexList, &(*colorScheme));
         updateGL();
     }
     else
@@ -1041,17 +1077,9 @@ QMenu* BioStruct3DGLWidget::getDisplayMenu()
 void BioStruct3DGLWidget::createActiveModelIndexList()
 {
     int numModels = biostruc.modelMap.count();
-    if (numModels > 1) {
-        multipleModels = true;
-        // set all models active
-        for (int i = 0; i < numModels; ++i) {
-            activeModelIndexList.append(i);
-        }
-    } else {
-        multipleModels = false;
-        activeModelIndexList.append(0);
-    }
-    
+    multipleModels = numModels > 1 ? true : false;
+    // set only first model active
+    activeModelIndexList.append(0);
 }
 
 
@@ -1081,6 +1109,7 @@ void BioStruct3DGLWidget::switchActiveModel(bool forward)
 void BioStruct3DGLWidget::sl_setNextModelAcitve()
 {
     switchActiveModel(true);
+    biostructRenderer->updateColorScheme();
     updateGL();
 }
 
@@ -1088,6 +1117,7 @@ void BioStruct3DGLWidget::sl_setNextModelAcitve()
 void BioStruct3DGLWidget::sl_setPrevModelAcitve()
 {
     switchActiveModel(false);
+    biostructRenderer->updateColorScheme();
     updateGL();
 }
 
@@ -1098,6 +1128,7 @@ void BioStruct3DGLWidget::sl_setAllModelsActive()
     for (int i = 0; i < numModels; ++i) {
         activeModelIndexList.append(i);
     }
+    biostructRenderer->updateColorScheme();
     updateGL();
 
 }
@@ -1176,6 +1207,7 @@ void BioStruct3DGLWidget::loadColorSchemes()
     Q_ASSERT(iter != schemeActions.end());
     colorScheme.reset(colorSchemeFactoryMap.value(currentColorSchemeName)->createInstance(this));
     colorScheme->setSelectionColor(selectionColor);
+    colorScheme->setUnselectedShadingLevel(unselectedShadingLevel/100.0);
 }
 
 void BioStruct3DGLWidget::loadGLRenderers()
@@ -1218,7 +1250,7 @@ void BioStruct3DGLWidget::sl_showSurface()
     QString surfaceType = qobject_cast<QAction *>( sender() )->text();
     surfaceCalcTask = new MolecularSurfaceCalcTask(surfaceType, atoms);
     AppContext::getTaskScheduler()->registerTopLevelTask(surfaceCalcTask);
-
+    
 }
 
 void BioStruct3DGLWidget::sl_hideSurface()
@@ -1235,7 +1267,7 @@ void BioStruct3DGLWidget::sl_selectSurfaceRenderer(QAction*  action)
         MolecularSurfaceRendererFactory* f = surfaceRendererFactoryMap.value(action->text());
         surfaceRenderer.reset( f->createInstance() );
     }
-
+    
     makeCurrent();
     updateGL();
 }
@@ -1248,6 +1280,7 @@ void BioStruct3DGLWidget::sl_onTaskFinished( Task* task )
 
     molSurface.reset();
     molSurface = surfaceCalcTask->getCalculatedSurface();
+    
 
     makeCurrent();
     updateGL();
@@ -1255,4 +1288,10 @@ void BioStruct3DGLWidget::sl_onTaskFinished( Task* task )
 
 }
 
+void BioStruct3DGLWidget::setUnselectedShadingLevel(int shading)
+{
+    colorScheme->setUnselectedShadingLevel(shading/100.0);
+    biostructRenderer->updateColorScheme();
+}
+
 } //namespace
