@@ -23,26 +23,25 @@
 #include <QtCore/QFile>
 #include <QtCore/QTextStream>
 
-#include <core_api/AppContext.h>
-#include <core_api/DocumentModel.h>
-#include <core_api/GObject.h>
-#include <core_api/Log.h>
-#include <core_api/ProjectModel.h>
-#include <gobjects/BioStruct3DObject.h>
-#include <gobjects/GObjectTypes.h>
-#include <util_tasks/LoadDocumentTask.h>
-#include <util_gui/ProjectTreeItemSelectorDialog.h>
-#include <util_gui/ProjectTreeController.h>
-#include <util_ov_annotated_dna/AnnotatedDNAView.h>
+#include <U2Core/AppContext.h>
+#include <U2Core/DocumentModel.h>
+#include <U2Core/GObject.h>
+#include <U2Core/Log.h>
+#include <U2Core/ProjectModel.h>
+#include <U2Core/BioStruct3DObject.h>
+#include <U2Core/GObjectTypes.h>
+#include <U2Core/LoadDocumentTask.h>
+#include <U2Gui/ProjectTreeItemSelectorDialog.h>
+#include <U2Gui/ProjectTreeController.h>
+#include <U2Misc/HBar.h>
+#include <U2View/AnnotatedDNAView.h>
 
 #include "BioStruct3DSplitter.h"
 #include "BioStruct3DGLWidget.h"
 #include "GLFrameManager.h"
 
 
-namespace GB2 { 
-
-static LogCategory log(ULOG_CAT_PLUGIN_BIOSTRUCT_3D);
+namespace U2 { 
 
 #define HEADER_HEIGHT 24
 #define MAX_SPLITTER_HEIGHT 1000
@@ -84,13 +83,13 @@ BioStruct3DGLWidget* BioStruct3DSplitter::addBioStruct3DGLWidget( BioStruct3DObj
     if (isViewCollapsed) {
         adaptSize(1);
     }
-	
+
     BioStruct3DGLWidget* glWidget = new BioStruct3DGLWidget(bioStructObj, dnaView, getGLFrameManager(), this);
     glWidget->installEventFilter(this);
     // Add widget to splitter
     biostrucViewMap.insert(bioStructObj, glWidget);
     splitter->addWidget(glWidget);
-		
+
     emit si_bioStruct3DGLWidgetAdded(glWidget);
 
     return glWidget;
@@ -121,23 +120,23 @@ void BioStruct3DSplitter::addObject(BioStruct3DObject* bioStructObj) {
 
 void BioStruct3DSplitter::dragEnterEvent(QDragEnterEvent *event) 
 {
-	const QMimeData* md = event->mimeData();
-	const GObjectMimeData* gomd = qobject_cast<const GObjectMimeData*>(md);
-	if (gomd != NULL) {
-		GObject* obj = gomd->objPtr.data();
+    const QMimeData* md = event->mimeData();
+    const GObjectMimeData* gomd = qobject_cast<const GObjectMimeData*>(md);
+    if (gomd != NULL) {
+        GObject* obj = gomd->objPtr.data();
         if (obj->getGObjectType() == GObjectTypes::BIOSTRUCTURE_3D) {
             BioStruct3DObject* bioStrucObj = qobject_cast<BioStruct3DObject*>(gomd->objPtr.data());
             if (biostrucViewMap.contains(bioStrucObj)) 
-			    event->acceptProposedAction();
+                event->acceptProposedAction();
         }
-	}
+    }
 }
 
 void BioStruct3DSplitter::dropEvent(QDropEvent *event) 
 {
-	const GObjectMimeData* gomd = qobject_cast<const GObjectMimeData*>(event->mimeData());
-	BioStruct3DObject* bioStrucObj = qobject_cast<BioStruct3DObject*>(gomd->objPtr.data());
-	Q_ASSERT(bioStrucObj != NULL);
+    const GObjectMimeData* gomd = qobject_cast<const GObjectMimeData*>(event->mimeData());
+    BioStruct3DObject* bioStrucObj = qobject_cast<BioStruct3DObject*>(gomd->objPtr.data());
+    Q_ASSERT(bioStrucObj != NULL);
     addBioStruct3DGLWidget(bioStrucObj);
 
 }
@@ -146,9 +145,8 @@ void BioStruct3DSplitter::dropEvent(QDropEvent *event)
 #define WIDGET_STATE_LIST_NAME  "WIDGET_STATE_MAP"
 #define OBJECT_ID_NAME "OBJECT_ID"
 
-BioStruct3DSplitter::~BioStruct3DSplitter()
-{
-    log.trace("BioStruct3DSplitter deleted");
+BioStruct3DSplitter::~BioStruct3DSplitter() {
+    uiLog.trace("BioStruct3DSplitter deleted");
 }
 
 void BioStruct3DSplitter::saveState( QVariantMap& m )
@@ -187,8 +185,6 @@ void BioStruct3DSplitter::updateState( const QVariantMap& m )
         BioStruct3DGLWidget* glWidget = addBioStruct3DGLWidget(obj);
         glWidget->setState(state);
     }
-    
-
 }
 
 bool BioStruct3DSplitter::removeObject(BioStruct3DObject* obj) {
@@ -199,8 +195,8 @@ bool BioStruct3DSplitter::removeObject(BioStruct3DObject* obj) {
         ++i;
     }
     biostrucViewMap.remove(obj);
-	bool isEmpty = biostrucViewMap.isEmpty();
-	return isEmpty;
+    bool isEmpty = biostrucViewMap.isEmpty();
+    return isEmpty;
 }
 
 
@@ -272,13 +268,13 @@ QList<BioStruct3DGLWidget*> BioStruct3DSplitter::getChildWidgets()
 
 int BioStruct3DSplitter::getNumVisibleWidgets()
 {
-	int numVisibleWidgets = 0;
-	foreach (BioStruct3DGLWidget* widget, biostrucViewMap) {
-		if (widget->isVisible()) {
-			++numVisibleWidgets;
-		}
-	}
-	return numVisibleWidgets;
+    int numVisibleWidgets = 0;
+    foreach (BioStruct3DGLWidget* widget, biostrucViewMap) {
+        if (widget->isVisible()) {
+            ++numVisibleWidgets;
+        }
+    }
+    return numVisibleWidgets;
 }
 
 void BioStruct3DSplitter::addModelFromObject( BioStruct3DObject* obj )
@@ -295,17 +291,6 @@ GLFrameManager* BioStruct3DSplitter::getGLFrameManager()
 {
     return glFrameManager.get();
 }
-///////////////////////////////////////////////////////////////////////////////////////////
-// Header widget toolbar
-class HBar : public QToolBar {
-public:
-    HBar(QWidget* w) : QToolBar(w){}
-protected:
-    void paintEvent(QPaintEvent* pe) {
-        Q_UNUSED(pe);
-        //do not draw any special toolbar control -> make is merged with parent widget
-    }
-};
 
 ///////////////////////////////////////////////////////////////////////////////////////////
 // Header widget
@@ -490,23 +475,23 @@ void SplitterHeaderWidget::sl_restoreDefaults()
 void SplitterHeaderWidget::sl_addBioStruct3DGLWidget( BioStruct3DGLWidget* glWidget )
 {
     int index = activeWidgetBox->count() + 1;
-	const char* pdbId = glWidget->getBioStruct3D().pdbId.constData();
+    const char* pdbId = glWidget->getBioStruct3D().pdbId.constData();
     
-	QString name = QString("%1: %2").arg(index).arg(pdbId) ;
+    QString name = QString("%1: %2").arg(index).arg(pdbId) ;
     activeWidgetBox->addItem(name);
     connect(glWidget, SIGNAL(si_widgetClosed(BioStruct3DGLWidget*)), this, SLOT(sl_closeWidget3DGLWidget(BioStruct3DGLWidget*)));
     glWidget->installEventFilter(this);
 
-	// Add show widget action
-	QString actionName( tr("show_%1").arg(pdbId) );
-	QAction* action = new QAction(actionName, glWidget);
-	action->setCheckable(true);
-	action->setChecked(true);
-	connect(action, SIGNAL(triggered(bool)), SLOT(sl_toggleBioStruct3DWidget(bool)));
-	showWidgetActionMap.insert(glWidget, action);
-	
-	widgets.append(glWidget);
-	enableToolbar();
+    // Add show widget action
+    QString actionName( tr("show_%1").arg(pdbId) );
+    QAction* action = new QAction(actionName, glWidget);
+    action->setCheckable(true);
+    action->setChecked(true);
+    connect(action, SIGNAL(triggered(bool)), SLOT(sl_toggleBioStruct3DWidget(bool)));
+    showWidgetActionMap.insert(glWidget, action);
+
+    widgets.append(glWidget);
+    enableToolbar();
 }
 
 bool SplitterHeaderWidget::eventFilter(QObject *obj, QEvent *event)
@@ -539,39 +524,39 @@ void SplitterHeaderWidget::sl_closeWidget3DGLWidget(BioStruct3DGLWidget* glWidge
     assert(index >= 0);
     widgets.removeAt(index);
     activeWidgetBox->removeItem(index);
-	splitter->getGLFrameManager()->removeGLWidgetFrame(glWidget);
+    splitter->getGLFrameManager()->removeGLWidgetFrame(glWidget);
     updateWidgetBox();
-	showWidgetActionMap.remove(glWidget);
-	if (widgets.isEmpty()) {
-		// TODO: maybe it's possible not to close splitter?
+    showWidgetActionMap.remove(glWidget);
+    if (widgets.isEmpty()) {
+        // TODO: maybe it's possible not to close splitter?
         //splitter->adaptSize(0);
         splitter->getCloseSplitterAction()->trigger();
         return;
-	}
-	updateToolbar();
+    }
+    updateToolbar();
 }
 
 void SplitterHeaderWidget::enableToolbar() {
-	activeWidgetBox->setEnabled(true);
-	restoreDefaultsButton->setEnabled(true);
-	zoomInButton->setEnabled(true);
-	zoomOutButton->setEnabled(true);
-	displayMenuButton->setEnabled(true);
-	widgetStateMenuButton->setEnabled(true);
+    activeWidgetBox->setEnabled(true);
+    restoreDefaultsButton->setEnabled(true);
+    zoomInButton->setEnabled(true);
+    zoomOutButton->setEnabled(true);
+    displayMenuButton->setEnabled(true);
+    widgetStateMenuButton->setEnabled(true);
     syncLockButton->setEnabled(splitter->getGLFrameManager()->getGLFrames().count() > 1);
 
 }
 
 
 void SplitterHeaderWidget::updateWidgetBox() {
-	activeWidgetBox->clear();
-	int index = 0;
-	foreach(BioStruct3DGLWidget* widget, widgets) {
-		++index;
-		const char* pdbId = widget->getBioStruct3D().pdbId.constData();
-		QString name = QString("%1: %2").arg(index).arg(pdbId);
-		activeWidgetBox->addItem(name);
-	}
+    activeWidgetBox->clear();
+    int index = 0;
+    foreach(BioStruct3DGLWidget* widget, widgets) {
+        ++index;
+        const char* pdbId = widget->getBioStruct3D().pdbId.constData();
+        QString name = QString("%1: %2").arg(index).arg(pdbId);
+        activeWidgetBox->addItem(name);
+    }
 
 }
 
@@ -586,27 +571,25 @@ void SplitterHeaderWidget::updateToolbar() {
     zoomOutButton->setEnabled(numVisibleWidgets > 0);
     syncLockButton->setEnabled(numVisibleWidgets > 1);
     displayMenuButton->setEnabled(numVisibleWidgets);
-	widgetStateMenuButton->setEnabled(!widgets.isEmpty());		
-	
-	
+    widgetStateMenuButton->setEnabled(!widgets.isEmpty());
 }
 
 void SplitterHeaderWidget::sl_toggleBioStruct3DWidget( bool show )
 {
-	BioStruct3DGLWidget* glWidget = qobject_cast<BioStruct3DGLWidget*> (sender()->parent());
-	Q_ASSERT(glWidget != NULL);
-	
-	glWidget->setVisible(show);
+    BioStruct3DGLWidget* glWidget = qobject_cast<BioStruct3DGLWidget*> (sender()->parent());
+    Q_ASSERT(glWidget != NULL);
 
-	int numVisibleWidgets = splitter->getNumVisibleWidgets();
+    glWidget->setVisible(show);
 
-	if ( (show == true && numVisibleWidgets == 1) ||
-		(show == false && numVisibleWidgets == 0) ) { 
-			splitter->adaptSize(numVisibleWidgets);
-	}
+    int numVisibleWidgets = splitter->getNumVisibleWidgets();
+
+    if ( (show == true && numVisibleWidgets == 1) ||
+        (show == false && numVisibleWidgets == 0) ) {
+            splitter->adaptSize(numVisibleWidgets);
+    }
+
+    updateToolbar();
 
-	updateToolbar();
-	
 }
 
 void SplitterHeaderWidget::sl_addModel()
@@ -718,7 +701,7 @@ bool DBLinksFile::load()
 {
     QFile file( QString(PATH_PREFIX_DATA)+ ":" + DB_LINKS_FILE_NAME );
     if(!file.exists() || !file.open(QIODevice::ReadOnly)){
-        log.error(SplitterHeaderWidget::tr("bs3d_links_file_not_found_%1").arg(DB_LINKS_FILE_NAME));
+        ioLog.error(SplitterHeaderWidget::tr("File not found: %1").arg(DB_LINKS_FILE_NAME));
         return false;
     } 
 
@@ -730,7 +713,7 @@ bool DBLinksFile::load()
         }
         QStringList fields = line.split("|");
         if (fields.size() != 2) {
-            log.error(SplitterHeaderWidget::tr("illegal_entry_%1").arg(line));
+            ioLog.error(SplitterHeaderWidget::tr("Illegal entry: %1").arg(line));
             continue;
         }
         DBLink linkInfo(fields[0], fields[1].trimmed());
