@@ -8,8 +8,8 @@
 *     for details.
 *****************************************************************/
 
-#include <core_api/Task.h>
-#include <util_ov_annotated_dna/ADVSplitWidget.h>
+#include <U2Core/Task.h>
+#include <U2View/ADVSplitWidget.h>
 
 #include <QtGui/QSplitter>
 #include <QtGui/QToolBar>
@@ -18,7 +18,7 @@
 #include <QtGui/QAction>
 #include <memory>
 
-namespace GB2 {
+namespace U2 {
 
 class BioStruct3DObject;
 class BioStruct3DGLWidget;
@@ -82,7 +82,7 @@ public:
     /*!
     * @return Number of visible splitter child widgets.
     */
-	int getNumVisibleWidgets();
+    int getNumVisibleWidgets();
     /*!
     * @return If number of visible children is null, sets splitter view collapsed, else restores it.
     */
@@ -92,7 +92,7 @@ public:
     */
     GLFrameManager* getGLFrameManager();
     QAction* getCloseSplitterAction() { return closeAction; }
-	/*!
+    /*!
     * QWidget virtual function, returns preferred widget size.
     */
     virtual QSize sizeHint () const {return QSize(0, 400);}
@@ -108,13 +108,13 @@ public:
     * Removes object and its views.
     */
     bool removeObject(BioStruct3DObject* obj);
-	
+
 signals:
     void si_bioStruct3DGLWidgetAdded(BioStruct3DGLWidget* w);
 
 private slots:
     //void sl_toggleBioStruct3DWidget(bool show);
-	//void sl_closeBioStruct3DGlWidget(BioStruct3DGLWidget* glWidget);
+    //void sl_closeBioStruct3DGlWidget(BioStruct3DGLWidget* glWidget);
     
 protected:
     void dragEnterEvent(QDragEnterEvent *event);
@@ -128,7 +128,7 @@ private:
     QSplitter*  parentSplitter;
     QAction*    closeAction;
     int         splitterHeight;
-	bool		isViewCollapsed;
+    bool        isViewCollapsed;
     
     SplitterHeaderWidget* header;
 };
@@ -169,11 +169,11 @@ class SplitterHeaderWidget : public QWidget {
 
 public:
     SplitterHeaderWidget(BioStruct3DSplitter* splitter);
-	QMap<BioStruct3DGLWidget*, QAction*> showWidgetActionMap;
-	void updateToolbar();
+    QMap<BioStruct3DGLWidget*, QAction*> showWidgetActionMap;
+    void updateToolbar();
     void enableToolbar();
     void updateWidgetBox();
-	
+
 public:    
     BioStruct3DSplitter* splitter;
     QToolButton* widgetStateMenuButton;
@@ -195,7 +195,7 @@ protected:
 private slots:
     
     void sl_addBioStruct3DGLWidget(BioStruct3DGLWidget* glWidget);
-	void sl_toggleBioStruct3DWidget(bool visible);
+    void sl_toggleBioStruct3DWidget(bool visible);
     void sl_closeWidget3DGLWidget(BioStruct3DGLWidget* glWidget);
     void sl_toggleSyncLock(bool on);
     void sl_addModel();
