@@ -8,17 +8,17 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_BIOSTRUCT3D_VIEW_PLUGIN_H_
-#define _GB2_BIOSTRUCT3D_VIEW_PLUGIN_H_
+#ifndef _U2_BIOSTRUCT3D_VIEW_PLUGIN_H_
+#define _U2_BIOSTRUCT3D_VIEW_PLUGIN_H_
 
-#include <core_api/PluginModel.h>
-#include <core_api/AppContext.h>
-#include <core_api/ObjectViewModel.h>
+#include <U2Core/PluginModel.h>
+#include <U2Core/AppContext.h>
+#include <U2Gui/ObjectViewModel.h>
 
 #include <QtCore/QMap>
 #include <QtGui/QAction>
 
-namespace GB2 {
+namespace U2 {
 
 class BioStruct3DSplitter;
 class BioStruct3DObject;
@@ -34,7 +34,7 @@ private:
 
 class BioStruct3DViewContext: public GObjectViewWindowContext {
     Q_OBJECT
-	QMap<GObjectView*, BioStruct3DSplitter*> splitterMap;
+    QMap<GObjectView*, BioStruct3DSplitter*> splitterMap;
 public:
     BioStruct3DViewContext(QObject* p);
     
@@ -53,7 +53,7 @@ protected:
 
 protected slots:
     void sl_close3DView();
-	virtual void sl_windowClosing(MWMDIWindow*);
+    virtual void sl_windowClosing(MWMDIWindow*);
 
 };
 
