@@ -8,15 +8,15 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_EXPORT_IMAGE_DIALOG_H_
-#define _GB2_EXPORT_IMAGE_DIALOG_H_
+#ifndef _U2_EXPORT_IMAGE_DIALOG_H_
+#define _U2_EXPORT_IMAGE_DIALOG_H_
 
 #include <QtCore/QList>
 #include <QtCore/QString>
 
 #include "ui_ExportImageDialog.h"
 
-namespace GB2 {
+namespace U2 {
 
 class BioStruct3DGLWidget;
 
@@ -35,20 +35,16 @@ private slots:
     void sl_onFormatsBoxItemChanged(const QString& text);
 
 private:
-    QList<QString> supportedFormats;
-    BioStruct3DGLWidget* glWidget;
-    static int fileCounter;
-
     void setupComponents();
-    void setupFormats();
+    void setSizeControlsEnabled(bool enabled);
+
     static bool isVectorGraphicFormat(const QString& formatName);
     static int getVectorFormatIdByName(const QString& formatName);
 
-
-
-};
-
-
+private:
+    QList<QString> supportedFormats;
+    BioStruct3DGLWidget* glWidget;
+}; // class ExportImageDialog
 
 } // namespace
 
