@@ -8,12 +8,12 @@
 *     for details.
 *****************************************************************/
 
-#include <core_api/Vector3D.h>
+#include <U2Core/Vector3D.h>
 
 #include "GLFrameManager.h"
-#include <core_api/Log.h>
+#include <U2Core/Log.h>
 
-namespace GB2 {
+namespace U2 {
 
 const GLfloat GLFrame::DEFAULT_ZOOM = 45.0f;
 //const Vector3D GLFrame::DEFAULT_CAMERA = Vector3D(0, 0, 0);
@@ -81,12 +81,12 @@ QVariantList Matrix4x4::store()
 
 GLFrame::GLFrame(QGLWidget* widget, float cameraNear, float cameraFar, float cameraZ) : glWidget(widget), synchLock(false)
 {
-	zoomFactor = DEFAULT_ZOOM;
+    zoomFactor = DEFAULT_ZOOM;
     rotMatrix.loadIdentity();
     cameraClipNear = cameraNear;
     cameraClipFar = cameraFar;
 
-	cameraPosition.set(0.0f, 0.0f, cameraZ);
+    cameraPosition.set(0.0f, 0.0f, cameraZ);
 
     // Set view settings
     //float scaleFactor = 2.5;
@@ -110,22 +110,22 @@ void GLFrame::performZoom( float delta )
 
 void GLFrame::performShift(float deltaX, float deltaY)
 {
-	static float defaultWidth=1092;
-	Vector3D shiftVector;
-	float frameFactor = glWidget->width()/defaultWidth;
+    static float defaultWidth=1092;
+    Vector3D shiftVector;
+    float frameFactor = glWidget->width()/defaultWidth;
 
-	shiftVector.set(deltaX*zoomFactor*frameFactor, deltaY*zoomFactor*frameFactor, 0);
-	cameraPosition+=shiftVector;
+    shiftVector.set(deltaX*zoomFactor*frameFactor, deltaY*zoomFactor*frameFactor, 0);
+    cameraPosition+=shiftVector;
 }
 
 const Vector3D GLFrame::getCameraPosition()const
 {
-	return cameraPosition;
+    return cameraPosition;
 }
 
 void GLFrame::setCameraPosition(float x, float y, float z)
 {
-	cameraPosition.set(x, y, z);
+    cameraPosition.set(x, y, z);
 }
 
 void GLFrame::rotateCamera(const Vector3D& rotAxis, float rotAngle )
@@ -144,8 +144,8 @@ void GLFrame::rotateCamera(const Vector3D& rotAxis, float rotAngle )
 
 void GLFrame::setState( const QVariantMap& state )
 {
-	cameraPosition.x = state.value(CAMERA_STATE_POSITION_X_ID, 0).value<float>();
-	cameraPosition.y = state.value(CAMERA_STATE_POSITION_Y_ID, 0).value<float>();
+    cameraPosition.x = state.value(CAMERA_STATE_POSITION_X_ID, 0).value<float>();
+    cameraPosition.y = state.value(CAMERA_STATE_POSITION_Y_ID, 0).value<float>();
 
     zoomFactor = state.value(ZOOM_FACTOR_ID, DEFAULT_ZOOM).value<float>();
     QVariantList rotML = state.value(ROTATION_MATRIX_ID).value<QVariantList>();
@@ -156,8 +156,8 @@ void GLFrame::setState( const QVariantMap& state )
 
 void GLFrame::writeStateToMap( QVariantMap& state )
 {
-	state[CAMERA_STATE_POSITION_X_ID] = QVariant::fromValue(cameraPosition.x);
-	state[CAMERA_STATE_POSITION_Y_ID] = QVariant::fromValue(cameraPosition.y);
+    state[CAMERA_STATE_POSITION_X_ID] = QVariant::fromValue(cameraPosition.x);
+    state[CAMERA_STATE_POSITION_Y_ID] = QVariant::fromValue(cameraPosition.y);
 
     state[ZOOM_FACTOR_ID] = QVariant::fromValue(zoomFactor);
     state[ROTATION_MATRIX_ID] = rotMatrix.store();
