@@ -9,18 +9,18 @@
 *****************************************************************/
 
 #include <QtOpenGL>
-#include <molecular_geometry/GeomUtils.h>
+#include <U2Algorithm/GeomUtils.h>
 #include <math.h>
 #include "GraphicUtils.h"
-#include <core_api/Log.h>
+#include <U2Core/Log.h>
 
-#include <datatype/BioStruct3D.h>
+#include <U2Core/BioStruct3D.h>
 #include <BioStruct3DColorScheme.h>
 
 
-namespace GB2 { 
+namespace U2 { 
 
-static LogCategory log("GraphUtils");
+static Logger log("GraphUtils");
 
 ///////////////////////////////////////////////////////////////////////////////////////////
 /// Color4f
@@ -31,81 +31,52 @@ Color4f::Color4f()
     color[1] = 0;
     color[2] = 0;
     color[3] = 1.0;
-
 }
 
-Color4f::Color4f( float r, float g, float b )
+Color4f::Color4f(float r, float g, float b, float a)
 {
     color[0] = r;
     color[1] = g;
     color[2] = b;
-    color[3] = 1.0;
-
+    color[3] = a;
 }
 
-Color4f::Color4f( const QColor& qColor )
+Color4f::Color4f( const QColor& qc)
 {
-    color[0] = qColor.redF();
-    color[1] = qColor.greenF();
-    color[2] = qColor.blueF();
-    color[3] = qColor.alphaF();
-
+    color[0] = qc.redF();
+    color[1] = qc.greenF();
+    color[2] = qc.blueF();
+    color[3] = qc.alphaF();
 }
 
-float Color4f::operator[]( unsigned int i ) const
-{
-    if (i < 4) {
-        return color[i];
+Color4f::Color4f(const Color4f &c) {
+    for (int i = 0; i < 4; ++i) {
+        color[i] = c.color[i];
     }
-    qCritical("Out of range");
-    return 0.0;
-        
 }
 
-Color4f& Color4f::operator+=( const Color4f& v )
+float Color4f::operator[] (unsigned int i ) const
 {
-//Do not effect alpha channel
-    color[0] += v[0];
-    color[1] += v[1];
-    color[2] += v[2];
-
-    return *this;        
+    assert(i < 4);
+    return color[i];
 }
 
-Color4f& Color4f::operator/=( double f )
-{
-	//Do not affect alpha channel
-	color[0]/=f; color[1]/=f; color[2]/=f;
-	return *this;
+float& Color4f::operator[] (unsigned int i) {
+    assert(i < 4);
+    return color[i];
 }
 
-bool Color4f::operator==(const Color4f &a)
+bool Color4f::operator== (const Color4f &a) const
 {
-	//Do not affect alpha channel
-	if (color[0]==a.color[0] && color[1]==a.color[1] && color[2]==a.color[2])
-	{
-		return true;
-	}
-	else
-	{
-		return false;
-	}
-}
-
-bool operator == (const Color4f &a, const Color4f &b)
-{
-	//Do not affect alpha channel
-	const float *aColor = a.getConstData();
-	const float *bColor = b.getConstData();
-
-	if (aColor[0]==bColor[0] && aColor[1]==bColor[1] && aColor[2]==bColor[2])
-	{
-		return true;
-	}
-	else
-	{
-		return false;
-	}
+    //Do not affect alpha channel
+    if (color[0]==a.color[0] && color[1]==a.color[1] && color[2]==a.color[2])
+    {
+        return true;
+    }
+    else
+    {
+        return false;
+    }
 }
 
 void glDrawCylinder(GLUquadric* pObj, const Vector3D& p1, const Vector3D& p2, double thickness, float renderDetailLevel)
@@ -126,13 +97,10 @@ void glDrawCylinder(GLUquadric* pObj, const Vector3D& p1, const Vector3D& p2, do
     glPopMatrix();
 }
 
-
-
-
+/* class Helix3D : public Object3D */
 Helix3D::Helix3D(const Color4f& cl, const Vector3D& c, const Vector3D& n, float r ) 
     : Object3D(cl), cterm(c), nterm(n), radius(r)
 {
-    
     pObj = gluNewQuadric();
     gluQuadricNormals(pObj, GLU_SMOOTH);
     Vector3D vec(nterm - cterm);
@@ -169,16 +137,14 @@ void Helix3D::draw(float renderDetailLevel)
         glTranslatef(0, 0, smallLength);
         gluDisk(pObj, 0, radius*0.4f, numSlices, numStacks);
     glPopMatrix();
-
-
 }
 
 Helix3D::~Helix3D()
 {
-	gluDeleteQuadric(pObj);
+    gluDeleteQuadric(pObj);
 }
 
-
+/* class Strand3D : public Object3D */
 Strand3D::Strand3D( const Color4f& cl, const Vector3D& c, const Vector3D& n, const Vector3D& up ) 
     : Object3D(cl), cterm(c), nterm(n), upVector(up) 
 {
@@ -426,7 +392,7 @@ void glDrawHalfWorm(const Vector3D& p0, const Vector3D& p1,
         }
     }
 
-    if (fblock) delete[] fblock;
+    delete[] fblock;
 } 
 
 void glDrawHalfBond( GLUquadric *pObj, const Vector3D& p1, const Vector3D&p2, double thickness, float renderDetailLevel)
@@ -654,58 +620,58 @@ void accPerspective(GLdouble fovy, GLdouble aspect,
 }
 void DisplayLists::drawAtomsBonds(const Color4f &viewAtomColor, float renderDetailLevel, const Molecule3DModel &model, const BioStruct3DColorScheme* colorScheme)
 {
-	GLUquadricObj *pObj = gluNewQuadric();
-	gluQuadricNormals(pObj, GLU_SMOOTH);
+    GLUquadricObj *pObj = gluNewQuadric();
+    gluQuadricNormals(pObj, GLU_SMOOTH);
 
-	glMaterialfv(GL_FRONT, GL_AMBIENT_AND_DIFFUSE, viewAtomColor.getConstData());
+    glMaterialfv(GL_FRONT, GL_AMBIENT_AND_DIFFUSE, viewAtomColor.getConstData());
 
-	static float bondThickness = 0.15f;
-	float radius = 0.35f;
-	int numSlices = 8 * renderDetailLevel;
+    static float bondThickness = 0.15f;
+    float radius = 0.35f;
+    int numSlices = 8 * renderDetailLevel;
 
-	foreach(const SharedAtom atom, model.atoms) {
-		Color4f atomColor = colorScheme->getAtomColor(atom);
-		if (viewAtomColor==atomColor)
-		{
-			Vector3D pos = atom->coord3d;
-//			glPushMatrix();
-			glTranslatef(pos.x, pos.y, pos.z);
-			gluSphere(pObj, radius, numSlices, numSlices);
-			glTranslatef(-pos.x, -pos.y, -pos.z);
-//			glPopMatrix();
-		}
-	}
+    foreach(const SharedAtom atom, model.atoms) {
+        Color4f atomColor = colorScheme->getAtomColor(atom);
+        if (viewAtomColor==atomColor)
+        {
+            Vector3D pos = atom->coord3d;
+//            glPushMatrix();
+            glTranslatef(pos.x, pos.y, pos.z);
+            gluSphere(pObj, radius, numSlices, numSlices);
+            glTranslatef(-pos.x, -pos.y, -pos.z);
+//            glPopMatrix();
+        }
+    }
 
-	foreach (Bond bond, model.bonds) {
-		const SharedAtom a1 = bond.getAtom1();
-		const SharedAtom a2 = bond.getAtom2();
+    foreach (Bond bond, model.bonds) {
+        const SharedAtom a1 = bond.getAtom1();
+        const SharedAtom a2 = bond.getAtom2();
 
-		const Color4f &a1Color = colorScheme->getAtomColor(a1);
-		const Color4f &a2Color = colorScheme->getAtomColor(a2);
+        const Color4f &a1Color = colorScheme->getAtomColor(a1);
+        const Color4f &a2Color = colorScheme->getAtomColor(a2);
 
-		Vector3D middle = (a1->coord3d + a2->coord3d) / 2;
+        Vector3D middle = (a1->coord3d + a2->coord3d) / 2;
 
-		if (a1Color==viewAtomColor)
-		{
-			if (a1Color==a2Color)
-			{
-	//			glMaterialfv(GL_FRONT, GL_AMBIENT_AND_DIFFUSE, a1Color);
-				glDrawCylinder(pObj, a1->coord3d, a2->coord3d, bondThickness, renderDetailLevel);
-			}
-			else
-			{
-//				glMaterialfv(GL_FRONT, GL_AMBIENT_AND_DIFFUSE, a1Color);
-				glDrawCylinder(pObj, a1->coord3d, middle, bondThickness, renderDetailLevel);
-			}
-		}
-		if (a2Color == viewAtomColor)
-		{
-//			glMaterialfv(GL_FRONT, GL_AMBIENT_AND_DIFFUSE, a2Color);
-			glDrawCylinder(pObj, middle, a2->coord3d, bondThickness, renderDetailLevel);
-		}
-	}
+        if (a1Color==viewAtomColor)
+        {
+            if (a1Color==a2Color)
+            {
+    //            glMaterialfv(GL_FRONT, GL_AMBIENT_AND_DIFFUSE, a1Color);
+                glDrawCylinder(pObj, a1->coord3d, a2->coord3d, bondThickness, renderDetailLevel);
+            }
+            else
+            {
+//                glMaterialfv(GL_FRONT, GL_AMBIENT_AND_DIFFUSE, a1Color);
+                glDrawCylinder(pObj, a1->coord3d, middle, bondThickness, renderDetailLevel);
+            }
+        }
+        if (a2Color == viewAtomColor)
+        {
+//            glMaterialfv(GL_FRONT, GL_AMBIENT_AND_DIFFUSE, a2Color);
+            glDrawCylinder(pObj, middle, a2->coord3d, bondThickness, renderDetailLevel);
+        }
+    }
 
-	gluDeleteQuadric(pObj);
+    gluDeleteQuadric(pObj);
 }
 
 void DisplayLists::createBigDisplayList(float renderDetailLevel, const BioStruct3D& bioStruct, const QList<int> &modelIndexList, const BioStruct3DColorScheme* colorScheme)
