@@ -16,7 +16,7 @@
 #include "TubeGLRenderer.h"
 
 
-namespace GB2 { 
+namespace U2 { 
 
 const QString TubeGLRenderer::ID(QObject::tr("Tubes"));
 
@@ -38,7 +38,7 @@ void TubeGLRenderer::drawTubes( const BioStruct3DColorScheme* colorScheme )
                 Color4f atomColor = colorScheme->getAtomColor(atom);
                 Vector3D pos = atom.constData()->coord3d;
                 glMaterialfv(GL_FRONT, GL_AMBIENT_AND_DIFFUSE, atomColor.getConstData());
-				glDrawAtom(pObj, pos, ribbonThickness, glWidget->getRenderDetailLevel());
+                glDrawAtom(pObj, pos, ribbonThickness, glWidget->getRenderDetailLevel());
 
                 if (!firstPass) {
                     // Draw bonds only between atoms of the same molecular chain
@@ -61,14 +61,14 @@ void TubeGLRenderer::drawTubes( const BioStruct3DColorScheme* colorScheme )
         }
     }
 
-	gluDeleteQuadric(pObj);
+    gluDeleteQuadric(pObj);
 }
 
 
 void TubeGLRenderer::drawBioStruct3D()
 {
 
-	drawTubes(colorScheme);
+    drawTubes(colorScheme);
 }
 
 
