@@ -8,17 +8,17 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_BIOSTRUCT3D_TUBE_RENDERER_H_
-#define _GB2_BIOSTRUCT3D_TUBE_RENDERER_H_
+#ifndef _U2_BIOSTRUCT3D_TUBE_RENDERER_H_
+#define _U2_BIOSTRUCT3D_TUBE_RENDERER_H_
 
 #include <QtCore/QSharedDataPointer>
 #include <QtCore/QVector>
-#include <datatype/BioStruct3D.h>
+#include <U2Core/BioStruct3D.h>
 
 #include "BioStruct3DGLRender.h"
 
 
-namespace GB2 {
+namespace U2 {
 
 
 class TubeGLRenderer : public BioStruct3DGLRenderer {
@@ -45,4 +45,4 @@ public:
 
 } //namespace
 
-#endif // _GB2_BIOSTRUCT3D_TUBE_RENDERER_H_
+#endif // _U2_BIOSTRUCT3D_TUBE_RENDERER_H_
