@@ -18,12 +18,12 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_BIOSTRUCT3D_VANDERWAALS_RENDERER_H_
-#define _GB2_BIOSTRUCT3D_VANDERWAALS_RENDERER_H_
+#ifndef _U2_BIOSTRUCT3D_VANDERWAALS_RENDERER_H_
+#define _U2_BIOSTRUCT3D_VANDERWAALS_RENDERER_H_
 
 #include "BioStruct3DGLRender.h"
 
-namespace GB2 { 
+namespace U2 { 
 
     class VanDerWaalsGLRenderer : public BioStruct3DGLRenderer {
 
@@ -44,4 +44,4 @@ namespace GB2 {
 
 } //namespace
 
-#endif // _GB2_BIOSTRUCT3D_VANDERWAALS_RENDERER_H_
+#endif // _U2_BIOSTRUCT3D_VANDERWAALS_RENDERER_H_
