@@ -18,7 +18,7 @@
 *     for details.
 *****************************************************************/
 
-#include <datatype/BioStruct3D.h>
+#include <U2Core/BioStruct3D.h>
 #include <QtOpenGL>
 
 #include "GraphicUtils.h"
@@ -27,7 +27,7 @@
 #include "WormsGLRenderer.h"
 
 
-namespace GB2 { 
+namespace U2 { 
 
 const QString WormsGLRenderer::ID(QObject::tr("Worms"));
 
@@ -97,8 +97,9 @@ void WormsGLRenderer::drawWorms(  )
                 if (a2->residueIndex - a1->residueIndex != 1) {
                     continue;
                 }
+
                 glMaterialfv(GL_FRONT, GL_AMBIENT_AND_DIFFUSE, getAtomColor(a1));
-				glDrawHalfWorm(a0->coord3d, a1->coord3d, a2->coord3d, a3->coord3d, ribbonThickness, false, false, tension, glWidget->getRenderDetailLevel());
+                glDrawHalfWorm(a0->coord3d, a1->coord3d, a2->coord3d, a3->coord3d, ribbonThickness, false, false, tension, glWidget->getRenderDetailLevel());
                 glMaterialfv(GL_FRONT, GL_AMBIENT_AND_DIFFUSE, getAtomColor(a2));
                 glDrawHalfWorm(a3->coord3d, a2->coord3d, a1->coord3d, a0->coord3d, ribbonThickness, false, false, tension, glWidget->getRenderDetailLevel());
             }
@@ -125,27 +126,26 @@ void WormsGLRenderer::drawWorms(  )
             //Draw 3d objects
             if (modelsIndexList.count() == 1) {
                 foreach( Object3D* obj, model.objects) {
-                                        obj->draw(glWidget->getRenderDetailLevel());
+                    obj->draw(glWidget->getRenderDetailLevel());
                 }
             }
 
         }
     }
 
-	gluDeleteQuadric(pObj);
+    gluDeleteQuadric(pObj);
 }
 
 
 void WormsGLRenderer::drawBioStruct3D()
 {
-	drawWorms();
+    drawWorms();
 
 }
 
-
-void WormsGLRenderer::updateColorScheme(  )
+void WormsGLRenderer::updateColorScheme()
 {
-     foreach  (int id, wormMap.keys() ) {
+    foreach  (int id, wormMap.keys() ) {
          Worm& worm = wormMap[id];
          int numModels = worm.models.count();
          for (int i= 0; i < numModels; ++i) {
@@ -157,8 +157,6 @@ void WormsGLRenderer::updateColorScheme(  )
     
     //TODO: optimization -> don't have to create everything again
     createObjects3D();
-    
-
 }
 
 void WormsGLRenderer::createObjects3D()
@@ -167,6 +165,7 @@ void WormsGLRenderer::createObjects3D()
         int startId = ss->startSequenceNumber;
         int endId = ss->endSequenceNumber;
         int chainId = ss->chainIndex;
+        Q_ASSERT( chainId != 0 );
         if (bioPolymerMap.contains(chainId)) {
             const BioPolymer& bpolymer = bioPolymerMap.value(chainId);
             int modelId = 0;
@@ -242,7 +241,7 @@ WormsGLRenderer::~WormsGLRenderer()
     }
 }
 
-const float* WormsGLRenderer::getAtomColor( const SharedAtom& atom )
+const float* WormsGLRenderer::getAtomColor(const SharedAtom& atom)
 {
     atomColor = colorScheme->getAtomColor(atom);
     return atomColor.getConstData();
@@ -252,15 +251,25 @@ Object3D* WormsGLRenderer::createHelix3D( int startId, int endId, const BioPolym
 {
     static float radius = 1.5f;
     QVector<Vector3D> helixPoints;
-    Color4f color(0,0,0);
+    Color4f color(0,0,0,0);
+
     for (int i = startId; i <= endId; ++i) {
         if (!bpModel.monomerMap.contains(i))
             continue;
         helixPoints.append(bpModel.monomerMap.value(i).alphaCarbon->coord3d);
-        color += colorScheme->getAtomColor(bpModel.monomerMap.value(i).alphaCarbon);
+
+        // getting "average" color
+        const Color4f c = colorScheme->getAtomColor(bpModel.monomerMap.value(i).alphaCarbon);
+        for (int i = 0; i < 4; ++i) {
+            color[i] += c[i];
+        }
     }
     QPair<Vector3D, Vector3D> axis = calcBestAxisThroughPoints(helixPoints);
-    color /= (endId - startId + 1); 
+
+    // getting "average" color
+    for (int i = 0; i < 4; ++i) {
+        color[i] /= (endId - startId + 1);
+    }
 
     return new Helix3D(color, axis.first, axis.second, radius);
 }
@@ -268,16 +277,26 @@ Object3D* WormsGLRenderer::createHelix3D( int startId, int endId, const BioPolym
 Object3D* WormsGLRenderer::createStrand3D( int startId, int endId, const BioPolymerModel &bpModel )
 {
     QVector<Vector3D> arrowPoints;
-    Color4f color(0,0,0);
+    Color4f color(0,0,0,0);
+
     for (int i = startId; i <= endId; ++i) {
         if (!bpModel.monomerMap.contains(i))
             continue;
         arrowPoints.append(bpModel.monomerMap.value(i).alphaCarbon->coord3d);
-        color += colorScheme->getAtomColor(bpModel.monomerMap.value(i).alphaCarbon);
+
+        // getting "average" color
+        const Color4f c = colorScheme->getAtomColor(bpModel.monomerMap.value(i).alphaCarbon);
+        for (int i = 0; i < 4; ++i) {
+            color[i] += c[i];
+        }
     }
-    color /= (endId - startId + 1); 
     QPair<Vector3D, Vector3D> axis = calcBestAxisThroughPoints(arrowPoints);
 
+    // getting "average" color
+    for (int i = 0; i < 4; ++i) {
+        color[i] /= (endId - startId + 1);
+    }
+
     return new Strand3D(color, axis.first, axis.second); 
 }
 
