@@ -18,22 +18,22 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_BIOSTRUCT3D_WORMS_RENDERER_H_
-#define _GB2_BIOSTRUCT3D_WORMS_RENDERER_H_
+#ifndef _U2_BIOSTRUCT3D_WORMS_RENDERER_H_
+#define _U2_BIOSTRUCT3D_WORMS_RENDERER_H_
 
 #include <QtCore/QSharedDataPointer>
 #include <QtCore/QVector>
 #include <QtCore/QMap>
 #include <QtCore/QPair>
 
-#include <core_api/Vector3D.h>
+#include <U2Core/Vector3D.h>
 #include "BioStruct3DGLRender.h"
 #include "GraphicUtils.h"
 
 class Object3D;
 class AtomData;
 
-namespace GB2 { 
+namespace U2 { 
 
     class WormsGLRenderer : public BioStruct3DGLRenderer {
 
@@ -71,7 +71,7 @@ namespace GB2 {
             // Worm building atom coords
             AtomsVector atoms;
             // Objects representing secondary structure
-            QVector<Object3D* >  objects;
+            QVector<Object3D*>  objects;
         };
         
         struct Worm {
@@ -106,4 +106,4 @@ namespace GB2 {
 
 } //namespace
 
-#endif // _GB2_BIOSTRUCT3D_WORMS_RENDERER_H_
+#endif // _U2_BIOSTRUCT3D_WORMS_RENDERER_H_
