@@ -11,27 +11,27 @@
 #include "ChromaViewPlugin.h"
 #include "ChromatogramView.h"
 
-#include <core_api/GObject.h>
-#include <core_api/DocumentModel.h>
-#include <gobjects/GObjectTypes.h>
-#include <gobjects/DNASequenceObject.h>
-#include <gobjects/DNAChromatogramObject.h>
-#include <core_api/MainWindow.h>
-#include <selection/DocumentSelection.h>
+#include <U2Core/GObject.h>
+#include <U2Core/DocumentModel.h>
+#include <U2Core/GObjectTypes.h>
+#include <U2Core/DNASequenceObject.h>
+#include <U2Core/DNAChromatogramObject.h>
+#include <U2Gui/MainWindow.h>
+#include <U2Core/DocumentSelection.h>
 
-#include <util_ov_annotated_dna/AnnotatedDNAView.h>
-#include <util_ov_annotated_dna/ADVSingleSequenceWidget.h>
-#include <util_ov_annotated_dna/ADVConstants.h>
-#include <util_ov_annotated_dna/ADVSequenceObjectContext.h>
+#include <U2View/AnnotatedDNAView.h>
+#include <U2View/ADVSingleSequenceWidget.h>
+#include <U2View/ADVConstants.h>
+#include <U2View/ADVSequenceObjectContext.h>
 
-#include <util_gui/GUIUtils.h>
+#include <U2Gui/GUIUtils.h>
 
 #include <QtGui/QMessageBox>
 #include <QtGui/QMenu>
 
-namespace GB2 {
+namespace U2 {
 
-extern "C" Q_DECL_EXPORT Plugin* GB2_PLUGIN_INIT_FUNC() {
+extern "C" Q_DECL_EXPORT Plugin* U2_PLUGIN_INIT_FUNC() {
     if (AppContext::getMainWindow()) {
         ChromaViewPlugin* plug = new ChromaViewPlugin();
         return plug;
