@@ -8,19 +8,19 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_CHROMA_VIEW_PLUGIN_H_
-#define _GB2_CHROMA_VIEW_PLUGIN_H_
+#ifndef _U2_CHROMA_VIEW_PLUGIN_H_
+#define _U2_CHROMA_VIEW_PLUGIN_H_
 
-#include <core_api/PluginModel.h>
-#include <core_api/AppContext.h>
-#include <core_api/ObjectViewModel.h>
+#include <U2Core/PluginModel.h>
+#include <U2Core/AppContext.h>
+#include <U2Gui/ObjectViewModel.h>
 
 #include <QtCore/QMap>
 #include <QtGui/QAction>
 
-#include <util_ov_annotated_dna/ADVSequenceWidget.h>
+#include <U2View/ADVSequenceWidget.h>
 
-namespace GB2 {
+namespace U2 {
 
 class ChromatogramView;
 
