@@ -10,41 +10,43 @@
 
 #include "ChromatogramView.h"
 
-#include <core_api/GObject.h>
-#include <core_api/MainWindow.h>
-#include <core_api/AppContext.h>
-#include <core_api/DocumentModel.h>
-#include <core_api/DNAAlphabet.h>
-#include <core_api/ProjectModel.h>
-#include <core_api/IOAdapter.h>
-#include <core_api/Log.h>
-#include <core_api/Task.h>
-#include <core_api/GUrlUtils.h>
-#include <core_api/DocumentUtils.h>
+#include <U2Core/GObject.h>
+#include <U2Gui/MainWindow.h>
+#include <U2Core/AppContext.h>
+#include <U2Core/DocumentModel.h>
+#include <U2Core/DNAAlphabet.h>
+#include <U2Core/ProjectModel.h>
+#include <U2Core/IOAdapter.h>
+#include <U2Core/Log.h>
+#include <U2Core/Task.h>
+#include <U2Core/GUrlUtils.h>
+#include <U2Core/DocumentUtils.h>
 
-#include <datatype/DNAChromatogram.h>
+#include <U2Core/DNAChromatogram.h>
 
-#include <gobjects/DNASequenceObject.h>
-#include <gobjects/GObjectTypes.h>
-#include <gobjects/DNAChromatogramObject.h>
-#include <gobjects/GObjectUtils.h>
+#include <U2Core/DNASequenceObject.h>
+#include <U2Core/GObjectTypes.h>
+#include <U2Core/DNAChromatogramObject.h>
+#include <U2Core/GObjectUtils.h>
 
-#include <selection/DNASequenceSelection.h>
+#include <U2Core/DNASequenceSelection.h>
 
-#include <util_ov_annotated_dna/ADVConstants.h>
-#include <util_ov_annotated_dna/ADVSequenceObjectContext.h>
-#include <util_ov_annotated_dna/AnnotatedDNAView.h>
+#include <U2View/ADVConstants.h>
+#include <U2View/ADVSequenceObjectContext.h>
+#include <U2View/AnnotatedDNAView.h>
 
-#include <util_gui/GScrollBar.h>
-#include <util_gui/GUIUtils.h>
-#include <util_gui/AddNewDocumentDialogImpl.h>
-#include <util_gui/ProjectTreeController.h>
-#include <util_gui/ProjectTreeItemSelectorDialog.h>
-#include <util_tasks/TaskSignalMapper.h>
-#include <util_tasks/LoadDocumentTask.h>
+#include <U2Misc/GScrollBar.h>
+#include <U2Gui/GUIUtils.h>
+#include <U2Gui/AddNewDocumentDialogController.h>
+#include <U2Gui/ProjectTreeController.h>
+#include <U2Gui/ProjectTreeItemSelectorDialog.h>
+#include <U2Core/TaskSignalMapper.h>
+#include <U2Core/LoadDocumentTask.h>
 
 
-namespace GB2 {
+namespace U2 {
+
+static const char GAP_CHAR = '-';
 
 ChromatogramView::ChromatogramView(QWidget* p, ADVSequenceObjectContext* v, GSequenceLineView* cv, const DNAChromatogram& chroma) 
 : GSequenceLineView(p, v), editDNASeq(NULL)
@@ -74,6 +76,7 @@ ChromatogramView::ChromatogramView(QWidget* p, ADVSequenceObjectContext* v, GSeq
     mP->addAction(QString("G"));
     mP->addAction(QString("T"));
     mP->addAction(QString("N"));
+    mP->addAction(QString(GAP_CHAR));
     connect(mP, SIGNAL(triggered(QAction*)),SLOT(sl_onPopupMenuCkicked(QAction*))); 
 
 
@@ -138,6 +141,8 @@ void ChromatogramView::buildPopupMenu(QMenu& m) {
 
 }
 
+static const int MAX_DNA_LEN = 1000*1000*1000;
+
 void ChromatogramView::mousePressEvent(QMouseEvent* me)
 {
     setFocus();
@@ -145,6 +150,10 @@ void ChromatogramView::mousePressEvent(QMouseEvent* me)
         GSequenceLineView::mousePressEvent(me);
         return;
     }
+    if (editDNASeq!=NULL && editDNASeq->getSequenceLen()>MAX_DNA_LEN) {
+        GSequenceLineView::mousePressEvent(me);
+        return;
+    }
     QPoint renderAreaPos = toRenderAreaPoint(me->pos());
 
     const LRegion& visibleRange = getVisibleRange();
@@ -166,20 +175,44 @@ void ChromatogramView::mousePressEvent(QMouseEvent* me)
     GSequenceLineView::mousePressEvent(me);
 }
 
+int ChromatogramView::getEditSeqIndex(int bcIndex) {
+    int before=0;
+    foreach(int gapIdx, gapIndexes) {
+        if (gapIdx<bcIndex) {
+            ++before;
+        }
+    }
+    return bcIndex - before;
+}
+
 void ChromatogramView::sl_onPopupMenuCkicked(QAction* a) {
     if (editDNASeq->isStateLocked()) {
         QMessageBox::critical(this, tr("error"), tr("sequence_object_was_locked"));
         return;
     }
     char newBase = a->text().at(0).toAscii();
-    if (newBase != editDNASeq->getSequence().at(selIndex)) {
-        switch (newBase) {
-            case 'A': editDNASeq->setBase(selIndex, 'A');break;
-            case 'C': editDNASeq->setBase(selIndex, 'C');break;
-            case 'G': editDNASeq->setBase(selIndex, 'G');break;
-            case 'T': editDNASeq->setBase(selIndex, 'T');break;
-            case 'N': editDNASeq->setBase(selIndex, 'N');break;
-        };
+    char curBase = currentBaseCalls.at(selIndex);
+    if (newBase != curBase) {
+        DNASequence editSequence = editDNASeq->getSequence();
+        int editSeqIdx = getEditSeqIndex(selIndex);
+        if (curBase==GAP_CHAR) {
+            bool ok = gapIndexes.removeOne(selIndex);
+            assert(ok);
+            Q_UNUSED(ok);
+            editSequence.seq.insert(editSeqIdx, newBase);
+        } else {
+            if (newBase!=GAP_CHAR) {
+                editSequence.seq[editSeqIdx] = newBase;
+            } else {
+                editSequence.seq.remove(editSeqIdx,1);
+                gapIndexes.append(selIndex);
+            }
+        }
+        
+        currentBaseCalls[selIndex] = newBase;
+
+        editDNASeq->setSequence(editSequence);
+
         indexOfChangedChars.insert(selIndex);
         char refBase = ctx->getSequenceData().at(selIndex);
         if (newBase == refBase) {
@@ -202,7 +235,7 @@ void ChromatogramView::sl_addNewSequenceObject() {
     m.url = GUrlUtils::rollFileName(seqUrl.dirPath() + "/" + seqUrl.baseFileName() + "_sequence.fa", DocumentUtils::getNewDocFileNameExcludesHint());
     c.addFlagToSupport(DocumentFormatFlag_SupportWriting);
     c.supportedObjectTypes+=GObjectTypes::SEQUENCE;
-    AddNewDocumentDialogImpl::run(NULL, m, c);
+    AddNewDocumentDialogController::run(NULL, m, c);
     if (!m.successful) {
         return;
     }
@@ -215,6 +248,7 @@ void ChromatogramView::sl_addNewSequenceObject() {
 
     DNASequenceObject* so = ctx->getSequenceObject();
     editDNASeq = qobject_cast<DNASequenceObject*>(so->clone());
+    currentBaseCalls = editDNASeq->getSequence();
     doc->addObject(editDNASeq);
     ctx->getAnnotatedDNAView()->addObject(editDNASeq);
     indexOfChangedChars.clear();
@@ -288,8 +322,9 @@ void ChromatogramView::sl_removeChanges()   {
     DNASequenceObject* seqObject = ctx->getSequenceObject();
     const QByteArray& sequence = seqObject->getSequence();
     for (QSet<int>::const_iterator it = indexOfChangedChars.constBegin(); it != indexOfChangedChars.constEnd(); ++it)  {
-        editDNASeq->setBase(*it, sequence[*it]);
+        currentBaseCalls[*it] = sequence[*it];
     }
+    editDNASeq->setSequence(DNASequence(currentBaseCalls));
     indexOfChangedChars.clear();
 }
 
@@ -368,7 +403,6 @@ void ChromatogramViewRenderArea::drawAll(QPaintDevice* pd)
 
     ChromatogramView* chromaView = qobject_cast<ChromatogramView*>(view);
 
-    //get sequence
     const LRegion& visible = view->getVisibleRange();
     assert(!visible.isEmpty());
 
@@ -424,7 +458,7 @@ void ChromatogramViewRenderArea::drawAll(QPaintDevice* pd)
     }
 
     if (pd->width() / charWidth > visible.len /dividerBoolShowBaseCallsChars && chromaView->editDNASeq!=NULL) {
-        drawOriginalBaseCalls(0, 0, width(), charHeight, p, visible, chromaView->editDNASeq->getSequence(), false);
+        drawOriginalBaseCalls(0, 0, width(), charHeight, p, visible, chromaView->currentBaseCalls, false);
     }
 
     if (completeRedraw || uf.testFlag(GSLV_UF_SelectionChanged)) {
