@@ -10,14 +10,14 @@
 
 #include "CircularItems.h"
 #include "CircularView.h"
-#include <gobjects/DNASequenceObject.h>
-#include <gobjects/AnnotationTableObject.h>
-#include <gobjects/AnnotationSettings.h>
-#include <util_gui/GraphUtils.h>
-#include <core_api/AppContext.h>
+#include <U2Core/DNASequenceObject.h>
+#include <U2Core/AnnotationTableObject.h>
+#include <U2Core/AnnotationSettings.h>
+#include <U2Misc/GraphUtils.h>
+#include <U2Core/AppContext.h>
 #include <QtGui/QGraphicsLineItem>
 
-namespace GB2 {
+namespace U2 {
 
 /************************************************************************/
 /* CircularAnnotationItem                                               */
@@ -102,16 +102,6 @@ const QList<CircurlarAnnotationRegionItem*>& CircularAnnotationItem::getRegions(
     return regions;
 }
 
-CircularAnnotationItem* CircularAnnotationItem::clone() {
-    QList<CircurlarAnnotationRegionItem*> clone_regions;
-    foreach(CircurlarAnnotationRegionItem* region, regions) {
-        CircurlarAnnotationRegionItem* clone_region = region->clone();
-        clone_regions.append(clone_region);
-    }
-    CircularAnnotationItem* _clone = new CircularAnnotationItem(annotation, clone_regions, ra);
-    _clone->setSelected(isSelected);
-    return _clone;
-}
 /************************************************************************/
 /* CircurlarAnnotationRegionItem                                        */
 /************************************************************************/
@@ -158,11 +148,6 @@ void CircurlarAnnotationRegionItem::setLabel( CircularAnnotationLabel* label ) {
     this->label = label;
 }
 
-CircurlarAnnotationRegionItem* CircurlarAnnotationRegionItem::clone() {
-    CircurlarAnnotationRegionItem* _clone = new CircurlarAnnotationRegionItem(shape(), isShort, number);
-    return _clone;
-}
-
 /************************************************************************/
 /* CircularAnnotationLabel                                              */
 /************************************************************************/
@@ -315,8 +300,7 @@ void CircularAnnotationLabel::getVacantPositions(const QVector<QRect>& rects, QV
             if(arcsin>startA - PI/16 || arcsin<endA + PI/16) {
                 result << rects.indexOf(rect);
             }
-        }
-        else {
+        } else {
             if(arcsin>startA - PI/16 && arcsin < endA + PI/16) {
                 result << rects.indexOf(rect);
             }
@@ -329,13 +313,13 @@ void CircularAnnotationLabel::getVacantInnerPositions(const QVector<QRect>& rect
         -midRect.height()/2 * sin(annotationAngle / 180.0 * PI)).toPoint();
     foreach(QRect r, rects) {
         if(midRegionPoint.y()>0) {
-            qreal delta = abs(midRegionPoint.y() - r.bottom());
+            qreal delta = qAbs(midRegionPoint.y() - r.bottom());
             if(delta<ra->height()/5.0) {
                 result << rects.indexOf(r);
             }
         }
         else {
-            qreal delta = abs(midRegionPoint.y() - r.top());
+            qreal delta = qAbs(midRegionPoint.y() - r.top());
             if(delta<ra->height()/5.0) {
                 result << rects.indexOf(r);
             }
@@ -456,121 +440,4 @@ int CircularAnnotationLabel::getRegion() const {
     return region;
 }
 
-CircularAnnotationLabel* CircularAnnotationLabel::clone() {
-    CircularAnnotationLabel* _clone = new CircularAnnotationLabel(annotation, region, seqLen, labelFont, ra);
-    _clone->annotationAngle = annotationAngle;
-    _clone->midRect = midRect;
-    _clone->midRegionPoint = midRegionPoint;
-    _clone->startA = startA;
-    _clone->endA = endA;
-    _clone->labelPos = labelPos;
-    _clone->connectionPoint = connectionPoint;
-    _clone->hasPosition = hasPosition;
-    _clone->labelText = labelText;
-    _clone->inner = inner;
-    _clone->setVisible(isVisible());
-    return _clone;
-}
-
-/************************************************************************/
-/* Circular Ruler                                                       */
-/************************************************************************/
-
-CircularRuler::CircularRuler(QPoint _center, int _rulerEllipseSize, qreal _rotationDegree, int _start, int _len, QFont _rulerFont, int _notchSize)
-: center(_center), rulerEllipseSize(_rulerEllipseSize), rotationDegree(_rotationDegree), start(_start), len(_len), rulerFont(_rulerFont), notchSize(_notchSize) {
-}
-
-void CircularRuler::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget) {
-    Q_UNUSED(option);
-    Q_UNUSED(widget);
-
-    qreal halfChar = 180.0/len;
-    GraphUtils::drawCircularRuler(*painter, center, rulerEllipseSize, rotationDegree - halfChar, start, len+1, notchSize, rulerFont);
-}
-
-QRectF CircularRuler::boundingRect() const {
-    return QRectF(-rulerEllipseSize/2, -rulerEllipseSize/2, rulerEllipseSize, rulerEllipseSize);
-}
-
-void CircularRuler::setRotationDegree(qreal degree) {
-    while(degree>360) {
-        rotationDegree-=360;
-    }
-    while (degree<0) {
-        rotationDegree+=360;
-    }
-    rotationDegree = degree;
-}
-
-void CircularRuler::setRulerSize(int diam) {
-    rulerEllipseSize = diam;
-}
-
-CircularRuler* CircularRuler::clone() {
-    CircularRuler* _clone = new CircularRuler(center, rulerEllipseSize, rotationDegree, start, len, rulerFont, notchSize);
-    return _clone;
-}
-
-/************************************************************************/
-/* Text item                                                            */
-/************************************************************************/
-
-QRectF TextItem::boundingRect() const {
-    QFontMetrics fm(font);
-    QRectF bound = fm.boundingRect(itemText+" ");
-    bound.moveCenter(textPos);
-    return bound;
-}
-
-void TextItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget ) {
-    Q_UNUSED(widget);
-    Q_UNUSED(option);
-
-    QRectF bound = boundingRect();
-    painter->drawText(bound, itemText);
-}
-
-TextItem* TextItem::clone() {
-    TextItem* ti = new TextItem(itemText, textPos, font);
-    return ti;
-}
-
-/************************************************************************/
-/* Circular Selection Item                                              */
-/************************************************************************/
-void CircularSelectionItem::addPath(QPainterPath& path) {
-    paths.append(&path);
-}
-
-void CircularSelectionItem::clear() {
-    paths.clear();
-}
-
-QRectF CircularSelectionItem::boundingRect() const {
-    QPainterPath location;
-    foreach(QPainterPath* path, paths) {
-        location = location.united(*path);
-    }
-    return location.boundingRect();
-}
-
-void CircularSelectionItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget ) {
-    Q_UNUSED(widget);
-    Q_UNUSED(option);
-    painter->save();
-    QPen selectionPen(QColor("#007DE3"));
-    selectionPen.setStyle(Qt::DashLine);
-    selectionPen.setWidth(1);
-    painter->setPen(selectionPen);
-    foreach(QPainterPath* path, paths) {
-        painter->drawPath(*path);
-    }
-    painter->restore();
-}
-
-CircularSelectionItem* CircularSelectionItem::clone() {
-    CircularSelectionItem* sel = new CircularSelectionItem(paths);
-    return sel;
-}
-
-} // namespace GB2
+} // namespace U2
