@@ -10,20 +10,20 @@
 
 #include "CircularView.h"
 
-#include <core_api/DNAAlphabet.h>
-#include <core_api/SelectionModel.h>
-#include <core_api/Log.h>
-#include <core_api/Timer.h>
-#include <core_api/AppContext.h>
+#include <U2Core/DNAAlphabet.h>
+#include <U2Core/SelectionModel.h>
+#include <U2Core/Timer.h>
+#include <U2Core/AppContext.h>
 
-#include <gobjects/DNASequenceObject.h>
-#include <gobjects/AnnotationTableObject.h>
-#include <gobjects/AnnotationSettings.h>
+#include <U2Core/DNASequenceObject.h>
+#include <U2Core/AnnotationTableObject.h>
+#include <U2Core/AnnotationSettings.h>
+#include <U2View/ADVSequenceWidget.h>
 
-#include <selection/DNASequenceSelection.h>
-#include <util_gui/GScrollBar.h>
-#include <util_text/FormatUtils.h>
-#include <util_gui/GraphUtils.h>
+#include <U2Core/DNASequenceSelection.h>
+#include <U2Misc/GScrollBar.h>
+#include <U2Core/FormatUtils.h>
+#include <U2Misc/GraphUtils.h>
 
 #include <QtGui/QTextEdit>
 #include <QtGui/QGridLayout>
@@ -32,34 +32,23 @@
 #include <QtGui/QDialog>
 
 #include "CircularItems.h"
-
-namespace GB2 {
-
-static LogCategory log(ULOG_CAT_ADV);
-const int CircularViewRenderArea::OUTER_ELLIPSE_SIZE = 512;
-const int CircularViewRenderArea::ELLIPSE_DELTA = 22;
-const int CircularViewRenderArea::INNER_ELLIPSE_SIZE = OUTER_ELLIPSE_SIZE - CV_REGION_ITEM_WIDTH;
-const int CircularViewRenderArea::RULER_ELLIPSE_SIZE = INNER_ELLIPSE_SIZE - CV_REGION_ITEM_WIDTH;
-const int CircularViewRenderArea::MIDDLE_ELLIPSE_SIZE = (INNER_ELLIPSE_SIZE + OUTER_ELLIPSE_SIZE) / 2;
-const int CircularViewRenderArea::ARROW_LENGTH = 32;
-const int CircularViewRenderArea::ARROW_HEIGHT_DELTA = 4;
-const int CircularViewRenderArea::MAX_DISPLAYING_LABELS = 20;
+#include <U2Core/Log.h>
 
 
+namespace U2 {
+
+const int CircularView::CV_REGION_ITEM_WIDTH = 20;
+
+const int CircularView::MIN_OUTER_SIZE = 100;
+const int CircularView::graduation = 16;
 
 
-#define MIN_OUTER_SIZE 100
+static Logger log("Circular view plugin");
+
 CircularView::CircularView(QWidget* p, ADVSequenceObjectContext* ctx)
-: GSequenceLineViewAnnotated(p, ctx), isCircularDNA(false)
+: GSequenceLineViewAnnotated(p, ctx), clockwise(true), holdSelection(false)
 {
-    const DNASequence& dna = ctx->getSequenceObject()->getDNASequence();
-    if (dna.info.contains(DNAInfo::LOCUS)) {
-        DNALocusInfo loi = dna.info.value(DNAInfo::LOCUS).value<DNALocusInfo>();
-        if (loi.topology == "circular") {
-            isCircularDNA = true;
-        }
-    }
-    
+    connect (ctx->getAnnotatedDNAView(), SIGNAL(si_sequenceWidgetRemoved(ADVSequenceWidget*)), SLOT(sl_sequenceWidgetRemoved(ADVSequenceWidget*)));
     foreach(AnnotationTableObject* obj, ctx->getAnnotationObjects()) {
         registerAnnotations(obj->getAnnotations());
     }
@@ -68,48 +57,16 @@ CircularView::CircularView(QWidget* p, ADVSequenceObjectContext* ctx)
     ra = qobject_cast<CircularViewRenderArea*>(renderArea);
     setMouseTracking(true);
 
-    sBar = new QScrollBar(Qt::Vertical, renderArea);
-
     connect(ctx->getSequenceGObject(), SIGNAL(si_sequenceChanged()), this, SLOT(sl_sequenceChanged()));
     pack();
-}
-
-CircularView::~CircularView() {}
-
-CircularViewRenderArea* CircularView::getRenderArea() const {
-    return ra;
-}
-
-const QMap<Annotation*,CircularAnnotationItem*>& CircularView:: getCircularItems() const {
-    return ra->circItems;
-}
-
-const QList<CircularAnnotationLabel*>& CircularView::getLabelList() const {
-    return ra->labelList;
-}
-
-CircularRuler* CircularView::getRuler() const {
-    return ra->ruler;
-}
-
-TextItem* CircularView::getSeqNameLabel() const {
-    return ra->seqNameItem;
-}
-
-TextItem* CircularView::getSeqLenLabel() const {
-    return ra->seqLenItem;
-}
-
-CircularSelectionItem* CircularView::getSelItem() const {
-    return ra->selItem;
-}
-
-QSize CircularView::sizeHint() const {
-    return QSize(600, 600);
+    
+    //mark sequence as circular
+    ctx->getSequenceObject()->setCircular(true);
 }
 
 void CircularView::pack() {
-    setMinimumHeight(10);
+    int minH = (ra->regionY.count() - 1)*ra->ellipseDelta + MIN_OUTER_SIZE;
+    setMinimumHeight(minH);
     layout = new QVBoxLayout();
     layout->setContentsMargins(0,0,0,0);
     layout->addWidget(renderArea);
@@ -117,116 +74,175 @@ void CircularView::pack() {
     setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Maximum);
 }
 
-void CircularView::updateVerticalScrollBar(int areaHeight) {
-    int offset = areaHeight - height();
-    sBar->disconnect(this);
-    sBar->setMinimum(int(-offset/2));
-    sBar->setMaximum(int(offset/2));
-    sBar->setSingleStep(1);
-    sBar->setPageStep(int(offset/2));
-    sBar->setSliderPosition(0);
-
-    connect(sBar, SIGNAL(valueChanged(int)), SLOT(sl_onSBarMoved(int)));
-}
-
-void CircularView::sl_onSBarMoved(int pos) {
-    Q_UNUSED(pos)
-    addUpdateFlags(GSLV_UF_NeedCompleteRedraw);
-    renderArea->update();
+void CircularView::sl_sequenceWidgetRemoved(ADVSequenceWidget* w) {
+    foreach (ADVSequenceObjectContext *wctx, w->getSequenceContexts()) {
+        if (ctx == wctx) {
+            close();
+        }
+    }
 }
 
 void CircularView::mousePressEvent(QMouseEvent * e) {
     GSequenceLineViewAnnotated::mousePressEvent(e);
-    CircularViewRenderArea* ra = qobject_cast<CircularViewRenderArea*>(renderArea);
     QPoint p = toRenderAreaPoint(e->pos());
-    QPoint point(p.x() - width()/2 , p.y() - height()/2);
+    int offset = ra->getCenterY();
+    QPoint point(p.x() - width()/2 , p.y() - offset);
     qreal arcsin = coordToAngle(point);
-    lastPressPos = 180 * 16 * arcsin / PI;
-    lastPressPos-=ra->rotationDegree*16;
+    lastPressPos = 180 * graduation * arcsin / PI;
+    lastPressPos-=ra->rotationDegree*graduation;
     if(lastPressPos<0) {
-        lastPressPos+=360*16;
+        lastPressPos+=360*graduation;
     }
     lastMovePos = lastPressPos;
     lastMouseY = point.y();
     currectSelectionLen = 0;
+
+    holdSelection = false;
+
     QWidget::mousePressEvent(e);
 }
 
+CircularView::Direction CircularView::getDirection(float a, float b) const {
+    if (a == b) {
+        return UNKNOWN;
+    }
+
+    a/=graduation;
+    b/=graduation;
+
+    bool cl = ( (a-b>=180) || ((b-a <=180) && (b-a >=0)) );
+
+    if (cl) {
+        return CW;
+    }
+    else {
+        return CCW;
+    }
+}
+
 void CircularView::mouseMoveEvent( QMouseEvent * e )
 {
+    QWidget::mouseMoveEvent(e);
+
     QPoint areaPoint = toRenderAreaPoint(e->pos());
-    QPoint point(areaPoint.x() - width()/2 , areaPoint.y() - height()/2);
+    QPoint point(areaPoint.x() - width()/2 , areaPoint.y() - ra->getCenterY());
     qreal arcsin = coordToAngle(point);
-    CircularViewRenderArea* ra = qobject_cast<CircularViewRenderArea*>(renderArea);
     ra->mouseAngle = arcsin;
 
     if (e->buttons() & Qt::LeftButton) {        
-        float a = 180 * 16 * arcsin / PI;
-        a-=ra->rotationDegree*16;
+        float a = 180 * graduation * arcsin / PI;
+        a-=ra->rotationDegree*graduation;
         if(a<0) {
-            a+=360*16;
+            a+=360*graduation;
+        }
+
+        Direction pressMove = getDirection(lastPressPos, lastMovePos);
+        Direction moveA = getDirection(lastMovePos, a);
+
+        float totalLen = qAbs(lastPressPos-lastMovePos) + qAbs(lastMovePos-a);
+        totalLen/=graduation;
+
+        if ((totalLen<10) && !holdSelection) {
+            if ((pressMove!=CW) && (moveA!=CW)) {
+                clockwise = false;
+            }
+            else if ((pressMove != CCW) && (moveA != CCW)) {
+                clockwise = true;
+            }
+
+            if (totalLen < 1) {
+                clockwise = lastPressPos < a;
+            }
+
+            holdSelection = true;
+        }
+
+        if (!clockwise) {
+            float tmp = a;
+            a = lastPressPos;
+            lastPressPos = tmp;
         }
-        //currectSelectionLen = a - lastPressPos;
 
         // compute selection
         int seqLen = ctx->getSequenceLen();
-        int selStart = lastPressPos / 5760.0 * seqLen + 0.5f;
-        int selEnd = a / 5760.0 * seqLen + 0.5f;
+        int selStart = lastPressPos / (360.0*graduation) * seqLen + 0.5f;
+        int selEnd = a / (360.0*graduation) * seqLen + 0.5f;
         int selLen = selEnd-selStart;
-        //int selLen = currectSelectionLen / 5760.0 * seqLen;
 
-        if (selLen < 0) {
-            selStart = selStart + selLen;
-            selLen *= -1;
+        bool twoParts = false;
+        if (selLen < 0) {    // 'a' and 'lastPressPos' are swapped so it should be positive
+            selLen = selEnd + seqLen - selStart;
+            Q_ASSERT(selLen>=0);
+
+            if (selEnd) {    // [0, selEnd]
+                twoParts = true;
+            }
         }
-        if (selLen > seqLen) {
-            selLen = seqLen;
+
+        if (selLen > seqLen-selStart) {
+            selLen = seqLen-selStart;
         }
-        if (selStart + selLen > seqLen) {
-            assert(seqLen-selStart>=0);
-            setSelection(LRegion(selStart, seqLen - selStart));
-        } else {
-            setSelection(LRegion(selStart, selLen));
+
+        if (!clockwise) {
+            float tmp = lastPressPos;
+            lastPressPos = a;
+            a = tmp;
         }
+
         lastMovePos = a;
         lastMouseY = point.y();
+
+        if (twoParts) {
+            setSelection(LRegion(selStart, seqLen-selStart));
+            addSelection(LRegion(0, selEnd));
+        }
+        else {
+            setSelection(LRegion(selStart, selLen));
+        }
     }
-    QWidget::mouseMoveEvent(e);
     renderArea->update();
 }
 
 void CircularView::mouseReleaseEvent(QMouseEvent* e) {
-	GSequenceLineViewAnnotated::mouseReleaseEvent(e);
+    GSequenceLineViewAnnotated::mouseReleaseEvent(e);
 }
 
-void CircularView::wheelEvent(QWheelEvent *we) {
-    //check if mouse hovers
-    bool renderAreaWheel = QRect(renderArea->x(), renderArea->y(),
-        renderArea->width(), renderArea->height()).contains(we->pos());
-    if (!renderAreaWheel) {
-        QWidget::wheelEvent(we);
-        return;
-    }
-    setFocus();
-    CircularViewRenderArea* ra = qobject_cast<CircularViewRenderArea*>(renderArea);
-    if(we->delta() > 0) {
-        ra->rotationDegree+=10;
-    }
-    else {
-        ra->rotationDegree-=10;
-    }
-    if(ra->rotationDegree<0) {
-        ra->rotationDegree+=360.0;
-    }
-    if(ra->rotationDegree>360) {
-        ra->rotationDegree-=360.0;
-    }
+void CircularView::setAngle(int angle) {
+    assert(angle>=0 && angle<=360);
+    ra->rotationDegree=angle;
     addUpdateFlags(GSLV_UF_NeedCompleteRedraw);
     renderArea->update();
-    QWidget::wheelEvent(we);
 }
 
 void CircularView::sl_onAnnotationSelectionChanged(AnnotationSelection* selection, const QList<Annotation*>& added, const QList<Annotation*>& removed) {
+    QList<Annotation*> toAdd;
+    foreach (Annotation* a, added) {
+        const QString splitStr = a->findFirstQualifierValue("SPLIT");
+        if (splitStr.isEmpty()) {
+            continue;
+        }
+        int curSplit = splitStr.toInt();
+        QList<Annotation*> another;
+        AnnotationTableObject* aObj = a->getGObject();
+        foreach (Annotation* target, aObj->getAnnotations()) {
+            if (target->getAnnotationName() == a->getAnnotationName()) {
+                if (target == a) {
+                    continue;
+                }
+                int newSplit = target->findFirstQualifierValue("SPLIT").toInt();
+                if ( qAbs(newSplit) == qAbs(curSplit)) {
+                    // found other split
+                    toAdd.append( target );
+                    break;
+                }
+            }
+        }
+    }
+    
+    foreach(Annotation* a, toAdd) {
+        selection->addToSelection(a);
+    }
+
     GSequenceLineViewAnnotated::sl_onAnnotationSelectionChanged(selection, added, removed);
     renderArea->update();
 }
@@ -241,7 +257,7 @@ QList<AnnotationSelectionData> CircularView::selectAnnotationByCoord( const QPoi
 {
     QList<AnnotationSelectionData> res;
     CircularViewRenderArea* renderArea = qobject_cast<CircularViewRenderArea*>(this->renderArea);
-    QPoint cp(coord - QPoint(width()/2, height()/2));
+    QPoint cp(coord - QPoint(width()/2, renderArea->getCenterY()));
     foreach(CircularAnnotationItem* item, renderArea->circItems) {
         int region = item->containsRegion(cp);
         if(region != -1) {
@@ -261,41 +277,100 @@ QList<AnnotationSelectionData> CircularView::selectAnnotationByCoord( const QPoi
     return res;
 }
 
-void CircularView::resizeEvent( QResizeEvent* e )
-{
-    CircularViewRenderArea* renderArea = qobject_cast<CircularViewRenderArea*>(this->renderArea);
-    qreal s = qMin(qreal(height()/500.0), qreal(width()/500.0));
-    int yLvl = renderArea->regionY.count();
-    int outerEllipseSize=CircularViewRenderArea::OUTER_ELLIPSE_SIZE*s - renderArea->ellipseDelta*yLvl;
+QSize CircularView::sizeHint() const {
+    return ra->size();
+}
 
-    if(outerEllipseSize<MIN_OUTER_SIZE) {
-        sBar->setHidden(false);
-        sBar->setFixedHeight(height());
-        updateVerticalScrollBar(MIN_OUTER_SIZE + renderArea->ellipseDelta*yLvl);
-    }
-    else {
-        //sBar->setSliderPosition(0);
-        sBar->setHidden(true);
-        renderArea->outerEllipseSize=outerEllipseSize;
-        renderArea->innerEllipseSize=renderArea->outerEllipseSize-CV_REGION_ITEM_WIDTH;
-        renderArea->rulerEllipseSize=renderArea->outerEllipseSize-CV_REGION_ITEM_WIDTH;
-        renderArea->middleEllipseSize = (renderArea->outerEllipseSize + renderArea->innerEllipseSize)/2;
-        renderArea->arrowLength=CircularViewRenderArea::ARROW_LENGTH*s;
-        //renderArea->arrowHeightDelta=int(CircularViewRenderArea::ARROW_HEIGHT_DELTA*s);
+const QMap<Annotation*,CircularAnnotationItem*>& CircularView::getCircularItems() const {
+    return ra->circItems;
+}
 
-        QFont font;
-        QFontMetrics fm(font);
-        int lblHeight = fm.height();
-        renderArea->maxDisplayingLabels = int(height()/lblHeight);
+const QList<CircularAnnotationLabel*>& CircularView::getLabelList() const {
+    return ra->labelList;
+}
+
+void CircularView::wheelEvent(QWheelEvent* we) {
+    if (we->modifiers()&Qt::ControlModifier) {
+        if (we->delta()>0) {
+            sl_zoomIn();
+        } else {
+            sl_zoomOut();
+        }
+    } else {
+        emit si_wheelMoved(we->delta());
     }
-    addUpdateFlags(GSLV_UF_ViewResized);
-    renderArea->update();
-	QWidget::resizeEvent(e);
+    QWidget::wheelEvent(we);
+}
+
+void CircularView::resizeEvent( QResizeEvent* e ) {
+    if (ra->fitsInView) {
+        sl_fitInView();
+    }
+    QWidget::resizeEvent(e);
+}
+
+#define VIEW_MARGIN 10
+void CircularView::sl_fitInView() {
+    int yLvl = ra->regionY.count() - 1;
+    ra->outerEllipseSize = qMin(height(), width()) - ra->ellipseDelta*yLvl - VIEW_MARGIN;
+    adaptSizes();
+    updateZoomActions();
+}
+
+#define ZOOM_SCALE 1.5
+void CircularView::sl_zoomIn() {
+    if (ra->outerEllipseSize / width() > 10) {
+        return;
+    }
+    ra->outerEllipseSize*=ZOOM_SCALE;
+    adaptSizes();
+    updateZoomActions();
+}
+
+void CircularView::sl_zoomOut() {
+    if (ra->fitsInView) {
+        return;
+    }
+    ra->outerEllipseSize/=ZOOM_SCALE;
+    adaptSizes();
+    updateZoomActions();
+}
+
+void CircularView::updateZoomActions() {
+    if (ra->outerEllipseSize*ZOOM_SCALE / width() > 10) {
+        emit si_zoomInDisabled(true);
+    } else {
+        emit si_zoomInDisabled(false);
+    }
+
+    int viewSize = qMin(height(), width()) - VIEW_MARGIN;
+    int size = ra->outerEllipseSize + (ra->regionY.count()-1)*ra->ellipseDelta;
+
+    if (size <= viewSize) {
+        emit si_fitInViewDisabled(true);
+        emit si_zoomOutDisabled(true);
+    } else {
+        emit si_fitInViewDisabled(false);
+        emit si_zoomOutDisabled(false);
+    }
+}
+
+void CircularView::adaptSizes() {
+    ra->innerEllipseSize=ra->outerEllipseSize-CV_REGION_ITEM_WIDTH;
+    ra->rulerEllipseSize=ra->outerEllipseSize-CV_REGION_ITEM_WIDTH;
+    ra->middleEllipseSize = (ra->outerEllipseSize + ra->innerEllipseSize)/2;
+    addUpdateFlags(GSLV_UF_NeedCompleteRedraw);
+    ra->update();
 }
 
 qreal CircularView::coordToAngle(const QPoint point) {
     float norm = sqrt((double)point.x()*point.x() + point.y()*point.y());
-    float arcsin = asin(abs(point.y())/norm);
+    float arcsin = 0.0;
+    if (abs(norm) > 1.0)
+    {
+        arcsin = asin(abs((double)point.y())/norm);
+    }
+
     if(point.x() < 0) {
         arcsin = PI - arcsin;
     }
@@ -308,20 +383,34 @@ qreal CircularView::coordToAngle(const QPoint point) {
 /************************************************************************/
 /* CircularViewRenderArea                                               */
 /************************************************************************/
-#define NOTCH_SIZE 5
+
+const int CircularViewRenderArea::OUTER_ELLIPSE_SIZE = 512;
+const int CircularViewRenderArea::ELLIPSE_DELTA = 22;
+const int CircularViewRenderArea::INNER_ELLIPSE_SIZE = OUTER_ELLIPSE_SIZE - CircularView::CV_REGION_ITEM_WIDTH;
+const int CircularViewRenderArea::RULER_ELLIPSE_SIZE = INNER_ELLIPSE_SIZE - CircularView::CV_REGION_ITEM_WIDTH;
+const int CircularViewRenderArea::MIDDLE_ELLIPSE_SIZE = (INNER_ELLIPSE_SIZE + OUTER_ELLIPSE_SIZE) / 2;
+const int CircularViewRenderArea::ARROW_LENGTH = 32;
+const int CircularViewRenderArea::ARROW_HEIGHT_DELTA = 4;
+const int CircularViewRenderArea::MAX_DISPLAYING_LABELS = 20;
+
+const int CircularViewRenderArea::MARKER_LEN = 30;
+const int CircularViewRenderArea::ARR_LEN = 4;
+const int CircularViewRenderArea::ARR_WIDTH = 10;
+const int CircularViewRenderArea::NOTCH_SIZE = 5;
+
+
 CircularViewRenderArea::CircularViewRenderArea(CircularView* d)
 : GSequenceLineViewAnnotatedRenderArea(d, true), outerEllipseSize(OUTER_ELLIPSE_SIZE),
 ellipseDelta(ELLIPSE_DELTA), innerEllipseSize(INNER_ELLIPSE_SIZE), rulerEllipseSize(RULER_ELLIPSE_SIZE),
 middleEllipseSize(MIDDLE_ELLIPSE_SIZE), arrowLength(ARROW_LENGTH),
 arrowHeightDelta(ARROW_HEIGHT_DELTA), maxDisplayingLabels(MAX_DISPLAYING_LABELS),
-circularView(d), rotationDegree(0), mouseAngle(0) {
+circularView(d), rotationDegree(0), mouseAngle(0), fitsInView(true), oldYlevel(0) {
     setMouseTracking(true);
 
     ADVSequenceObjectContext* ctx = view->getSequenceContext();
 
     int len = ctx->getSequenceLen();
     int start = 1;
-    ruler = new CircularRuler(QPoint(0,0), rulerEllipseSize, rotationDegree, start, len, rulerFont, NOTCH_SIZE);
 
     //build annotation items to get number of region levels for proper resize
     AnnotationSettingsRegistry* asr = AppContext::getAnnotationsSettingsRegistry();
@@ -331,14 +420,18 @@ circularView(d), rotationDegree(0), mouseAngle(0) {
             buildAnnotationItem(DrawAnnotationPass_DrawFill, a, false, as);
         }
     }
-    //////////////////////////////////////////////////////////////////////////
-
-    seqNameItem=new TextItem();
-    seqLenItem=new TextItem();
-
-    selItem = new CircularSelectionItem();
 }
 
+void CircularViewRenderArea::adaptNumberOfLabels(int h) {
+
+    QFont font;
+    QFontMetrics fm(font);
+
+    int lblHeight = fm.height();
+    maxDisplayingLabels = int(h/lblHeight);
+}
+
+
 void CircularViewRenderArea::drawAll(QPaintDevice* pd) {
     QPainter p(pd);
     p.setRenderHint(QPainter::Antialiasing);
@@ -346,21 +439,26 @@ void CircularViewRenderArea::drawAll(QPaintDevice* pd) {
     bool completeRedraw = uf.testFlag(GSLV_UF_NeedCompleteRedraw) || uf.testFlag(GSLV_UF_ViewResized) || 
         uf.testFlag(GSLV_UF_AnnotationsChanged);
 
-    int scrolPos = circularView->getScrollPos();
+    int viewSize = qMin(circularView->height(), circularView->width());
+    verticalOffset = parentWidget()->height()/2;
+    if (outerEllipseSize + (regionY.count()-1)*ellipseDelta + VIEW_MARGIN > viewSize) {
+        verticalOffset += rulerEllipseSize/2;
+        fitsInView = false;
+    } else {
+        fitsInView = true;
+    }
     if (completeRedraw) {
         QPainter pCached(cachedView);
         pCached.setRenderHint(QPainter::Antialiasing);
         pCached.fillRect(0, 0, pd->width(), pd->height(), Qt::white);
-        /*pCached.translate(pd->width()/2, pd->height()/2);*/
-        pCached.translate(parentWidget()->width()/2, parentWidget()->height()/2 - scrolPos);
+        pCached.translate(parentWidget()->width()/2, verticalOffset);
         pCached.setPen(Qt::black);
         drawRuler(pCached);
         drawAnnotations(pCached);
         pCached.end();
     }
     p.drawPixmap(0, 0, *cachedView);
-    /*p.translate(width()/2, height()/2);*/
-    p.translate(parentWidget()->width()/2, parentWidget()->height()/2 - scrolPos);
+    p.translate(parentWidget()->width()/2, verticalOffset);
 
     drawSequenceName(p);
 
@@ -369,6 +467,14 @@ void CircularViewRenderArea::drawAll(QPaintDevice* pd) {
     drawSequenceSelection(p);
 
     drawMarker(p);
+
+    if (oldYlevel!=regionY.count()) {
+        oldYlevel = regionY.count();
+        if (verticalOffset<=parentWidget()->height()/2) {
+            circularView->sl_fitInView();
+            paintEvent(new QPaintEvent(rect()));
+        }
+    }
 }
 
 void CircularViewRenderArea::drawAnnotationsSelection(QPainter& p) {
@@ -381,18 +487,6 @@ void CircularViewRenderArea::drawAnnotationsSelection(QPainter& p) {
     foreach(CircularAnnotationItem* item, circItems.values()) {
         item->setSelected(false);
     }
-
-    /*foreach(const AnnotationSelectionData& asd, ctx->getAnnotationsSelection()->getSelection()) {
-        CircularAnnotationItem* item = circItems[asd.annotation];
-        item->setSelected(true);
-        item->paint(&p, NULL, this);
-        foreach(const CircurlarAnnotationRegionItem* r, item->getRegions()) {
-            CircularAnnotationLabel* lbl = r->getLabel();
-            if(lbl->isVisible()) {
-                lbl->paint(&p, NULL, this);
-            }
-        }
-    }*/
     foreach(const AnnotationSelectionData& asd, ctx->getAnnotationsSelection()->getSelection()) {
         AnnotationTableObject* o = asd.annotation->getGObject();
         if (ctx->getAnnotationObjects().contains(o)) {
@@ -435,26 +529,37 @@ void CircularViewRenderArea::drawSequenceName(QPainter& p) {
     
     p.setPen(boldPen);
 
-    seqNameItem->setText(docName);
-    seqNameItem->setPos(QPoint(0,0));
-    seqNameItem->paint(&p, NULL, this);
+    QPointF namePt;
+    QPointF lenPt;
+    
+    QRectF nameBound = fm.boundingRect(docName+' ');
+    QRectF lenBound = fm.boundingRect(seqLen+' ');
+    
+    if (!fitsInView) {
+        int delta = verticalOffset - parentWidget()->height();
+        namePt = QPointF(0, -delta-nameBound.height()-lenBound.height());
+        lenPt = namePt + QPointF(0, lenBound.height());
+    } else {
+        namePt = QPointF(0,0);
+        lenPt = QPointF(0, nameBound.height());
+    }
+    
+    nameBound.moveCenter(namePt);
+    p.drawText(nameBound, docName);
 
-    seqLenItem->setText(seqLen);
-    seqLenItem->setPos(QPoint(0, seqNameItem->boundingRect().height()));
-    seqLenItem->paint(&p, NULL, this);
+    lenBound.moveCenter(lenPt);
+    p.drawText(lenBound, seqLen);
 }
 
-void CircularViewRenderArea::drawSequenceSelection( QPainter& p )
-{
-    selItem->clear();
-    
+void CircularViewRenderArea::drawSequenceSelection( QPainter& p ) {
     ADVSequenceObjectContext* ctx = view->getSequenceContext();
     int seqLen = ctx->getSequenceLen();
     const QList<LRegion>& selection = view->getSequenceContext()->getSequenceSelection()->getSelectedRegions();
 
+    QList<QPainterPath*> paths;
+
     foreach(const LRegion& r, selection) {
-        QPainterPath* pathPtr = new QPainterPath();
-        QPainterPath& path = *pathPtr;
+        QPainterPath* path = new QPainterPath();
         int yLevel = regionY.count() - 1;
         QRect outerRect(-outerEllipseSize/2 - yLevel * ellipseDelta/2 - ARROW_HEIGHT_DELTA,
             -outerEllipseSize/2 - yLevel * ellipseDelta/2 - ARROW_HEIGHT_DELTA,
@@ -464,29 +569,157 @@ void CircularViewRenderArea::drawSequenceSelection( QPainter& p )
             rulerEllipseSize - 2*NOTCH_SIZE, rulerEllipseSize-2*NOTCH_SIZE);
         float startAngle = r.startPos / (float)seqLen * 360 + rotationDegree;
         float spanAngle = r.len / (float)seqLen * 360;
-        path.moveTo(outerRect.width()/2 * cos(-startAngle / 180.0 * PI),
+        path->moveTo(outerRect.width()/2 * cos(-startAngle / 180.0 * PI),
             -outerRect.width()/2 * sin(-startAngle / 180.0 * PI));
-        path.arcTo(outerRect, -startAngle, -spanAngle);
-        path.arcTo(innerRect, -startAngle-spanAngle, spanAngle);
-        path.closeSubpath();
-        selItem->addPath(path);
+        path->arcTo(outerRect, -startAngle, -spanAngle);
+        path->arcTo(innerRect, -startAngle-spanAngle, spanAngle);
+        path->closeSubpath();
+        paths.append(path);
     }
-
-    selItem->paint(&p, NULL, this);
+    p.save();
+    QPen selectionPen(QColor("#007DE3"));
+    selectionPen.setStyle(Qt::DashLine);
+    selectionPen.setWidth(1);
+    p.setPen(selectionPen);
+    foreach(QPainterPath* path, paths) {
+        p.drawPath(*path);
+    }
+    p.restore();
 }
 
-void CircularViewRenderArea::drawRuler( QPainter& p )
-{   
-    ruler->setRotationDegree(rotationDegree);
-    ruler->setRulerSize(rulerEllipseSize);
-    ruler->paint(&p, NULL, this);
+void normalizeAngle(qreal& a) {
+    while(a>360) {
+        a-=360;
+    }
+    while(a<0) {
+        a+=360;
+    }
+}
+
+void normalizeAngleRad(qreal& a) {
+    while(a>2*PI) {
+        a-=2*PI;
+    }
+    while(a<0) {
+        a+=2*PI;
+    }
+}
+
+void CircularViewRenderArea::drawRulerNotches(QPainter& p, int start, int span, int seqLen) {
+    int notchSize = 5;
+    QFont f;
+    QFontMetrics fm(f);
+    int cw = fm.width('0');
+    int N = QString::number(start+span).length()*cw*3/2.0 + 0.5f;
+    int rulerLen = span / (float)seqLen * PI * rulerEllipseSize;
+    int chunk = GraphUtils::findChunk(rulerLen, span, N);
+    start-=start%chunk;
+    float halfChar = 180 / (float)seqLen;
+    for (int currentNotch=start+chunk; currentNotch < start + span + chunk; currentNotch+=chunk) {
+        if (currentNotch > seqLen) {
+            currentNotch = seqLen;
+        }
+        qreal d = currentNotch / (float)seqLen * 360 + rotationDegree - halfChar;
+        d*=PI/180.0;
+        d = 2*PI - d;
+        QPoint point1 ( rulerEllipseSize * cos(d) / 2.0 + 0.5f, - rulerEllipseSize * sin(d) / 2.0 - 0.5f);
+        point1-=QPoint(0,0);
+        QPoint point2 = point1 - QPoint(notchSize*cos(d), -notchSize*sin(d));
+        QPoint point3 = point2 - QPoint(3*cos(d), 0);
+        if (currentNotch == 0) {
+
+        }
+        QString label = FormatUtils::formatNumber(currentNotch);
+        QRect bounding = p.boundingRect(0,0,1000,1000, Qt::AlignLeft, label);
+
+        normalizeAngleRad(d);
+        if(d>PI/4 && d<=PI/2 + PI/4) {
+            QPoint dP((float)bounding.width() / 2 * (1-cos(d)), 0);
+            bounding.moveTopRight(point3 + dP);
+        } else if(d>PI/2 + PI/4 && d<=PI + PI/4) {
+            QPoint dP(0, (float)bounding.height() / 2 * (1-sin(d)));
+            bounding.moveTopLeft(point3 - dP);
+        } else if(d>PI + PI/4 && d<=3*PI/2 + PI/4) {
+            QPoint dP((float)bounding.width() / 2 * (1-cos(d)), 0);
+            bounding.moveBottomRight(point3 + dP);
+        } else {
+            QPoint dP(0, (float)bounding.height() / 2 * (1-sin(d)));
+            bounding.moveTopRight(point3 - dP);
+        }
+
+        p.drawLine(point1,point2);
+        p.drawText(bounding, label);
+    }
+}
+
+qreal CircularViewRenderArea::getVisibleAngle() const {
+    int w = parentWidget()->width();
+    int h = parentWidget()->height();
+
+    int y = verticalOffset - h;
+    float x = rulerEllipseSize/2.0;
+    assert(y>0);
+    assert(x>y);
+    int rulerChord = 2*sqrt(double(x*x - y*y));
+    rulerChord = qMin(rulerChord, w);
+    assert(qAbs(rulerChord)<qAbs(rulerEllipseSize));
+    qreal spanAngle = qAbs(asin(rulerChord/(double)rulerEllipseSize));
+    return spanAngle;
+}
+
+QPair<int,int> CircularViewRenderArea::getVisibleRange() const {
+    ADVSequenceObjectContext* ctx = view->getSequenceContext();
+    int seqLen = ctx->getSequenceObject()->getSequenceLen();
+    if (verticalOffset <= parentWidget()->height()) {
+        return qMakePair<int,int>(0, seqLen);
+    }
+    qreal spanAngle = getVisibleAngle();
+    qreal startAngle = 3*PI/2.0 - spanAngle;
+    qreal temp = startAngle - rotationDegree*PI/180.0;
+    normalizeAngleRad(temp);
+    int start = seqLen*temp/(2.0*PI) + 0.5f;
+    int span = seqLen*spanAngle/(double(PI)) + 0.5f;
+    return qMakePair<int,int>(start, span);
+}
+
+void CircularViewRenderArea::drawRuler( QPainter& p ) {
+    p.save();
+    ADVSequenceObjectContext* ctx = view->getSequenceContext();
+    const LRegion& range = ctx->getSequenceObject()->getSequenceRange();
+    int seqLen = range.len;
+    normalizeAngle(rotationDegree);
+
+    if (fitsInView) {
+        drawRulerNotches(p, range.startPos, seqLen, seqLen);
+    } else {
+        const QPair<int,int>& loc = getVisibleRange();
+        int start = loc.first;
+        int span = loc.second;
+        if (start==seqLen) {
+            drawRulerNotches(p, 0, span, seqLen);
+        } else if (start + span > seqLen) {
+            int span1 = seqLen - start;
+            int span2 = start + span - seqLen;
+            assert(span1);
+            assert(span2);
+            drawRulerNotches(p, start, span1, seqLen);
+            drawRulerNotches(p, 0, span2, seqLen);
+        } else {
+            drawRulerNotches(p, start, span, seqLen);
+        }
+    }
+    QPen boldPen(Qt::black);
+    boldPen.setWidth(3);
+    p.setPen(boldPen);
+    QRectF rulerRect(-rulerEllipseSize/2, -rulerEllipseSize/2, rulerEllipseSize, rulerEllipseSize);
+    rulerRect.moveCenter(QPointF(0,0));
+    p.drawEllipse(rulerRect);
+    p.restore();
 }
 
 void CircularViewRenderArea::drawAnnotations(QPainter& p) {
     ADVSequenceObjectContext* ctx = view->getSequenceContext();
 
-    QPen pen1(Qt::SolidLine);
-    pen1.setWidth(1);
     foreach(CircularAnnotationItem* item, circItems) {
         delete item;
     }
@@ -503,12 +736,6 @@ void CircularViewRenderArea::drawAnnotations(QPainter& p) {
         foreach(Annotation* a, ao->getAnnotations()) {
             AnnotationSettings* as = asr->getAnnotationSettings(a->getAnnotationName());
             buildAnnotationItem(DrawAnnotationPass_DrawFill, a, false, as);
-        }
-    }
-    pen1.setWidth(2);
-    foreach(AnnotationTableObject* ao, ctx->getAnnotationObjects()) {
-        foreach(Annotation* a, ao->getAnnotations()) {
-            AnnotationSettings* as = asr->getAnnotationSettings(a->getAnnotationName());
             buildAnnotationLabel(p.font(), a, as);
         }
     }
@@ -641,7 +868,7 @@ void CircularViewRenderArea::buildAnnotationItem(DrawAnnotationPass pass, Annota
 }
 
 void CircularViewRenderArea::buildAnnotationLabel(const QFont& font, Annotation* a, const AnnotationSettings* as) {
-	
+
     if (!as->visible) {
         return;
     }
@@ -662,10 +889,7 @@ void CircularViewRenderArea::buildAnnotationLabel(const QFont& font, Annotation*
     }
 }
 
-LRegion CircularViewRenderArea::getAnnotationYRange(Annotation* a, const LRegion& r, const AnnotationSettings* as) const{
-    Q_UNUSED(a);
-    Q_UNUSED(r);
-    Q_UNUSED(as);
+LRegion CircularViewRenderArea::getAnnotationYRange(Annotation*, int, const AnnotationSettings*) const{
     return LRegion(0,0);
 }
 
@@ -674,9 +898,6 @@ void CircularViewRenderArea::resizeEvent( QResizeEvent *e ) {
     QWidget::resizeEvent(e);
 }
 
-#define MARKER_LEN 30
-#define ARR_LEN 4
-#define ARR_WIDTH 10
 void CircularViewRenderArea::drawMarker(QPainter& p) {
     int yLevel = regionY.count() - 1;
     QPen markerPen;
@@ -715,6 +936,8 @@ void CircularViewRenderArea::drawMarker(QPainter& p) {
 #define LABEL_PAD 30
 void CircularViewRenderArea::evaluateLabelPositions() {
     labelEmptyPositions.clear();
+    labelEmptyInnerPositions.clear();
+
     QFont f;
     QFontMetrics fm(f);
     int labelHeight = fm.height();
@@ -723,10 +946,20 @@ void CircularViewRenderArea::evaluateLabelPositions() {
     int cw = fm.width('O');
 
     int areaHeight = height();
+    
     /*int minAreaHeight = outerEllipseSize + ellipseDelta*lvlsNum;
     areaHeight = qMax(areaHeight, minAreaHeight);*/
 
-    for(int zPos=-areaHeight/2 + labelHeight; zPos<areaHeight/2 - labelHeight; zPos+=labelHeight) {
+    int z0 = -areaHeight/2 + labelHeight;
+    int z1 = areaHeight/2 - labelHeight;
+    if (!fitsInView) {
+        int wH = parentWidget()->height();
+        if (verticalOffset>wH) {
+            z0 = -outerRadius;
+            z1 = -outerRadius*cos(getVisibleAngle());
+        }
+    }
+    for(int zPos=z0; zPos<z1; zPos+=labelHeight) {
         int x = sqrt(float(outerRadius*outerRadius - zPos*zPos));
         if(width()/2-x>0) {
             QRect l_rect(-x - LABEL_PAD, zPos, width()/2-(x+LABEL_PAD), labelHeight);
@@ -735,7 +968,7 @@ void CircularViewRenderArea::evaluateLabelPositions() {
         }
     }
     //inner points
-    labelEmptyInnerPositions.clear();
+    
     int innerRadius = rulerEllipseSize/2 - LABEL_PAD;
     for (int zPos=-innerRadius+labelHeight; zPos<-2*labelHeight; zPos+=labelHeight) {
         int x = sqrt(float(innerRadius*innerRadius - zPos*zPos));
