@@ -12,10 +12,10 @@
 #define __CUDA_SUPPORT_PLUGIN_H__
 
 #include <cuda.h>
-#include <core_api/PluginModel.h>
-#include <core_api/CudaGpuRegistry.h>
+#include <U2Core/PluginModel.h>
+#include <U2Algorithm/CudaGpuRegistry.h>
 
-namespace GB2 {
+namespace U2 {
 
 #define ULOG_CAT_PLUGIN_CUDA_SUPPORT "Plugin: CudaSupport"
 
