@@ -8,16 +8,17 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_DNA_EXPORT_PLUGIN_H_
-#define _GB2_DNA_EXPORT_PLUGIN_H_
+#ifndef _U2_DNA_EXPORT_PLUGIN_H_
+#define _U2_DNA_EXPORT_PLUGIN_H_
 
-#include <core_api/PluginModel.h>
-#include <core_api/ServiceModel.h>
+#include <U2Core/PluginModel.h>
+#include <U2Core/ServiceModel.h>
 
-namespace GB2 {
+namespace U2 {
 
 class ExportProjectViewItemsContoller;
 class ExportSequenceViewItemsController;
+class ExportAlignmentViewItemsController;
 
 class DNAExportPlugin : public Plugin {
     Q_OBJECT
@@ -36,6 +37,7 @@ protected:
 
     ExportProjectViewItemsContoller*    projectViewController;
     ExportSequenceViewItemsController*  sequenceViewController;
+    ExportAlignmentViewItemsController* alignmentViewController;
 
 };
 
