@@ -8,17 +8,20 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_DNA_EXPORT_PLUGIN_TESTS_H_
-#define _GB2_DNA_EXPORT_PLUGIN_TESTS_H_
+#ifndef _U2_DNA_EXPORT_PLUGIN_TESTS_H_
+#define _U2_DNA_EXPORT_PLUGIN_TESTS_H_
 
 
-#include <test_framework/xmltest/XMLTestUtils.h>
-#include <test_framework/xmltest/DocumentModelTests.h>
+#include <U2Test/XMLTestUtils.h>
 #include <QtXml/QDomElement>
+#include <U2Core/LRegion.h>
+#include "ExportTasks.h"
 
-namespace GB2 {
+
+namespace U2 {
 
 class DNASequenceObject;
+class MAlignmentObject;
 
 class GTest_ImportPhredQualityScoresTask : public GTest {
     Q_OBJECT
@@ -33,11 +36,33 @@ public:
 
 };
 
+class GTest_ExportNucleicToAminoAlignmentTask : public GTest {
+    Q_OBJECT
+
+
+public:
+    SIMPLE_XML_TEST_BODY_WITH_FACTORY_EXT(GTest_ExportNucleicToAminoAlignmentTask, "export-nucleic-alignment", TaskFlags_NR_FOSCOE);
+
+    void prepare();
+    ReportResult report();
+    QList<Task*> onSubTaskFinished(Task* subTask);
+
+    int                 transTable;
+    QString             inputFile;
+    QString             outputFileName;
+    QString             expectedOutputFile;
+    LRegion             selectedRows;
+    ExportMSA2MSATask*  exportTask;
+    LoadDocumentTask*   resultLoadTask;
+    MAlignment          srcAl;
+    MAlignment          resAl;
+};
+
 class DNAExportPluginTests {
 public:
     static QList<XMLTestFactory*> createTestFactories();
 };
 
-} // namespace GB2
+} // namespace U2
 
 #endif
