@@ -8,13 +8,13 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_EXPORT_ANNOTATIONS_2_CSV_TASK_H_
-#define _GB2_EXPORT_ANNOTATIONS_2_CSV_TASK_H_
+#ifndef _U2_EXPORT_ANNOTATIONS_2_CSV_TASK_H_
+#define _U2_EXPORT_ANNOTATIONS_2_CSV_TASK_H_
 
-#include <core_api/Task.h>
-#include <core_api/DNATranslation.h>
+#include <U2Core/Task.h>
+#include <U2Core/DNATranslation.h>
 
-namespace GB2 {
+namespace U2 {
 
 class Annotation;
 
@@ -22,10 +22,10 @@ class ExportAnnotations2CSVTask : public Task {
     Q_OBJECT
 public:
     ExportAnnotations2CSVTask(
-		const QList<Annotation*>& annotations, 
-		const QByteArray& sequence, 
-		DNATranslation *complementTranslation, 
-		bool exportSequence, const QString& url);
+        const QList<Annotation*>& annotations,
+        const QByteArray& sequence,
+        DNATranslation *complementTranslation,
+        bool exportSequence, const QString& url);
 
     void run();
 private:
@@ -36,6 +36,6 @@ private:
     QString url;
 };
 
-} // namespace GB2
+} // namespace U2
 
 #endif 
