@@ -8,16 +8,16 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_EXPORT_CHROMATOGRAM_DIALOG_H_
-#define _GB2_EXPORT_CHROMATOGRAM_DIALOG_H_
+#ifndef _U2_EXPORT_CHROMATOGRAM_DIALOG_H_
+#define _U2_EXPORT_CHROMATOGRAM_DIALOG_H_
 
-#include <core_api/core_api.h>
-#include <core_api/GUrl.h>
+#include <U2Core/global.h>
+#include <U2Core/GUrl.h>
 
 #include <QtGui/QDialog>
 #include <ui/ui_ExportChromatogramDialog.h>
 
-namespace GB2 {
+namespace U2 {
 
 class SaveDocumentGroupController;
 
@@ -35,6 +35,9 @@ public:
     bool    addToProjectFlag;
     bool reversed;
     bool complemented;
+    
+private slots:
+    void sl_onBrowseClicked();
 
 private:    
     SaveDocumentGroupController* saveController;
