@@ -8,15 +8,15 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_EXPORT_MSA2SEQ_DIALOG_H_
-#define _GB2_EXPORT_MSA2SEQ_DIALOG_H_
+#ifndef _U2_EXPORT_MSA2SEQ_DIALOG_H_
+#define _U2_EXPORT_MSA2SEQ_DIALOG_H_
 
-#include <core_api/core_api.h>
+#include <U2Core/global.h>
 
 #include <QtGui/QDialog>
 #include <ui/ui_ExportMSA2SequencesDialog.h>
 
-namespace GB2 {
+namespace U2 {
 
 class SaveDocumentGroupController;
 
