@@ -8,15 +8,15 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_EXPORT_PROJECT_VIEW_ITEMS_H_
-#define _GB2_EXPORT_PROJECT_VIEW_ITEMS_H_
+#ifndef _U2_EXPORT_PROJECT_VIEW_ITEMS_H_
+#define _U2_EXPORT_PROJECT_VIEW_ITEMS_H_
 
-#include <core_api/core_api.h>
+#include <U2Core/global.h>
 
 #include <QtGui/QAction>
 #include <QtGui/QMenu>
 
-namespace GB2 {
+namespace U2 {
 
 class ExportProjectViewItemsContoller : public QObject {
     Q_OBJECT
@@ -29,8 +29,10 @@ private slots:
     void sl_saveSequencesToSequenceFormat();
     void sl_saveSequencesAsAlignment();
     void sl_saveAlignmentAsSequences();
+    void sl_exportNucleicAlignmentToAmino();
     void sl_importAnnotationsFromCSV();
     void sl_exportChromatogramToSCF();
+    void sl_exportAnnotationsToCSV();
 
 private:
     void addExportMenu(QMenu& m);
@@ -39,8 +41,10 @@ private:
     QAction* exportSequencesToSequenceFormatAction;
     QAction* exportSequencesAsAlignmentAction;
     QAction* exportAlignmentAsSequencesAction;
+    QAction* exportNucleicAlignmentToAminoAction;
     QAction* importAnnotationsFromCSVAction;
     QAction* exportDNAChromatogramAction;
+    QAction* exportAnnotations2CSV;
 
 };
 
