@@ -10,44 +10,47 @@
 
 #include "ExportSequenceViewItems.h"
 #include "ExportUtils.h"
-#include "ExportTasks.h"
+#include "ExportSequenceTask.h"
 #include "ExportSequencesDialog.h"
 #include "ExportAnnotations2CSVDialog.h"
 #include "ExportAnnotations2CSVTask.h"
 #include "ExportSequences2MSADialog.h"
+#include "GetSequenceByIdDialog.h"
 
-#include <core_api/AppContext.h>
-#include <core_api/DNATranslation.h>
-#include <core_api/DocumentFormats.h>
-#include <core_api/GUrlUtils.h>
-#include <core_api/DocumentUtils.h>
-#include <core_api/L10n.h>
+#include <U2Core/AppContext.h>
+#include <U2Core/DNATranslation.h>
+#include <U2Core/BaseDocumentFormats.h>
+#include <U2Core/GUrlUtils.h>
+#include <U2Core/DocumentUtils.h>
+#include <U2Core/L10n.h>
 
-#include <gobjects/GObjectTypes.h>
-#include <gobjects/AnnotationTableObject.h>
-#include <gobjects/DNASequenceObject.h>
-#include <gobjects/GObjectUtils.h>
-#include <gobjects/MAlignmentObject.h>
+#include <U2Core/GObjectTypes.h>
+#include <U2Core/AnnotationTableObject.h>
+#include <U2Core/DNASequenceObject.h>
+#include <U2Core/GObjectUtils.h>
+#include <U2Core/MAlignmentObject.h>
 
-#include <selection/GObjectSelection.h>
-#include <selection/DocumentSelection.h>
-#include <selection/SelectionUtils.h>
-#include <selection/AnnotationSelection.h>
-#include <selection/DNASequenceSelection.h>
+#include <U2Core/GObjectSelection.h>
+#include <U2Core/DocumentSelection.h>
+#include <U2Core/SelectionUtils.h>
+#include <U2Core/AnnotationSelection.h>
+#include <U2Core/DNASequenceSelection.h>
 
-#include <util_ov_annotated_dna/AnnotatedDNAView.h>
-#include <util_ov_annotated_dna/ADVSequenceObjectContext.h>
-#include <util_ov_annotated_dna/ADVConstants.h>
+#include <U2View/AnnotatedDNAView.h>
+#include <U2View/ADVSequenceObjectContext.h>
+#include <U2View/ADVConstants.h>
 
 
-#include <util_gui/DialogUtils.h>
-#include <util_gui/GUIUtils.h>
-#include <util_text/TextUtils.h>
+#include <U2Misc/DialogUtils.h>
+#include <U2Gui/GUIUtils.h>
+#include <U2Core/TextUtils.h>
+#include <U2Core/LoadRemoteDocumentTask.h>
+#include <U2Gui/OpenViewTask.h>
 
 #include <QtGui/QMainWindow>
 #include <QtGui/QMessageBox>
 
-namespace GB2 {
+namespace U2 {
 
 
 //////////////////////////////////////////////////////////////////////////
@@ -81,24 +84,33 @@ void ExportSequenceViewItemsController::buildMenu(GObjectView* v, QMenu* m) {
 
 
 ADVExportContext::ADVExportContext(AnnotatedDNAView* v) : view(v) {
-    sequence2SequenceAction = new QAction(tr("Export selected sequence region"), this);
+    sequence2SequenceAction = new QAction(tr("Export selected sequence region..."), this);
     connect(sequence2SequenceAction, SIGNAL(triggered()), SLOT(sl_saveSelectedSequences()));
 
-    annotations2SequenceAction = new QAction(tr("Export sequence of selected annotations"), this);
+    annotations2SequenceAction = new QAction(tr("Export sequence of selected annotations..."), this);
     connect(annotations2SequenceAction, SIGNAL(triggered()), SLOT(sl_saveSelectedAnnotationsSequence()));
 
-    annotations2CSVAction = new QAction(tr("Export annotations to CSV format"), this);
+    annotations2CSVAction = new QAction(tr("Export annotations to CSV format..."), this);
     connect(annotations2CSVAction, SIGNAL(triggered()), SLOT(sl_saveSelectedAnnotationsToCSV()));
 
-    annotationsToAlignmentAction = new QAction(QIcon(":core/images/msa.png"), tr("Make an alignment of selected annotations"), this);
+    annotationsToAlignmentAction = new QAction(QIcon(":core/images/msa.png"), tr("Align selected annotations..."), this);
     connect(annotationsToAlignmentAction, SIGNAL(triggered()), SLOT(sl_saveSelectedAnnotationsToAlignment()));
 
-    sequenceToAlignmentAction = new QAction(QIcon(":core/images/msa.png"), tr("Make an alignment of selected sequences"), this);
+    annotationsToAlignmentWithTranslatedAction = new QAction(QIcon(":core/images/msa.png"), tr("Align selected annotations (amino acids)..."), this);
+    connect(annotationsToAlignmentWithTranslatedAction, SIGNAL(triggered()), SLOT(sl_saveSelectedAnnotationsToAlignmentWithTranslation()));
+
+    sequenceToAlignmentAction = new QAction(QIcon(":core/images/msa.png"), tr("Align selected sequence regions..."), this);
     connect(sequenceToAlignmentAction, SIGNAL(triggered()), SLOT(sl_saveSelectedSequenceToAlignment()));
 
-    sequenceToAlignmentWithTranslationAction = new QAction(QIcon(":core/images/msa.png"), tr("Make an alignment of translated sequence"), this);
+    sequenceToAlignmentWithTranslationAction = new QAction(QIcon(":core/images/msa.png"), tr("Align selected sequence regions (amino acids)..."), this);
     connect(sequenceToAlignmentWithTranslationAction, SIGNAL(triggered()), SLOT(sl_saveSelectedSequenceToAlignmentWithTranslation()));
 
+    sequenceById = new QAction(tr("Export sequences by 'id'"), this);
+    connect(sequenceById, SIGNAL(triggered()), SLOT(sl_getSequenceById()));
+    sequenceByAccession = new QAction(tr("Export sequences by 'accession'"), this);
+    connect(sequenceByAccession, SIGNAL(triggered()), SLOT(sl_getSequenceByAccession()));
+    sequenceByDBXref = new QAction(tr("Export sequences by 'db_xref'"), this);
+    connect(sequenceByDBXref, SIGNAL(triggered()), SLOT(sl_getSequenceByDBXref()));
 
     connect(view->getAnnotationsSelection(), 
         SIGNAL(si_selectionChanged(AnnotationSelection*, const QList<Annotation*>&, const QList<Annotation*>& )), 
@@ -145,39 +157,76 @@ static bool allNucleic(const QList<ADVSequenceObjectContext*>& seqs) {
 
 void ADVExportContext::updateActions() {
     bool hasSelectedAnnotations = !view->getAnnotationsSelection()->isEmpty();
+    bool hasSelectedGroups = view->getAnnotationsGroupSelection();
     int nSequenceSelections = 0;
     foreach(ADVSequenceObjectContext* c, view->getSequenceContexts()) {
-        nSequenceSelections += c->getSequenceSelection()->isEmpty() ? 0 : 1;
+        nSequenceSelections += c->getSequenceSelection()->getSelectedRegions().count();
     }
 
     sequence2SequenceAction->setEnabled(nSequenceSelections>=1);
     annotations2SequenceAction->setEnabled(hasSelectedAnnotations);
-    annotations2CSVAction->setEnabled(hasSelectedAnnotations);
+    annotations2CSVAction->setEnabled(hasSelectedAnnotations || hasSelectedGroups);
+
+    bool _allNucleic = allNucleic(view->getSequenceContexts());
 
     bool hasMultipleAnnotationsSelected = view->getAnnotationsSelection()->getSelection().size() > 1;
     annotationsToAlignmentAction->setEnabled(hasMultipleAnnotationsSelected);
+    annotationsToAlignmentWithTranslatedAction->setEnabled(hasMultipleAnnotationsSelected && _allNucleic);
 
     bool hasMultiSequenceSelection = nSequenceSelections > 1;
     sequenceToAlignmentAction->setEnabled(hasMultiSequenceSelection);
-
-    bool _allNucleic = allNucleic(view->getSequenceContexts());
     sequenceToAlignmentWithTranslationAction->setEnabled(hasMultiSequenceSelection && _allNucleic);
 }
 
 void ADVExportContext::buildMenu(QMenu* m) {
-    QMenu* sub = GUIUtils::findSubMenu(m, ADV_MENU_EXPORT);
+    QMenu* alignMenu = GUIUtils::findSubMenu(m, ADV_MENU_ALIGN);
+    alignMenu->addAction(sequenceToAlignmentAction);
+    alignMenu->addAction(sequenceToAlignmentWithTranslationAction);
+    alignMenu->addAction(annotationsToAlignmentAction);
+    alignMenu->addAction(annotationsToAlignmentWithTranslatedAction);
 
-    if (view->getSequenceContexts().size() > 1) {
-        sub->addAction(sequenceToAlignmentAction);
-    }
-    if (sequenceToAlignmentWithTranslationAction->isEnabled()) {
-        sub->addAction(sequenceToAlignmentWithTranslationAction);
-    }
-    sub->addAction(annotationsToAlignmentAction);
+    QMenu* exportMenu = GUIUtils::findSubMenu(m, ADV_MENU_EXPORT);
+    exportMenu->addAction(sequence2SequenceAction);
+    exportMenu->addAction(annotations2SequenceAction);
+    exportMenu->addAction(annotations2CSVAction);
 
-    sub->addAction(sequence2SequenceAction);
-    sub->addAction(annotations2SequenceAction);
-    sub->addAction(annotations2CSVAction);
+    bool isShowId = false;
+    bool isShowAccession = false;
+    bool isShowDBXref = false;
+    QString name;
+    if(!view->getAnnotationsSelection()->getSelection().isEmpty()) {
+        name = view->getAnnotationsSelection()->getSelection().first().annotation->getAnnotationName();
+    }
+    foreach(const AnnotationSelectionData &sel, view->getAnnotationsSelection()->getSelection()) {
+        if(name != sel.annotation->getAnnotationName()) {
+            name = "";
+        }
+        
+        if(!isShowId && !sel.annotation->findFirstQualifierValue("id").isEmpty()) {
+            isShowId = true;
+        } else if(!isShowAccession && !sel.annotation->findFirstQualifierValue("accession").isEmpty()) {
+            isShowAccession = true;
+        } else if(!isShowDBXref && !sel.annotation->findFirstQualifierValue("db_xref").isEmpty()) {
+            isShowDBXref = true;
+        }
+    }
+    if(isShowId || isShowAccession || isShowDBXref) {
+        name = name.isEmpty() ? "" : "from '" + name + "'";
+        QMenu *fetchMenu = new QMenu(tr("Fetch sequences from remote database"));
+        m->insertMenu(exportMenu->menuAction(),fetchMenu);
+        if(isShowId) {
+            sequenceById->setText(tr("Fetch sequences by 'id' %1").arg(name));
+            fetchMenu->addAction(sequenceById);
+        }
+        if(isShowAccession) {
+            sequenceByAccession->setText(tr("Fetch sequences by 'accession' %1").arg(name));
+            fetchMenu->addAction(sequenceByAccession);
+        }
+        if(isShowDBXref) {
+            sequenceByDBXref->setText(tr("Fetch sequences by 'db_xref' %1").arg(name));
+            fetchMenu->addAction(sequenceByDBXref);
+        }
+    }
 }
 
 
@@ -186,7 +235,6 @@ void ADVExportContext::sl_saveSelectedAnnotationsSequence() {
     AnnotationGroupSelection* ags = view->getAnnotationsGroupSelection();
 
     QSet<Annotation*> annotations;
-
     const QList<AnnotationSelectionData>& aData = as->getSelection();
     foreach(const AnnotationSelectionData& ad, aData) {
         annotations.insert(ad.annotation);
@@ -201,31 +249,30 @@ void ADVExportContext::sl_saveSelectedAnnotationsSequence() {
         QMessageBox::warning(view->getWidget(), L10N::warningTitle(), tr("No annotations selected!"));
         return;
     }
-    bool merge = true;
-    QSetIterator<Annotation*> iter(annotations);
-    const bool strand = iter.peekNext()->isOnComplementStrand();
-
+    
     bool allowComplement = true;
     bool allowTranslation = true;
     bool allowBackTranslation = true;
 
-    while (iter.hasNext()) {
-        Annotation* curr = iter.next();
-        if (curr->isOnComplementStrand() != strand) {
-            merge = false;
-        }
-        ADVSequenceObjectContext* seqCtx = view->getSequenceContext(curr->getGObject());
+    QMap<const ADVSequenceObjectContext*, QList<SharedAnnotationData> > annotationsPerSeq;
+    foreach(Annotation* a, annotations) {
+        ADVSequenceObjectContext* seqCtx = view->getSequenceContext(a->getGObject());
         if (seqCtx == NULL) {
             continue;
         }
-        DNASequenceObject* dnaSeq = seqCtx->getSequenceObject();
-        if (GObjectUtils::findComplementTT(dnaSeq) == NULL) {
+        QList<SharedAnnotationData>& annsPerSeq = annotationsPerSeq[seqCtx];
+        annsPerSeq.append(a->data());
+        if (annsPerSeq.size() > 1) {
+            continue;
+        }
+        DNASequenceObject* seqObj = seqCtx->getSequenceObject();
+        if (GObjectUtils::findComplementTT(seqObj) == NULL) {
             allowComplement = false;
         }
-        if (GObjectUtils::findAminoTT(dnaSeq, false) == NULL) {
+        if (GObjectUtils::findAminoTT(seqObj, false) == NULL) {
             allowTranslation = false;
         }
-        if (GObjectUtils::findBackTranslationTT(dnaSeq) == NULL) {
+        if (GObjectUtils::findBackTranslationTT(seqObj) == NULL) {
             allowBackTranslation = false;
         }
     }
@@ -234,67 +281,47 @@ void ADVExportContext::sl_saveSelectedAnnotationsSequence() {
     GUrl seqUrl = view->getSequenceInFocus()->getSequenceGObject()->getDocument()->getURL();
     GUrl defaultUrl = GUrlUtils::rollFileName(seqUrl.dirPath() + "/" + seqUrl.baseFileName() + "_annotation." + fileExt, DocumentUtils::getNewDocFileNameExcludesHint());
 
-    ExportSequencesDialog d(merge, allowComplement, allowTranslation, allowBackTranslation, defaultUrl.getURLString(), BaseDocumentFormats::PLAIN_FASTA, AppContext::getMainWindow()->getQMainWindow());
+    ExportSequencesDialog d(true, allowComplement, allowTranslation, allowBackTranslation, defaultUrl.getURLString(), BaseDocumentFormats::PLAIN_FASTA, AppContext::getMainWindow()->getQMainWindow());
     d.setWindowTitle(annotations2SequenceAction->text());
+    d.disableAllFramesOption(true); // only 1 frame is suitable
+    d.disableStrandOption(true);    // strand is already recorded in annotation
+    d.disableAnnotationsOption(true);   // here we do not export annotations for sequence under another annotations
     int rc = d.exec();
     if (rc == QDialog::Rejected) {
         return;
     }
     assert(d.file.length() > 0);
 
-    QHash<QString, TriState> usedNames;
-    foreach(Annotation* a, annotations) {
-        const QString& name = a->getAnnotationName();
-        usedNames[name] = usedNames.contains(name) ? TriState_Yes : TriState_No;
+    ExportAnnotationSequenceTaskSettings s;
+    ExportUtils::loadDNAExportSettingsFromDlg(s.exportSequenceSettings,d);
+    foreach(const ADVSequenceObjectContext* seqCtx, annotationsPerSeq.keys()) {
+        ExportSequenceAItem ei;
+        DNASequenceObject* seqObj = seqCtx->getSequenceObject();
+        ei.sequence = seqObj->getDNASequence();
+        ei.complTT = seqCtx->getComplementTT();
+        ei.aminoTT = d.translate ? seqCtx->getAminoTT() : NULL;
+        if (d.useSpecificTable && ei.sequence.alphabet->isNucleic()) {
+            DNATranslationRegistry* tr = AppContext::getDNATranslationRegistry();
+            ei.aminoTT = tr->lookupTranslation(seqObj->getAlphabet(), DNATranslationType_NUCL_2_AMINO, d.translationTable);
+        }
+        ei.annotations = annotationsPerSeq.value(seqCtx);
+        s.items.append(ei);
     }
+    Task* t = ExportUtils::wrapExportTask(new ExportAnnotationSequenceTask(s), d.addToProject);
+    AppContext::getTaskScheduler()->registerTopLevelTask(t);
+}
 
-    ExportSequencesTaskSettings s;
-    ExportUtils::loadDNAExportSettingsFromDlg(s,d);
-
-    QList<Annotation*> sortedAnnotations = annotations.toList();
-    qStableSort(sortedAnnotations.begin(), sortedAnnotations.end(), strand ? annotationGreaterThanByRegion : annotationLessThanByRegion);
-
-    foreach(Annotation* a, sortedAnnotations) {
-        ADVSequenceObjectContext* seqCtx = view->getSequenceContext(a->getGObject());
-        if (seqCtx == NULL) {
-            continue;
-        } 
-        DNATranslation* complTT = a->isOnComplementStrand() ? seqCtx->getComplementTT() : NULL;
-        DNATranslation* aminoTT = d.translate ? (d.useSpecificTable ? GObjectUtils::findAminoTT(seqCtx->getSequenceObject(), false, d.translationTable) : seqCtx->getAminoTT()) : NULL;
-        DNATranslation* nucleicTT = d.backTranslate ? GObjectUtils::findBackTranslationTT(seqCtx->getSequenceObject(), d.translationTable) : NULL;
-        LRegion seqReg(0, seqCtx->getSequenceLen());
-        const QByteArray& sequence = seqCtx->getSequenceData();
-
-        const QList<LRegion>& location = a->getLocation();
-        bool multi = location.size() > 1;
-        for (int i=0; i < location.size(); i++) {
-            QString prefix = a->getAnnotationName();
-            if (multi) {
-                prefix+=QString(" part %1 of %2").arg(QString::number(i+1)).arg(QString::number(location.size()));
+static QList<SharedAnnotationData> findAnnotationsInRegion(const LRegion& region, const QList<AnnotationTableObject*>& aobjects) {
+    QList<SharedAnnotationData> result;
+    foreach (const AnnotationTableObject* aobj, aobjects) {
+        foreach(Annotation* a, aobj->getAnnotations()) {
+            LRegion areg = LRegion::containingRegion(a->getLocation());
+            if (region.contains(areg)) {
+                result.append(a->data());
             }
-            QString name = prefix;
-            for (int j=0; usedNames.contains(name) && usedNames.value(name) == TriState_Yes; j++) {
-                name = prefix + "|" + QString::number(j);
-            }
-            usedNames[name] = TriState_Yes;
-            s.names.append(name);
-
-            LRegion reg = location[i].intersect(seqReg);
-            QByteArray partSeq = sequence.mid(reg.startPos, reg.len);//TODO: mid() creates a copy -> optimize!!
-            if (complTT!=NULL) {
-                complTT->translate(partSeq.data(), partSeq.length());
-                TextUtils::reverse(partSeq.data(), partSeq.length()); //todo: do it not in the main thread, but in task!!
-            }
-            s.sequences.append(partSeq);
-            s.alphabets.append(seqCtx->getAlphabet());
-            s.complTranslations.append(complTT);
-            s.aminoTranslations.append(aminoTT);
-            s.nucleicTranslations.append(nucleicTT);
         }
     }
-    assert(s.names.size() > 0);
-    Task* t = ExportUtils::wrapExportTask(new ExportSequencesTask(s), d.addToProject);
-    AppContext::getTaskScheduler()->registerTopLevelTask(t);
+    return result;
 }
 
 void ADVExportContext::sl_saveSelectedSequences() {
@@ -330,22 +357,28 @@ void ADVExportContext::sl_saveSelectedSequences() {
     const QByteArray& sequence = seqCtx->getSequenceData();
     DNAAlphabet* al = seqCtx->getAlphabet();
 
-    ExportSequencesTaskSettings s;
+    ExportSequenceTaskSettings s;
     ExportUtils::loadDNAExportSettingsFromDlg(s,d);
+    QSet<QString> usedNames;
     foreach(const LRegion& r, regions) {
         QString prefix = QString("region [%1 %2]").arg(QString::number(r.startPos+1)).arg(QString::number(r.endPos()));
         QString name = prefix;
-        for (int i=0; s.names.contains(name); i++) {
-            name = prefix + "|" + QString::number(i);
+        for (int i = 0; i < s.items.size(); ++i) {
+            if (usedNames.contains(name)) {
+                name = prefix + "|" + QString::number(i);
+            }
         }
-        s.names.append(name);
-        s.alphabets.append(al);
-        s.sequences.append(QByteArray(sequence.constData() + r.startPos, r.len)); //todo: optimize to avoid copying!!
-        s.complTranslations.append(seqCtx->getComplementTT());
-        s.aminoTranslations.append(d.translate ? (d.useSpecificTable ? GObjectUtils::findAminoTT(seqCtx->getSequenceObject(), false, d.translationTable) : seqCtx->getAminoTT()) : NULL);
-        s.nucleicTranslations.append(d.backTranslate ? GObjectUtils::findBackTranslationTT(seqCtx->getSequenceObject(), d.translationTable) : NULL);
+        usedNames.insert(name);
+        ExportSequenceItem ei;
+        QByteArray seq(sequence.constData() + r.startPos, r.len);
+        ei.sequence = DNASequence(name, seq, al);
+        ei.complTT = seqCtx->getComplementTT();
+        ei.aminoTT = d.translate ? (d.useSpecificTable ? GObjectUtils::findAminoTT(seqCtx->getSequenceObject(), false, d.translationTable) : seqCtx->getAminoTT()) : NULL;
+        ei.backTT = d.backTranslate ? GObjectUtils::findBackTranslationTT(seqCtx->getSequenceObject(), d.translationTable) : NULL;
+        ei.annotations = findAnnotationsInRegion(r, seqCtx->getAnnotationObjects().toList());
+        s.items.append(ei);
     }
-    Task* t = ExportUtils::wrapExportTask(new ExportSequencesTask(s), d.addToProject);
+    Task* t = ExportUtils::wrapExportTask(new ExportSequenceTask(s), d.addToProject);
     AppContext::getTaskScheduler()->registerTopLevelTask(t);
 }
 
@@ -406,6 +439,13 @@ void ADVExportContext::sl_saveSelectedAnnotationsToCSV() {
 
     ExportAnnotations2CSVDialog d(AppContext::getMainWindow()->getQMainWindow());
     d.setWindowTitle(annotations2CSVAction->text());
+    
+    Annotation* first = *annotationSet.begin();
+    const GUrl& url = first->getGObject()->getDocument()->getURL();
+    QString fileName = url.isLocalFile() ? url.getURLString() : url.fileName();
+    fileName += ".csv";
+    d.setFileName(fileName);
+    
     if (QDialog::Accepted != d.exec()) {
         return;
     }
@@ -427,11 +467,11 @@ void ADVExportContext::sl_saveSelectedAnnotationsToCSV() {
 
 #define MAX_ALI_MODEL (10*1000*1000)
 
-QString ADVExportContext::prepareMAFromAnnotations(MAlignment& ma) {
+QString ADVExportContext::prepareMAFromAnnotations(MAlignment& ma, bool translate) {
     assert(ma.isEmpty());
     const QList<AnnotationSelectionData>& selection = view->getAnnotationsSelection()->getSelection();
     if (selection.size() < 2) {
-        return tr("At least 2 sequences required");        
+        return tr("At least 2 annotations are required");        
     }
     // check that all sequences are present and have the same alphabets
     DNAAlphabet* al = NULL;
@@ -449,17 +489,15 @@ QString ADVExportContext::prepareMAFromAnnotations(MAlignment& ma) {
             DNAAlphabet* al2 = seqCtx->getAlphabet();
             //BUG524: support alphabet reduction
             if (al->getType() != al2->getType()) {
-                return tr("Different alphabets");                
+                return tr("Different sequence alphabets");                
             } else if (al != al2) {
                 al = al->getMap().count(true) >= al2->getMap().count(true) ? al : al2;
             }
         }
     }
-
     int maxLen = 0;
     ma.setAlphabet(al);
     QSet<QString> names;
-    //TODO: check if amino translation is needed
     foreach(const AnnotationSelectionData& a, selection) {
         QString rowName = ExportUtils::genUniqueName(names, a.annotation->getAnnotationName());
         AnnotationTableObject* ao = a.annotation->getGObject();
@@ -471,9 +509,11 @@ QString ADVExportContext::prepareMAFromAnnotations(MAlignment& ma) {
             return tr("Alignment is too large");
         }
 
-		QByteArray rowSequence;
-        AnnotationSelection::getAnnotationSequence(rowSequence, a, MAlignment_GapChar, sequence, complTT, NULL);
-		ma.addRow(MAlignmentRow(rowName, rowSequence));
+        bool doComplement = a.annotation->isOnComplementStrand();
+        DNATranslation* aminoTT = translate ? seqCtx->getAminoTT() : NULL;
+        QByteArray rowSequence;
+        AnnotationSelection::getAnnotationSequence(rowSequence, a, MAlignment_GapChar, sequence,  doComplement? complTT : NULL, aminoTT);
+        ma.addRow(MAlignmentRow(rowName, rowSequence));
         names.insert(rowName);
     }
     return "";
@@ -482,24 +522,25 @@ QString ADVExportContext::prepareMAFromAnnotations(MAlignment& ma) {
 QString ADVExportContext::prepareMAFromSequences(MAlignment& ma, bool translate) {
     assert(ma.isEmpty());
 
-    DNAAlphabet* al = translate ? AppContext::getDNAAlphabetRegistry()->findById(BaseDNAAlphabetIds::AMINO_DEFAULT) : NULL;
+    DNAAlphabet* al = translate ? AppContext::getDNAAlphabetRegistry()->findById(BaseDNAAlphabetIds::AMINO_DEFAULT()) : NULL;
 
     //derive alphabet
     int nItems = 0;
+    bool forceTranslation = false;
     foreach(ADVSequenceObjectContext* c, view->getSequenceContexts()) {
         if (c->getSequenceSelection()->isEmpty()) {
             continue;
         }
-        nItems++;
+        nItems += c->getSequenceSelection()->getSelectedRegions().count();
         DNAAlphabet* seqAl = c->getAlphabet();
         if (al == NULL) {
             al = seqAl;
         } else if (al != seqAl) {
             if (al->isNucleic() && seqAl->isAmino()) {
-                translate = true;
+                forceTranslation = true;
                 al = seqAl;
             } else if (al->isAmino() && seqAl->isNucleic()) {
-                translate = true;
+                forceTranslation = true;
             } else {
                 return tr("Can't derive alignment alphabet");
             }
@@ -519,29 +560,28 @@ QString ADVExportContext::prepareMAFromSequences(MAlignment& ma, bool translate)
             continue;
         }
         DNAAlphabet* seqAl = c->getAlphabet();
-        LRegion r = c->getSequenceSelection()->getSelectedRegions().first();
-        const QByteArray& seq = c->getSequenceData();
-        maxLen = qMax(maxLen, r.len);
-        if (maxLen * rows.size() > MAX_ALI_MODEL) {
-            return tr("Alignment is too large");
-        }
-        QByteArray mid = seq.mid(r.startPos, r.len);
-        if (translate && seqAl->isNucleic()) {
-            DNATranslation* aminoTT = c->getAminoTT();
+        DNATranslation* aminoTT = ((translate || forceTranslation) && seqAl->isNucleic()) ? c->getAminoTT() : NULL;
+        foreach(const LRegion& r, c->getSequenceSelection()->getSelectedRegions()) {
+            const QByteArray& seq = c->getSequenceData();
+            maxLen = qMax(maxLen, r.len);
+            if (maxLen * rows.size() > MAX_ALI_MODEL) {
+                return tr("Alignment is too large");
+            }
+            QByteArray mid = seq.mid(r.startPos, r.len);
             if (aminoTT!=NULL) {
                 int len = aminoTT->translate(mid.data(), mid.size());
                 mid.resize(len);
             }
+            MAlignmentRow row(ExportUtils::genUniqueName(names, c->getSequenceGObject()->getGObjectName()), mid);
+            names.insert(row.getName());
+            rows.append(row);
         }
-        MAlignmentRow row(ExportUtils::genUniqueName(names, c->getSequenceGObject()->getGObjectName()), mid);
-        names.insert(row.getName());
-        rows.append(row);
     }
 
     ma.setAlphabet(al);
-	foreach(const MAlignmentRow& row, rows) {
-		ma.addRow(row);
-	}
+    foreach(const MAlignmentRow& row, rows) {
+        ma.addRow(row);
+    }
     return "";
 }
 
@@ -549,7 +589,7 @@ QString ADVExportContext::prepareMAFromSequences(MAlignment& ma, bool translate)
 
 void ADVExportContext::selectionToAlignment(const QString& title, bool annotations, bool translate) {
     MAlignment ma(MA_OBJECT_NAME);
-    QString err = annotations ? prepareMAFromAnnotations(ma) : prepareMAFromSequences(ma, translate);
+    QString err = annotations ? prepareMAFromAnnotations(ma, translate) : prepareMAFromSequences(ma, translate);
     if (!err.isEmpty()) {
         QMessageBox::critical(NULL, L10N::errorTitle(), err);
         return;
@@ -561,6 +601,8 @@ void ADVExportContext::selectionToAlignment(const QString& title, bool annotatio
 
     ExportSequences2MSADialog d(view->getWidget());
     d.setWindowTitle(title);
+    d.setOkButtonText(tr("Create alignment"));
+    d.setFileLabelText(tr("Save alignment to file"));
     int rc = d.exec();
     if (rc != QDialog::Accepted) {
         return;
@@ -574,6 +616,11 @@ void ADVExportContext::sl_saveSelectedAnnotationsToAlignment() {
     selectionToAlignment(annotationsToAlignmentAction->text(), true, false);   
 }
 
+void ADVExportContext::sl_saveSelectedAnnotationsToAlignmentWithTranslation() {
+    selectionToAlignment(annotationsToAlignmentAction->text(), true, true);   
+}
+
+
 void ADVExportContext::sl_saveSelectedSequenceToAlignment() {
     selectionToAlignment(sequenceToAlignmentAction->text(), false, false);   
 }
@@ -582,4 +629,78 @@ void ADVExportContext::sl_saveSelectedSequenceToAlignmentWithTranslation() {
     selectionToAlignment(sequenceToAlignmentWithTranslationAction->text(), false, true);   
 }
 
+void ADVExportContext::sl_getSequenceByDBXref() {
+    const QList<AnnotationSelectionData>& selection = view->getAnnotationsSelection()->getSelection();
+
+    QStringList genbankID ;
+    foreach(const AnnotationSelectionData &sel, selection) {
+        Annotation* ann = sel.annotation;
+        QString tmp  = ann->findFirstQualifierValue("db_xref");
+        if(!tmp.isEmpty()) {
+            genbankID  << tmp.split(":").last();
+        }
+    }
+    QString listId = genbankID.join(",");
+    fetchSequencesFromRemoteDB(listId);
+}
+
+void ADVExportContext::sl_getSequenceByAccession() {
+    const QList<AnnotationSelectionData>& selection = view->getAnnotationsSelection()->getSelection();
+
+    QStringList genbankID ;
+    foreach(const AnnotationSelectionData &sel, selection) {
+        Annotation* ann = sel.annotation;
+        QString tmp  = ann->findFirstQualifierValue("accession");
+        if(!tmp.isEmpty()) {
+            genbankID << tmp;
+        }
+    }
+    QString listId = genbankID.join(",");
+    fetchSequencesFromRemoteDB(listId);
+}
+
+void ADVExportContext::sl_getSequenceById() {
+    const QList<AnnotationSelectionData>& selection = view->getAnnotationsSelection()->getSelection();
+
+    QStringList genbankID ;
+    foreach(const AnnotationSelectionData &sel, selection) {
+        Annotation* ann = sel.annotation;
+        QString tmp = ann->findFirstQualifierValue("id");
+        if(!tmp.isEmpty()) {
+            int off = tmp.indexOf("|");
+            int off1 = tmp.indexOf("|", off + 1);
+            genbankID  << tmp.mid(off + 1, off1 - off - 1);
+        }
+    }
+    QString listId = genbankID.join(",");
+    fetchSequencesFromRemoteDB(listId);
+}
+
+void ADVExportContext::fetchSequencesFromRemoteDB(const QString & listId) {
+    const QList<AnnotationSelectionData>& selection = view->getAnnotationsSelection()->getSelection();
+    AnnotationTableObject *ao = selection.first().annotation->getGObject();
+    DNAAlphabet* seqAl = view->getSequenceObjectsWithContexts().first()->getAlphabet();
+
+    QString db;
+    if(seqAl->getId() == BaseDNAAlphabetIds::NUCL_DNA_DEFAULT()) {
+        db = "NCBI GenBank (DNA sequence)";
+    } else if(seqAl->getId() == BaseDNAAlphabetIds::AMINO_DEFAULT()) {
+        db = "NCBI protein sequence database";
+    } else {
+        return;
+    }
+    
+    GetSequenceByIdDialog dlg(view->getWidget());
+    if(dlg.exec() == QDialog::Accepted) {
+        QString dir = dlg.getDirectory();
+        Task *t;
+        if(dlg.isAddToProject()) {
+            t = new LoadRemoteDocumentAndOpenViewTask(listId, db, dir);
+        } else {
+            t = new LoadRemoteDocumentTask(listId, db, dir);
+        }
+        AppContext::getTaskScheduler()->registerTopLevelTask(t);
+    }
+}
+
 } //namespace
