@@ -8,15 +8,15 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_EXPORT_SEQ2MSA_DIALOG_H_
-#define _GB2_EXPORT_SEQ2MSA_DIALOG_H_
+#ifndef _U2_EXPORT_SEQ2MSA_DIALOG_H_
+#define _U2_EXPORT_SEQ2MSA_DIALOG_H_
 
-#include <core_api/core_api.h>
+#include <U2Core/global.h>
 
 #include <QtGui/QDialog>
 #include <ui/ui_ExportSequences2MSADialog.h>
 
-namespace GB2 {
+namespace U2 {
 
 class SaveDocumentGroupController;
 
@@ -24,6 +24,9 @@ class ExportSequences2MSADialog : public QDialog, Ui_ExportSequences2MSADialog {
     Q_OBJECT
 public:
     ExportSequences2MSADialog(QWidget* p, const QString& defaultUrl = QString() );
+    
+    void setOkButtonText(const QString& text) const;
+    void setFileLabelText(const QString& text) const;
 
     virtual void accept();
 
