@@ -11,21 +11,19 @@
 #include "ExportUtils.h"
 
 #include "ExportSequencesDialog.h"
-#include "ExportTasks.h"
+#include "ExportSequenceTask.h"
 
-namespace GB2 {
+namespace U2 {
 
-void ExportUtils::loadDNAExportSettingsFromDlg(ExportSequencesTaskSettings& s, const ExportSequencesDialog& d)  {
+void ExportUtils::loadDNAExportSettingsFromDlg(ExportSequenceTaskSettings& s, const ExportSequencesDialog& d)  {
     s.fileName = d.file;
     s.merge = d.merge;
     s.mergeGap = d.mergeGap;
-    s.allAminoStrands = d.translateAllFrames;
+    s.allAminoFrames = d.translateAllFrames;
     s.strand = d.strand;
     s.formatId = d.formatId;
-    s.useSpecificTable = d.useSpecificTable;
-    s.translationTable = d.translationTable;
-    s.backTranslate = d.backTranslate;
     s.mostProbable = d.mostProbable;
+    s.saveAnnotations = d.withAnnotations;
 }
 
 Task* ExportUtils::wrapExportTask(AbstractExportTask* t, bool addToProject) {
