@@ -8,30 +8,29 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_EXPORT_UTILS_H_
-#define _GB2_EXPORT_UTILS_H_
+#ifndef _U2_EXPORT_UTILS_H_
+#define _U2_EXPORT_UTILS_H_
 
-#include <core_api/core_api.h>
+#include <U2Core/global.h>
 
 
-namespace GB2 {
+namespace U2 {
 
 class Task;
 class ExportSequencesDialog;
-class ExportSequencesTaskSettings;
+class ExportSequenceTaskSettings;
 class AbstractExportTask;
 
 class ExportUtils: public QObject {
     Q_OBJECT
 public:
 
-    static void loadDNAExportSettingsFromDlg(ExportSequencesTaskSettings& s, const ExportSequencesDialog& d);
+    static void loadDNAExportSettingsFromDlg(ExportSequenceTaskSettings& s, const ExportSequencesDialog& d);
 
     static Task* wrapExportTask(AbstractExportTask* t, bool addToProject);
 
     // generates unique name using prefix + numbers
     static QString genUniqueName(const QSet<QString>& names, QString prefix);
-    
 };
 
 }//namespace
