@@ -8,41 +8,41 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_GRAPHPACK_CUMULATIVE_SKEW_H_
-#define _GB2_GRAPHPACK_CUMULATIVE_SKEW_H_
+#ifndef _U2_GRAPHPACK_CUMULATIVE_SKEW_H_
+#define _U2_GRAPHPACK_CUMULATIVE_SKEW_H_
 
 #include "DNAGraphPackPlugin.h"
 
-#include <util_ov_annotated_dna/GSequenceGraphView.h>
+#include <U2View/GSequenceGraphView.h>
 
 #include <QtGui/QAction>
 #include <QtCore/QList>
 #include <QtCore/QBitArray>
 
-namespace GB2 {
+namespace U2 {
 
 class CumulativeSkewGraphFactory : public GSequenceGraphFactory {
-	Q_OBJECT
+    Q_OBJECT
 public:
-	enum GCumulativeSkewType { GC, AT };
-	CumulativeSkewGraphFactory(GCumulativeSkewType t, QObject* p);
-	virtual QList<GSequenceGraphData*> createGraphs(GSequenceGraphView* v);
+    enum GCumulativeSkewType { GC, AT };
+    CumulativeSkewGraphFactory(GCumulativeSkewType t, QObject* p);
+    virtual QList<GSequenceGraphData*> createGraphs(GSequenceGraphView* v);
     virtual GSequenceGraphDrawer* getDrawer(GSequenceGraphView* v);
-	virtual bool isEnabled(DNASequenceObject* o) const;
+    virtual bool isEnabled(DNASequenceObject* o) const;
 private:
-	QPair<char, char> cumPair;
+    QPair<char, char> cumPair;
 };
 
 class CumulativeSkewGraphAlgorithm : public GSequenceGraphAlgorithm {
 public:
-	CumulativeSkewGraphAlgorithm(const QPair<char, char>& _p);
+    CumulativeSkewGraphAlgorithm(const QPair<char, char>& _p);
     virtual ~CumulativeSkewGraphAlgorithm() {}
 
-	float getValue(int begin, int end, const QByteArray& seq);
-	virtual void calculate(QVector<float>& res, DNASequenceObject* o, const LRegion& r, const GSequenceGraphWindowData* d);
+    float getValue(int begin, int end, const QByteArray& seq);
+    virtual void calculate(QVector<float>& res, DNASequenceObject* o, const LRegion& r, const GSequenceGraphWindowData* d);
 
 private:
-	QPair<char, char> p;
+    QPair<char, char> p;
 };
 
 } // namespace
