@@ -15,22 +15,22 @@
 #include "EntropyAlgorithm.h"
 #include "CumulativeSkew.h"
 
-#include <core_api/MainWindow.h>
-#include <core_api/AppContext.h>
+#include <U2Gui/MainWindow.h>
+#include <U2Core/AppContext.h>
 
-#include <util_ov_annotated_dna/AnnotatedDNAView.h>
-#include <util_ov_annotated_dna/ADVConstants.h>
-#include <util_ov_annotated_dna/ADVSingleSequenceWidget.h>
-#include <util_ov_annotated_dna/ADVSequenceObjectContext.h>
+#include <U2View/AnnotatedDNAView.h>
+#include <U2View/ADVConstants.h>
+#include <U2View/ADVSingleSequenceWidget.h>
+#include <U2View/ADVSequenceObjectContext.h>
 
-#include <util_gui/GUIUtils.h>
+#include <U2Gui/GUIUtils.h>
 
-namespace GB2 {
+namespace U2 {
 
-extern "C" Q_DECL_EXPORT Plugin* GB2_PLUGIN_INIT_FUNC() {
+extern "C" Q_DECL_EXPORT Plugin* U2_PLUGIN_INIT_FUNC() {
     if (AppContext::getMainWindow()) {
         DNAGraphPackPlugin * plug = new DNAGraphPackPlugin();
-	    return plug;
+        return plug;
     }
     return NULL;
 }
@@ -43,15 +43,15 @@ DNAGraphPackPlugin::DNAGraphPackPlugin() : Plugin(tr("dna_graphpack_plugin"), tr
 
 DNAGraphPackViewContext::DNAGraphPackViewContext(QObject* p) : GObjectViewWindowContext(p, ANNOTATED_DNA_VIEW_FACTORY_ID) 
 {
-	graphFactories.append(new BaseContentGraphFactory(BaseContentGraphFactory::GC, this));
-	graphFactories.append(new BaseContentGraphFactory(BaseContentGraphFactory::AG, this));
-	graphFactories.append(new DeviationGraphFactory(DeviationGraphFactory::GC, this));
-	graphFactories.append(new DeviationGraphFactory(DeviationGraphFactory::AT, this));
-	graphFactories.append(new KarlinGraphFactory(this));
+    graphFactories.append(new BaseContentGraphFactory(BaseContentGraphFactory::GC, this));
+    graphFactories.append(new BaseContentGraphFactory(BaseContentGraphFactory::AG, this));
+    graphFactories.append(new DeviationGraphFactory(DeviationGraphFactory::GC, this));
+    graphFactories.append(new DeviationGraphFactory(DeviationGraphFactory::AT, this));
+    graphFactories.append(new KarlinGraphFactory(this));
     graphFactories.append(new EntropyGraphFactory(this));
 
-//	graphFactories.append(new CumulativeSkewGraphFactory(CumulativeSkewGraphFactory::GC, this));
-//	graphFactories.append(new CumulativeSkewGraphFactory(CumulativeSkewGraphFactory::AT, this));
+//    graphFactories.append(new CumulativeSkewGraphFactory(CumulativeSkewGraphFactory::GC, this));
+//    graphFactories.append(new CumulativeSkewGraphFactory(CumulativeSkewGraphFactory::AT, this));
 }
 
 
@@ -94,24 +94,24 @@ void DNAGraphPackViewContext::sl_sequenceWidgetAdded(ADVSequenceWidget* w) {
 }
 
 void DNAGraphPackViewContext::sl_handleGraphAction() {
-	GraphAction* ga = qobject_cast<GraphAction*>(sender());
-	if (ga->isChecked()) {
+    GraphAction* ga = qobject_cast<GraphAction*>(sender());
+    if (ga->isChecked()) {
         assert(ga->view == NULL);
         GraphMenuAction* ma = qobject_cast<GraphMenuAction*>(ga->parent());
         assert(ma!=NULL);
         ADVSingleSequenceWidget* sw = qobject_cast<ADVSingleSequenceWidget*>(ma->seqWidget);
-		ga->view = new GSequenceGraphViewWithFactory(sw, ga->factory);
+        ga->view = new GSequenceGraphViewWithFactory(sw, ga->factory);
         ga->view->setGraphDrawer(ga->factory->getDrawer(ga->view));
-		QList<GSequenceGraphData*> graphs = ga->factory->createGraphs(ga->view);
-		foreach(GSequenceGraphData* g, graphs) {
-			ga->view->addGraphData(g);
-		}
+        QList<GSequenceGraphData*> graphs = ga->factory->createGraphs(ga->view);
+        foreach(GSequenceGraphData* g, graphs) {
+            ga->view->addGraphData(g);
+        }
         sw->addSequenceView(ga->view);
-	} else {
+    } else {
         assert(ga->view != NULL);
-		delete ga->view;
+        delete ga->view;
         ga->view = NULL;
-	}
+    }
 }
 
 
