@@ -11,14 +11,14 @@
 #include "EntropyAlgorithm.h"
 #include "DNAGraphPackPlugin.h"
 
-#include <core_api/DNAAlphabet.h>
-#include <gobjects/DNASequenceObject.h>
-#include <document_format/DNATranslationImpl.h>
-#include <util_text/TextUtils.h>
+#include <U2Core/DNAAlphabet.h>
+#include <U2Core/DNASequenceObject.h>
+#include <U2Core/DNATranslationImpl.h>
+#include <U2Core/TextUtils.h>
 
 #include <math.h>
 
-/* TRANSLATOR GB2::EntropyGraphFactory */
+/* TRANSLATOR U2::EntropyGraphFactory */
 
 /**
  * entropy = sum (p * log(2) p) where p - frequency of dif codons
@@ -26,10 +26,10 @@
  * have entropy lower than random sequence
  **/
 
-namespace GB2 {
+namespace U2 {
 
 static QString nameByType() {
-	return EntropyGraphFactory::tr("informational_entropy");
+    return EntropyGraphFactory::tr("informational_entropy");
 
 }
 
@@ -42,18 +42,18 @@ EntropyGraphFactory::EntropyGraphFactory(QObject* p)
 #define MAX_INDEX_SIZE 512
 
 bool EntropyGraphFactory::isEnabled(DNASequenceObject* o) const {
-	DNAAlphabet* al = o->getAlphabet();
-	return al->isNucleic() && al->getAlphabetChars().size() <= MAX_CHARS_IN_ALPHABET;
+    DNAAlphabet* al = o->getAlphabet();
+    return al->isNucleic() && al->getAlphabetChars().size() <= MAX_CHARS_IN_ALPHABET;
 }
 
 QList<GSequenceGraphData*> EntropyGraphFactory::createGraphs(GSequenceGraphView* v) {
     Q_UNUSED(v);
-	QList<GSequenceGraphData*> res;
-	assert(isEnabled(v->getSequenceObject()));
-	GSequenceGraphData* d = new GSequenceGraphData(getGraphName());
-	d->ga = new EntropyGraphAlgorithm;
-	res.append(d);
-	return res;
+    QList<GSequenceGraphData*> res;
+    assert(isEnabled(v->getSequenceObject()));
+    GSequenceGraphData* d = new GSequenceGraphData(getGraphName());
+    d->ga = new EntropyGraphAlgorithm;
+    res.append(d);
+    return res;
 }
 
 GSequenceGraphDrawer* EntropyGraphFactory::getDrawer(GSequenceGraphView* v) {
@@ -71,10 +71,10 @@ EntropyGraphAlgorithm::EntropyGraphAlgorithm()
 
 void EntropyGraphAlgorithm::calculate(QVector<float>& res, DNASequenceObject* o, const LRegion& vr, const GSequenceGraphWindowData* d) {
     assert(d!=NULL);
-	int nSteps = GSequenceGraphUtils::getNumSteps(vr, d->window, d->step);
-	res.reserve(nSteps);
-	
-	const QByteArray& seq = o->getSequence();
+    int nSteps = GSequenceGraphUtils::getNumSteps(vr, d->window, d->step);
+    res.reserve(nSteps);
+
+    const QByteArray& seq = o->getSequence();
     const DNAAlphabet* al = o->getAlphabet();
     
     // prepare index -> TODO: make it once and cache!
@@ -85,16 +85,16 @@ void EntropyGraphAlgorithm::calculate(QVector<float>& res, DNASequenceObject* o,
     // algorithm
     float log10_2 = log10(2.0);
     const char* seqStr = seq.constData();
-	for (int i = 0; i < nSteps; i++) {
-		int start = vr.startPos + i * d->step;
-		int end = start + d->window;
-		for (int x = start; x < end-2; x++) {
+    for (int i = 0; i < nSteps; i++) {
+        int start = vr.startPos + i * d->step;
+        int end = start + d->window;
+        for (int x = start; x < end-2; x++) {
             int& val = index.mapNC(seqStr + x);
             val++;
-		}
+        }
         //derive entropy from triplets and zero them
         float total = end-start-2;
-		float ent = 0;
+        float ent = 0;
         for (int j = 0; j < indexSize; j++) {
             int ifreq = mapData[j];
             if (ifreq == 0) {
@@ -102,10 +102,10 @@ void EntropyGraphAlgorithm::calculate(QVector<float>& res, DNASequenceObject* o,
             }
             mapData[j] = 0; //zero triplets
             float freq = ifreq / total;
-			ent -= freq*log10(freq)/log10_2;
-		}
-		res.append(ent);
-	}
+            ent -= freq*log10(freq)/log10_2;
+        }
+        res.append(ent);
+    }
 }
 
 } // namespace
