@@ -8,36 +8,36 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_GRAPHPACK_ENTROPY_H_
-#define _GB2_GRAPHPACK_ENTROPY_H_
+#ifndef _U2_GRAPHPACK_ENTROPY_H_
+#define _U2_GRAPHPACK_ENTROPY_H_
 
 #include "DNAGraphPackPlugin.h"
 
-#include <util_ov_annotated_dna/GSequenceGraphView.h>
+#include <U2View/GSequenceGraphView.h>
 
 #include <QtGui/QAction>
 #include <QtCore/QList>
 #include <QtCore/QBitArray>
 
-namespace GB2 {
+namespace U2 {
 
 class AnnotatedDNAView;
 
 class EntropyGraphFactory : public GSequenceGraphFactory {
-	Q_OBJECT
+    Q_OBJECT
 public:
-	EntropyGraphFactory(QObject* p);
-	virtual QList<GSequenceGraphData*> createGraphs(GSequenceGraphView* v);
+    EntropyGraphFactory(QObject* p);
+    virtual QList<GSequenceGraphData*> createGraphs(GSequenceGraphView* v);
     virtual GSequenceGraphDrawer* getDrawer(GSequenceGraphView* v);
-	virtual bool isEnabled(DNASequenceObject* o) const;
+    virtual bool isEnabled(DNASequenceObject* o) const;
 };
 
 class EntropyGraphAlgorithm : public GSequenceGraphAlgorithm {
 public:
-	EntropyGraphAlgorithm();
+    EntropyGraphAlgorithm();
     virtual ~EntropyGraphAlgorithm() {}
 
-	virtual void calculate(QVector<float>& res, DNASequenceObject* o, const LRegion& r, const GSequenceGraphWindowData* d);
+    virtual void calculate(QVector<float>& res, DNASequenceObject* o, const LRegion& r, const GSequenceGraphWindowData* d);
 };
 
 } // namespace
