@@ -10,20 +10,20 @@
 
 #include "KarlinSignatureDifferenceGraph.h"
 
-#include <core_api/DNAAlphabet.h>
-#include <gobjects/DNASequenceObject.h>
-#include <util_text/TextUtils.h>
+#include <U2Core/DNAAlphabet.h>
+#include <U2Core/DNASequenceObject.h>
+#include <U2Core/TextUtils.h>
 #include "DNAGraphPackPlugin.h"
-#include <core_api/AppContext.h>
-#include <core_api/DNAAlphabet.h>
-#include <core_api/DNATranslation.h>
+#include <U2Core/AppContext.h>
+#include <U2Core/DNAAlphabet.h>
+#include <U2Core/DNATranslation.h>
 
 
-/* TRANSLATOR GB2::KarlinGraphFactory */
+/* TRANSLATOR U2::KarlinGraphFactory */
 
-namespace GB2 {
+namespace U2 {
 static QString nameByType() {
-	return KarlinGraphFactory::tr("karlin_signature_difference_graph");
+    return KarlinGraphFactory::tr("karlin_signature_difference_graph");
 
 }
 
@@ -34,18 +34,18 @@ KarlinGraphFactory::KarlinGraphFactory(QObject* p)
 
 //+
 bool KarlinGraphFactory::isEnabled(DNASequenceObject* o) const {
-	DNAAlphabet* al = o->getAlphabet();
-	return al->isNucleic();
+    DNAAlphabet* al = o->getAlphabet();
+    return al->isNucleic();
 }
 
 QList<GSequenceGraphData*> KarlinGraphFactory::createGraphs(GSequenceGraphView* v) {
     Q_UNUSED(v);
-	QList<GSequenceGraphData*> res;
-	assert(isEnabled(v->getSequenceObject()));
-	GSequenceGraphData* d = new GSequenceGraphData(getGraphName());
-	d->ga = new KarlinGraphAlgorithm();
-	res.append(d);
-	return res;
+    QList<GSequenceGraphData*> res;
+    assert(isEnabled(v->getSequenceObject()));
+    GSequenceGraphData* d = new GSequenceGraphData(getGraphName());
+    d->ga = new KarlinGraphAlgorithm();
+    res.append(d);
+    return res;
 }
 //+
 GSequenceGraphDrawer* KarlinGraphFactory::getDrawer(GSequenceGraphView* v) {
@@ -74,64 +74,64 @@ static int getIndex(char nucl)
 //todo:: use limits
 static const float FLOAT_MIN = 0.000000001f;
 
-KarlinGraphAlgorithm::KarlinGraphAlgorithm()	:	global_relative_abundance_values(NULL)
+KarlinGraphAlgorithm::KarlinGraphAlgorithm() : global_relative_abundance_values(NULL)
 {
 }
 KarlinGraphAlgorithm::~KarlinGraphAlgorithm()
 {
-	delete[] global_relative_abundance_values;
+    delete[] global_relative_abundance_values;
 }
 
 void KarlinGraphAlgorithm::calculate(QVector<float>& res, DNASequenceObject* o, const LRegion& vr, const GSequenceGraphWindowData* d) {
-	assert(d!=NULL);
-	int nSteps = GSequenceGraphUtils::getNumSteps(vr, d->window, d->step);
-	res.reserve(nSteps);
+    assert(d!=NULL);
+    int nSteps = GSequenceGraphUtils::getNumSteps(vr, d->window, d->step);
+    res.reserve(nSteps);
 
-	DNAAlphabet* al = o->getAlphabet();
-	assert(al->isNucleic());
+    DNAAlphabet* al = o->getAlphabet();
+    assert(al->isNucleic());
     
     DNATranslationRegistry* tr = AppContext::getDNATranslationRegistry();
-	QList<DNATranslation*> complTs = tr->lookupTranslation(al, DNATranslationType_NUCL_2_COMPLNUCL);
-	assert(!complTs.empty());
+    QList<DNATranslation*> complTs = tr->lookupTranslation(al, DNATranslationType_NUCL_2_COMPLNUCL);
+    assert(!complTs.empty());
 
-	DNATranslation* complTrans = complTs.first();
-	mapTrans = complTrans->getOne2OneMapper();
+    DNATranslation* complTrans = complTs.first();
+    mapTrans = complTrans->getOne2OneMapper();
     
-	const QByteArray& seq = o->getSequence();
-	int seqLen = seq.size();
-	const char* seqc = seq.constData();
-	if (global_relative_abundance_values == NULL)	{
-		global_relative_abundance_values = new float[16];
-		calculateRelativeAbundance(seqc, seqLen, global_relative_abundance_values);
-	}
-	//check!!
-	for (int i = 0; i < nSteps; i++) {
-		int start = vr.startPos + i * d->step;
-		int end = start + d->window;
-		float val = getValue(start, end, seq);
-		res.append(val);
-	}
+    const QByteArray& seq = o->getSequence();
+    int seqLen = seq.size();
+    const char* seqc = seq.constData();
+    if (global_relative_abundance_values == NULL) {
+        global_relative_abundance_values = new float[16];
+        calculateRelativeAbundance(seqc, seqLen, global_relative_abundance_values);
+    }
+    //check!!
+    for (int i = 0; i < nSteps; i++) {
+        int start = vr.startPos + i * d->step;
+        int end = start + d->window;
+        float val = getValue(start, end, seq);
+        res.append(val);
+    }
 }
 
 float KarlinGraphAlgorithm::getValue (int start, int end, const QByteArray& s) {
     float relative_abundance_values[16];
-	calculateRelativeAbundance (s.constData()+start, end - start, relative_abundance_values);
-	float signature_difference = 0;
-	for (int first_base = 0 ; first_base < 4 ; ++first_base) {
-		for (int second_base = 0 ; second_base < 4 ; ++second_base) {
-			int idx = IDX(first_base,  second_base);
-			float global_value = global_relative_abundance_values[idx];
-			float local_value = relative_abundance_values[idx];
-			signature_difference += qAbs(global_value - local_value);
-		}
-	}
-	float res = signature_difference / 16.0;
-	return res;
+    calculateRelativeAbundance (s.constData()+start, end - start, relative_abundance_values);
+    float signature_difference = 0;
+    for (int first_base = 0 ; first_base < 4 ; ++first_base) {
+        for (int second_base = 0 ; second_base < 4 ; ++second_base) {
+            int idx = IDX(first_base,  second_base);
+            float global_value = global_relative_abundance_values[idx];
+            float local_value = relative_abundance_values[idx];
+            signature_difference += qAbs(global_value - local_value);
+        }
+    }
+    float res = signature_difference / 16.0;
+    return res;
 }
 
 void KarlinGraphAlgorithm::calculateRelativeAbundance (const char* seq, int length, float* results) { 
     QByteArray tmp;
-	tmp.resize(length);
+    tmp.resize(length);
 
     int base_counts[4]={0, 0, 0 ,0};
     int dinucleotide_base_counts[16]={0, 0, 0 ,0,  0, 0, 0 ,0,  0, 0, 0 ,0,  0, 0, 0 ,0,};
