@@ -8,21 +8,22 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_DNA_STAT_PLUGIN_H_
-#define _GB2_DNA_STAT_PLUGIN_H_
+#ifndef _U2_DNA_STAT_PLUGIN_H_
+#define _U2_DNA_STAT_PLUGIN_H_
 
-#include <core_api/PluginModel.h>
-#include <core_api/ObjectViewModel.h>
+#include <U2Core/PluginModel.h>
+#include <U2Gui/ObjectViewModel.h>
 
-namespace GB2 {
+namespace U2 {
 
 class DNAStatPlugin : public Plugin {
-	Q_OBJECT
+    Q_OBJECT
 public:
     DNAStatPlugin();
-	
+
 private:
-    GObjectViewWindowContext* viewCtx;
+    GObjectViewWindowContext* statViewCtx;
+    GObjectViewWindowContext* distanceViewCtx;
 };
 
 class DNAStatMSAEditorContext: public GObjectViewWindowContext {
@@ -37,6 +38,18 @@ protected:
     virtual void initViewContext(GObjectView* view);
 };
 
+class DistanceMatrixMSAEditorContext: public GObjectViewWindowContext {
+    Q_OBJECT
+public:
+    DistanceMatrixMSAEditorContext(QObject* p);
+
+protected slots:
+    void sl_showDistanceMatrixDialog();
+    void buildMenu(GObjectView* v, QMenu* m);
+protected:
+    virtual void initViewContext(GObjectView* view);
+};
+
 
 } //namespace
 
