@@ -9,72 +9,88 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/DotPlotDialog.ui" line="27"/>
+        <location filename="../src/ui/DotPlotDialog.ui" line="30"/>
         <source>Dotplot parameters</source>
         <translation>Dotplot параметры</translation>
     </message>
     <message>
-        <location filename="../src/ui/DotPlotDialog.ui" line="49"/>
+        <location filename="../src/ui/DotPlotDialog.ui" line="52"/>
         <source>Custom algorithm</source>
         <translation>Выбранный алгоритм</translation>
     </message>
     <message>
-        <location filename="../src/ui/DotPlotDialog.ui" line="96"/>
+        <location filename="../src/ui/DotPlotDialog.ui" line="99"/>
         <source>X axis sequence</source>
         <translation>Последовательность оси X</translation>
     </message>
     <message>
-        <location filename="../src/ui/DotPlotDialog.ui" line="109"/>
+        <location filename="../src/ui/DotPlotDialog.ui" line="112"/>
         <source>Minimum repeat length</source>
         <translation>Мин длина повторов</translation>
     </message>
     <message>
-        <location filename="../src/ui/DotPlotDialog.ui" line="116"/>
+        <location filename="../src/ui/DotPlotDialog.ui" line="119"/>
         <source>Y axis sequence</source>
         <translation>Последовательность оси Y</translation>
     </message>
     <message>
-        <location filename="../src/ui/DotPlotDialog.ui" line="123"/>
+        <location filename="../src/ui/DotPlotDialog.ui" line="126"/>
         <source>Repeats  identity</source>
         <translation>Идентичность повторов</translation>
     </message>
     <message>
-        <location filename="../src/ui/DotPlotDialog.ui" line="148"/>
+        <location filename="../src/ui/DotPlotDialog.ui" line="151"/>
         <source>bp</source>
         <translation>нк</translation>
     </message>
     <message>
-        <location filename="../src/ui/DotPlotDialog.ui" line="176"/>
+        <location filename="../src/ui/DotPlotDialog.ui" line="179"/>
         <source>Heuristic based selection of repeat length so the number of repeats in the sequence will not exceed 1000</source>
         <translation>Эвристический подбор длины повторов, с тем чтобы кол-во повторов в последовательности не превысило 1000</translation>
     </message>
     <message>
-        <location filename="../src/ui/DotPlotDialog.ui" line="179"/>
+        <location filename="../src/ui/DotPlotDialog.ui" line="182"/>
         <source>1k</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/DotPlotDialog.ui" line="204"/>
+        <location filename="../src/ui/DotPlotDialog.ui" line="207"/>
         <source>%</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/DotPlotDialog.ui" line="226"/>
+        <location filename="../src/ui/DotPlotDialog.ui" line="229"/>
         <source>Resets repeats identity to 100%</source>
         <translation>Сбросить к 100%</translation>
     </message>
     <message>
-        <location filename="../src/ui/DotPlotDialog.ui" line="229"/>
+        <location filename="../src/ui/DotPlotDialog.ui" line="232"/>
         <source>100</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/DotPlotDialog.ui" line="307"/>
+        <location filename="../src/ui/DotPlotDialog.ui" line="287"/>
+        <source>Search inverted repeats</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/ui/DotPlotDialog.ui" line="294"/>
+        <source>Search direct repeats</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/ui/DotPlotDialog.ui" line="333"/>
+        <location filename="../src/ui/DotPlotDialog.ui" line="340"/>
+        <source>default</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/ui/DotPlotDialog.ui" line="383"/>
         <source>OK</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/DotPlotDialog.ui" line="317"/>
+        <location filename="../src/ui/DotPlotDialog.ui" line="393"/>
         <source>Cancel</source>
         <translation>Отмена</translation>
     </message>
@@ -82,75 +98,90 @@
 <context>
     <name>DotPlotFilesDialog</name>
     <message>
-        <location filename="../src/ui/DotPlotFilesDialog.ui" line="23"/>
-        <source>Dotplot</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/ui/DotPlotFilesDialog.ui" line="36"/>
         <source>Open sequences to build dotplot</source>
-        <translation>Выберите последовательности для построения dotplot</translation>
+        <translation type="obsolete">Выберите последовательности для построения dotplot</translation>
     </message>
     <message>
-        <location filename="../src/ui/DotPlotFilesDialog.ui" line="66"/>
-        <location filename="../src/ui/DotPlotFilesDialog.ui" line="73"/>
         <source>File name:</source>
-        <translation>Имя файла:</translation>
+        <translation type="obsolete">Имя файла:</translation>
     </message>
     <message>
-        <location filename="../src/ui/DotPlotFilesDialog.ui" line="90"/>
-        <location filename="../src/ui/DotPlotFilesDialog.ui" line="97"/>
+        <location filename="../src/ui/DotPlotFilesDialog.ui" line="48"/>
+        <location filename="../src/ui/DotPlotFilesDialog.ui" line="142"/>
         <source>...</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/DotPlotFilesDialog.ui" line="118"/>
-        <location filename="../src/ui/DotPlotFilesDialog.ui" line="132"/>
         <source>Merge sequences</source>
-        <translation>Объединить последовательности</translation>
+        <translation type="obsolete">Объединить последовательности</translation>
     </message>
     <message>
-        <location filename="../src/ui/DotPlotFilesDialog.ui" line="139"/>
+        <location filename="../src/ui/DotPlotFilesDialog.ui" line="23"/>
+        <source>Build dotplot from sequences</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/ui/DotPlotFilesDialog.ui" line="38"/>
+        <source>File with first sequence</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/ui/DotPlotFilesDialog.ui" line="55"/>
         <location filename="../src/ui/DotPlotFilesDialog.ui" line="149"/>
+        <source>Join all sequences found in the file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/ui/DotPlotFilesDialog.ui" line="75"/>
+        <location filename="../src/ui/DotPlotFilesDialog.ui" line="169"/>
         <source>Gap size:</source>
         <translation>Длина пропуска:</translation>
     </message>
     <message>
-        <location filename="../src/ui/DotPlotFilesDialog.ui" line="196"/>
+        <location filename="../src/ui/DotPlotFilesDialog.ui" line="108"/>
+        <source>Compare sequence against itself</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/ui/DotPlotFilesDialog.ui" line="128"/>
+        <source>File with second sequence</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/ui/DotPlotFilesDialog.ui" line="219"/>
         <source>Next</source>
         <translation>Далее</translation>
     </message>
     <message>
-        <location filename="../src/ui/DotPlotFilesDialog.ui" line="206"/>
+        <location filename="../src/ui/DotPlotFilesDialog.ui" line="229"/>
         <source>Cancel</source>
         <translation>Отмена</translation>
     </message>
     <message>
-        <location filename="../src/ui/DotPlotFilesDialog.ui" line="125"/>
         <source>One sequence</source>
-        <translation>Одна последовательность</translation>
+        <translation type="obsolete">Одна последовательность</translation>
     </message>
 </context>
 <context>
-    <name>GB2::DotPlotDialog</name>
+    <name>U2::DotPlotDialog</name>
     <message>
-        <location filename="../src/DotPlotDialog.cpp" line="19"/>
+        <location filename="../src/DotPlotDialog.cpp" line="26"/>
         <source>Auto</source>
         <translation>Автовыбор</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotDialog.cpp" line="20"/>
+        <location filename="../src/DotPlotDialog.cpp" line="27"/>
         <source>Suffix index</source>
         <translation>Суффиксный индекс</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotDialog.cpp" line="21"/>
+        <location filename="../src/DotPlotDialog.cpp" line="28"/>
         <source>Diagonals</source>
         <translation>Диагональный</translation>
     </message>
 </context>
 <context>
-    <name>GB2::DotPlotDialogs</name>
+    <name>U2::DotPlotDialogs</name>
     <message>
         <location filename="../src/DotPlotClasses.cpp" line="122"/>
         <source>Task is already running</source>
@@ -162,14 +193,22 @@
         <translation>Задача построения или загрузки dotplot уже запущена</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotClasses.cpp" line="128"/>
         <source>Save DotPlot</source>
-        <translation>Сохранить dotplot</translation>
+        <translation type="obsolete">Сохранить dotplot</translation>
+    </message>
+    <message>
+        <source>Save DotPlot before deletion?</source>
+        <translation type="obsolete">Сохранить dotplot перед удалением?</translation>
     </message>
     <message>
         <location filename="../src/DotPlotClasses.cpp" line="128"/>
-        <source>Save DotPlot before deletion?</source>
-        <translation>Сохранить dotplot перед удалением?</translation>
+        <source>Save dot-plot</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/DotPlotClasses.cpp" line="128"/>
+        <source>Save dot-plot data before closing?</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/DotPlotClasses.cpp" line="134"/>
@@ -198,8 +237,27 @@
     </message>
     <message>
         <location filename="../src/DotPlotClasses.cpp" line="146"/>
+        <source>Current and loading sequences are different. Continue loading dot-plot anyway?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/DotPlotClasses.cpp" line="152"/>
+        <source>Wrong dot-plot file format, loading aborted</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/DotPlotClasses.cpp" line="158"/>
+        <source>Both sequence alphabets must be 4-symbols DNA alphabets</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/DotPlotClasses.cpp" line="164"/>
+        <source>Too many results. Try to increase minimum repeat length</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
         <source>Current and loading sequences are different. Continue loading DotPlot anyway?</source>
-        <translation>Текущие и загружаемые последовательности отличаются. Продолжать загрузку dotplot?</translation>
+        <translation type="obsolete">Текущие и загружаемые последовательности отличаются. Продолжать загрузку dotplot?</translation>
     </message>
     <message>
         <location filename="../src/DotPlotClasses.cpp" line="152"/>
@@ -207,9 +265,8 @@
         <translation>Неправильный формат</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotClasses.cpp" line="152"/>
         <source>Wrong DotPlot file format, loading aborted</source>
-        <translation>Неправильный формат файла dotplot, загрузка прервана</translation>
+        <translation type="obsolete">Неправильный формат файла dotplot, загрузка прервана</translation>
     </message>
     <message>
         <location filename="../src/DotPlotClasses.cpp" line="158"/>
@@ -217,183 +274,213 @@
         <translation>Неправильные типы алфавитов</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotClasses.cpp" line="158"/>
         <source>Both alphabets must be default DNA nucleotide</source>
-        <translation>Оба алфавита должны быть стандартными алфавитами ДНК нуклеотидов</translation>
+        <translation type="obsolete">Оба алфавита должны быть стандартными алфавитами ДНК нуклеотидов</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotClasses.cpp" line="164"/>
         <source>No project</source>
-        <translation>Нет проекта</translation>
+        <translation type="obsolete">Нет проекта</translation>
+    </message>
+    <message>
+        <source>Create or load project first</source>
+        <translation type="obsolete">Создайте или загрузите проект для начала</translation>
     </message>
     <message>
         <location filename="../src/DotPlotClasses.cpp" line="164"/>
-        <source>Create or load project first</source>
-        <translation>Создайте или загрузите проект для начала</translation>
-    </message>
-    <message>
-        <location filename="../src/DotPlotClasses.cpp" line="170"/>
         <source>Too many results</source>
         <translation>Слишком много результатов</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotClasses.cpp" line="170"/>
         <source>Too many results. Try to increase min length</source>
-        <translation>Слишком много результатов. Попробуйте уменьшить минимальную длину повтора</translation>
+        <translation type="obsolete">Слишком много результатов. Попробуйте уменьшить минимальную длину повтора</translation>
     </message>
 </context>
 <context>
-    <name>GB2::DotPlotFilesDialog</name>
+    <name>U2::DotPlotFilesDialog</name>
     <message>
-        <location filename="../src/DotPlotFilesDialog.cpp" line="33"/>
+        <location filename="../src/DotPlotFilesDialog.cpp" line="48"/>
         <source>Open first file</source>
         <translation>Открыть первый файл</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotFilesDialog.cpp" line="50"/>
+        <location filename="../src/DotPlotFilesDialog.cpp" line="65"/>
         <source>Open second file</source>
         <translation>Открыть второй файл</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotFilesDialog.cpp" line="73"/>
+        <location filename="../src/DotPlotFilesDialog.cpp" line="90"/>
         <source>Select files</source>
         <translation>Выберите файлы</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotFilesDialog.cpp" line="73"/>
+        <location filename="../src/DotPlotFilesDialog.cpp" line="90"/>
         <source>Select files first to build dotplot</source>
         <translation>Выберите файлы, чтобы посмотрить dotplot</translation>
     </message>
 </context>
 <context>
-    <name>GB2::DotPlotLoadDocumentsTask</name>
+    <name>U2::DotPlotLoadDocumentsTask</name>
     <message>
-        <location filename="../src/DotPlotTasks.cpp" line="161"/>
+        <location filename="../src/DotPlotTasks.cpp" line="208"/>
         <source>DotPlot loading</source>
         <translation>Dotplot загружается</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotTasks.cpp" line="203"/>
+        <location filename="../src/DotPlotTasks.cpp" line="250"/>
         <source>Detecting format error for file %1</source>
         <translation>Ошибка определения формата файла %1</translation>
     </message>
 </context>
 <context>
-    <name>GB2::DotPlotPlugin</name>
+    <name>U2::DotPlotPlugin</name>
     <message>
-        <location filename="../src/DotPlotPlugin.cpp" line="35"/>
+        <location filename="../src/DotPlotPlugin.cpp" line="36"/>
         <source>Dotplot</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/DotPlotPlugin.cpp" line="35"/>
+        <location filename="../src/DotPlotPlugin.cpp" line="36"/>
         <source>Build dotplot for sequences</source>
         <translation>Построение dotplot для последовательностей</translation>
     </message>
 </context>
 <context>
-    <name>GB2::DotPlotViewAction</name>
+    <name>U2::DotPlotSplitter</name>
     <message>
-        <location filename="../src/DotPlotPlugin.h" line="55"/>
+        <location filename="../src/DotPlotSplitter.cpp" line="27"/>
+        <source>Multiple view synchronization lock</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/DotPlotSplitter.cpp" line="28"/>
+        <source>Keep aspect ratio</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/DotPlotSplitter.cpp" line="29"/>
+        <source>Zoom in (&lt;b&gt; + &lt;/b&gt;)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/DotPlotSplitter.cpp" line="30"/>
+        <source>Zoom out (&lt;b&gt; - &lt;/b&gt;)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/DotPlotSplitter.cpp" line="31"/>
+        <source>Reset zooming (&lt;b&gt;0&lt;/b&gt;)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/DotPlotSplitter.cpp" line="32"/>
+        <source>Select tool (&lt;b&gt;S&lt;/b&gt;)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/DotPlotSplitter.cpp" line="33"/>
+        <source>Hand tool (&lt;b&gt;H&lt;/b&gt;)</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>U2::DotPlotViewAction</name>
+    <message>
+        <location filename="../src/DotPlotPlugin.h" line="58"/>
         <source>Show dot plot</source>
         <translation>Показать dotplot</translation>
     </message>
 </context>
 <context>
-    <name>GB2::DotPlotViewContext</name>
+    <name>U2::DotPlotViewContext</name>
     <message>
-        <location filename="../src/DotPlotPlugin.cpp" line="48"/>
-        <source>Build dotplot</source>
-        <translation>Построить dotplot</translation>
-    </message>
-    <message>
-        <location filename="../src/DotPlotPlugin.cpp" line="173"/>
-        <source>DotPlot</source>
-        <translation>Dotplot</translation>
+        <location filename="../src/DotPlotPlugin.cpp" line="58"/>
+        <location filename="../src/DotPlotPlugin.cpp" line="181"/>
+        <source>Build dotplot...</source>
+        <translation>Построить dotplot...</translation>
     </message>
 </context>
 <context>
-    <name>GB2::DotPlotWidget</name>
+    <name>U2::DotPlotWidget</name>
     <message>
         <source>Settings</source>
         <translation type="obsolete">Настройки</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="54"/>
+        <location filename="../src/DotPlotWidget.cpp" line="86"/>
         <source>Parameters</source>
         <translation>Параметры</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="57"/>
+        <location filename="../src/DotPlotWidget.cpp" line="89"/>
         <source>Save as image</source>
         <translation>Сохранить как изображение</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="60"/>
+        <location filename="../src/DotPlotWidget.cpp" line="92"/>
         <source>Save</source>
         <translation>Сохранить</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="63"/>
+        <location filename="../src/DotPlotWidget.cpp" line="95"/>
         <source>Load</source>
         <translation>Загрузить</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="66"/>
+        <location filename="../src/DotPlotWidget.cpp" line="98"/>
         <source>Remove</source>
         <translation>Удалить</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="69"/>
+        <location filename="../src/DotPlotWidget.cpp" line="160"/>
         <source>Save/Load</source>
         <translation>Сохранить/Загрузить</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="76"/>
+        <location filename="../src/DotPlotWidget.cpp" line="159"/>
         <source>Dotplot</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="234"/>
+        <location filename="../src/DotPlotWidget.cpp" line="400"/>
         <source>Save Dotplot image</source>
         <translation>Сохранение изображения dotplot</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="234"/>
+        <location filename="../src/DotPlotWidget.cpp" line="400"/>
         <source>Image Files (*.png *.jpg *.bmp)</source>
         <translation>Файлы изображений (*.png *.jpg *.bmp)</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="251"/>
+        <location filename="../src/DotPlotWidget.cpp" line="417"/>
         <source>Save Dotplot</source>
         <translation>Сохранить dotplot</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="251"/>
-        <location filename="../src/DotPlotWidget.cpp" line="296"/>
+        <location filename="../src/DotPlotWidget.cpp" line="417"/>
+        <location filename="../src/DotPlotWidget.cpp" line="463"/>
         <source>Dotplot files (*.dpt)</source>
         <translation>Файлы dotplot (*.dpt)</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="296"/>
+        <location filename="../src/DotPlotWidget.cpp" line="463"/>
         <source>Load Dotplot</source>
         <translation>Загрузить dotplot</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="611"/>
+        <location filename="../src/DotPlotWidget.cpp" line="893"/>
         <source>min length</source>
         <translation>Мин длина</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="611"/>
+        <location filename="../src/DotPlotWidget.cpp" line="893"/>
         <source>identity</source>
         <translation>идентичность</translation>
     </message>
 </context>
 <context>
-    <name>GB2::LoadDotPlotTask</name>
+    <name>U2::LoadDotPlotTask</name>
     <message>
-        <location filename="../src/DotPlotTasks.cpp" line="39"/>
+        <location filename="../src/DotPlotTasks.cpp" line="41"/>
         <source>Wrong dotplot format</source>
         <translation>Неправильный формат файла dotplot</translation>
     </message>
@@ -404,7 +491,7 @@
     </message>
 </context>
 <context>
-    <name>GB2::SaveDotPlotTask</name>
+    <name>U2::SaveDotPlotTask</name>
     <message>
         <location filename="../src/DotPlotTasks.h" line="19"/>
         <source>DotPlot saving</source>
