@@ -8,13 +8,13 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_ENZYMES_PLUGIN_H_
-#define _GB2_ENZYMES_PLUGIN_H_
+#ifndef _U2_ENZYMES_PLUGIN_H_
+#define _U2_ENZYMES_PLUGIN_H_
 
-#include <core_api/PluginModel.h>
-#include <core_api/ObjectViewModel.h>
+#include <U2Core/PluginModel.h>
+#include <U2Gui/ObjectViewModel.h>
 
-namespace GB2 {
+namespace U2 {
 
 class EnzymesADVContext;
 
@@ -22,20 +22,29 @@ class EnzymesPlugin : public Plugin  {
     Q_OBJECT
 public:
     EnzymesPlugin();
+    ~EnzymesPlugin();
+    void createToolsMenu();
+private slots:
+    void sl_onOpenDigestSequenceDialog();
+    void sl_onOpenConstructMoleculeDialog();
 private:
     EnzymesADVContext*  ctxADV;
+    QAction* openDigestSequenceDialog;
+    QAction* openConstructMoleculeDialog;
 };
 
 class EnzymesADVContext: public GObjectViewWindowContext {
     Q_OBJECT
 public:
-    EnzymesADVContext(QObject* p);
+    EnzymesADVContext(QObject* p, const QList<QAction*>& cloningActions);
 
 protected slots:
     void sl_search();
 
 protected:
+    virtual void buildMenu(GObjectView* v, QMenu* m);
     virtual void initViewContext(GObjectView* view);
+    QList<QAction*> cloningActions;
 };
 
 } //namespace
