@@ -13,19 +13,19 @@
 #include "EnzymesIO.h"
 #include <limits>
 
-#include <core_api/GObjectReference.h>
-#include <core_api/AppContext.h>
-#include <core_api/Settings.h>
-#include <core_api/Log.h>
-#include <core_api/Timer.h>
+#include <U2Core/GObjectReference.h>
+#include <U2Core/AppContext.h>
+#include <U2Core/Settings.h>
+#include <U2Core/Log.h>
+#include <U2Core/Timer.h>
 
-#include <util_gui/CreateAnnotationWidgetController.h>
-#include <util_gui/DialogUtils.h>
-#include <util_gui/GUIUtils.h>
-#include <util_ov_annotated_dna/ADVSequenceObjectContext.h>
-#include <util_ov_annotated_dna/AnnotatedDNAView.h>
-#include <selection/DNASequenceSelection.h>
-#include <gobjects/DNASequenceObject.h>
+#include <U2Gui/CreateAnnotationWidgetController.h>
+#include <U2Misc/DialogUtils.h>
+#include <U2Gui/GUIUtils.h>
+#include <U2View/ADVSequenceObjectContext.h>
+#include <U2View/AnnotatedDNAView.h>
+#include <U2Core/DNASequenceSelection.h>
+#include <U2Core/DNASequenceObject.h>
 
 #include <QtCore/QCoreApplication>
 #include <QtCore/QFileInfo>
@@ -40,23 +40,15 @@
 //TODO: group by TYPE, ORGANIZM
 //TODO: check whole group (tristate mode)
 
-namespace GB2 {
-
-#define DATA_DIR_KEY            QString("enzymes")
-#define DATA_FILE_KEY           QString("plugin_enzymes/lastFile")
-#define LAST_SELECTION_KEY      QString("plugin_enzymes/selection")
-#define SEP                     (",")
-#define DEFAULT_ENZYMES_FILE    QString("rebase_v003_t2_com.bairoch.gz")
-#define ANY_VALUE -1
-
-static LogCategory log(ULOG_ENZYME_PLUGIN);
-
-QList<SEnzymeData>  FindEnzymesDialog::loadedEnzymes;
-QSet<QString>       FindEnzymesDialog::lastSelection;
+namespace U2 {
 
 
-FindEnzymesDialog::FindEnzymesDialog(ADVSequenceObjectContext* sctx) 
-: QDialog(sctx->getAnnotatedDNAView()->getWidget()), seqCtx(sctx) {
+static Logger log(ULOG_ENZYME_PLUGIN);
+
+QList<SEnzymeData>   EnzymesSelectorWidget::loadedEnzymes;
+QSet<QString>        EnzymesSelectorWidget::lastSelection;
+
+EnzymesSelectorWidget::EnzymesSelectorWidget() {
     setupUi(this);
     ignoreItemChecks = false;
 
@@ -69,27 +61,8 @@ FindEnzymesDialog::FindEnzymesDialog(ADVSequenceObjectContext* sctx)
     tree->setColumnWidth(0, 110); //id
     tree->setColumnWidth(1, 75); //accession
     tree->setColumnWidth(2, 50); //type
-    
-    sbRangeStart->setMaximum(seqCtx->getSequenceLen());
-    sbRangeEnd->setMaximum(seqCtx->getSequenceLen());
-    sbRangeEnd->setValue(seqCtx->getSequenceLen());
-    bool hasSelection = !seqCtx->getSequenceSelection()->isEmpty();
-    rbSelectionRange->setEnabled(hasSelection);
-    rbSelectionRange->setChecked(hasSelection);
+
     totalEnzymes = 0;
-
-    maxHitSB->setMaximum(INT_MAX);
-    minHitSB->setMaximum(INT_MAX);
-
-    maxHitSB->setMinimum(ANY_VALUE);
-    minHitSB->setMinimum(ANY_VALUE);
-
-    minHitSB->setSpecialValueText(tr("Any"));
-    maxHitSB->setSpecialValueText(tr("Any"));
-
-    maxHitSB->setValue(ANY_VALUE);
-    minHitSB->setValue(ANY_VALUE);
-
     minLength = 1;
 
     connect(enzymesFileButton, SIGNAL(clicked()), SLOT(sl_selectFile()));
@@ -100,20 +73,6 @@ FindEnzymesDialog::FindEnzymesDialog(ADVSequenceObjectContext* sctx)
     connect(saveSelectionButton, SIGNAL(clicked()), SLOT(sl_saveSelectionToFile()));
     connect(enzymeInfo, SIGNAL(clicked()), SLOT(sl_openDBPage()));
 
-    CreateAnnotationModel acm;
-    acm.sequenceObjectRef = GObjectReference(sctx->getSequenceGObject());
-    acm.hideAnnotationName = true;
-    acm.hideLocation = true;
-    acm.data->name = "enzyme";
-    acm.sequenceLen = sctx->getSequenceObject()->getSequenceLen();
-    ac = new CreateAnnotationWidgetController(acm, this);
-    QWidget* caw = ac->getWidget();    
-    QVBoxLayout* l = new QVBoxLayout();
-    l->setMargin(0);
-    l->addWidget(caw);
-    annotationsWidget->setLayout(l);
-    annotationsWidget->setMinimumSize(caw->layout()->minimumSize());
-    
     if (loadedEnzymes.isEmpty()) {
         QString lastUsedFile = AppContext::getSettings()->getValue(DATA_FILE_KEY).toString();
         loadFile(lastUsedFile);
@@ -122,12 +81,12 @@ FindEnzymesDialog::FindEnzymesDialog(ADVSequenceObjectContext* sctx)
     }
 }
 
-FindEnzymesDialog::~FindEnzymesDialog() {
+EnzymesSelectorWidget::~EnzymesSelectorWidget() {
     QStringList sl(lastSelection.toList());
     AppContext::getSettings()->setValue(LAST_SELECTION_KEY, sl.join(SEP));
 }
 
-void FindEnzymesDialog::initSettings() {
+void EnzymesSelectorWidget::initSettings() {
     QString dir = DialogUtils::getLastOpenFileDir(DATA_DIR_KEY);
     if (dir.isEmpty() || !QDir(dir).exists()) {
         dir = QDir::searchPaths( PATH_PREFIX_DATA ).first() + "/enzymes/";
@@ -142,7 +101,32 @@ void FindEnzymesDialog::initSettings() {
     lastSelection = selStr.split(SEP).toSet();
 }
 
-void FindEnzymesDialog::loadFile(const QString& url) {
+QList<SEnzymeData> EnzymesSelectorWidget::getSelectedEnzymes() {
+    QList<SEnzymeData> selectedEnzymes;
+    lastSelection.clear();
+    for(int i=0, n = tree->topLevelItemCount(); i<n; i++){
+        EnzymeGroupTreeItem* gi = static_cast<EnzymeGroupTreeItem*>(tree->topLevelItem(i));
+        for (int j=0, m = gi->childCount(); j < m; j++) {
+            EnzymeTreeItem* item = static_cast<EnzymeTreeItem*>(gi->child(j));
+            if (item->checkState(0) == Qt::Checked) {
+                selectedEnzymes.append(item->enzyme);
+                lastSelection.insert(item->enzyme->id);
+            }
+        }
+    }
+    return selectedEnzymes;
+}
+
+QList<SEnzymeData> EnzymesSelectorWidget::getLoadedEnzymes() {
+    if (loadedEnzymes.isEmpty()) {
+        TaskStateInfo ti;
+        QString lastUsedFile = AppContext::getSettings()->getValue(DATA_FILE_KEY).toString();
+        loadedEnzymes = EnzymesIO::readEnzymes(lastUsedFile, ti);
+    }
+    return loadedEnzymes;
+}
+
+void EnzymesSelectorWidget::loadFile(const QString& url) {
     TaskStateInfo ti;
     QList<SEnzymeData> enzymes;
 
@@ -170,12 +154,12 @@ void FindEnzymesDialog::loadFile(const QString& url) {
     setEnzymesList(enzymes);
 }
 
-void FindEnzymesDialog::saveFile(const QString& url) {
+void EnzymesSelectorWidget::saveFile(const QString& url) {
     TaskStateInfo ti;
     QString source = AppContext::getSettings()->getValue(DATA_FILE_KEY).toString();
-    
+
     GTIMER(c1,t1,"FindEnzymesDialog::saveFile [EnzymesIO::writeEnzymes]");
-    
+
     QSet<QString> enzymes;
 
     for(int i=0, n = tree->topLevelItemCount(); i<n; i++){
@@ -189,7 +173,7 @@ void FindEnzymesDialog::saveFile(const QString& url) {
     }
 
     EnzymesIO::writeEnzymes(url, source, enzymes, ti);
-    
+
     if (ti.hasErrors()) {
         if (isVisible()) {
             QMessageBox::critical(NULL, tr("Error"), ti.getError());
@@ -200,16 +184,16 @@ void FindEnzymesDialog::saveFile(const QString& url) {
     }
     if (QMessageBox::question(this, tr("New enzymes database has been saved."),
         tr("Do you want to work with new database?"), QMessageBox::Yes | QMessageBox::No) == QMessageBox::Yes) {
-        loadFile(url);
+            loadFile(url);
     }
 }
 
-void FindEnzymesDialog::setEnzymesList(const QList<SEnzymeData>& enzymes) {
+void EnzymesSelectorWidget::setEnzymesList(const QList<SEnzymeData>& enzymes) {
     tree->setSortingEnabled(false);
     tree->disconnect(this);
     tree->clear();
     totalEnzymes = 0;
-    
+
     GTIMER(c2,t2,"FindEnzymesDialog::loadFile [refill data tree]");
     foreach (const SEnzymeData& enz, enzymes) {
         EnzymeTreeItem* item = new EnzymeTreeItem(enz);
@@ -219,7 +203,7 @@ void FindEnzymesDialog::setEnzymesList(const QList<SEnzymeData>& enzymes) {
         totalEnzymes++;
         EnzymeGroupTreeItem* gi = findGroupItem(enz->id.isEmpty() ? QString(" ") : enz->id.left(1), true);
         gi->addChild(item);
-        
+
     }
     for(int i=0, n = tree->topLevelItemCount(); i<n; i++) {
         EnzymeGroupTreeItem* gi = static_cast<EnzymeGroupTreeItem*>(tree->topLevelItem(i));
@@ -237,15 +221,15 @@ void FindEnzymesDialog::setEnzymesList(const QList<SEnzymeData>& enzymes) {
     connect(tree, SIGNAL(itemChanged(QTreeWidgetItem*,int)), SLOT(sl_itemChanged(QTreeWidgetItem*, int)));
 
 
-//     GTIMER(c4,t4,"FindEnzymesDialog::loadFile [resize tree]");
-//     tree->header()->resizeSections(QHeaderView::ResizeToContents);
-//     t4.stop();
+    //     GTIMER(c4,t4,"FindEnzymesDialog::loadFile [resize tree]");
+    //     tree->header()->resizeSections(QHeaderView::ResizeToContents);
+    //     t4.stop();
 
     updateStatus();
     loadedEnzymes = enzymes;
 }
 
-EnzymeGroupTreeItem* FindEnzymesDialog::findGroupItem(const QString& s, bool create) {
+EnzymeGroupTreeItem* EnzymesSelectorWidget::findGroupItem(const QString& s, bool create) {
     for(int i=0, n = tree->topLevelItemCount(); i<n; i++) {
         EnzymeGroupTreeItem* gi = static_cast<EnzymeGroupTreeItem*>(tree->topLevelItem(i));
         if (gi->s == s) {
@@ -260,7 +244,7 @@ EnzymeGroupTreeItem* FindEnzymesDialog::findGroupItem(const QString& s, bool cre
     return NULL;
 }
 
-void FindEnzymesDialog::updateStatus() {
+void EnzymesSelectorWidget::updateStatus() {
     int nChecked = 0;
     QStringList checkedNamesList;
     for(int i=0, n = tree->topLevelItemCount(); i<n; i++){
@@ -273,10 +257,10 @@ void FindEnzymesDialog::updateStatus() {
     checkedNamesList.sort();
     checkedEnzymesEdit->setPlainText(checkedNamesList.join(","));
 
-    statusLabel->setText(tr("Number of enzymes: %1, selected %2").arg(totalEnzymes).arg(nChecked));
+    emit si_selectionModified(totalEnzymes, nChecked);
 }
 
-void FindEnzymesDialog::sl_selectFile() {
+void EnzymesSelectorWidget::sl_selectFile() {
     LastOpenDirHelper dir(DATA_DIR_KEY);
     dir.url = QFileDialog::getOpenFileName(this, tr("Select enzyme database file"), dir.dir, EnzymesIO::getFileDialogFilter());
     if (!dir.url.isEmpty()) {
@@ -284,7 +268,7 @@ void FindEnzymesDialog::sl_selectFile() {
     }
 }
 
-void FindEnzymesDialog::sl_selectAll() {
+void EnzymesSelectorWidget::sl_selectAll() {
     ignoreItemChecks =  true;
     for(int i=0, n = tree->topLevelItemCount(); i<n; i++){
         EnzymeGroupTreeItem* gi = static_cast<EnzymeGroupTreeItem*>(tree->topLevelItem(i));
@@ -298,7 +282,7 @@ void FindEnzymesDialog::sl_selectAll() {
     updateStatus();
 }
 
-void FindEnzymesDialog::sl_selectNone() {
+void EnzymesSelectorWidget::sl_selectNone() {
     ignoreItemChecks = true;
     for(int i=0, n = tree->topLevelItemCount(); i<n; i++){
         EnzymeGroupTreeItem* gi = static_cast<EnzymeGroupTreeItem*>(tree->topLevelItem(i));
@@ -312,7 +296,7 @@ void FindEnzymesDialog::sl_selectNone() {
     updateStatus();
 }
 
-void FindEnzymesDialog::sl_selectByLength() {
+void EnzymesSelectorWidget::sl_selectByLength() {
     bool ok;
     int len = QInputDialog::getInt(this, tr("Minimum length"), tr("Enter minimum length of recognition sites"), minLength, 1, 20, 1, &ok);
     if (ok) {
@@ -335,7 +319,7 @@ void FindEnzymesDialog::sl_selectByLength() {
     updateStatus();
 }
 
-void FindEnzymesDialog::sl_inverseSelection() {
+void EnzymesSelectorWidget::sl_inverseSelection() {
     ignoreItemChecks = true;
     for(int i=0, n = tree->topLevelItemCount(); i<n; i++){
         EnzymeGroupTreeItem* gi = static_cast<EnzymeGroupTreeItem*>(tree->topLevelItem(i));
@@ -350,7 +334,7 @@ void FindEnzymesDialog::sl_inverseSelection() {
     updateStatus();
 }
 
-void FindEnzymesDialog::sl_saveSelectionToFile() {
+void EnzymesSelectorWidget::sl_saveSelectionToFile() {
     LastOpenDirHelper dir(DATA_DIR_KEY);
     dir.url = QFileDialog::getSaveFileName(this, tr("Select enzyme database file"), dir.dir, EnzymesIO::getFileDialogFilter());
     if (!dir.url.isEmpty()) {
@@ -359,21 +343,96 @@ void FindEnzymesDialog::sl_saveSelectionToFile() {
     updateStatus();
 }
 
-#define MAX_ENZYMES_TO_FIND 100*1000
+void EnzymesSelectorWidget::sl_openDBPage() {
+    QTreeWidgetItem* ci = tree->currentItem();
+    EnzymeTreeItem* item = ci == NULL || ci->parent() == 0 ? NULL : static_cast<EnzymeTreeItem*>(tree->currentItem());
+    if (item == NULL) {
+        QMessageBox::critical(this, tr("Error!"), tr("No enzyme selected!"));
+        return;
+    }
+    QString suffix = item->enzyme->accession;
+    if (suffix.isEmpty()){
+        suffix = item->enzyme->id;
+    } else if (suffix.startsWith("RB")) {
+        suffix = suffix.mid(2);
 
-void FindEnzymesDialog::accept() {
-    QList<SEnzymeData> selectedEnzymes;
-    lastSelection.clear();
+    }
+    GUIUtils::runWebBrowser("http://rebase.neb.com/cgi-bin/reb_get.pl?enzname="+suffix);
+}
+
+void EnzymesSelectorWidget::sl_itemChanged(QTreeWidgetItem* item, int col) {
+    if (item->parent() == NULL  || col != 0 || ignoreItemChecks) {
+        return;
+    }
+    EnzymeTreeItem* ei = static_cast<EnzymeTreeItem*>(item);
+    EnzymeGroupTreeItem* gi = static_cast<EnzymeGroupTreeItem*>(ei->parent());
+    gi->updateVisual();
+    updateStatus();
+}
+
+int EnzymesSelectorWidget::getNumSelected()
+{
+    int nChecked = 0;
     for(int i=0, n = tree->topLevelItemCount(); i<n; i++){
         EnzymeGroupTreeItem* gi = static_cast<EnzymeGroupTreeItem*>(tree->topLevelItem(i));
-        for (int j=0, m = gi->childCount(); j < m; j++) {
-            EnzymeTreeItem* item = static_cast<EnzymeTreeItem*>(gi->child(j));
-            if (item->checkState(0) == Qt::Checked) {
-                selectedEnzymes.append(item->enzyme);
-                lastSelection.insert(item->enzyme->id);
-            }
-        }
+        nChecked+= gi->checkedEnzymes.size();
     }
+    return nChecked;
+}
+
+FindEnzymesDialog::FindEnzymesDialog(ADVSequenceObjectContext* sctx)
+: QDialog(sctx->getAnnotatedDNAView()->getWidget()), seqCtx(sctx) {
+    setupUi(this);
+
+    CreateAnnotationModel acm;
+    acm.sequenceObjectRef = GObjectReference(sctx->getSequenceGObject());
+    acm.hideAnnotationName = true;
+    acm.hideLocation = true;
+    acm.data->name = ANNOTATION_GROUP_ENZYME;
+    acm.sequenceLen = sctx->getSequenceObject()->getSequenceLen();
+    ac = new CreateAnnotationWidgetController(acm, this);
+    QWidget* caw = ac->getWidget();    
+    QVBoxLayout* l = new QVBoxLayout();
+    l->setMargin(0);
+    l->addWidget(caw);
+    annotationsWidget->setLayout(l);
+    annotationsWidget->setMinimumSize(caw->layout()->minimumSize());
+
+    circularButton->setChecked(seqCtx->getSequenceObject()->isCircular());
+
+    maxHitSB->setMaximum(INT_MAX);
+    minHitSB->setMaximum(INT_MAX);
+
+    maxHitSB->setMinimum(ANY_VALUE);
+    minHitSB->setMinimum(ANY_VALUE);
+
+    minHitSB->setValue(1);
+    maxHitSB->setValue(2);
+   
+    sbRangeStart->setMaximum( seqCtx->getSequenceLen() );
+    sbRangeEnd->setMaximum( seqCtx->getSequenceLen() );
+
+    QVBoxLayout* vl = new QVBoxLayout();
+    enzSel = new EnzymesSelectorWidget();
+    vl->setMargin(0);
+    vl->addWidget(enzSel);
+    enzymesSelectorWidget->setLayout(vl);
+    enzymesSelectorWidget->setMinimumSize(enzSel->size());
+
+    connect(enzSel, SIGNAL(si_selectionModified(int,int)), SLOT(sl_onSelectionModified(int,int)));
+    sl_onSelectionModified( enzSel->getTotalNumber(),enzSel->getNumSelected());
+    
+    
+}
+
+#define MAX_ENZYMES_TO_FIND 100*1000
+
+void FindEnzymesDialog::sl_onSelectionModified(int total, int nChecked) {
+    statusLabel->setText(tr("Total number of enzymes: %1, selected %2").arg(total).arg(nChecked));
+}
+
+void FindEnzymesDialog::accept() {
+    QList<SEnzymeData> selectedEnzymes = enzSel->getSelectedEnzymes();
     
     if (selectedEnzymes.isEmpty()) {
         QMessageBox::critical(this, tr("Error!"), tr("No enzymes selected!"));
@@ -399,61 +458,44 @@ void FindEnzymesDialog::accept() {
         return;
     }
 
-    LRegion range;
-    if (rbSequenceRange->isEnabled()) {
-        range = LRegion(0, seqCtx->getSequenceLen());
-    } else if (rbSelectionRange->isEnabled() && !seqCtx->getSequenceSelection()->getSelectedRegions().isEmpty()) {
-        range = seqCtx->getSequenceSelection()->getSelectedRegions().first();
+    QList<LRegion> range;
+    if (rbSequenceRange->isChecked()) {
+        range.append( LRegion(0, seqCtx->getSequenceLen()) );
+    } else if (rbSelectionRange->isChecked() && !seqCtx->getSequenceSelection()->getSelectedRegions().isEmpty()) {
+        range = seqCtx->getSequenceSelection()->getSelectedRegions();
     } else {
-        range.startPos = qMin(sbRangeStart->value(), sbRangeEnd->value());
-        range.len = qMax(sbRangeStart->value(), sbRangeEnd->value()) - range.startPos;
-        if (range.len == 0) {
+        LRegion r;
+        r.startPos = qMin(sbRangeStart->value(), sbRangeEnd->value());
+        r.len = qMax(sbRangeStart->value(), sbRangeEnd->value()) - r.startPos;
+        if (r.len == 0) {
             QMessageBox::critical(this, tr("Error!"), tr("Invalid range!"));
             sbRangeStart->setFocus();
             return;
         }
+        range.append(r);
     }
     ac->prepareAnnotationObject();
     const CreateAnnotationModel& m = ac->getModel();
-    QString group = m.groupName;
     AnnotationTableObject* obj = m.getAnnotationObject();
-    assert(!group.isEmpty() && obj!=NULL);
-    bool circular = circularButton->isChecked();
+    QString groupName = m.groupName;
+    assert(!groupName.isEmpty() && obj!=NULL);
     
-    FindEnzymesToAnnotationsTask* task = new FindEnzymesToAnnotationsTask(obj, group, seqCtx->getSequenceObject()->getDNASequence(),
-                                                    range, selectedEnzymes, MAX_ENZYMES_TO_FIND, minHitVal, maxHitVal, circular); 
+    FindEnzymesTaskConfig cfg;
+
+    cfg.circular = circularButton->isChecked();
+    cfg.groupName = groupName;
+    cfg.region = range;
+    cfg.maxResults = MAX_ENZYMES_TO_FIND;
+    cfg.maxHitCount = maxHitVal;
+    cfg.minHitCount = minHitVal;
+
+    FindEnzymesToAnnotationsTask* task = new FindEnzymesToAnnotationsTask(obj,  seqCtx->getSequenceObject()->getDNASequence(),
+                                                    selectedEnzymes, cfg); 
     AppContext::getTaskScheduler()->registerTopLevelTask(task);
   
     QDialog::accept();
 }
 
-void FindEnzymesDialog::sl_openDBPage() {
-    QTreeWidgetItem* ci = tree->currentItem();
-    EnzymeTreeItem* item = ci == NULL || ci->parent() == 0 ? NULL : static_cast<EnzymeTreeItem*>(tree->currentItem());
-    if (item == NULL) {
-        QMessageBox::critical(this, tr("Error!"), tr("No enzyme selected!"));
-        return;
-    }
-    QString suffix = item->enzyme->accession;
-    if (suffix.isEmpty()){
-        suffix = item->enzyme->id;
-    } else if (suffix.startsWith("RB")) {
-        suffix = suffix.mid(2);
-        
-    }
-    GUIUtils::runWebBrowser("http://rebase.neb.com/cgi-bin/reb_get.pl?enzname="+suffix);
-}
-
-void FindEnzymesDialog::sl_itemChanged(QTreeWidgetItem* item, int col) {
-    if (item->parent() == NULL  || col != 0 || ignoreItemChecks) {
-        return;
-    }
-    EnzymeTreeItem* ei = static_cast<EnzymeTreeItem*>(item);
-    EnzymeGroupTreeItem* gi = static_cast<EnzymeGroupTreeItem*>(ei->parent());
-    gi->updateVisual();
-    updateStatus();
-}
-
 //////////////////////////////////////////////////////////////////////////
 // Tree item
 EnzymeTreeItem::EnzymeTreeItem(const SEnzymeData& ed) 
