@@ -8,19 +8,20 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_GENOME_ALIGNER_PLUGIN_H_
-#define _GB2_GENOME_ALIGNER_PLUGIN_H_
+#ifndef _U2_GENOME_ALIGNER_PLUGIN_H_
+#define _U2_GENOME_ALIGNER_PLUGIN_H_
 
-#include <core_api/PluginModel.h>
+#include <U2Core/PluginModel.h>
 
-namespace GB2 {
+namespace U2 {
 
 class GenomeAlignerPlugin : public Plugin  {
     Q_OBJECT
 public:
     GenomeAlignerPlugin();
+    ~GenomeAlignerPlugin();
 };
 
 } //namespace
 
-#endif // _GB2_GENOME_ALIGNER_PLUGIN_H_
+#endif // _U2_GENOME_ALIGNER_PLUGIN_H_
