@@ -12,18 +12,25 @@
 #define _DIST_MATRIX_MODEL_WIDGET_H_
 
 #include "ui/ui_GenomeAlignerSettings.h"
-#include "util_dna_assembly/DnaAssemblyGUIExtension.h"
+#include "U2View/DnaAssemblyGUIExtension.h"
 
-namespace GB2{
+namespace U2{
 
-class GenomeAlignerSettingsWidget : public DnaAssemblyGUIExtensionWidget, Ui_GenomeAlignerSettings {
+class GenomeAlignerSettingsWidget : public DnaAssemblyAlgorithmMainWidget, Ui_GenomeAlignerSettings {
     Q_OBJECT
 public:
     GenomeAlignerSettingsWidget(QWidget* parent);
     virtual QMap<QString,QVariant> getDnaAssemblyCustomSettings();
-    DNA_ASSEMBLY_GUI_EXTENSION_FACTORY(GenomeAlignerSettingsWidget)
+    virtual bool isIndexOk();
+    virtual void buildIndexUrl(const GUrl& url);
+
+private slots:
+    void sl_onSetIndexFileNameButtonClicked();
+    void sl_onOpenPrebuildIndexFileNameButtonClicked();
+private:
+    QString refUrl;
 };
 
 }
 
-#endif
\ No newline at end of file
+#endif
