@@ -8,21 +8,21 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_ORF_MARKER_PLUGIN_H_
-#define _GB2_ORF_MARKER_PLUGIN_H_
+#ifndef _U2_ORF_MARKER_PLUGIN_H_
+#define _U2_ORF_MARKER_PLUGIN_H_
 
-#include <core_api/PluginModel.h>
-#include <core_api/ObjectViewModel.h>
+#include <U2Core/PluginModel.h>
+#include <U2Gui/ObjectViewModel.h>
 
-namespace GB2 {
+namespace U2 {
 
 class XMLTestFactory;
 
 class ORFMarkerPlugin : public Plugin {
-	Q_OBJECT
+    Q_OBJECT
 public:
     ORFMarkerPlugin();
-	~ORFMarkerPlugin();
+    ~ORFMarkerPlugin();
 
 private:
     GObjectViewWindowContext* viewCtx;
@@ -42,7 +42,7 @@ protected:
 
 class ORFMarkerTests {
 public:
-	static QList<XMLTestFactory*> createTestFactories();
+    static QList<XMLTestFactory*> createTestFactories();
 };
 
 
