@@ -8,24 +8,22 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_ORF_MARKER_TESTS_H_
-#define _GB2_ORF_MARKER_TESTS_H_
+#ifndef _U2_ORF_MARKER_TESTS_H_
+#define _U2_ORF_MARKER_TESTS_H_
 
-#include <test_framework/xmltest/XMLTestUtils.h>
-#include <test_framework/xmltest/XMLTestUtils.h>
-#include <core_api/GObject.h>
+#include <U2Test/XMLTestUtils.h>
+#include <U2Core/GObject.h>
 #include <QtXml/QDomElement>
-#include <test_framework/xmltest/DocumentModelTests.h>
-#include <core_api/LRegion.h>
-#include <gobjects/AnnotationTableObject.h>
-#include <util_ov_annotated_dna/AnnotatedDNAView.h>
-#include <util_algorithm/ORFAlgorithmTask.h>
+#include <U2Core/LRegion.h>
+#include <U2Core/AnnotationTableObject.h>
+#include <U2View/AnnotatedDNAView.h>
+#include <U2Algorithm/ORFAlgorithmTask.h>
 
-#include <core_api/DNAAlphabet.h>
-#include <core_api/DNATranslation.h>
-#include <core_api/AppContext.h>
+#include <U2Core/DNAAlphabet.h>
+#include <U2Core/DNATranslation.h>
+#include <U2Core/AppContext.h>
 
-namespace GB2 {
+namespace U2 {
 
 class GTest_ORFMarkerTask : public GTest {
     Q_OBJECT
