@@ -8,14 +8,14 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_ORF_WORKER_H_
-#define _GB2_ORF_WORKER_H_
+#ifndef _U2_ORF_WORKER_H_
+#define _U2_ORF_WORKER_H_
 
-#include <workflow_library/LocalDomain.h>
-#include <workflow_support/WorkflowUtils.h>
-#include <util_algorithm/ORFFinder.h>
+#include <U2Lang/LocalDomain.h>
+#include <U2Lang/WorkflowUtils.h>
+#include <U2Algorithm/ORFFinder.h>
 
-namespace GB2 {
+namespace U2 {
 
 namespace LocalWorkflow {
 
@@ -59,7 +59,7 @@ public:
     virtual Worker* createWorker(Actor* a) {return new ORFWorker(a);}
 };
 
-}//Workflow namespace
-}//GB2 namespace
+}// Workflow namespace
+}// U2 namespace
 
 #endif
