@@ -10,17 +10,15 @@
 
 #include "RF_SArray_TandemFinder.h"
 #include "RFConstants.h"
-#include <core_api/AppContext.h>
-#include <core_api/AppSettings.h>
-#include <core_api/Log.h>
-#include <core_api/Timer.h>
+#include <U2Core/AppContext.h>
+#include <U2Core/AppSettings.h>
+#include <U2Core/Log.h>
+#include <U2Core/Timer.h>
 #include <QMutexLocker>
-#include <util_tasks/LoadDocumentTask.h>
-#include <util_tasks/CreateAnnotationTask.h>
+#include <U2Core/LoadDocumentTask.h>
+#include <U2Core/CreateAnnotationTask.h>
 
-namespace GB2 {
-
-static LogCategory log(ULOG_CAT_REPEAT_FINDER);
+namespace U2 {
 
 const int FindTandemsTaskSettings::DEFAULT_MIN_REPEAT_COUNT = 0;
 const int FindTandemsTaskSettings::DEFAULT_MIN_TANDEM_SIZE = 9;
@@ -41,11 +39,11 @@ QList<Task*> FindTandemsToAnnotationsTask::onSubTaskFinished(Task* subTask) {
         return res;
     }
 
-	if (qobject_cast<TandemFinder*>(subTask)!=NULL){
-		TandemFinder* tandemFinderTask = qobject_cast<TandemFinder*>(subTask);
+    if (qobject_cast<TandemFinder*>(subTask)!=NULL){
+        TandemFinder* tandemFinderTask = qobject_cast<TandemFinder*>(subTask);
         QList<SharedAnnotationData> annotations = importTandemAnnotations( tandemFinderTask->getResults(), tandemFinderTask->getSettings().seqRegion.startPos,  tandemFinderTask->getSettings().showOverlappedTandems );
         if (!annotations.isEmpty()) {
-            log.info(tr("Found %1 repeat regions").arg(annotations.size()));
+            algoLog.info(tr("Found %1 repeat regions").arg(annotations.size()));
             Task* createTask = new CreateAnnotationsTask(annObjRef, annGroup, annotations);
             createTask->setSubtaskProgressWeight(0);
             res.append(createTask);
@@ -117,11 +115,11 @@ void TandemFinder::prepare(){
 }
 
 void TandemFinder::run(){
-    log.trace(tr("Find tandems finished %1").arg(GTimer::currentTimeMicros()-startTime));
+    algoLog.trace(tr("Find tandems finished %1").arg(GTimer::currentTimeMicros()-startTime));
 }
 
 QList<Task*> TandemFinder::onSubTaskFinished(Task* subTask){
-	if (qobject_cast<SequenceWalkerTask*>(subTask)!=NULL){
+    if (qobject_cast<SequenceWalkerTask*>(subTask)!=NULL){
         setMaxParallelSubtasks(AppContext::getAppSettings()->getAppResourcePool()->getIdealThreadCount());
         return regionTasks;
     }
@@ -155,7 +153,7 @@ void TandemFinder::onRegion(SequenceWalkerSubtask* t, TaskStateInfo& ti){
 }
 
 TandemFinder_Region::~TandemFinder_Region(){
-	QMutexLocker tandemsAccessLocker(&tandemsAccessMutex);
+    QMutexLocker tandemsAccessLocker(&tandemsAccessMutex);
 }
 
 QList<Task*> TandemFinder_Region::onSubTaskFinished(Task* subTask){
@@ -234,9 +232,9 @@ QList<Task*> ConcreteTandemFinder::onSubTaskFinished(Task* subTask){
 }
 
 void ConcreteTandemFinder::cleanup(){
-	if (getSubtasks().size()==0) {
-		return;
-	}
+    if (getSubtasks().size()==0) {
+        return;
+    }
     getSubtasks().first()->cleanup();
 }
 
