@@ -8,19 +8,19 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_REPEAT_PLUGIN_H_
-#define _GB2_REPEAT_PLUGIN_H_
+#ifndef _U2_REPEAT_PLUGIN_H_
+#define _U2_REPEAT_PLUGIN_H_
 
-#include <core_api/PluginModel.h>
-#include <core_api/ObjectViewModel.h>
+#include <U2Core/PluginModel.h>
+#include <U2Gui/ObjectViewModel.h>
 
-namespace GB2 {
+namespace U2 {
 
 class RepeatFinderPlugin : public Plugin {
-	Q_OBJECT
+    Q_OBJECT
 public:
     RepeatFinderPlugin();
-	
+
 private:
     GObjectViewWindowContext* viewCtx;
 };
@@ -32,7 +32,7 @@ public:
 
 protected slots:
     void sl_showDialog();
-	void sl_showTandemDialog();
+    void sl_showTandemDialog();
 
 protected:
     virtual void initViewContext(GObjectView* view);
