@@ -12,16 +12,16 @@
 
 #include "FindRepeatsTask.h"
 #include "RF_SArray_TandemFinder.h"
-#include <util_algorithm/SArrayIndex.h>
-#include <util_algorithm/SArrayBasedFindTask.h>
-#include <core_api/DNAAlphabet.h>
-#include <core_api/AppContext.h>
-#include <gobjects/DNASequenceObject.h>
+#include <U2Algorithm/SArrayIndex.h>
+#include <U2Algorithm/SArrayBasedFindTask.h>
+#include <U2Core/DNAAlphabet.h>
+#include <U2Core/AppContext.h>
+#include <U2Core/DNASequenceObject.h>
 
-#include <core_api/DocumentModel.h>
-#include <core_api/DocumentFormats.h>
+#include <U2Core/DocumentModel.h>
+#include <U2Core/BaseDocumentFormats.h>
 
-namespace GB2 {
+namespace U2 {
 
 #define SEQ_ATTR    "seq"
 #define SEQ2_ATTR   "seq2"
@@ -63,32 +63,32 @@ LRegion GTest_FindSingleSequenceRepeatsTask::parseRegion(const QString& n, const
 }
 
 void GTest_FindSingleSequenceRepeatsTask::init(XMLTestFormat *tf, const QDomElement& el) {
-	Q_UNUSED(tf);
+    Q_UNUSED(tf);
 
-	seq = el.attribute(SEQ_ATTR);
-	if (seq.isEmpty()) {
-		stateInfo.setError(QString("Value not found '%1'").arg(SEQ_ATTR));
-		return;
-	}
-	seq2 = el.attribute(SEQ2_ATTR);
-	if (seq2.isEmpty()) {
-		seq2 = seq;
-	}
+    seq = el.attribute(SEQ_ATTR);
+    if (seq.isEmpty()) {
+        stateInfo.setError(QString("Value not found '%1'").arg(SEQ_ATTR));
+        return;
+    }
+    seq2 = el.attribute(SEQ2_ATTR);
+    if (seq2.isEmpty()) {
+        seq2 = seq;
+    }
     region = parseRegion(REG_ATTR, el);
 
-	QString algStr = el.attribute(ALG_ATTR);
+    QString algStr = el.attribute(ALG_ATTR);
 
-	if (algStr == "suffix") {
-		alg = RFAlgorithm_Suffix;
-	}
-	else {
-		if (algStr == "diagonal") {
-			alg = RFAlgorithm_Diagonal;
-		}
-		else {
-			alg = RFAlgorithm_Auto;
-		}
-	}
+    if (algStr == "suffix") {
+        alg = RFAlgorithm_Suffix;
+    }
+    else {
+        if (algStr == "diagonal") {
+            alg = RFAlgorithm_Diagonal;
+        }
+        else {
+            alg = RFAlgorithm_Auto;
+        }
+    }
 
     minD = el.attribute(MIND_ATTR, "-1").toInt();
     maxD = el.attribute(MAXD_ATTR, "-1").toInt();
@@ -139,20 +139,20 @@ void GTest_FindSingleSequenceRepeatsTask::prepare() {
         return;
     }
     DNASequenceObject * seqObj = getContext<DNASequenceObject>(this, seq);
-	if (seqObj == NULL){
-		stateInfo.setError("can't find sequence1");
-		return;
-	}
+    if (seqObj == NULL){
+        stateInfo.setError("can't find sequence1");
+        return;
+    }
 
-	DNASequenceObject * seq2Obj = seqObj;
+    DNASequenceObject * seq2Obj = seqObj;
 
-	if (seq != seq2) {
-		seq2Obj = getContext<DNASequenceObject>(this, seq2);
-		if (seq2Obj == NULL){
-			stateInfo.setError("can't find sequence2");
-			return;
-		}
-	}
+    if (seq != seq2) {
+        seq2Obj = getContext<DNASequenceObject>(this, seq2);
+        if (seq2Obj == NULL){
+            stateInfo.setError("can't find sequence2");
+            return;
+        }
+    }
 
     if (region.isEmpty()) {
         region = seqObj->getSequenceRange();
@@ -168,12 +168,12 @@ void GTest_FindSingleSequenceRepeatsTask::prepare() {
 
     
     QList<RFAlgorithm> algos;
-	if (alg == RFAlgorithm_Auto) {
-		algos << RFAlgorithm_Diagonal << RFAlgorithm_Suffix;
-	}
-	else {
-		algos << alg;
-	}
+    if (alg == RFAlgorithm_Auto) {
+        algos << RFAlgorithm_Diagonal << RFAlgorithm_Suffix;
+    }
+    else {
+        algos << alg;
+    }
 
     FindRepeatsTaskSettings s;
     s.minLen = w;
@@ -258,38 +258,38 @@ void GTest_FindSingleSequenceRepeatsTask::run() {
 //---------------------------------------------------------------------------------------------------------
 //---------------------------------------------------------------------------------------------------------
 void GTest_FindTandemRepeatsTask::init(XMLTestFormat *tf, const QDomElement& el) {
-	Q_UNUSED(tf);
+    Q_UNUSED(tf);
 
     minD = el.attribute(MIND_ATTR, "-1").toInt();
     maxD = el.attribute(MAXD_ATTR, "-1").toInt();
 
-	minSize = el.attribute("minSize", "3").toInt();
-	repeatCount = el.attribute("repeatCount", "3").toInt();
+    minSize = el.attribute("minSize", "3").toInt();
+    repeatCount = el.attribute("repeatCount", "3").toInt();
 
-	inverted = el.attribute("invert") == "true";
+    inverted = el.attribute("invert") == "true";
     reflect = el.attribute("reflect", "true") == "true";
     filterNested = el.attribute("filterNested", "false") == "true";
 
     results = el.attribute(RESULT_ATTR);
-	sequence = el.attribute("sequence");
+    sequence = el.attribute("sequence");
 }
 
 void GTest_FindTandemRepeatsTask::prepare() {
     if (hasErrors() || isCanceled()) {
         return;
     }
-	//this->getContext(this,"")
-	//new DNAAlphabetRegistryImpl(
-//	TaskResourceUsage* tru = AppContext::getTaskScheduler()->getTaskResources(NULL).constData();
-	DNAAlphabet* alph = AppContext::getDNAAlphabetRegistry()->findById(BaseDNAAlphabetIds::NUCL_DNA_DEFAULT);
-	seqObj = new DNASequence(QString("sequence"), sequence.toAscii(), alph );
-	if (seqObj == NULL){
-		stateInfo.setError("can't find sequence1");
-		return;
-	}
-	string = (char*)(seqObj->constData());
+    //this->getContext(this,"")
+    //new DNAAlphabetRegistryImpl(
+//    TaskResourceUsage* tru = AppContext::getTaskScheduler()->getTaskResources(NULL).constData();
+    DNAAlphabet* alph = AppContext::getDNAAlphabetRegistry()->findById(BaseDNAAlphabetIds::NUCL_DNA_DEFAULT());
+    seqObj = new DNASequence(QString("sequence"), sequence.toAscii(), alph );
+    if (seqObj == NULL){
+        stateInfo.setError("can't find sequence1");
+        return;
+    }
+    string = (char*)(seqObj->constData());
 
-	int maxLen = sequence.length();
+    int maxLen = sequence.length();
     if (minD == -1) {
         minD = -maxLen;
     } 
@@ -302,9 +302,9 @@ void GTest_FindTandemRepeatsTask::prepare() {
 
 
     FindTandemsTaskSettings s;
-	s.minPeriod = minSize;
-	s.minRepeatCount = repeatCount;
-	s.seqRegion = region; 
+    s.minPeriod = minSize;
+    s.minRepeatCount = repeatCount;
+    s.seqRegion = region;
     s.nThreads = 1;//todo: add to settings 
 
     addSubTask( new TandemFinder(s, *seqObj) );
@@ -316,16 +316,16 @@ void GTest_FindTandemRepeatsTask::run() {
     }
     QList<Tandem> expectedResults;
     // load file with results
-	QStringList resList = results.split(';', QString::SkipEmptyParts);
-	foreach(const QString& result, resList){
+    QStringList resList = results.split(';', QString::SkipEmptyParts);
+    foreach(const QString& result, resList){
         QStringList hit = result.split(',', QString::SkipEmptyParts);
         if (hit.size()!=3) {
             stateInfo.setError(QString("Can't parse results line: %1").arg(result));
             return;
         }
-		bool offsetConverted;
+        bool offsetConverted;
         Tandem tnd(hit[0].toInt(&offsetConverted), hit[2].toInt(), hit[1].toInt());
-		if ( !offsetConverted || tnd.size == 0 || tnd.repeatLen==0) {
+        if ( !offsetConverted || tnd.size == 0 || tnd.repeatLen==0) {
             stateInfo.setError(QString("Can't parse results line: %1").arg(result));
             return;
         }
@@ -333,15 +333,15 @@ void GTest_FindTandemRepeatsTask::run() {
     }
 
     //check all subtasks
-	TandemFinder* sub = qobject_cast<TandemFinder*>(this->getSubtasks()[0]);
+    TandemFinder* sub = qobject_cast<TandemFinder*>(this->getSubtasks()[0]);
     QList<Tandem> calcResults = sub->getResults();
     if (expectedResults.size()!=calcResults.size()) {
-		QString results("First results are:\n");
-		for (int i=0, n = qMin(calcResults.size(),3); i < n; i++) {
-			Tandem rc = calcResults[i];
-			results.append(QString("%1 %2 %3\n").arg(rc.offset).arg(rc.size).arg(rc.repeatLen));
-		}
-		stateInfo.setError(QString("Results count not matched, num = %1, expected = %2\n%3").arg(calcResults.size()).arg(expectedResults.size()).arg(results));
+        QString results("First results are:\n");
+        for (int i=0, n = qMin(calcResults.size(),3); i < n; i++) {
+            Tandem rc = calcResults[i];
+            results.append(QString("%1 %2 %3\n").arg(rc.offset).arg(rc.size).arg(rc.repeatLen));
+        }
+        stateInfo.setError(QString("Results count not matched, num = %1, expected = %2\n%3").arg(calcResults.size()).arg(expectedResults.size()).arg(results));
         return;
     }
     qSort(expectedResults);
@@ -350,15 +350,15 @@ void GTest_FindTandemRepeatsTask::run() {
     for (int i=0, n = expectedResults.size(); i < n; i++) {
         Tandem re = expectedResults[i];
         Tandem rc = calcResults[i];
-		if (re.offset!=rc.offset || re.size != rc.size || re.repeatLen!=rc.repeatLen) {
+        if (re.offset!=rc.offset || re.size != rc.size || re.repeatLen!=rc.repeatLen) {
             stateInfo.setError(QString("Results not matched, expected(%1, %2, %3), computed(%4, %5, %6)")
-				.arg(re.offset).arg(re.size).arg(re.repeatLen)
-				.arg(rc.offset).arg(rc.size).arg(rc.repeatLen) );
+                .arg(re.offset).arg(re.size).arg(re.repeatLen)
+                .arg(rc.offset).arg(rc.size).arg(rc.repeatLen) );
             return;
         }
     }
 
-	delete seqObj;
+    delete seqObj;
 }
 
 //---------------------------------------------------------------------------------------------------------
@@ -366,141 +366,141 @@ void GTest_FindTandemRepeatsTask::run() {
 
 
 LRegion GTest_FindRealTandemRepeatsTask::parseRegion(const QString& n, const QDomElement& el) {
-	LRegion res;
-	QString v = el.attribute(n);
-	if (v.isEmpty()) {
-		return res;
-	}
-	int idx = v.indexOf("..");
-	if (idx == -1 || idx+2 >= v.length()) {
-		return res;
-	}
-	QString v1 = v.left(idx);
-	QString v2 = v.mid(idx+2);
-	int startPos = v1.toInt();
-	int endPos = v2.toInt();
-	if (startPos >= 0 && endPos > startPos) {
-		res.startPos = startPos - 1;
-		res.len = endPos - startPos + 1;
-	}
-	return res;
+    LRegion res;
+    QString v = el.attribute(n);
+    if (v.isEmpty()) {
+        return res;
+    }
+    int idx = v.indexOf("..");
+    if (idx == -1 || idx+2 >= v.length()) {
+        return res;
+    }
+    QString v1 = v.left(idx);
+    QString v2 = v.mid(idx+2);
+    int startPos = v1.toInt();
+    int endPos = v2.toInt();
+    if (startPos >= 0 && endPos > startPos) {
+        res.startPos = startPos - 1;
+        res.len = endPos - startPos + 1;
+    }
+    return res;
 }
 
 void GTest_FindRealTandemRepeatsTask::init(XMLTestFormat *tf, const QDomElement& el) {
-	Q_UNUSED(tf);
+    Q_UNUSED(tf);
 
-	minD = el.attribute(MIND_ATTR, "-1").toInt();
-	maxD = el.attribute(MAXD_ATTR, "-1").toInt();
+    minD = el.attribute(MIND_ATTR, "-1").toInt();
+    maxD = el.attribute(MAXD_ATTR, "-1").toInt();
 
-	minSize = el.attribute("minSize", "1").toInt();
-	repeatCount = el.attribute("repeatCount", "3").toInt();
+    minSize = el.attribute("minSize", "1").toInt();
+    repeatCount = el.attribute("repeatCount", "3").toInt();
 
-	inverted = el.attribute("invert") == "true";
-	reflect = el.attribute("reflect", "true") == "true";
-	filterNested = el.attribute("filterNested", "false") == "true";
+    inverted = el.attribute("invert") == "true";
+    reflect = el.attribute("reflect", "true") == "true";
+    filterNested = el.attribute("filterNested", "false") == "true";
 
-	results = el.attribute(RESULT_ATTR);
-	if (results.isEmpty()) {
-		stateInfo.setError(QString("Value not found '%1'").arg(RESULT_ATTR));
-		return;
-	}
+    results = el.attribute(RESULT_ATTR);
+    if (results.isEmpty()) {
+        stateInfo.setError(QString("Value not found '%1'").arg(RESULT_ATTR));
+        return;
+    }
 
-	sequence = el.attribute("sequence");
-	if (sequence.isEmpty()) {
-		stateInfo.setError(QString("Value not found '%1'").arg("sequence"));
-		return;
-	}
+    sequence = el.attribute("sequence");
+    if (sequence.isEmpty()) {
+        stateInfo.setError(QString("Value not found '%1'").arg("sequence"));
+        return;
+    }
 }
 
 void GTest_FindRealTandemRepeatsTask::prepare() {
-	if (hasErrors() || isCanceled()) {
-		return;
-	}
-	DNASequenceObject * seqObj = getContext<DNASequenceObject>(this, sequence);
-	if (seqObj == NULL){
-		stateInfo.setError("can't find sequence1");
-		return;
-	}
-	if (region.isEmpty()) {
-		region = seqObj->getSequenceRange();
-	}
+    if (hasErrors() || isCanceled()) {
+        return;
+    }
+    DNASequenceObject * seqObj = getContext<DNASequenceObject>(this, sequence);
+    if (seqObj == NULL){
+        stateInfo.setError("can't find sequence1");
+        return;
+    }
+    if (region.isEmpty()) {
+        region = seqObj->getSequenceRange();
+    }
 
-	int maxLen = seqObj->getSequenceLen();
-	if (minD == -1) {
-		minD = -maxLen;
-	} 
-	if (maxD == -1) {
-		maxD = maxLen;
-	}
+    int maxLen = seqObj->getSequenceLen();
+    if (minD == -1) {
+        minD = -maxLen;
+    }
+    if (maxD == -1) {
+        maxD = maxLen;
+    }
 
-	FindTandemsTaskSettings s;
-	s.minPeriod = minSize;
-	s.minRepeatCount = repeatCount;
-	s.seqRegion = region; 
-	s.nThreads = 1;//todo: add to settings 
+    FindTandemsTaskSettings s;
+    s.minPeriod = minSize;
+    s.minRepeatCount = repeatCount;
+    s.seqRegion = region;
+    s.nThreads = 1;//todo: add to settings
 
-	addSubTask( new TandemFinder(s, seqObj->getDNASequence()) );
+    addSubTask( new TandemFinder(s, seqObj->getDNASequence()) );
 }
 
 void GTest_FindRealTandemRepeatsTask::run() {
-	if (hasErrors() || isCanceled()) {
-		return;
-	}
-	QList<Tandem> expectedResults;
-	// load file with results
-	QString fname = env->getVar("COMMON_DATA_DIR") + "/" + results;
-	QFile file(fname);
-	if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
-		stateInfo.setError(QString("Can't open results file %1").arg(fname));
-		return;
-	}
+    if (hasErrors() || isCanceled()) {
+        return;
+    }
+    QList<Tandem> expectedResults;
+    // load file with results
+    QString fname = env->getVar("COMMON_DATA_DIR") + "/" + results;
+    QFile file(fname);
+    if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+        stateInfo.setError(QString("Can't open results file %1").arg(fname));
+        return;
+    }
 
-	while (!file.atEnd()) {
-		QString line = file.readLine();
-		QStringList hit = line.split(' ', QString::SkipEmptyParts);
-		if (hit.size()!=5) {
-			stateInfo.setError(QString("Can't parse results line: %1").arg(line));
-			return;
-		}
-		bool h1ok, h2ok, h3ok;
-		Tandem t(hit[0].toInt(&h1ok)-1, hit[3].toInt(&h2ok), hit[2].toInt(&h3ok));
-		if (!h1ok || !h2ok || !h3ok) {
-			stateInfo.setError(QString("Can't parse results line: %1").arg(line));
-			return;
-		}
-		expectedResults.append(t);
-	}
-	file.close();
+    while (!file.atEnd()) {
+        QString line = file.readLine();
+        QStringList hit = line.split(' ', QString::SkipEmptyParts);
+        if (hit.size()!=5) {
+            stateInfo.setError(QString("Can't parse results line: %1").arg(line));
+            return;
+        }
+        bool h1ok, h2ok, h3ok;
+        Tandem t(hit[0].toInt(&h1ok)-1, hit[3].toInt(&h2ok), hit[2].toInt(&h3ok));
+        if (!h1ok || !h2ok || !h3ok) {
+            stateInfo.setError(QString("Can't parse results line: %1").arg(line));
+            return;
+        }
+        expectedResults.append(t);
+    }
+    file.close();
 
-	qSort(expectedResults);
+    qSort(expectedResults);
 
-	//check all subtasks
-	TandemFinder* sub = qobject_cast<TandemFinder*>(this->getSubtasks()[0]);
-	QList<Tandem> calcResults = sub->getResults();
-	QMutableListIterator<Tandem> cIt(calcResults);
-	QMutableListIterator<Tandem> eIt(expectedResults);
-	while (cIt.hasNext() && eIt.hasNext()){
-		Tandem er = eIt.peekNext();
-		Tandem cr = cIt.peekNext();
-		if (er<cr){
-			eIt.next();
-//			eIt.remove();
-		}else if(cr<er){
-			cIt.next();
-			cIt.remove();
-		}else{
-			eIt.next();
-			eIt.remove();
-			cIt.next();
-			cIt.remove();
-		}
-	}
-	if (!expectedResults.isEmpty()){
-		QString result("First of them:\n");
-		Tandem rc = expectedResults[0];
-		result.append(QString("%1 %2 %3\n").arg(rc.offset).arg(rc.size).arg(rc.repeatLen));
-		stateInfo.setError(QString("Not all expected tandems found: total %1\n%2").arg(expectedResults.size()).arg(result));
-	}
+    //check all subtasks
+    TandemFinder* sub = qobject_cast<TandemFinder*>(this->getSubtasks()[0]);
+    QList<Tandem> calcResults = sub->getResults();
+    QMutableListIterator<Tandem> cIt(calcResults);
+    QMutableListIterator<Tandem> eIt(expectedResults);
+    while (cIt.hasNext() && eIt.hasNext()){
+        Tandem er = eIt.peekNext();
+        Tandem cr = cIt.peekNext();
+        if (er<cr){
+            eIt.next();
+//            eIt.remove();
+        }else if(cr<er){
+            cIt.next();
+            cIt.remove();
+        }else{
+            eIt.next();
+            eIt.remove();
+            cIt.next();
+            cIt.remove();
+        }
+    }
+    if (!expectedResults.isEmpty()){
+        QString result("First of them:\n");
+        Tandem rc = expectedResults[0];
+        result.append(QString("%1 %2 %3\n").arg(rc.offset).arg(rc.size).arg(rc.repeatLen));
+        stateInfo.setError(QString("Not all expected tandems found: total %1\n%2").arg(expectedResults.size()).arg(result));
+    }
 }
 
 //---------------------------------------------------------------------------------------------------------
@@ -635,7 +635,7 @@ QList<XMLTestFactory*> RepeatFinderTests::createTestFactories() {
     QList<XMLTestFactory*> res;
     res.append(GTest_FindSingleSequenceRepeatsTask::createFactory());
     res.append(GTest_FindTandemRepeatsTask::createFactory());
-	res.append(GTest_FindRealTandemRepeatsTask::createFactory());
+    res.append(GTest_FindRealTandemRepeatsTask::createFactory());
     res.append( GTest_SArrayBasedFindTask::createFactory() );
     return res;
 }
