@@ -11,9 +11,9 @@
 #ifndef PAIRALIGNMENTSTRINGS_H
 #define PAIRALIGNMENTSTRINGS_H
 
-#include <core_api/LRegion.h>
+#include <U2Core/LRegion.h>
 
-namespace GB2 {
+namespace U2 {
 
 class PairAlignSequences {
 public:
