@@ -10,19 +10,17 @@
 
 #include "SWTaskFactory.h"
 
-namespace GB2 {
+namespace U2 {
 
-    SWTaskFactory::SWTaskFactory(AlgType _algType)
-    {
-        algType = _algType;
-    }
+SWTaskFactory::SWTaskFactory(SW_AlgType _algType) {
+    algType = _algType;
+}
 
-    SWTaskFactory::~SWTaskFactory()
-    {
-    }
+SWTaskFactory::~SWTaskFactory() {
+}
 
-    Task* SWTaskFactory::getTaskInstance( const SmithWatermanSettings& config, const QString& taskName) const {            
-            return new SWAlgorithmTask(config, taskName, algType);
-    }
+Task* SWTaskFactory::getTaskInstance( const SmithWatermanSettings& config, const QString& taskName) const {            
+    return new SWAlgorithmTask(config, taskName, algType);
+}
 
 } // namespace
