@@ -15,7 +15,7 @@
 
 #include "SmithWatermanAlgorithm.h"
 
-namespace GB2 {
+namespace U2 {
 
 class SmithWatermanAlgorithmCUDA : public SmithWatermanAlgorithm {
 public:
