@@ -12,17 +12,14 @@
 
 #include "SmithWatermanAlgorithmSSE2.h"
 
-#include <core_api/Log.h>
-
 #include <emmintrin.h>
 #include <iostream>
 
 using namespace std;
 
-namespace GB2 {
+namespace U2 {
+    
     
-    static LogCategory log(ULOG_CAT_SW);
-
 //     static bool PRINT_DIRECTIONS = false;
 //     static bool PRINT_SCORE = false;
 //     static bool PRINT_JUST_SCORE = false;
@@ -31,34 +28,26 @@ namespace GB2 {
 //     static bool PRINT_F_SHIFT = false;
 //     static bool PRINT_H = false;
 
-    void SmithWatermanAlgorithmSSE2::launch(const SMatrix& _substitutionMatrix, QByteArray const & _patternSeq, QByteArray const & _searchSeq, int _gapOpen, int _gapExtension, int _minScore) {
-    
-        log.details("START SmithWatermanAlgorithmSSE2::launch");
-        setValues(_substitutionMatrix, _patternSeq, _searchSeq, _gapOpen, _gapExtension, _minScore);
+void SmithWatermanAlgorithmSSE2::launch(const SMatrix& _substitutionMatrix, QByteArray const & _patternSeq, QByteArray const & _searchSeq, int _gapOpen, int _gapExtension, int _minScore) {
+    setValues(_substitutionMatrix, _patternSeq, _searchSeq, _gapOpen, _gapExtension, _minScore);
+    int maxScor = 0;
+    if (isValidParams() && calculateMatrixLength()) {
+        maxScor = calculateMatrixSSE2(patternSeq.length(),(unsigned char *)searchSeq.data(), searchSeq.length(), (-1)*(gapOpen + gapExtension), (-1)*(gapExtension));
 
-        int maxScor = 0;
-        if (isValidParams() && calculateMatrixLength()) {
-            maxScor = calculateMatrixSSE2(patternSeq.length(),(unsigned char *)searchSeq.data(), searchSeq.length(), (-1)*(gapOpen + gapExtension), (-1)*(gapExtension));
-
-            if (minScore <= maxScor) {
-                calculateMatrix();
-            }            
-        }
-        else {
-            //No result
-            // See validationParams();
-            //Perhaps reason: minScore > maxScore 
-            //  or gap_open >= 0 or gap_extension >= 0
-        }
-
-        log.details("FINISH SmithWatermanAlgorithmSSE2::launch");
+        if (minScore <= maxScor) {
+            calculateMatrix();
+        }            
+    } else {
+        //No result
+        // See validationParams();
+        //Perhaps reason: minScore > maxScore 
+        //  or gap_open >= 0 or gap_extension >= 0
     }
+}
 
 //Calculating dynamic matrix
 //and save results
 void SmithWatermanAlgorithmSSE2::calculateMatrix() {
-    log.info("RUN calculateMatrix()");
-
     char ch;
     //ScoreType substValue = 0; //warning: unused variable substValue
     ScoreType max = 0;
@@ -189,7 +178,7 @@ void SmithWatermanAlgorithmSSE2::calculateMatrix() {
 
         directionSearchSeq[odd][0] = i - 1;
 
-		p.score = 0;
+        p.score = 0;
 
         for (int j = 0; j < patternSeq.length(); j += nElementsInVec) {                            
 //TODO: use __m128i*, not array
@@ -219,9 +208,9 @@ void SmithWatermanAlgorithmSSE2::calculateMatrix() {
             _mm_store_si128((__m128i*) &maxArray[0], maxVec);
 
 
-//Use non vector operations for calculate maxScore and backtrace			
+//Use non vector operations for calculate maxScore and backtrace
             for (int pp = j; pp < j + nElementsInVec && pp < patternSeq.length(); pp++) {
-				int eIndex = pp + 1;
+                int eIndex = pp + 1;
                 ee1 = EArray[eIndex - 1] + gapExtension;                
                 ee2 = matrix[getRow(i)][pp - 1] + gapOpen;
 
@@ -250,15 +239,15 @@ void SmithWatermanAlgorithmSSE2::calculateMatrix() {
                     directionSearchSeq[even][col] = directionSearchSeq[odd][col - 1];                
                 }
                 if (max >= p.score) {
-					p.score = max;
-					p.intervalSeq1.startPos = directionSearchSeq[even][col];
-					p.intervalSeq1.len = i - p.intervalSeq1.startPos;
+                    p.score = max;
+                    p.intervalSeq1.startPos = directionSearchSeq[even][col];
+                    p.intervalSeq1.len = i - p.intervalSeq1.startPos;
                 }
-            }			
+            }
         }    
-		if (p.score >= minScore) {
-			pairAlignmentStrings.append(p);
-		}
+        if (p.score >= minScore) {
+            pairAlignmentStrings.append(p);
+        }
         //Print matrix
         //          for(int k = 0; k < patternSeq.length() + 1 ; k++) cout <<matrix[getRow(i)][k] <<" ";
         //          cout <<endl;            
@@ -276,8 +265,6 @@ void SmithWatermanAlgorithmSSE2::calculateMatrix() {
     //TODO: it is correct?    
     _mm_free(matrix[0]);
     delete matrix;
-
-    log.info("FINISH calculateMatrix()");
 }
 
 int SmithWatermanAlgorithmSSE2::calculateMatrixSSE2(unsigned queryLength, unsigned char *dbSeq, unsigned dbLength, unsigned short gapOpenOrig, unsigned short gapExtend) {
