@@ -17,7 +17,7 @@
 
 #include <emmintrin.h>
 
-namespace GB2 {
+namespace U2 {
 
 class SmithWatermanAlgorithmSSE2 : public SmithWatermanAlgorithm {
 public:
