@@ -13,11 +13,11 @@
 #ifndef _SW_CUDA_CPP_H
 #define _SW_CUDA_CPP_H
 
-#include <core_api/LRegion.h>
+#include <U2Core/LRegion.h>
 
 struct resType
 {
-    GB2::LRegion reg;
+    U2::LRegion reg;
     int score;
 };
 
@@ -25,10 +25,10 @@ class sw_cuda_cpp {
 public:    
     typedef int ScoreType;
 
-    QList<resType> launch(const char * seqLib, int seqLibLength, ScoreType* queryProfile, ScoreType qProfLen, int queryLength, ScoreType gapOpen, ScoreType gapExtension, ScoreType maxScore);    
-    static quint64 estimateNeededGpuMemory( int seqLibLength, ScoreType qProfLen, int queryLength );	
-	static const int MAX_BLOCKS_NUMBER;	
-	static const int MAX_SHARED_VECTOR_LENGTH;	
+    QList<resType> launch(const char * seqLib, int seqLibLength, ScoreType* queryProfile, ScoreType qProfLen, int queryLength, ScoreType gapOpen, ScoreType gapExtension, ScoreType maxScore);
+    static quint64 estimateNeededGpuMemory( int seqLibLength, ScoreType qProfLen, int queryLength );
+    static const int MAX_BLOCKS_NUMBER;
+    static const int MAX_SHARED_VECTOR_LENGTH;
 };
 
 #endif
