@@ -13,33 +13,33 @@
 #include "WeightMatrixPlugin.h"
 #include "WeightMatrixIO.h"
 
-#include <core_api/AppContext.h>
-#include <core_api/IOAdapter.h>
-#include <core_api/DocumentModel.h>
-#include <core_api/DNAAlphabet.h>
-#include <core_api/Settings.h>
-#include <core_api/Counter.h>
+#include <U2Core/AppContext.h>
+#include <U2Core/IOAdapter.h>
+#include <U2Core/DocumentModel.h>
+#include <U2Core/DNAAlphabet.h>
+#include <U2Core/Settings.h>
+#include <U2Core/Counter.h>
 
-#include <gobjects/GObjectTypes.h>
-#include <gobjects/MAlignmentObject.h>
-#include <gobjects/DNASequenceObject.h>
+#include <U2Core/GObjectTypes.h>
+#include <U2Core/MAlignmentObject.h>
+#include <U2Core/DNASequenceObject.h>
 
-#include <document_format/DocumentFormatUtils.h>
-#include <core_api/DocumentUtils.h>
+#include <U2Formats/DocumentFormatUtils.h>
+#include <U2Core/DocumentUtils.h>
 
-#include <util_gui/DialogUtils.h>
-#include <util_tasks/LoadDocumentTask.h>
+#include <U2Misc/DialogUtils.h>
+#include <U2Core/LoadDocumentTask.h>
 
-#include <util_weight_matrix/DIProperties.h>
-#include <util_weight_matrix/PWMConversionAlgorithm.h>
-#include <util_weight_matrix/PWMConversionAlgorithmRegistry.h>
+#include <U2Core/DIProperties.h>
+#include <U2Algorithm/PWMConversionAlgorithm.h>
+#include <U2Algorithm/PWMConversionAlgorithmRegistry.h>
 
 #include <QtGui/QFileDialog>
 #include <QtGui/QMessageBox>
 
 #define SETTINGS_ROOT   QString("plugin_weight_matrix/")
 
-namespace GB2 {
+namespace U2 {
 
 PWMBuildDialogController::PWMBuildDialogController(QWidget* w) 
 : QDialog(w), logoArea(NULL)
@@ -71,11 +71,29 @@ void PWMBuildDialogController::sl_inFileButtonClicked() {
     QString inFile = QFileInfo(lod.url).absoluteFilePath();
     inputEdit->setText(inFile);
     
-    QList<DocumentFormat*> formats = DocumentFormatUtils::detectFormat(inFile);
+    QList<DocumentFormat*> formats = DocumentUtils::detectFormat(inFile);
     if (formats.isEmpty()) {
         return;
     }
-    DocumentFormat* format = formats.first();
+
+    DocumentFormat* format = NULL;
+    foreach(DocumentFormat* f, formats) {
+        if(f->getSupportedObjectTypes().contains(GObjectTypes::MULTIPLE_ALIGNMENT)) {
+            format = f;
+            break;
+        } 
+    }
+
+    if(format == NULL) {
+        foreach(DocumentFormat* f, formats){
+            if(f->getSupportedObjectTypes().contains(GObjectTypes::SEQUENCE)) {
+                format = f;
+                break;
+            }
+        }
+    }
+
+    //DocumentFormat* format = formats.first();
     IOAdapterFactory* iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::url2io(inFile));
     TaskStateInfo ti;
     QVariantMap hints;
@@ -86,25 +104,11 @@ void PWMBuildDialogController::sl_inFileButtonClicked() {
 
     assert (doc != NULL);
 
-    int bitsize = 30;
-    int logoheight = 150;
-
     QList<GObject*> mobjs = doc->findGObjectByType(GObjectTypes::MULTIPLE_ALIGNMENT);
     if (!mobjs.isEmpty()) {
         MAlignmentObject* mobj =  qobject_cast<MAlignmentObject*>(mobjs.first());
         MAlignment ma = mobj->getMAlignment();
-        if (ma.getLength() < 50) {
-            AlignmentLogoSettings logoSettings(ma);
-            logoSettings.bitSize = bitsize;
-            logoWidget->resize(logoWidget->width(), logoheight);
-            logoWidget->setMinimumHeight(logoheight);
-            if (logoArea != NULL) {
-                logoArea->replaceSettings(logoSettings);   
-            } else {
-                logoArea = new AlignmentLogoRenderArea(logoSettings, logoWidget);
-            }
-            logoArea->repaint();
-        }
+        replaceLogo(ma);
     } else {
         mobjs = doc->findGObjectByType(GObjectTypes::SEQUENCE);
         if (!mobjs.isEmpty()) {
@@ -118,25 +122,16 @@ void PWMBuildDialogController::sl_inFileButtonClicked() {
             }
             DNASequenceObject* dnaObj = qobject_cast<DNASequenceObject*>(mobjs.first());
             MAlignment ma(dnaObj->getDNASequence().getName(), dnaObj->getAlphabet(), rows);
-            if (ma.getLength() < 50) {
-                AlignmentLogoSettings logoSettings(ma);
-                logoSettings.bitSize = bitsize;
-                logoWidget->resize(logoWidget->width(), logoheight);
-                logoWidget->setMinimumHeight(logoheight);
-                if (logoArea != NULL) {
-                    logoArea->replaceSettings(logoSettings);   
-                } else {
-                    logoArea = new AlignmentLogoRenderArea(logoSettings, logoWidget);
-                }
-                logoArea->repaint();
-            }
+            replaceLogo(ma);
         } else {
             PFMatrix pfm = WeightMatrixIO::readPFMatrix(iof, lod.url, ti);
             if (ti.hasErrors()) {
+                logoArea->hide();
                 return;
             }
             int len = pfm.getLength();
             if (len == 0) {
+                logoArea->hide();
                 ti.setError(tr("Zero length matrix is not allowed"));
                 return;
             }
@@ -166,25 +161,30 @@ void PWMBuildDialogController::sl_inFileButtonClicked() {
                 }
                 rows.append(MAlignmentRow("", arr));
             }
-            DNAAlphabet* al = AppContext::getDNAAlphabetRegistry()->findById(BaseDNAAlphabetIds::NUCL_DNA_DEFAULT);
+            DNAAlphabet* al = AppContext::getDNAAlphabetRegistry()->findById(BaseDNAAlphabetIds::NUCL_DNA_DEFAULT());
             MAlignment ma(QString("Temporary alignment"), al, rows);
-            if (ma.getLength() < 50) {
-                AlignmentLogoSettings logoSettings(ma);
-                logoSettings.bitSize = bitsize;
-                logoWidget->resize(logoWidget->width(), logoheight);
-                logoWidget->setMinimumHeight(logoheight);
-                if (logoArea != NULL) {
-                    logoArea->replaceSettings(logoSettings);   
-                } else {
-                    logoArea = new AlignmentLogoRenderArea(logoSettings, logoWidget);
-                }
-                logoArea->repaint();
-            }
-            
+            replaceLogo(ma);
         }
     }
 }
 
+void PWMBuildDialogController::replaceLogo(const MAlignment& ma) {
+    int logoheight = 150;
+    if (ma.getLength() < 50) {
+        AlignmentLogoSettings logoSettings(ma);
+        logoWidget->resize(logoWidget->width(), logoheight);
+        logoWidget->setMinimumHeight(logoheight);
+        logoWidget->show();
+
+        if (logoArea != NULL) {
+            logoArea->replaceSettings(logoSettings);   
+        } else {
+            logoArea = new AlignmentLogoRenderArea(logoSettings, logoWidget);
+        }
+        logoArea->repaint();
+    }
+}
+
 void PWMBuildDialogController::sl_outFileButtonClicked() {
     LastOpenDirHelper lod(WeightMatrixIO::WEIGHT_MATRIX_ID);
     if (frequencyButton->isChecked()) {
@@ -371,12 +371,29 @@ PFMatrixBuildToFileTask::PFMatrixBuildToFileTask(const QString& inFile, const QS
     c.supportedObjectTypes += GObjectTypes::MULTIPLE_ALIGNMENT;
     c.supportedObjectTypes += GObjectTypes::SEQUENCE;
     c.rawData = BaseIOAdapters::readFileHeader(inFile);
-    QList<DocumentFormat*> formats = DocumentFormatUtils::detectFormat(inFile);
+    QList<DocumentFormat*> formats = DocumentUtils::detectFormat(inFile);
     if (formats.isEmpty()) {
         stateInfo.setError(  tr("Input format error") );
         return;
     }
-    DocumentFormatId format = formats.first()->getFormatId();
+
+    DocumentFormatId format = "";
+    foreach(const DocumentFormat* f, formats) {
+        if(f->getSupportedObjectTypes().contains(GObjectTypes::MULTIPLE_ALIGNMENT)) {
+            format = f->getFormatId();
+            break;
+        } 
+    }
+    if(format.isEmpty()) {
+        foreach(const DocumentFormat* f, formats) {
+            if(f->getSupportedObjectTypes().contains(GObjectTypes::SEQUENCE)) {
+                format = f->getFormatId();
+                break;
+            }
+        }
+    }
+
+    //DocumentFormatId format = formats.first()->getFormatId();
     IOAdapterFactory* iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::url2io(inFile));
     loadTask = new LoadDocumentTask(format, inFile, iof);
     loadTask->setSubtaskProgressWeight(0.03F);
@@ -501,7 +518,7 @@ PWMatrixBuildToFileTask::PWMatrixBuildToFileTask(const QString& inFile, const QS
     c.supportedObjectTypes += GObjectTypes::MULTIPLE_ALIGNMENT;
     c.supportedObjectTypes += GObjectTypes::SEQUENCE;
     c.rawData = BaseIOAdapters::readFileHeader(inFile);
-    QList<DocumentFormat*> formats = DocumentFormatUtils::detectFormat(inFile);
+    QList<DocumentFormat*> formats = DocumentUtils::detectFormat(inFile);
     if (formats.isEmpty()) {
         stateInfo.setError(  tr("Input format error") );
         return;
