@@ -17,27 +17,27 @@
 #include "WeightMatrixAlgorithm.h"
 #include "WeightMatrixIO.h"
 
-#include <util_ov_annotated_dna/AnnotatedDNAView.h>
-#include <util_ov_annotated_dna/ADVSequenceObjectContext.h>
+#include <U2View/AnnotatedDNAView.h>
+#include <U2View/ADVSequenceObjectContext.h>
 
-#include <util_weight_matrix/PWMConversionAlgorithmRegistry.h>
+#include <U2Algorithm/PWMConversionAlgorithmRegistry.h>
 
-#include <util_gui/CreateAnnotationDialog.h>
-#include <util_gui/CreateAnnotationWidgetController.h>
-#include <util_gui/DialogUtils.h>
+#include <U2Gui/CreateAnnotationDialog.h>
+#include <U2Gui/CreateAnnotationWidgetController.h>
+#include <U2Misc/DialogUtils.h>
 
-#include <gobjects/DNASequenceObject.h>
-#include <gobjects/GObjectUtils.h>
+#include <U2Core/DNASequenceObject.h>
+#include <U2Core/GObjectUtils.h>
 
-#include <core_api/DNATranslation.h>
-#include <core_api/DNAAlphabet.h>
-#include <core_api/AppContext.h>
-#include <core_api/IOAdapter.h>
-#include <core_api/L10n.h>
-#include <util_gui/GUIUtils.h>
-#include <util_text/TextUtils.h>
-#include <util_tasks/CreateAnnotationTask.h>
-#include <selection/DNASequenceSelection.h>
+#include <U2Core/DNATranslation.h>
+#include <U2Core/DNAAlphabet.h>
+#include <U2Core/AppContext.h>
+#include <U2Core/IOAdapter.h>
+#include <U2Core/L10n.h>
+#include <U2Gui/GUIUtils.h>
+#include <U2Core/TextUtils.h>
+#include <U2Core/CreateAnnotationTask.h>
+#include <U2Core/DNASequenceSelection.h>
 
 #include <assert.h>
 
@@ -46,7 +46,7 @@
 #include <QtGui/QListWidgetItem>
 #include <QtGui/QFileDialog>
 
-namespace GB2 {
+namespace U2 {
 
 class WeightMatrixResultItem : public QTreeWidgetItem {
 public:
@@ -89,7 +89,7 @@ public:
 };
 
 
-/* TRANSLATOR GB2::PWMSearchDialogController */ 
+/* TRANSLATOR U2::PWMSearchDialogController */ 
 
 PWMSearchDialogController::PWMSearchDialogController(ADVSequenceObjectContext* _ctx, QWidget *p):QDialog(p) {
     setupUi(this);
@@ -195,7 +195,9 @@ bool PWMSearchDialogController::eventFilter(QObject *obj, QEvent *ev) {
 void PWMSearchDialogController::sl_selectModelFile() {
     LastOpenDirHelper lod(WeightMatrixIO::WEIGHT_MATRIX_ID);
     lod.url = QFileDialog::getOpenFileName(this, tr("Select file with frequency or weight matrix"), lod, 
-         WeightMatrixIO::getAllMatrixFileFilter(false) + "\n" + WeightMatrixIO::getPFMFileFilter(false) + "\n" + WeightMatrixIO::getPWMFileFilter());
+         WeightMatrixIO::getAllMatrixFileFilter(false) + ";;" +
+         WeightMatrixIO::getPFMFileFilter(false) + ";;" +
+         WeightMatrixIO::getPWMFileFilter(true));
     if (lod.url.isEmpty()) {
         return;
     }
@@ -299,6 +301,10 @@ void PWMSearchDialogController::sl_onAlgoChanged(QString newAlgo){
     PWMConversionAlgorithmFactory* factory = AppContext::getPWMConversionAlgorithmRegistry()->getAlgorithmFactory(newAlgo);
     PWMConversionAlgorithm* algo = factory->createAlgorithm();
     PWMatrix m = algo->convert(intermediate);
+    if (m.getLength() == 0) {
+        QMessageBox::critical(this, L10N::errorTitle(), tr("Zero length or corrupted model\nMaybe model data is not enough for selected algorithm"));
+        return;
+    }
     updateModel(m);
 }
 
@@ -523,6 +529,9 @@ void PWMSearchDialogController::loadFile(QString filename) {
         PWMConversionAlgorithmFactory* factory = AppContext::getPWMConversionAlgorithmRegistry()->getAlgorithmFactory(algorithmCombo->currentText());
         PWMConversionAlgorithm* algo = factory->createAlgorithm();
         m = algo->convert(intermediate);
+        if (m.getLength() == 0) {
+            QMessageBox::critical(this, L10N::errorTitle(), tr("Zero length or corrupted model\nMaybe model data is not enough for selected algorithm"));
+        }
     }
     updateModel(m);
     QFileInfo fi(filename);
