@@ -10,10 +10,10 @@
 
 #include "SetParametersDialogController.h"
 
-#include <core_api/AppContext.h>
-#include <util_weight_matrix/PWMConversionAlgorithmRegistry.h>
+#include <U2Core/AppContext.h>
+#include <U2Algorithm/PWMConversionAlgorithmRegistry.h>
 
-namespace GB2 {
+namespace U2 {
 
 SetParametersDialogController::SetParametersDialogController(QWidget *w) 
     : QDialog(w) {
