@@ -8,8 +8,8 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_WEIGHT_MATRIX_SET_PARAMETERS_DIALOG_CONTROLLER_H_
-#define _GB2_WEIGHT_MATRIX_SET_PARAMETERS_DIALOG_CONTROLLER_H_
+#ifndef _U2_WEIGHT_MATRIX_SET_PARAMETERS_DIALOG_CONTROLLER_H_
+#define _U2_WEIGHT_MATRIX_SET_PARAMETERS_DIALOG_CONTROLLER_H_
 
 #include <ui/ui_SetDefaultParametersDialog.h>
 
@@ -17,7 +17,7 @@
 
 #include "WeightMatrixPlugin.h"
 
-namespace GB2 {
+namespace U2 {
 
 class SetParametersDialogController : public QDialog, public Ui_SetDefaultParametersDialog {
     Q_OBJECT
