@@ -8,21 +8,21 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_WEIGHT_MATRIX_VIEW_MATRIX_DIALOG_CONTROLLER_H_
-#define _GB2_WEIGHT_MATRIX_VIEW_MATRIX_DIALOG_CONTROLLER_H_
+#ifndef _U2_WEIGHT_MATRIX_VIEW_MATRIX_DIALOG_CONTROLLER_H_
+#define _U2_WEIGHT_MATRIX_VIEW_MATRIX_DIALOG_CONTROLLER_H_
 
 #include <ui/ui_ViewMatrixDialog.h>
 
 #include <QtGui/QDialog>
 
-#include <datatype/PFMatrix.h>
-#include <datatype/PWMatrix.h>
+#include <U2Core/PFMatrix.h>
+#include <U2Core/PWMatrix.h>
 
-#include <util_ov_msaedit/AlignmentLogo.h>
+#include <U2View/AlignmentLogo.h>
 
 #include "WeightMatrixPlugin.h"
 
-namespace GB2 {
+namespace U2 {
 
 class ViewMatrixDialogController : public QDialog, public Ui_ViewMatrixDialog {
     Q_OBJECT
