@@ -8,14 +8,14 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_WEIGHT_MATRIX_ALGORITHM_H_
-#define _GB2_WEIGHT_MATRIX_ALGORITHM_H_
+#ifndef _U2_WEIGHT_MATRIX_ALGORITHM_H_
+#define _U2_WEIGHT_MATRIX_ALGORITHM_H_
 
-#include <util_weight_matrix/PWMConversionAlgorithm.h>
+#include <U2Algorithm/PWMConversionAlgorithm.h>
 
-#include <core_api/DNATranslation.h>
+#include <U2Core/DNATranslation.h>
 
-namespace GB2 {
+namespace U2 {
 
 enum MatrixBuldTarget {
     FREQUENCY_MATRIX,
