@@ -12,31 +12,36 @@
 #include "WeightMatrixWorkers.h"
 #include "WeightMatrixIO.h"
 #include "PWMSearchDialogController.h"
-#include <workflow/Datatype.h>
-#include <workflow/IntegralBusModel.h>
-#include <workflow/WorkflowEnv.h>
-#include <workflow/WorkflowRegistry.h>
-#include <workflow_library/BioActorLibrary.h>
-#include <workflow_support/CoreDataTypes.h>
-#include <workflow_support/DelegateEditors.h>
-#include <workflow_support/CoreLibConstants.h>
+#include <U2Lang/Datatype.h>
+#include <U2Lang/IntegralBusModel.h>
+#include <U2Lang/WorkflowEnv.h>
+#include <U2Lang/ActorPrototypeRegistry.h>
+#include <U2Lang/BioActorLibrary.h>
+#include <U2Lang/CoreDataTypes.h>
+#include <U2Designer/DelegateEditors.h>
+#include <U2Lang/CoreLibConstants.h>
 
-#include <core_api/AppContext.h>
-#include <core_api/IOAdapter.h>
-#include <core_api/Log.h>
-#include <core_api/GUrlUtils.h>
-#include <util_tasks/FailTask.h>
+#include <U2Core/AppContext.h>
+#include <U2Core/IOAdapter.h>
+#include <U2Core/Log.h>
+#include <U2Core/GUrlUtils.h>
+#include <U2Core/FailTask.h>
 
 
-/* TRANSLATOR GB2::WeightMatrixIO */
+/* TRANSLATOR U2::WeightMatrixIO */
 
-namespace GB2 {
+namespace U2 {
 namespace LocalWorkflow {
 
-const QString PWMatrixReader::ACTOR_ID("pwmatrix.read");
-const QString PWMatrixWriter::ACTOR_ID("pwmatrix.write");
-const QString PFMatrixReader::ACTOR_ID("pfmatrix.read");
-const QString PFMatrixWriter::ACTOR_ID("pfmatrix.write");
+const QString PWMatrixReader::ACTOR_ID("wmatrix-read");
+const QString PWMatrixWriter::ACTOR_ID("wmatrix-write");
+const QString PFMatrixReader::ACTOR_ID("fmatrix-read");
+const QString PFMatrixWriter::ACTOR_ID("fmatrix-write");
+
+static const QString FMATRIX_OUT_PORT_ID("out-fmatrix"); // FIXME: redifinition
+static const QString FMATRIX_IN_PORT_ID("in-fmatrix"); // FIXME: redifinition
+static const QString WMATRIX_OUT_PORT_ID("out-wmatrix"); // FIXME: redifinition
+static const QString WMATRIX_IN_PORT_ID("in-wmatrix"); // FIXME: redifinition
 
 const QString PWMatrixWorkerFactory::WEIGHT_MATRIX_MODEL_TYPE_ID("pwmatrix.model");
 const QString PFMatrixWorkerFactory::FREQUENCY_MATRIX_MODEL_TYPE_ID("pfmatrix.model");
@@ -53,12 +58,12 @@ DataTypePtr const PWMatrixWorkerFactory::WEIGHT_MATRIX_MODEL_TYPE() {
     return dtr->getById(WEIGHT_MATRIX_MODEL_TYPE_ID);
 }
 
+const Descriptor PWMatrixWorkerFactory::WMATRIX_SLOT("wmatrix", WeightMatrixIO::tr("Weight matrix"), "");
+
 const Descriptor PWMatrixWorkerFactory::WEIGHT_MATRIX_CATEGORY() {return Descriptor("hweightmatrix", WeightMatrixIO::tr("Weight matrix"), "");}
 
-static LogCategory log(ULOG_CAT_WD);
-
 PWMatrixIOProto::PWMatrixIOProto(const Descriptor& _desc, const QList<PortDescriptor*>& _ports, const QList<Attribute*>& _attrs ) 
-    : BusActorPrototype(_desc, _ports, _attrs) {
+    : IntegralBusActorPrototype(_desc, _ports, _attrs) {
 }
 
 bool PWMatrixIOProto::isAcceptableDrop(const QMimeData * md, QVariantMap * params, const QString & urlAttrId ) const {
@@ -84,13 +89,13 @@ ReadPWMatrixProto::ReadPWMatrixProto(const Descriptor& _desc, const QList<PortDe
 
         attrs << new Attribute(CoreLibConstants::URL_IN_ATTR(), CoreDataTypes::STRING_TYPE(), true);
         QMap<QString, PropertyDelegate*> delegateMap;
-        delegateMap[CoreLibConstants::URL_IN_ATTR_ID] = new URLDelegate(WeightMatrixIO::getPWMFileFilter(), WeightMatrixIO::WEIGHT_MATRIX_ID, true);
+        delegateMap[CoreLibConstants::URL_IN_ATTR().getId()] = new URLDelegate(WeightMatrixIO::getPWMFileFilter(), WeightMatrixIO::WEIGHT_MATRIX_ID, true);
         setEditor(new DelegateEditor(delegateMap));
         setIconPath(":weight_matrix/images/weight_matrix.png");
 }
 
 bool ReadPWMatrixProto::isAcceptableDrop(const QMimeData * md, QVariantMap * params ) const {
-    return PWMatrixIOProto::isAcceptableDrop( md, params, CoreLibConstants::URL_IN_ATTR_ID );
+    return PWMatrixIOProto::isAcceptableDrop( md, params, CoreLibConstants::URL_IN_ATTR().getId() );
 }
 
 WritePWMatrixProto::WritePWMatrixProto(const Descriptor& _desc, const QList<PortDescriptor*>& _ports, const QList<Attribute*>& _attrs ) 
@@ -99,47 +104,50 @@ WritePWMatrixProto::WritePWMatrixProto(const Descriptor& _desc, const QList<Port
         attrs << new Attribute(BioActorLibrary::FILE_MODE_ATTR(), CoreDataTypes::NUM_TYPE(), false, SaveDoc_Roll);
 
         QMap<QString, PropertyDelegate*> delegateMap;
-        delegateMap[CoreLibConstants::URL_OUT_ATTR_ID] = new URLDelegate(WeightMatrixIO::getPWMFileFilter(), WeightMatrixIO::WEIGHT_MATRIX_ID, false );
+        delegateMap[CoreLibConstants::URL_OUT_ATTR().getId()] = new URLDelegate(WeightMatrixIO::getPWMFileFilter(), WeightMatrixIO::WEIGHT_MATRIX_ID, false );
         delegateMap[BioActorLibrary::FILE_MODE_ATTR_ID] = new FileModeDelegate(false);
 
         setEditor(new DelegateEditor(delegateMap));
         setIconPath(":weight_matrix/images/weight_matrix.png");
-        setValidator(new ScreenedParamValidator(CoreLibConstants::URL_OUT_ATTR_ID, ports.first()->getId(), CoreLibConstants::URL_SLOT_ID));
-        setPortValidator(CoreLibConstants::IN_PORT_ID, new ScreenedSlotValidator(CoreLibConstants::URL_SLOT_ID));
+        setValidator(new ScreenedParamValidator(CoreLibConstants::URL_OUT_ATTR().getId(), ports.first()->getId(), CoreLibConstants::URL_SLOT().getId()));
+        setPortValidator(WMATRIX_IN_PORT_ID, new ScreenedSlotValidator(CoreLibConstants::URL_SLOT().getId()));
 }
 
 bool WritePWMatrixProto::isAcceptableDrop(const QMimeData * md, QVariantMap * params ) const {
-    return PWMatrixIOProto::isAcceptableDrop( md, params, CoreLibConstants::URL_OUT_ATTR_ID );
+    return PWMatrixIOProto::isAcceptableDrop( md, params, CoreLibConstants::URL_OUT_ATTR().getId() );
 }
 
 void PWMatrixWorkerFactory::init() 
 {
-    WProtoRegistry* r = WorkflowEnv::getProtoRegistry();
+    ActorPrototypeRegistry* r = WorkflowEnv::getProtoRegistry();
     assert(r);
-    DataTypePtr dt = WEIGHT_MATRIX_MODEL_TYPE();
     {        
         QMap<Descriptor, DataTypePtr> m;
-        Descriptor sd(CoreLibConstants::URL_SLOT_ID, WeightMatrixIO::tr("Location"), WeightMatrixIO::tr("Location hint for the target file."));
-        m[sd] = CoreDataTypes::STRING_TYPE();
-        m[*dt] = dt;
+        Descriptor sd(CoreLibConstants::URL_SLOT().getId(), WeightMatrixIO::tr("Location"), WeightMatrixIO::tr("Location hint for the target file."));
+        m[CoreLibConstants::URL_SLOT()] = CoreDataTypes::STRING_TYPE();
+        m[WMATRIX_SLOT] = WEIGHT_MATRIX_MODEL_TYPE();
         DataTypePtr t(new MapDataType(Descriptor("write.pwmatrix.content"), m));
 
         QList<PortDescriptor*> p; QList<Attribute*> a;
-        Descriptor pd(CoreLibConstants::IN_PORT_ID, WeightMatrixIO::tr("Weight matrix"), WeightMatrixIO::tr("Input weight matrix"));
+        Descriptor pd(WMATRIX_IN_PORT_ID, WeightMatrixIO::tr("Weight matrix"), WeightMatrixIO::tr("Input weight matrix"));
         p << new PortDescriptor(pd, t, true /*input*/);
         Descriptor desc(PWMatrixWriter::ACTOR_ID, WeightMatrixIO::tr("Write weight matrix"), WeightMatrixIO::tr("Saves all input weight matrices to specified location."));
-        BusActorPrototype* proto = new WritePWMatrixProto(desc, p, a);
+        IntegralBusActorPrototype* proto = new WritePWMatrixProto(desc, p, a);
         proto->setPrompter(new PWMatrixWritePrompter());
-        r->registerProto(WEIGHT_MATRIX_CATEGORY(), proto);
+        r->registerProto(BioActorLibrary::CATEGORY_TRANSCRIPTION(), proto);
     }
     {
         QList<PortDescriptor*> p; QList<Attribute*> a;
-        Descriptor pd(CoreLibConstants::OUT_PORT_ID, WeightMatrixIO::tr("Weight matrix"), WeightMatrixIO::tr("Loaded weight matrices data."));
-        p << new PortDescriptor(pd, dt, false /*input*/, true /*multi*/);
+        Descriptor pd(WMATRIX_OUT_PORT_ID, WeightMatrixIO::tr("Weight matrix"), WeightMatrixIO::tr("Loaded weight matrices data."));
+        
+        QMap<Descriptor, DataTypePtr> outM;
+        outM[WMATRIX_SLOT] = WEIGHT_MATRIX_MODEL_TYPE();
+        p << new PortDescriptor(pd, DataTypePtr(new MapDataType("wmatrix.read.out", outM)), false /*input*/, true /*multi*/);
+        
         Descriptor desc(PWMatrixReader::ACTOR_ID, WeightMatrixIO::tr("Read weight matrix"), WeightMatrixIO::tr("Reads weight matrices from file(s). The files can be local or Internet URLs."));
-        BusActorPrototype* proto = new ReadPWMatrixProto(desc, p, a);
+        IntegralBusActorPrototype* proto = new ReadPWMatrixProto(desc, p, a);
         proto->setPrompter(new PWMatrixReadPrompter());
-        r->registerProto(WEIGHT_MATRIX_CATEGORY(), proto);
+        r->registerProto(BioActorLibrary::CATEGORY_TRANSCRIPTION(), proto);
     }
 
     PWMatrixBuildWorker::registerProto();
@@ -171,16 +179,16 @@ Worker* PWMatrixWorkerFactory::createWorker(Actor* a) {
 }
 
 QString PWMatrixReadPrompter::composeRichDoc() {
-    return tr("Read model(s) from <u>%1</u>").arg(getURL(CoreLibConstants::URL_IN_ATTR_ID));
+    return tr("Read model(s) from <u>%1</u>").arg(getURL(CoreLibConstants::URL_IN_ATTR().getId()));
 }
 
 QString PWMatrixWritePrompter::composeRichDoc() {
-    BusPort* input = qobject_cast<BusPort*>(target->getPort(CoreLibConstants::IN_PORT_ID));
+    IntegralBusPort* input = qobject_cast<IntegralBusPort*>(target->getPort(WMATRIX_IN_PORT_ID));
     Actor* producer = input->getProducer(PWMatrixWorkerFactory::WEIGHT_MATRIX_MODEL_TYPE_ID);
     if (!producer) {
-        return getURL(CoreLibConstants::URL_OUT_ATTR_ID);
+        return getURL(CoreLibConstants::URL_OUT_ATTR().getId());
     }
-    QString url = getScreenedURL(input, CoreLibConstants::URL_OUT_ATTR_ID, CoreLibConstants::URL_SLOT_ID); 
+    QString url = getScreenedURL(input, CoreLibConstants::URL_OUT_ATTR().getId(), CoreLibConstants::URL_SLOT().getId()); 
     QString doc = tr("Save the profile(s) from <u>%1</u> to %2.")
         .arg(producer->getLabel())
         .arg(url);
@@ -188,8 +196,8 @@ QString PWMatrixWritePrompter::composeRichDoc() {
 }
 
 void PWMatrixReader::init() {
-    output = ports.value(CoreLibConstants::OUT_PORT_ID);
-    urls = DesignerUtils::expandToUrls(actor->getParameter(CoreLibConstants::URL_IN_ATTR_ID)->getAttributeValue<QString>());
+    output = ports.value(WMATRIX_OUT_PORT_ID);
+    urls = WorkflowUtils::expandToUrls(actor->getParameter(CoreLibConstants::URL_IN_ATTR().getId())->getAttributeValue<QString>());
     mtype = PWMatrixWorkerFactory::WEIGHT_MATRIX_MODEL_TYPE();
 }
 
@@ -212,33 +220,33 @@ void PWMatrixReader::sl_taskFinished() {
         if (urls.isEmpty() && tasks.isEmpty()) {
             output->setEnded();
         }
-        log.info(tr("Loaded weight matrix from %1").arg(t->getURL()));
+        ioLog.info(tr("Loaded weight matrix from %1").arg(t->getURL()));
     }
 }
 
 void PWMatrixWriter::init() {
-    input = ports.value(CoreLibConstants::IN_PORT_ID);
+    input = ports.value(WMATRIX_IN_PORT_ID);
 }
 
 Task* PWMatrixWriter::tick() {
     Message inputMessage = getMessageAndSetupScriptValues(input);
-    url = actor->getParameter(CoreLibConstants::URL_OUT_ATTR_ID)->getAttributeValue<QString>();
+    url = actor->getParameter(CoreLibConstants::URL_OUT_ATTR().getId())->getAttributeValue<QString>();
     fileMode = actor->getParameter(BioActorLibrary::FILE_MODE_ATTR_ID)->getAttributeValue<uint>();
     QVariantMap data = inputMessage.getData().toMap();
     
-    PWMatrix model = data.value(PWMatrixWorkerFactory::WEIGHT_MATRIX_MODEL_TYPE_ID).value<PWMatrix>();
+    PWMatrix model = data.value(PWMatrixWorkerFactory::WMATRIX_SLOT.getId()).value<PWMatrix>();
     QString anUrl = url;
     if (anUrl.isEmpty()) {
-        anUrl = data.value(CoreLibConstants::URL_SLOT_ID).toString();
+        anUrl = data.value(CoreLibConstants::URL_SLOT().getId()).toString();
     }
     if (anUrl.isEmpty()) {
         QString err = tr("Unspecified URL for writing weight matrix");
-        if (failFast) {
+        //if (failFast) {
             return new FailTask(err);
-        } else {
-            log.error(err);
+        /*} else {
+            ioLog.error(err);
             return NULL;
-        }
+        }*/
     }
     assert(!anUrl.isEmpty());
     int count = ++counter[anUrl];
@@ -247,7 +255,7 @@ Task* PWMatrixWriter::tick() {
     } else {
         anUrl = GUrlUtils::ensureFileExt( anUrl, QStringList(WeightMatrixIO::WEIGHT_MATRIX_EXT)).getURLString();
     }
-    log.info(tr("Writing weight matrix to %1").arg(anUrl));
+    ioLog.info(tr("Writing weight matrix to %1").arg(anUrl));
     return new PWMatrixWriteTask(anUrl, model, fileMode);
 }
 
@@ -266,10 +274,12 @@ DataTypePtr const PFMatrixWorkerFactory::FREQUENCY_MATRIX_MODEL_TYPE() {
     return dtr->getById(FREQUENCY_MATRIX_MODEL_TYPE_ID);
 }
 
+const Descriptor PFMatrixWorkerFactory::FMATRIX_SLOT("fmatrix", WeightMatrixIO::tr("Frequency matrix"), "");
+
 const Descriptor PFMatrixWorkerFactory::FREQUENCY_MATRIX_CATEGORY() {return Descriptor("hweightmatrix", WeightMatrixIO::tr("Weight matrix"), "");}
 
 PFMatrixIOProto::PFMatrixIOProto(const Descriptor& _desc, const QList<PortDescriptor*>& _ports, const QList<Attribute*>& _attrs ) 
-: BusActorPrototype(_desc, _ports, _attrs) {
+: IntegralBusActorPrototype(_desc, _ports, _attrs) {
 }
 
 bool PFMatrixIOProto::isAcceptableDrop(const QMimeData * md, QVariantMap * params, const QString & urlAttrId ) const {
@@ -295,13 +305,13 @@ ReadPFMatrixProto::ReadPFMatrixProto(const Descriptor& _desc, const QList<PortDe
 
     attrs << new Attribute(CoreLibConstants::URL_IN_ATTR(), CoreDataTypes::STRING_TYPE(), true);
     QMap<QString, PropertyDelegate*> delegateMap;
-    delegateMap[CoreLibConstants::URL_IN_ATTR_ID] = new URLDelegate(WeightMatrixIO::getPFMFileFilter(), WeightMatrixIO::FREQUENCY_MATRIX_ID, true);
+    delegateMap[CoreLibConstants::URL_IN_ATTR().getId()] = new URLDelegate(WeightMatrixIO::getPFMFileFilter(), WeightMatrixIO::FREQUENCY_MATRIX_ID, true);
     setEditor(new DelegateEditor(delegateMap));
     setIconPath(":weight_matrix/images/weight_matrix.png");
 }
 
 bool ReadPFMatrixProto::isAcceptableDrop(const QMimeData * md, QVariantMap * params ) const {
-    return PFMatrixIOProto::isAcceptableDrop( md, params, CoreLibConstants::URL_IN_ATTR_ID );
+    return PFMatrixIOProto::isAcceptableDrop( md, params, CoreLibConstants::URL_IN_ATTR().getId());
 }
 
 WritePFMatrixProto::WritePFMatrixProto(const Descriptor& _desc, const QList<PortDescriptor*>& _ports, const QList<Attribute*>& _attrs ) 
@@ -310,47 +320,50 @@ WritePFMatrixProto::WritePFMatrixProto(const Descriptor& _desc, const QList<Port
     attrs << new Attribute(BioActorLibrary::FILE_MODE_ATTR(), CoreDataTypes::NUM_TYPE(), false, SaveDoc_Roll);
 
     QMap<QString, PropertyDelegate*> delegateMap;
-    delegateMap[CoreLibConstants::URL_OUT_ATTR_ID] = new URLDelegate(WeightMatrixIO::getPFMFileFilter(), WeightMatrixIO::FREQUENCY_MATRIX_ID, false );
+    delegateMap[CoreLibConstants::URL_OUT_ATTR().getId()] = new URLDelegate(WeightMatrixIO::getPFMFileFilter(), WeightMatrixIO::FREQUENCY_MATRIX_ID, false );
     delegateMap[BioActorLibrary::FILE_MODE_ATTR_ID] = new FileModeDelegate(false);
 
     setEditor(new DelegateEditor(delegateMap));
     setIconPath(":weight_matrix/images/weight_matrix.png");
-    setValidator(new ScreenedParamValidator(CoreLibConstants::URL_OUT_ATTR_ID, ports.first()->getId(), CoreLibConstants::URL_SLOT_ID));
-    setPortValidator(CoreLibConstants::IN_PORT_ID, new ScreenedSlotValidator(CoreLibConstants::URL_SLOT_ID));
+    setValidator(new ScreenedParamValidator(CoreLibConstants::URL_OUT_ATTR().getId(), ports.first()->getId(), CoreLibConstants::URL_SLOT().getId()));
+    setPortValidator(FMATRIX_IN_PORT_ID, new ScreenedSlotValidator(CoreLibConstants::URL_SLOT().getId()));
 }
 
 bool WritePFMatrixProto::isAcceptableDrop(const QMimeData * md, QVariantMap * params ) const {
-    return PFMatrixIOProto::isAcceptableDrop( md, params, CoreLibConstants::URL_OUT_ATTR_ID );
+    return PFMatrixIOProto::isAcceptableDrop( md, params, CoreLibConstants::URL_OUT_ATTR().getId() );
 }
 
 void PFMatrixWorkerFactory::init() 
 {
-    WProtoRegistry* r = WorkflowEnv::getProtoRegistry();
+    ActorPrototypeRegistry* r = WorkflowEnv::getProtoRegistry();
     assert(r);
-    DataTypePtr dt = FREQUENCY_MATRIX_MODEL_TYPE();
     {        
         QMap<Descriptor, DataTypePtr> m;
-        Descriptor sd(CoreLibConstants::URL_SLOT_ID, WeightMatrixIO::tr("Location"), WeightMatrixIO::tr("Location hint for the target file."));
-        m[sd] = CoreDataTypes::STRING_TYPE();
-        m[*dt] = dt;
+        Descriptor sd(CoreLibConstants::URL_SLOT().getId(), WeightMatrixIO::tr("Location"), WeightMatrixIO::tr("Location hint for the target file."));
+        m[CoreLibConstants::URL_SLOT()] = CoreDataTypes::STRING_TYPE();
+        m[PFMatrixWorkerFactory::FMATRIX_SLOT] = PFMatrixWorkerFactory::FREQUENCY_MATRIX_MODEL_TYPE();
         DataTypePtr t(new MapDataType(Descriptor("write.pfmatrix.content"), m));
 
         QList<PortDescriptor*> p; QList<Attribute*> a;
-        Descriptor pd(CoreLibConstants::IN_PORT_ID, WeightMatrixIO::tr("Frequency matrix"), WeightMatrixIO::tr("Input frequency matrix"));
+        Descriptor pd(FMATRIX_IN_PORT_ID, WeightMatrixIO::tr("Frequency matrix"), WeightMatrixIO::tr("Input frequency matrix"));
         p << new PortDescriptor(pd, t, true /*input*/);
         Descriptor desc(PFMatrixWriter::ACTOR_ID, WeightMatrixIO::tr("Write frequency matrix"), WeightMatrixIO::tr("Saves all input frequency matrices to specified location."));
-        BusActorPrototype* proto = new WritePFMatrixProto(desc, p, a);
+        IntegralBusActorPrototype* proto = new WritePFMatrixProto(desc, p, a);
         proto->setPrompter(new PFMatrixWritePrompter());
-        r->registerProto(FREQUENCY_MATRIX_CATEGORY(), proto);
+        r->registerProto(BioActorLibrary::CATEGORY_TRANSCRIPTION(), proto);
     }
     {
         QList<PortDescriptor*> p; QList<Attribute*> a;
-        Descriptor pd(CoreLibConstants::OUT_PORT_ID, WeightMatrixIO::tr("Frequency matrix"), WeightMatrixIO::tr("Loaded weight matrices data."));
-        p << new PortDescriptor(pd, dt, false /*input*/, true /*multi*/);
+        Descriptor pd(FMATRIX_OUT_PORT_ID, WeightMatrixIO::tr("Frequency matrix"), WeightMatrixIO::tr("Loaded weight matrices data."));
+        
+        QMap<Descriptor, DataTypePtr> outM;
+        outM[PFMatrixWorkerFactory::FMATRIX_SLOT] = PFMatrixWorkerFactory::FREQUENCY_MATRIX_MODEL_TYPE();
+        p << new PortDescriptor(pd, DataTypePtr(new MapDataType("fmatrix.read.out", outM)), false /*input*/, true /*multi*/);
+        
         Descriptor desc(PFMatrixReader::ACTOR_ID, WeightMatrixIO::tr("Read frequency matrix"), WeightMatrixIO::tr("Reads frequency matrices from file(s). The files can be local or Internet URLs."));
-        BusActorPrototype* proto = new ReadPFMatrixProto(desc, p, a);
+        IntegralBusActorPrototype* proto = new ReadPFMatrixProto(desc, p, a);
         proto->setPrompter(new PFMatrixReadPrompter());
-        r->registerProto(FREQUENCY_MATRIX_CATEGORY(), proto);
+        r->registerProto(BioActorLibrary::CATEGORY_TRANSCRIPTION(), proto);
     }
 
     PFMatrixBuildWorker::registerProto();
@@ -382,16 +395,16 @@ Worker* PFMatrixWorkerFactory::createWorker(Actor* a) {
 }
 
 QString PFMatrixReadPrompter::composeRichDoc() {
-    return tr("Read model(s) from <u>%1</u>").arg(getURL(CoreLibConstants::URL_IN_ATTR_ID));
+    return tr("Read model(s) from <u>%1</u>").arg(getURL(CoreLibConstants::URL_IN_ATTR().getId()));
 }
 
 QString PFMatrixWritePrompter::composeRichDoc() {
-    BusPort* input = qobject_cast<BusPort*>(target->getPort(CoreLibConstants::IN_PORT_ID));
+    IntegralBusPort* input = qobject_cast<IntegralBusPort*>(target->getPort(FMATRIX_IN_PORT_ID));
     Actor* producer = input->getProducer(PFMatrixWorkerFactory::FREQUENCY_MATRIX_MODEL_TYPE_ID);
     if (!producer) {
-        return getURL(CoreLibConstants::URL_OUT_ATTR_ID);
+        return getURL(CoreLibConstants::URL_OUT_ATTR().getId());
     }
-    QString url = getScreenedURL(input, CoreLibConstants::URL_OUT_ATTR_ID, CoreLibConstants::URL_SLOT_ID); 
+    QString url = getScreenedURL(input, CoreLibConstants::URL_OUT_ATTR().getId(), CoreLibConstants::URL_SLOT().getId()); 
     QString doc = tr("Save the profile(s) from <u>%1</u> to %2.")
         .arg(producer->getLabel())
         .arg(url);
@@ -399,8 +412,8 @@ QString PFMatrixWritePrompter::composeRichDoc() {
 }
 
 void PFMatrixReader::init() {
-    output = ports.value(CoreLibConstants::OUT_PORT_ID);
-    urls = DesignerUtils::expandToUrls(actor->getParameter(CoreLibConstants::URL_IN_ATTR_ID)->getAttributeValue<QString>());
+    output = ports.value(FMATRIX_OUT_PORT_ID);
+    urls = WorkflowUtils::expandToUrls(actor->getParameter(CoreLibConstants::URL_IN_ATTR().getId())->getAttributeValue<QString>());
     mtype = PFMatrixWorkerFactory::FREQUENCY_MATRIX_MODEL_TYPE();
 }
 
@@ -423,33 +436,33 @@ void PFMatrixReader::sl_taskFinished() {
         if (urls.isEmpty() && tasks.isEmpty()) {
             output->setEnded();
         }
-        log.info(tr("Loaded frequency matrix from %1").arg(t->getURL()));
+        ioLog.info(tr("Loaded frequency matrix from %1").arg(t->getURL()));
     }
 }
 
 void PFMatrixWriter::init() {
-    input = ports.value(CoreLibConstants::IN_PORT_ID);
+    input = ports.value(FMATRIX_IN_PORT_ID);
 }
 
 Task* PFMatrixWriter::tick() {
     Message inputMessage = getMessageAndSetupScriptValues(input);
-    url = actor->getParameter(CoreLibConstants::URL_OUT_ATTR_ID)->getAttributeValue<QString>();
+    url = actor->getParameter(CoreLibConstants::URL_OUT_ATTR().getId())->getAttributeValue<QString>();
     fileMode = actor->getParameter(BioActorLibrary::FILE_MODE_ATTR_ID)->getAttributeValue<uint>();
     QVariantMap data = inputMessage.getData().toMap();
-    PFMatrix model = data.value(PFMatrixWorkerFactory::FREQUENCY_MATRIX_MODEL_TYPE_ID).value<PFMatrix>();
+    PFMatrix model = data.value(PFMatrixWorkerFactory::FMATRIX_SLOT.getId()).value<PFMatrix>();
     
     QString anUrl = url;
     if (anUrl.isEmpty()) {
-        anUrl = data.value(CoreLibConstants::URL_SLOT_ID).toString();
+        anUrl = data.value(CoreLibConstants::URL_SLOT().getId()).toString();
     }
     if (anUrl.isEmpty()) {
         QString err = tr("Unspecified URL for writing frequency matrix");
-        if (failFast) {
+        //if (failFast) {
             return new FailTask(err);
-        } else {
-            log.error(err);
+        /*} else {
+            ioLog.error(err);
             return NULL;
-        }
+        }*/
     }
     assert(!anUrl.isEmpty());
     int count = ++counter[anUrl];
@@ -458,10 +471,10 @@ Task* PFMatrixWriter::tick() {
     } else {
         anUrl = GUrlUtils::ensureFileExt( anUrl, QStringList(WeightMatrixIO::FREQUENCY_MATRIX_EXT)).getURLString();
     }
-    log.info(tr("Writing frequency matrix to %1").arg(anUrl));
+    ioLog.info(tr("Writing frequency matrix to %1").arg(anUrl));
     return new PFMatrixWriteTask(anUrl, model, fileMode);
 }
 
 
 } //namespace LocalWorkflow
-} //namespace GB2
\ No newline at end of file
+} //namespace U2
