@@ -8,15 +8,15 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_CHOOSE_DIALOG_CONTROLLER_H_
-#define _GB2_CHOOSE_DIALOG_CONTROLLER_H_
+#ifndef _U2_CHOOSE_DIALOG_CONTROLLER_H_
+#define _U2_CHOOSE_DIALOG_CONTROLLER_H_
 
-#include <core_api/core_api.h>
+#include <U2Core/global.h>
 
 #include <ui/ui_ChooseItemDialog.h>
-#include <workflow/WorkflowModel.h>
+#include <U2Lang/ActorModel.h>
 
-namespace GB2 {
+namespace U2 {
 
     class ChooseItemDialog : public QDialog,  public Ui_ChooseItemDialog {
         Q_OBJECT
