@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -8,14 +8,14 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_WORKFLOW_ITERATION_LIST_H_
-#define _GB2_WORKFLOW_ITERATION_LIST_H_
+#ifndef _U2_WORKFLOW_ITERATION_LIST_H_
+#define _U2_WORKFLOW_ITERATION_LIST_H_
 
-#include <workflow/Schema.h>
+#include <U2Lang/Schema.h>
 //#include <ui/ui_WorkflowEditorWidget.h>
 #include <QtGui/QListView>
 
-namespace GB2 {
+namespace U2 {
 using namespace Workflow;
 class WorkflowView;
 
@@ -31,7 +31,7 @@ public:
     int current() const;
     QItemSelection selection() const;
     void selectIteration(int id);
-    bool expandList(const QPair<ActorId, QString>& key, const QVariant& val);
+    bool expandList(const ActorId& id, const QString& key, const QVariant& val);
 
 signals:
     void iterationListAboutToChange();
@@ -44,12 +44,15 @@ private slots:
     void sl_cloneIteration();
     void sl_selectIterations();
     void sl_iterationSelected();
-
+    void sl_updateActions();
+    
 private:
     void setupIterationUI(QWidget*);
     void updateIterationState();
 
     QListView* iterationList;
+    QAction * cloneAction;
+    QAction * removeAction;
 };
 
 
