@@ -8,31 +8,28 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_WORKFLOW_SCENE_SERIALIZER_H_
-#define _GB2_WORKFLOW_SCENE_SERIALIZER_H_
+#ifndef _U2_WORKFLOW_SCENE_SERIALIZER_H_
+#define _U2_WORKFLOW_SCENE_SERIALIZER_H_
 
-#include <workflow_support/SchemaSerializer.h>
+#include <U2Lang/SchemaSerializer.h>
 
 class QGraphicsItem;
 
-namespace GB2 {
+namespace U2 {
 
 class WorkflowScene;
 class WorkflowProcessItem;
-class WBusItem;
+class WorkflowBusItem;
 
 class SceneSerializer {
 public:
     static void saveItems(const QList<QGraphicsItem*>& items, QDomElement& proj);
-    static void saveProcess(const WorkflowProcessItem* pit, QDomElement& proj);
-    static void saveFlow(const WBusItem* dit, QDomElement& proj);
-
+    
     static void scene2xml(const WorkflowScene* scene, QDomDocument& xml);
     static QString xml2scene(const QDomElement& projectElement, WorkflowScene* scene, QMap<ActorId, ActorId>& remapping, 
         bool ignoreErrors = false, bool select = false);
-
 };
 
-} //namespace
+} // U2
 
-#endif
+#endif // _U2_WORKFLOW_SCENE_SERIALIZER_H_
