@@ -12,21 +12,15 @@
 #include "WorkflowEditorDelegates.h"
 #include "IterationListWidget.h"
 
-#include <core_api/Log.h>
-
 #include <QtGui/QPushButton>
-
 #include <QtCore/QAbstractItemModel>
 #include <QtGui/QTableView>
 #include <QtGui/QScrollBar>
 #include <QtGui/QHeaderView>
 
-namespace GB2 {
+namespace U2 {
 
-static LogCategory log(ULOG_CAT_WD);
-
-class CfgTreeItem
-{
+class CfgTreeItem {
 public:
     CfgTreeItem(Actor* a, CfgTreeItem *parent = 0) : parentItem(parent), actor(a) {}
     CfgTreeItem(const QString& name, CfgTreeItem *parent) : parentItem(parent), actor(parent->actor), name(name) {}
@@ -42,7 +36,7 @@ public:
 
 class CfgTreeModel : public QAbstractItemModel {
 public:
-    CfgTreeModel(QList<Actor*> actors, QList<Iteration>& lst, QObject *parent = 0) : QAbstractItemModel(parent), iterations(lst)
+    CfgTreeModel(QList<Actor*> actors, QList<Iteration> &lst, QObject *parent = 0) : QAbstractItemModel(parent), iterations(lst)
     {
         root = new CfgTreeItem(NULL);
         foreach(Actor* a, actors) {
@@ -111,6 +105,9 @@ public:
         CfgTreeItem *item = getItem(index);
         if (item->name.isEmpty() || index.column() == 0)
             return Qt::ItemIsEnabled;
+        if(index.column() == 1) {
+            return Qt::ItemIsEnabled | Qt::ItemIsSelectable;
+        }
 
         return Qt::ItemIsEditable | Qt::ItemIsEnabled | Qt::ItemIsSelectable;
     }
@@ -207,22 +204,24 @@ public:
         {
         case Qt::EditRole:
         case ConfigurationEditor::ItemValueRole:
-            if (col == 1) {
+            /*if (col == 1) {
                 QVariant old = item->actor->getParameter(item->name)->getAttributePureValue();
                 if (old != value) {
                     item->actor->setParameter(item->name, value);
                     emit dataChanged(index, createIndex(index.row(), iterations.size() + 1, item));
-                }
-            } else {
+                
+                }return true;
+            } else {*/
                 ActorId aid = item->actor->getId();
                 QVariantMap& cfg = iterations[col-2].cfg[aid];
                 const QString& key = item->name;
                 QVariant old = cfg.contains(key) ? cfg.value(key) : item->actor->getParameter(key)->getAttributePureValue();
                 if (old != value) {
                     cfg.insert(key, value);
+
                     emit dataChanged(index, index);
                 }
-            }
+           // }
             return true;
         }
         return false;
@@ -236,7 +235,7 @@ private:
 
 
 
-SchemaConfigurationDialog::SchemaConfigurationDialog(const Schema& sh, const QList<Iteration>& lst, QWidget* p) : QDialog(p)
+SchemaConfigurationDialog::SchemaConfigurationDialog(const Schema& sh, const QList<Iteration> &lst, QWidget* p) : QDialog(p)
 {
     setupUi(this);
 
@@ -249,7 +248,7 @@ SchemaConfigurationDialog::SchemaConfigurationDialog(const Schema& sh, const QLi
     
     iterationBox->hide();
  
-    CfgTreeModel *model = new CfgTreeModel(sh.procs, iterationList->list(), this);
+    CfgTreeModel *model = new CfgTreeModel(sh.getProcesses(), iterationList->list(), this);
     ProxyDelegate *delegate = new ProxyDelegate(this);
     treeView->setModel(model);
     treeView->setItemDelegate(delegate);  
