@@ -8,14 +8,14 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_WCFG_DIALOG_CONTROLLER_H_
-#define _GB2_WCFG_DIALOG_CONTROLLER_H_
+#ifndef _U2_WCFG_DIALOG_CONTROLLER_H_
+#define _U2_WCFG_DIALOG_CONTROLLER_H_
 
 #include <ui/ui_SchemaConfigurationDialog.h>
-#include <workflow/WorkflowModel.h>
-#include <workflow/Schema.h>
+#include <U2Lang/ActorModel.h>
+#include <U2Lang/Schema.h>
 
-namespace GB2 {
+namespace U2 {
 class IterationListWidget;
 using namespace Workflow;
 
@@ -23,7 +23,7 @@ class SchemaConfigurationDialog : public QDialog,  public Ui_SchemaConfiguration
     Q_OBJECT
 public:
     SchemaConfigurationDialog(const Schema& schema, 
-        const QList<Iteration>& lst, QWidget* p = NULL);
+        const QList<Iteration> &lst, QWidget* p = NULL);
 
     QList<Iteration>& getIterations() const;
     bool hasModifications() const {return modified;}
