@@ -10,13 +10,13 @@
 
 #include "WorkflowMetaDialog.h"
 
-#include <workflow_support/WorkflowUtils.h>
-#include <core_api/AppContext.h>
-#include <core_api/Settings.h>
-
+#include <U2Lang/WorkflowUtils.h>
+#include <U2Core/AppContext.h>
+#include <U2Core/Settings.h>
+#include <U2Designer/DesignerUtils.h>
 #include <QtGui/QFileDialog>
 
-namespace GB2 {
+namespace U2 {
 
 WorkflowMetaDialog::WorkflowMetaDialog(const Metadata& meta): meta(meta) {
     setupUi(this);
@@ -34,9 +34,17 @@ WorkflowMetaDialog::WorkflowMetaDialog(const Metadata& meta): meta(meta) {
 }
 
 void WorkflowMetaDialog::sl_onSave() {
+    assert(!WorkflowUtils::WD_FILE_EXTENSIONS.isEmpty());
     QString url = urlEdit->text();
-    if (!url.endsWith(".uws", Qt::CaseInsensitive)) {
-        url.append(".uws");
+    bool endsWithWDExt = false;
+    foreach( const QString & ext, WorkflowUtils::WD_FILE_EXTENSIONS ) {
+        assert(!ext.isEmpty());
+        if(url.endsWith(ext)) {
+            endsWithWDExt = true;
+        }
+    }
+    if(!endsWithWDExt) {
+        url.append("." + WorkflowUtils::WD_FILE_EXTENSIONS.first());
     }
     meta.url = url;
     meta.comment = commentEdit->toPlainText();
