@@ -8,15 +8,15 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_WMETADIALOG_H_
-#define _GB2_WMETADIALOG_H_
+#ifndef _U2_WMETADIALOG_H_
+#define _U2_WMETADIALOG_H_
 
 #include "ui/ui_WorkflowMetaDialog.h"
 
-#include <workflow/WorkflowModel.h>
-#include <workflow/Schema.h>
+#include <U2Lang/ActorModel.h>
+#include <U2Lang/Schema.h>
 
-namespace GB2 {
+namespace U2 {
 using namespace Workflow;
 class WorkflowMetaDialog : public QDialog, public Ui_WorkflowMetaDialog {
     Q_OBJECT
