@@ -12,14 +12,16 @@
 #include "ItemViewStyle.h"
 #include "WorkflowViewController.h"
 
-#include <workflow/WorkflowRegistry.h>
-#include <workflow/WorkflowModel.h>
-#include <workflow/IntegralBusModel.h>
-#include <workflow_support/WorkflowRunTask.h>
-#include <workflow_support/WorkflowSettings.h>
+#include <U2Lang/ActorPrototypeRegistry.h>
+#include <U2Lang/ActorModel.h>
+#include <U2Lang/IntegralBusModel.h>
+#include <U2Lang/IntegralBus.h>
+#include <U2Lang/WorkflowRunTask.h>
+#include <U2Lang/WorkflowSettings.h>
+#include <U2Lang/WorkflowUtils.h>
 
-#include <core_api/Log.h>
-#include <QBitmap>
+#include <U2Core/Log.h>
+#include <QtGui/QBitmap>
 #include <QtGui/QPainter>
 #include <QtGui/QGraphicsTextItem>
 #include <QtGui/QGraphicsSimpleTextItem>
@@ -28,14 +30,12 @@
 #include <QtGui/QGraphicsView>
 #include <QtGui/QRadialGradient>
 #include <QtGui/QTextDocument>
-#include <qmath.h>
+#include <QtCore/qmath.h>
 
-#include <workflow_support/QVariantUtils.h>
+#include <U2Core/QVariantUtils.h>
 #include <QtXml/qdom.h>
 
-namespace GB2 {
-
-static LogCategory log(ULOG_CAT_WD);
+namespace U2 {
 
 
 WorkflowProcessItem::WorkflowProcessItem(Actor* prc) : process(prc) {
@@ -49,12 +49,7 @@ WorkflowProcessItem::WorkflowProcessItem(Actor* prc) : process(prc) {
 
     styles[ItemStyles::SIMPLE] = new SimpleProcStyle(this);
     styles[ItemStyles::EXTENDED] = new ExtendedProcStyle(this);
-    StyleId sid = WorkflowSettings::defaultStyle();
-    if (!styles.contains(sid)) {
-        sid = ItemStyles::EXTENDED;
-    }
-    currentStyle = styles.value(sid);
-
+    currentStyle = getStyleByIdSafe(WorkflowSettings::defaultStyle());
     currentStyle->setActive(true);
     createPorts();
 }
@@ -66,6 +61,23 @@ WorkflowProcessItem::~WorkflowProcessItem()
     qDeleteAll(ports);
 }
 
+ItemViewStyle* WorkflowProcessItem::getStyleByIdSafe(StyleId id) const {
+    if (!styles.contains(id)) {
+        uiLog.trace(QString("Unknown workflow item style: %1").arg(id));
+        id = ItemStyles::EXTENDED;
+    }
+    ItemViewStyle* result = styles.value(id);
+    assert(result!=NULL);
+    return result;
+}
+
+ItemViewStyle* WorkflowProcessItem::getStyleById(const StyleId & id) const {
+    return styles.value(id);
+}
+
+bool WorkflowProcessItem::containsStyle(const StyleId & id) const {
+    return styles.contains(id);
+}
 
 WorkflowPortItem* WorkflowProcessItem::getPort(const QString& id) const {
     foreach(WorkflowPortItem* pit, ports) {
@@ -116,7 +128,7 @@ void WorkflowProcessItem::sl_update() {
 void WorkflowProcessItem::setStyle(StyleId s) {
     prepareGeometryChange();
     currentStyle->setActive(false);
-    currentStyle = styles.value(s);
+    currentStyle = getStyleByIdSafe(s);
     currentStyle->setActive(true);
     currentStyle->refresh();
     foreach(WorkflowPortItem* pit, ports) {
@@ -245,19 +257,19 @@ void WorkflowProcessItem::paint(QPainter *painter,
 QVariant WorkflowProcessItem::itemChange ( GraphicsItemChange change, const QVariant & value ) 
 {
     switch(change) {
-        case ItemSelectedHasChanged:
-        {
-            currentStyle->update();
+    case ItemSelectedHasChanged:
+    {
+        currentStyle->update();
+    }
+        break;
+    case ItemZValueHasChanged:
+    {
+        qreal z = qVariantValue<qreal>(value);
+        foreach(WorkflowPortItem* pit, ports) {
+            pit->setZValue(z);
         }
+    }
         break;
-        case ItemZValueHasChanged:
-		{
-            qreal z = qVariantValue<qreal>(value);
-			foreach(WorkflowPortItem* pit, ports) {
-				pit->setZValue(z);
-			}
-		}
-		break;
     case ItemPositionChange:
         if (WorkflowSettings::snap2Grid()) {
             // value is the new position.
@@ -267,19 +279,25 @@ QVariant WorkflowProcessItem::itemChange ( GraphicsItemChange change, const QVar
             return newPos;
         }
         /*foreach(WorkflowPortItem* pit, ports) {
-            foreach(WBusItem*bit, pit->getDataFlows()) {
+            foreach(WorkflowBusItem*bit, pit->getDataFlows()) {
                 bit->prepareGeometryChange();
             }
         }*/
         break;
-	case ItemPositionHasChanged:
-        foreach(WorkflowPortItem* pit, ports) {
-            pit->setPos(pos());
-            foreach(WBusItem*bit, pit->getDataFlows()) {
-                bit->updatePos();
+    case ItemPositionHasChanged:
+        {
+            foreach(WorkflowPortItem* pit, ports) {
+                pit->setPos(pos());
+                foreach(WorkflowBusItem*bit, pit->getDataFlows()) {
+                    bit->updatePos();
+                }
+            }
+            WorkflowScene * sc = qobject_cast<WorkflowScene*>(scene());
+            if(sc != NULL) {
+                sc->setModified(true);
             }
         }
-		break;
+        break;
     case ItemSceneHasChanged:
         if (scene()) {
             foreach(WorkflowPortItem* pit, ports) {
@@ -287,21 +305,20 @@ QVariant WorkflowProcessItem::itemChange ( GraphicsItemChange change, const QVar
             }
         }
         break;
-	case ItemSceneChange: 
-		if (qVariantValue<QGraphicsScene*>(value) == NULL) {
-			foreach(WorkflowPortItem* pit, ports) {
-				scene()->removeItem(pit);
-			}
-		}
-		break;
+    case ItemSceneChange:
+        if (qVariantValue<QGraphicsScene*>(value) == NULL) {
+            foreach(WorkflowPortItem* pit, ports) {
+                scene()->removeItem(pit);
+            }
+        }
+        break;
     default:
         break;
     }
     return QGraphicsItem::itemChange(change, value);
 }
 
-bool WorkflowProcessItem::sceneEvent( QEvent * event )
-{
+bool WorkflowProcessItem::sceneEvent( QEvent * event ) {
     if (currentStyle->sceneEventFilter(this, event)) {
         return true;
     }
@@ -345,25 +362,25 @@ void WorkflowProcessItem::loadState(QDomElement& el) {
 ///////////// PIO /////////////
 
 WorkflowPortItem* WorkflowPortItem::findNearbyBindingCandidate(const QPointF& pos) const {
-	QPainterPath neighbourhood;
-	neighbourhood.addEllipse(pos, R/2, R/2);
-	//QRectF neighbourhood(pos.x() - R/2, pos.y() + R/2, R, R);
-	WorkflowPortItem* candidate = NULL;
-	qreal distance = R*2;
-	foreach(QGraphicsItem* it, scene()->items(neighbourhood, Qt::IntersectsItemBoundingRect)) {
+    QPainterPath neighbourhood;
+    neighbourhood.addEllipse(pos, R/2, R/2);
+    //QRectF neighbourhood(pos.x() - R/2, pos.y() + R/2, R, R);
+    WorkflowPortItem* candidate = NULL;
+    qreal distance = R*2;
+    foreach(QGraphicsItem* it, scene()->items(neighbourhood, Qt::IntersectsItemBoundingRect)) {
         WorkflowPortItem* next = qgraphicsitem_cast<WorkflowPortItem*>(it);
-		if (next) {
-			if (bindCandidates.contains(next)) {
-				QLineF l(pos, next->headToScene());
-				qreal len = l.length();				
-				if (distance > len) {
-					distance = len;
-					candidate = next;
-				}
-			}
-		}
-	}
-	return candidate;
+        if (next) {
+            if (bindCandidates.contains(next)) {
+                QLineF l(pos, next->headToScene());
+                qreal len = l.length();
+                if (distance > len) {
+                    distance = len;
+                    candidate = next;
+                }
+            }
+        }
+    }
+    return candidate;
 }
 
 //static const QCursor portRotationCursor = QCursor(QBitmap(":workflow_designer/images/rot_cur.png")); //FIXME
@@ -404,6 +421,7 @@ void WorkflowPortItem::adaptOwnerShape() {
 }
 
 void WorkflowPortItem::setOrientation(qreal angle) {
+    qreal oldOrientation = orientation;
     orientation = angle;
     bool snap2grid = WorkflowSettings::snap2Grid();
     if (ItemStyles::SIMPLE == currentStyle) {
@@ -419,8 +437,7 @@ void WorkflowPortItem::setOrientation(qreal angle) {
         resetTransform();
         translate(x, y);
         rotate(angle);    
-    } else {
-        
+    } else { // EXTENDED STYLE
         resetTransform();
         QRectF rec = owner->boundingRect();
         QPolygonF pol(owner->shape().toFillPolygon());
@@ -469,15 +486,22 @@ void WorkflowPortItem::setOrientation(qreal angle) {
         //log.info(QString("a=%1 pa=%2 pn=%3 n=%4 df=%5").arg(angle).arg(polyAngle).arg(polyLine.normalVector().angle()).arg(norm).arg(df));
         rotate(-norm);
     }
+    if(oldOrientation != orientation) {
+        WorkflowScene * sc = qobject_cast<WorkflowScene*>(owner->scene());
+        if(sc != NULL) {
+            sc->setModified(true);
+            sc->update();
+        }
+    }
 }
 
-WBusItem* WorkflowPortItem::getDataFlow(const WorkflowPortItem* otherPit) const {
-	foreach(WBusItem* dit, flows) {
-		if ((port->isInput() ? dit->getOutPort() : dit->getInPort()) == otherPit) {
-			return dit;
-		}
-	}
-	return NULL;
+WorkflowBusItem* WorkflowPortItem::getDataFlow(const WorkflowPortItem* otherPit) const {
+    foreach(WorkflowBusItem* dit, flows) {
+        if ((port->isInput() ? dit->getOutPort() : dit->getInPort()) == otherPit) {
+            return dit;
+        }
+    }
+    return NULL;
 }
 
 static bool checkTypes(Port* p1, Port* p2) {
@@ -502,50 +526,59 @@ static bool checkTypes(Port* p1, Port* p2) {
 
 WorkflowPortItem* WorkflowPortItem::checkBindCandidate(const QGraphicsItem* it) const 
 {
-	switch (it->type()) {
-			case WorkflowProcessItemType: 
-				{
-					const WorkflowProcessItem* receiver = static_cast<const WorkflowProcessItem*>(it);
+    switch (it->type()) {
+            case WorkflowProcessItemType:
+                {
+                    const WorkflowProcessItem* receiver = static_cast<const WorkflowProcessItem*>(it);
                     // try best matches first
                     foreach(WorkflowPortItem* otherPit, receiver->getPortItems()) {
                         if (port->canBind(otherPit->getPort()) && checkTypes(port, otherPit->getPort())) {
                             return otherPit;
                         }
                     }
-					// take first free port
-					foreach(WorkflowPortItem* otherPit, receiver->getPortItems()) {
-						if (port->canBind(otherPit->getPort())) {
-							return otherPit;
-						}
-					}
-				}
-				break;
-			case WorkflowPortItemType:
-				{
-					WorkflowPortItem* otherPit = (WorkflowPortItem*)(it);
-					if (port->canBind(otherPit->getPort())) {
-						return otherPit;
-					}
-				}
-				break;
-	}
-	return NULL;
+                    // take first free port
+                    foreach(WorkflowPortItem* otherPit, receiver->getPortItems()) {
+                        if (port->canBind(otherPit->getPort())) {
+                            return otherPit;
+                        }
+                    }
+                }
+                break;
+            case WorkflowPortItemType:
+                {
+                    WorkflowPortItem* otherPit = (WorkflowPortItem*)(it);
+                    if (port->canBind(otherPit->getPort())) {
+                        return otherPit;
+                    }
+                }
+                break;
+    }
+    return NULL;
 }
 
-
-WBusItem* WorkflowPortItem::tryBind(WorkflowPortItem* otherPit) {
-    WBusItem* dit = NULL;
+WorkflowBusItem* WorkflowPortItem::tryBind(WorkflowPortItem* otherPit) {
+    WorkflowBusItem* dit = NULL;
+   
+    QList<QString> linkedActors;
     if (port->canBind(otherPit->getPort())) {
-        dit = new WBusItem(this, otherPit);
+        WorkflowUtils::getLinkedActorsId(port->owner(), linkedActors);
+        if(linkedActors.contains(otherPit->getPort()->owner()->getId())) {
+            return NULL;
+        }
+
+        dit = new WorkflowBusItem(this, otherPit);
         flows << dit;
         otherPit->flows << dit;
-        scene()->addItem(dit);
+        WorkflowScene * sc = qobject_cast<WorkflowScene*>(scene());
+        assert(sc != NULL);
+        sc->addItem(dit);
+        sc->setModified(true);
         dit->updatePos();
     }
     return dit;
 }
 
-void WorkflowPortItem::removeDataFlow(WBusItem* flow) {
+void WorkflowPortItem::removeDataFlow(WorkflowBusItem* flow) {
     assert(flows.contains(flow));
     flows.removeOne(flow);
     port->removeLink(flow->getBus());
@@ -557,7 +590,7 @@ QPointF WorkflowPortItem::head(const QGraphicsItem* item) const {
 }
 
 QPointF WorkflowPortItem::headToScene() const {
-	return mapToScene(A, 0);
+    return mapToScene(A, 0);
 }
 
 QLineF WorkflowPortItem::arrow(const QGraphicsItem* item) const {
@@ -568,25 +601,25 @@ QRectF WorkflowPortItem::boundingRect(void) const {
     QRectF rect(0, -A, A+A/2, 2*A);
     if (dragging) {
         rect |= QRectF(QPointF(A, 0), dragPoint);
-		//FIXME arrow tip inclusion
+        //FIXME arrow tip inclusion
     }
     return rect;
 }
 
 static void drawArrow(QPainter *painter, const QPen& pen, const QPointF& p1, const QPointF& p2) {
-	painter->setPen(pen);
-	QLineF l(p1, p2);
-	painter->drawLine(l);
-	//draw arrow tip
-	painter->save();
-	painter->translate(p2);
-	painter->rotate(-l.angle());
-	QRectF rf(-3*A, -A/2, A*1.5, A);
-	QPainterPath tip(QPointF(0,0));
-	tip.arcTo(rf, -50, 100);
-	tip.closeSubpath();
-	painter->fillPath(tip, QBrush(pen.color()));
-	painter->restore();
+    painter->setPen(pen);
+    QLineF l(p1, p2);
+    painter->drawLine(l);
+    //draw arrow tip
+    painter->save();
+    painter->translate(p2);
+    painter->rotate(-l.angle());
+    QRectF rf(-3*A, -A/2, A*1.5, A);
+    QPainterPath tip(QPointF(0,0));
+    tip.arcTo(rf, -50, 100);
+    tip.closeSubpath();
+    painter->fillPath(tip, QBrush(pen.color()));
+    painter->restore();
 }
 
 static QList<WorkflowPortItem*> getCandidates(WorkflowPortItem* port) {
@@ -617,17 +650,17 @@ void WorkflowPortItem::paint(QPainter *painter,
         painter->setPen(pen);
     }
 
-	//painter->fillRect(boundingRect(), QBrush(Qt::magenta, Qt::Dense4Pattern));
+    //painter->fillRect(boundingRect(), QBrush(Qt::magenta, Qt::Dense4Pattern));
     painter->setRenderHint(QPainter::Antialiasing);
     painter->drawLine(0, 0, bl, 0);
-	
+
     if (port->isInput()) {
         if (highlight) {
             QPainterPath path;
             path.addEllipse(bl, -A/2, A, A);
             painter->fillPath(path, QBrush(greenLight));
         } else {
-                    painter->drawArc(QRectF(bl, -A/2, A, A), 90*16, 180*16);
+            painter->drawArc(QRectF(bl, -A/2, A, A), 90*16, 180*16);
         }
     } else {
         if (highlight) {
@@ -635,7 +668,7 @@ void WorkflowPortItem::paint(QPainter *painter,
             path.addEllipse(p1, A/2, A/2);
             painter->fillPath(path, QBrush(greenLight));
         } else {
-		    painter->drawEllipse(p1, A/2, A/2);
+            painter->drawEllipse(p1, A/2, A/2);
         }
     }
     if (0 && port->getWidth() == 0) {
@@ -660,16 +693,16 @@ void WorkflowPortItem::paint(QPainter *painter,
         painter->restore();
     }
     if (dragging) {
-		QPen pen;
-		//pen.setWidthF(3);
-		pen.setStyle(Qt::DotLine);
+        QPen pen;
+        //pen.setWidthF(3);
+        pen.setStyle(Qt::DotLine);
         if (sticky) {
             pen.setColor(stickyLight);
         }
-		if (port->isInput())
-			drawArrow(painter, pen, dragPoint, p1);
-		else
-			drawArrow(painter, pen, p1, dragPoint);
+        if (port->isInput())
+            drawArrow(painter, pen, dragPoint, p1);
+        else
+            drawArrow(painter, pen, p1, dragPoint);
     } 
     else if (option->state & QStyle::State_Selected) {
         QPen pen;
@@ -678,6 +711,7 @@ void WorkflowPortItem::paint(QPainter *painter,
         painter->setPen(pen);
         painter->drawRoundedRect(boundingRect(), 30, 30, Qt::RelativeSize);
     }
+
 }
 
 void WorkflowPortItem::mouseMoveEvent( QGraphicsSceneMouseEvent * event ) {
@@ -718,11 +752,11 @@ void WorkflowPortItem::mouseMoveEvent( QGraphicsSceneMouseEvent * event ) {
     } 
     if (dragging) {
         dragPoint = rotating ? mapFromScene(event->scenePos()) : event->pos();
-		WorkflowPortItem* preferable = findNearbyBindingCandidate(event->scenePos());
-		if (preferable) {
-			dragPoint = preferable->head(this);
+        WorkflowPortItem* preferable = findNearbyBindingCandidate(event->scenePos());
+        if (preferable) {
+            dragPoint = preferable->head(this);
             sticky = true;
-		}
+        }
     } 
 }
 
@@ -756,17 +790,17 @@ void WorkflowPortItem::mouseReleaseEvent ( QGraphicsSceneMouseEvent * event ) {
         //bool done = false;
         WorkflowPortItem* otherPit = NULL;
         foreach(QGraphicsItem * it, li) {
-			otherPit = checkBindCandidate(it);
-            WBusItem* dit;
-			if (otherPit && (dit = tryBind(otherPit))) {
+            otherPit = checkBindCandidate(it);
+            WorkflowBusItem* dit;
+            if (otherPit && (dit = tryBind(otherPit))) {
                 scene()->clearSelection();
-                BusPort* bp = qobject_cast<BusPort*>(dit->getInPort()->getPort());
+                IntegralBusPort* bp = qobject_cast<IntegralBusPort*>(dit->getInPort()->getPort());
                 if (bp) {
                     bp->setupBusMap();
                 }
                 dit->getInPort()->setSelected(true);
-				break;
-			}
+                break;
+            }
         }
         prepareGeometryChange();
         dragging = false;dragPoint = QPointF();
@@ -782,10 +816,8 @@ void WorkflowPortItem::hoverEnterEvent ( QGraphicsSceneHoverEvent * event ) {
     if (getWorkflowScene()->isLocked()) {
         return;
     }
-    setCursor((event->modifiers() & portRotationModifier) ? 
-//portRotationCursor 
-QCursor(QPixmap(":workflow_designer/images/rot_cur.png"))
-: QCursor(Qt::OpenHandCursor));
+    setCursor((event->modifiers() & portRotationModifier) ? QCursor(QPixmap(":workflow_designer/images/rot_cur.png")) : 
+                                                                                                    QCursor(Qt::OpenHandCursor));
 }
 
 void WorkflowPortItem::hoverLeaveEvent(QGraphicsSceneHoverEvent *) {
@@ -794,17 +826,17 @@ void WorkflowPortItem::hoverLeaveEvent(QGraphicsSceneHoverEvent *) {
 
 QVariant WorkflowPortItem::itemChange ( GraphicsItemChange change, const QVariant & value ) {
     if (change == ItemPositionChange || change == ItemTransformChange) {
-        foreach(WBusItem* dit, flows) {
+        foreach(WorkflowBusItem* dit, flows) {
             dit->prepareGeometryChange();
         }
     } else if (change == ItemPositionHasChanged || change == ItemTransformHasChanged) {
-        foreach(WBusItem* dit, flows) {
+        foreach(WorkflowBusItem* dit, flows) {
             //TODO correct update
             //dit->update(dit->boundingRect());
             dit->updatePos();
         }
     } else if (change == ItemSceneChange && qVariantValue<QGraphicsScene*>(value) == NULL) {
-        foreach(WBusItem* dit, flows) {
+        foreach(WorkflowBusItem* dit, flows) {
             scene()->removeItem(dit);
             delete dit;
         }
@@ -815,8 +847,8 @@ QVariant WorkflowPortItem::itemChange ( GraphicsItemChange change, const QVarian
 
 ////////////////// Flow //////////////
 
-WBusItem::WBusItem(WorkflowPortItem* p1, WorkflowPortItem* p2) 
-{	
+WorkflowBusItem::WorkflowBusItem(WorkflowPortItem* p1, WorkflowPortItem* p2) 
+{
     if (p1->getPort()->isInput()) {
         assert(!p2->getPort()->isInput());
         dst = p1;
@@ -836,14 +868,14 @@ WBusItem::WBusItem(WorkflowPortItem* p1, WorkflowPortItem* p2)
     connect(dst->getPort(), SIGNAL(bindingChanged()), this, SLOT(sl_update()));
 }
 
-WBusItem::~WBusItem()
+WorkflowBusItem::~WorkflowBusItem()
 {
     assert(bus == NULL);
     //delete text;
 }
 
 
-void WBusItem::updatePos() {
+void WorkflowBusItem::updatePos() {
 //     QPointF p1 = dst->pos();
 //     QPointF p2 = src->pos();
     QPointF p1 = dst->headToScene();
@@ -852,7 +884,7 @@ void WBusItem::updatePos() {
     setPos((p1.x() + p2.x())/2, (p1.y() + p2.y())/2);
 }
 
-QVariant WBusItem::itemChange ( GraphicsItemChange change, const QVariant & value ) {
+QVariant WorkflowBusItem::itemChange ( GraphicsItemChange change, const QVariant & value ) {
     if (change == ItemSceneChange && qVariantValue<QGraphicsScene*>(value) == NULL) {
         dst->removeDataFlow(this);
         src->removeDataFlow(this);
@@ -864,16 +896,16 @@ QVariant WBusItem::itemChange ( GraphicsItemChange change, const QVariant & valu
     return QGraphicsItem::itemChange(change, value);
 }
 
-void WBusItem::hoverEnterEvent ( QGraphicsSceneHoverEvent * event ) {
+void WorkflowBusItem::hoverEnterEvent ( QGraphicsSceneHoverEvent * event ) {
     Q_UNUSED(event);
     setCursor(QCursor(Qt::PointingHandCursor));
 }
-void WBusItem::hoverLeaveEvent ( QGraphicsSceneHoverEvent * event ) {
+void WorkflowBusItem::hoverLeaveEvent ( QGraphicsSceneHoverEvent * event ) {
     Q_UNUSED(event);
     unsetCursor();
 }
 
-QRectF WBusItem::boundingRect(void) const {
+QRectF WorkflowBusItem::boundingRect(void) const {
     QRectF brect(mapFromItem(dst, dst->boundingRect()).boundingRect() | mapFromItem(src, src->boundingRect()).boundingRect());
     QRectF trect(text->boundingRect().translated(text->pos()));
     if (/*getWorkflowScene()->getRunner()*/ true) {
@@ -882,25 +914,25 @@ QRectF WBusItem::boundingRect(void) const {
     return brect | trect;
 }
 
-QPainterPath WBusItem::shape () const {
-	QPainterPath p;
-	QPointF p1 = dst->head(this);
-	QPointF p2 = src->head(this);
-	QLineF direct(p2,p1);
-	QLineF n = direct.normalVector();
-	n.setLength(A/2);
-	p.moveTo(n.p2());
-	p.lineTo(n.translated(p1-p2).p2());
-	QLineF rn(n.p2(), n.p1());
-	rn.translate(n.p1()-n.p2());
-	p.lineTo(rn.translated(p1-p2).p2());
-	p.lineTo(rn.p2());
-	p.closeSubpath();
-	p.addRect(text->boundingRect().translated(text->pos()));
-	return p;
+QPainterPath WorkflowBusItem::shape () const {
+    QPainterPath p;
+    QPointF p1 = dst->head(this);
+    QPointF p2 = src->head(this);
+    QLineF direct(p2,p1);
+    QLineF n = direct.normalVector();
+    n.setLength(A/2);
+    p.moveTo(n.p2());
+    p.lineTo(n.translated(p1-p2).p2());
+    QLineF rn(n.p2(), n.p1());
+    rn.translate(n.p1()-n.p2());
+    p.lineTo(rn.translated(p1-p2).p2());
+    p.lineTo(rn.p2());
+    p.closeSubpath();
+    p.addRect(text->boundingRect().translated(text->pos()));
+    return p;
 }
 
-void WBusItem::paint ( QPainter * painter, const QStyleOptionGraphicsItem * option, QWidget * widget) {
+void WorkflowBusItem::paint ( QPainter * painter, const QStyleOptionGraphicsItem * option, QWidget * widget) {
     Q_UNUSED(widget);
     painter->setRenderHint(QPainter::Antialiasing);
     QColor baseColor(0x66, 0x66, 0x66);
@@ -910,9 +942,9 @@ void WBusItem::paint ( QPainter * painter, const QStyleOptionGraphicsItem * opti
     QPointF p2 = src->head(this);
 
     QPainterPath path;
-	path.addEllipse(p2, A/2 - 2, A/2 - 2);
-	path.addEllipse(p1, A/2 - 2, A/2 - 2);
-	painter->fillPath(path, QBrush(baseColor));
+    path.addEllipse(p2, A/2 - 2, A/2 - 2);
+    path.addEllipse(p1, A/2 - 2, A/2 - 2);
+    painter->fillPath(path, QBrush(baseColor));
 
     QPen pen = painter->pen();
     if (option->state & QStyle::State_Selected) {
@@ -922,8 +954,8 @@ void WBusItem::paint ( QPainter * painter, const QStyleOptionGraphicsItem * opti
     if (!validate()) {
         pen.setColor(Qt::red);
     }
-	drawArrow(painter, pen, p2, p1);
-    update();
+    drawArrow(painter, pen, p2, p1);
+    //update();
 
     painter->setRenderHint(QPainter::NonCosmeticDefaultPen);
     QColor yc = QColor(Qt::yellow).lighter();yc.setAlpha(127);
@@ -933,22 +965,26 @@ void WBusItem::paint ( QPainter * painter, const QStyleOptionGraphicsItem * opti
 
     WorkflowRunTask* rt = getWorkflowScene()->getRunner();
     if (rt) {
-        int num = rt->getMsgNum(this->bus);
-        QString rts = QString("%1 in queue").arg(num);
+        int msgsInQueue = rt->getMsgNum(this->bus);
+        int passed = rt->getMsgPassed(this->bus);
+        QString rts = QString("%1 in queue, %2 passed").arg(msgsInQueue).arg(passed);
         QRectF rtb = textRec.translated(0, -QFontMetricsF(QFont()).height());
+        qreal shift = (QFontMetricsF(QFont()).width(rts) - rtb.width()) / 2;
+        rtb.setLeft(rtb.left() - shift);
+        rtb.setRight(rtb.right() + shift);
         painter->drawText(rtb, Qt::AlignHCenter, rts);
-        if (num == 0) {
+        if (msgsInQueue == 0) {
             return;
         }
-        qreal dx = (p2.x() - p1.x())/num;
-        qreal dy = (p2.y() - p1.y())/num;
+        qreal dx = (p2.x() - p1.x())/msgsInQueue;
+        qreal dy = (p2.y() - p1.y())/msgsInQueue;
         QPointF dp(dx,dy);
         QColor c1("#AA0404");
         painter->setPen(c1);
         c1.setAlphaF(0.8);
         QColor c2(Qt::white);
         c2.setAlphaF(0.8);
-        while (num-- > 0) {
+        while (msgsInQueue-- > 0) {
             QPainterPath p;
             p.addEllipse(p1, 3,3);
             QRadialGradient rg(p1+QPointF(1.,-1.), 3);
@@ -964,19 +1000,19 @@ void WBusItem::paint ( QPainter * painter, const QStyleOptionGraphicsItem * opti
     }
 }
 
-void WBusItem::sl_update() {
+void WorkflowBusItem::sl_update() {
     update();
 }
 
-bool WBusItem::validate() {
+bool WorkflowBusItem::validate() {
     QStringList lst;
     return dst->getPort()->validate(lst);
 }
 
-void WBusItem::saveState(QDomElement& el) const {
+void WorkflowBusItem::saveState(QDomElement& el) const {
     el.setAttribute("hint-pos", QVariantUtils::var2String(text->pos()));
 }
-void WBusItem::loadState(QDomElement& el) {
+void WorkflowBusItem::loadState(QDomElement& el) {
     if (el.hasAttribute("hint-pos")) {
         QPointF pos = QVariantUtils::String2Var(el.attribute("hint-pos")).toPointF();
         if (!pos.isNull()) {
