@@ -8,10 +8,10 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_WORKFLOW_VIEW_ITEMS_H_
-#define _GB2_WORKFLOW_VIEW_ITEMS_H_
+#ifndef _U2_WORKFLOW_VIEW_ITEMS_H_
+#define _U2_WORKFLOW_VIEW_ITEMS_H_
 
-#include <workflow/WorkflowModel.h>
+#include <U2Lang/ActorModel.h>
 
 #include <QtGui/QAction>
 #include <QtGui/QWidget>
@@ -20,10 +20,11 @@
 
 class QDomElement;
 
-namespace GB2 {
+namespace U2 {
 using namespace Workflow;
 class WorkflowScene;
 class ItemViewStyle;
+
 typedef QString StyleId;
 
 #define GRID_STEP 15
@@ -61,7 +62,7 @@ public:
 };
 
 class WorkflowPortItem;
-class WBusItem;
+class WorkflowBusItem;
 enum {
     WorkflowProcessItemType = QGraphicsItem::UserType + 1, 
     WorkflowPortItemType,
@@ -71,7 +72,7 @@ enum {
 class WorkflowProcessItem : public QObject, public StyledItem {
     Q_OBJECT
 public:
-	WorkflowProcessItem(Actor* process);
+    WorkflowProcessItem(Actor* process);
     virtual ~WorkflowProcessItem();
     Actor* getProcess() const {return process;}
     WorkflowPortItem* getPort(const QString& id) const;
@@ -91,6 +92,11 @@ public:
 
     void saveState(QDomElement& ) const;
     void loadState(QDomElement& );
+    
+    ItemViewStyle* getStyleByIdSafe(StyleId id) const;
+    ItemViewStyle* getStyleById(const StyleId & id) const;
+    bool containsStyle(const StyleId & id) const;
+    
 protected:
     QVariant itemChange ( GraphicsItemChange change, const QVariant & value );
     virtual bool sceneEvent ( QEvent * event );
@@ -100,7 +106,7 @@ private:
     void createPorts();
     QMap<StyleId, ItemViewStyle*> styles;
     ItemViewStyle* currentStyle;
-	Actor* process;
+    Actor* process;
     QList<WorkflowPortItem*> ports;
 };
 
@@ -110,16 +116,16 @@ public:
     virtual ~WorkflowPortItem();
     Port* getPort() const {return port;}
     WorkflowProcessItem* getOwner() const {return owner;}
-    QList<WBusItem*> getDataFlows() const {return flows;}
-	WBusItem* getDataFlow(const WorkflowPortItem* other) const;
-	WorkflowPortItem* checkBindCandidate(const QGraphicsItem* it) const;
-	WorkflowPortItem* findNearbyBindingCandidate(const QPointF& at) const;
-    WBusItem* tryBind(WorkflowPortItem* otherPort);
-    void removeDataFlow(WBusItem* flow);
+    QList<WorkflowBusItem*> getDataFlows() const {return flows;}
+    WorkflowBusItem* getDataFlow(const WorkflowPortItem* other) const;
+    WorkflowPortItem* checkBindCandidate(const QGraphicsItem* it) const;
+    WorkflowPortItem* findNearbyBindingCandidate(const QPointF& at) const;
+    WorkflowBusItem* tryBind(WorkflowPortItem* otherPort);
+    void removeDataFlow(WorkflowBusItem* flow);
     // position of the arrow tip in items coordinates 
     QPointF head(const QGraphicsItem* item) const;
-	// position of the arrow tip in scene coordinates
-	QPointF headToScene() const;
+    // position of the arrow tip in scene coordinates
+    QPointF headToScene() const;
     // direction of the arrow in items coordinates 
     QLineF arrow(const QGraphicsItem* item) const;
     QRectF boundingRect(void) const;
@@ -150,7 +156,7 @@ private:
     Port* port;
     WorkflowProcessItem* owner;
     qreal orientation;
-    QList<WBusItem*> flows;
+    QList<WorkflowBusItem*> flows;
     bool dragging;
     bool rotating;
     bool sticky;
@@ -159,13 +165,13 @@ private:
     QPointF dragPoint;
 };
 
-class WBusItem : public QObject, public StyledItem {
+class WorkflowBusItem : public QObject, public StyledItem {
     Q_OBJECT
     friend class WorkflowPortItem;
     friend class WorkflowProcessItem;
 public:
-    WBusItem(WorkflowPortItem* p1, WorkflowPortItem* p2);
-    virtual ~WBusItem();
+    WorkflowBusItem(WorkflowPortItem* p1, WorkflowPortItem* p2);
+    virtual ~WorkflowBusItem();
     WorkflowPortItem *getInPort() const {return dst;}
     WorkflowPortItem *getOutPort() const {return src;}
     Link* getBus() const {return bus;}
@@ -178,14 +184,16 @@ public:
 
     void saveState(QDomElement& ) const;
     void loadState(QDomElement& );
-
+    
+    QGraphicsItem* getText() const {return text;}
+    
 protected:
     QVariant itemChange ( GraphicsItemChange change, const QVariant & value );
-	//void mouseMoveEvent ( QGraphicsSceneMouseEvent * event );
-	//void mousePressEvent ( QGraphicsSceneMouseEvent * event );
-	//void mouseReleaseEvent ( QGraphicsSceneMouseEvent * event );
-	void hoverEnterEvent ( QGraphicsSceneHoverEvent * event );
-	void hoverLeaveEvent ( QGraphicsSceneHoverEvent * event );
+    //void mouseMoveEvent ( QGraphicsSceneMouseEvent * event );
+    //void mousePressEvent ( QGraphicsSceneMouseEvent * event );
+    //void mouseReleaseEvent ( QGraphicsSceneMouseEvent * event );
+    void hoverEnterEvent ( QGraphicsSceneHoverEvent * event );
+    void hoverLeaveEvent ( QGraphicsSceneHoverEvent * event );
 private slots:
     void sl_update();
 
@@ -194,11 +202,12 @@ private:
     Link* bus;
     WorkflowPortItem *dst, *src;
     QGraphicsItem* text;
-	//bool dragging;
-	//QPointF dragPoint;
+    //bool dragging;
+    //QPointF dragPoint;
 };
 
-}//namespace
+} // U2
 
+Q_DECLARE_METATYPE(U2::StyleId);
 
 #endif
