@@ -11,29 +11,27 @@
 #include "BaseDocWorker.h"
 
 #include "CoreLib.h"
-#include <workflow/WorkflowEnv.h>
-#include <workflow_support/WorkflowUtils.h>
-#include <workflow_support/CoreLibConstants.h>
-#include <workflow_library/BioActorLibrary.h>
-#include <util_tasks/LoadDocumentTask.h>
-#include <util_tasks/SaveDocumentTask.h>
-#include <util_tasks/FailTask.h>
-#include <util_tasks/MultiTask.h>
+#include <U2Lang/WorkflowEnv.h>
+#include <U2Lang/WorkflowUtils.h>
+#include <U2Lang/CoreLibConstants.h>
+#include <U2Lang/BioActorLibrary.h>
+#include <U2Core/LoadDocumentTask.h>
+#include <U2Core/SaveDocumentTask.h>
+#include <U2Core/FailTask.h>
+#include <U2Core/MultiTask.h>
 
-#include <core_api/AppContext.h>
-#include <core_api/GUrlUtils.h>
-#include <core_api/ProjectModel.h>
-#include <core_api/Log.h>
-#include <core_api/DocumentModel.h>
-#include <core_api/IOAdapter.h>
-#include <core_api/DocumentUtils.h>
-#include <util_gui/DialogUtils.h>
+#include <U2Core/AppContext.h>
+#include <U2Core/GUrlUtils.h>
+#include <U2Core/ProjectModel.h>
+#include <U2Core/Log.h>
+#include <U2Core/DocumentModel.h>
+#include <U2Core/IOAdapter.h>
+#include <U2Core/DocumentUtils.h>
+#include <U2Misc/DialogUtils.h>
 
-namespace GB2 {
+namespace U2 {
 namespace LocalWorkflow {
 
-static LogCategory log(ULOG_CAT_WD);
-
 /**********************************
  * BaseDocReader
  **********************************/
@@ -43,7 +41,7 @@ done(false), attachDoc2Proj(false) {
 }
 
 void BaseDocReader::init() {
-    QStringList urls = DesignerUtils::expandToUrls(actor->getParameter(CoreLibConstants::URL_IN_ATTR_ID)->getAttributeValue<QString>());
+    QStringList urls = WorkflowUtils::expandToUrls(actor->getParameter(CoreLibConstants::URL_IN_ATTR().getId())->getAttributeValue<QString>());
     Project* p = AppContext::getProject();
     foreach(QString url, urls) {
         Document* doc = NULL;
@@ -158,7 +156,7 @@ Task* BaseDocWriter::tick() {
         if( formatAttr != NULL ) { // user sets format
             format = AppContext::getDocumentFormatRegistry()->getFormatById( formatAttr->getAttributeValue<QString>() );
         }
-        url = actor->getParameter(CoreLibConstants::URL_OUT_ATTR_ID)->getAttributeValue<QString>();
+        url = actor->getParameter(CoreLibConstants::URL_OUT_ATTR().getId())->getAttributeValue<QString>();
         fileMode = actor->getParameter(BioActorLibrary::FILE_MODE_ATTR_ID)->getAttributeValue<uint>();
         fileMode |= SaveDoc_DestroyAfter;
         Attribute* a = actor->getParameter(CoreLibConstants::APPEND_ATTR_ID);
@@ -175,27 +173,28 @@ Task* BaseDocWriter::tick() {
         QString anUrl = url;
         
         if (anUrl.isEmpty()) {
-            anUrl = data.value(CoreLibConstants::URL_SLOT_ID).toString();
+            anUrl = data.value(CoreLibConstants::URL_SLOT().getId()).toString();
         }
         
         if (anUrl.isEmpty()) {
             QString err = tr("Unspecified URL to write %1").arg(format->getFormatName());
-            if (failFast) {
+            //if (failFast) {
                 return new FailTask(err);
-            } else {
-                log.error(err);
+            /*} else {
+                coreLog.error(err);
                 return NULL;
-            }
+            }*/
         }
         
         // set correct file extension
         
         GUrl path(anUrl);
         QStringList suffixList = format->getSupportedDocumentFileExtensions();
-        QString suffix = path.completeFileSuffix();
+        QString suffix = /*path.completeFileSuffix();*/ path.lastFileSuffix();
         QString newSuffix = suffixList.first();
-        if (suffix.contains(GZIP_SUFFIX)) {
+        if (suffix.contains("gz")) {
             newSuffix.append(GZIP_SUFFIX);
+            suffix = path.completeFileSuffix();
             suffix.remove(GZIP_SUFFIX);
         }
         if (!suffixList.contains(suffix)) {
@@ -227,7 +226,7 @@ Task* BaseDocWriter::tick() {
 Task* BaseDocWriter::processDocs()
 {
     if(docs.isEmpty()) {
-        log.error( "nothing to write: no documents" );
+        coreLog.error( "nothing to write: no documents" );
         return NULL;
     }
     QList<Task*> tlist;
@@ -245,7 +244,7 @@ Task* BaseDocWriter::processDocs()
             anUrl = GUrlUtils::ensureFileExt(anUrl, format->getSupportedDocumentFileExtensions()).getURLString();
         }
         doc->setURL(anUrl);
-        log.info(tr("Writing to %1 [%2]").arg(anUrl).arg(format->getFormatName()));
+        ioLog.details(tr("Writing to %1 [%2]").arg(anUrl).arg(format->getFormatName()));
         tlist << new SaveDocumentTask(doc, SaveDocFlags(fileMode), DocumentUtils::getNewDocFileNameExcludesHint());
     }
     docs.clear();
@@ -254,4 +253,4 @@ Task* BaseDocWriter::processDocs()
 }
 
 } // Workflow namespace
-} // GB2 namespace
+} // U2 namespace
