@@ -8,12 +8,12 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_WORKFLOW_CORE_LIB_LIB_H_
-#define _GB2_WORKFLOW_CORE_LIB_LIB_H_
+#ifndef _U2_WORKFLOW_CORE_LIB_LIB_H_
+#define _U2_WORKFLOW_CORE_LIB_LIB_H_
 
-#include <workflow/Datatype.h>
+#include <U2Lang/Datatype.h>
 
-namespace GB2 {
+namespace U2 {
 
 namespace Workflow {
 
@@ -21,9 +21,10 @@ class CoreLib : public QObject {
     Q_OBJECT
 public:
     static void init();
+    static void initUsersWorkers();
 };
 
-}//Workflow namespace
-}//GB2 namespace
+} // Workflow namespace
+} // U2 namespace
 
 #endif
