@@ -11,32 +11,32 @@
 #include "DocActors.h"
 #include "CoreLib.h"
 
-#include <workflow_support/CoreDataTypes.h>
-#include <workflow_support/DelegateEditors.h>
-#include <workflow_support/CoreLibConstants.h>
-#include <workflow_library/BioDatatypes.h>
-#include <workflow_library/BioActorLibrary.h>
-#include <core_api/DocumentModel.h>
-#include <util_tasks/SaveDocumentTask.h>
-#include <util_gui/DialogUtils.h>
+#include <U2Lang/CoreDataTypes.h>
+#include <U2Designer/DelegateEditors.h>
+#include <U2Lang/CoreLibConstants.h>
+#include <U2Lang/BioDatatypes.h>
+#include <U2Lang/BioActorLibrary.h>
+#include <U2Core/DocumentModel.h>
+#include <U2Core/SaveDocumentTask.h>
+#include <U2Misc/DialogUtils.h>
 
-namespace GB2 {
+namespace U2 {
 namespace Workflow {
 
 /****************************
  * DocActorProto
  *****************************/
 DocActorProto::DocActorProto(const DocumentFormatId& _fid, const Descriptor& _desc, const QList<PortDescriptor*>& _ports, 
-                             const QList<Attribute*>& _attrs ) : BusActorPrototype(_desc, _ports, _attrs), fid(_fid) {
+                             const QList<Attribute*>& _attrs ) : IntegralBusActorPrototype(_desc, _ports, _attrs), fid(_fid) {
 }
 
 DocActorProto::DocActorProto(const Descriptor& _desc, const GObjectType& t, const QList<PortDescriptor*>& _ports,
-                             const QList<Attribute*>& _attrs ) : BusActorPrototype(_desc, _ports, _attrs), type(t) {
+                             const QList<Attribute*>& _attrs ) : IntegralBusActorPrototype(_desc, _ports, _attrs), type(t) {
 }
 
 bool DocActorProto::isAcceptableDrop(const QMimeData * md, QVariantMap * params, const QString & urlAttrId ) const {
     QList<DocumentFormat*> fs;
-    QString url = DesignerUtils::getDropUrl(fs, md);
+    QString url = WorkflowUtils::getDropUrl(fs, md);
     foreach(DocumentFormat* df, fs) {
         if (fid == df->getFormatId()) {
             if (params) {
@@ -64,29 +64,31 @@ ReadDocActorProto::ReadDocActorProto(const DocumentFormatId& _fid, const Descrip
                                      const QList<Attribute*>& _attrs ) : DocActorProto( _fid, _desc, _ports, _attrs ) {
     attrs << new Attribute( CoreLibConstants::URL_IN_ATTR(), CoreDataTypes::STRING_TYPE(), true );
     QMap< QString, PropertyDelegate* > delegateMap;
-    delegateMap[CoreLibConstants::URL_IN_ATTR_ID] = new URLDelegate( prepareDocumentFilter(), QString(), true );
+    delegateMap[CoreLibConstants::URL_IN_ATTR().getId()] = new URLDelegate( prepareDocumentFilter(), QString(), true );
     setEditor( new DelegateEditor( delegateMap ) );
 }
 
 bool ReadDocActorProto::isAcceptableDrop(const QMimeData * md, QVariantMap * params ) const {
-    return DocActorProto::isAcceptableDrop( md, params, CoreLibConstants::URL_IN_ATTR_ID );
+    return DocActorProto::isAcceptableDrop( md, params, CoreLibConstants::URL_IN_ATTR().getId() );
 }
 
 /****************************
  * WriteDocActorProto
  *****************************/
 WriteDocActorProto::WriteDocActorProto(const DocumentFormatId& _fid, const Descriptor& _desc, const QList<PortDescriptor*>& _ports, 
-                                       const QList<Attribute*>& _attrs ) : DocActorProto( _fid, _desc, _ports, _attrs ) {
+                                       const QString & portId, const QList<Attribute*>& _attrs )
+: DocActorProto( _fid, _desc, _ports, _attrs ), outPortId(portId) {
     construct();
 }
 
 WriteDocActorProto::WriteDocActorProto(const Descriptor& _desc, const GObjectType & t, const QList<PortDescriptor*>& _ports, 
-                                       const QList<Attribute*>& _attrs ) : DocActorProto(_desc, t, _ports, _attrs) {
+                                       const QString & portId, const QList<Attribute*>& _attrs )
+: DocActorProto(_desc, t, _ports, _attrs), outPortId(portId) {
     construct();
 }
 
 bool WriteDocActorProto::isAcceptableDrop(const QMimeData * md, QVariantMap * params ) const {
-    return DocActorProto::isAcceptableDrop( md, params, CoreLibConstants::URL_OUT_ATTR_ID );
+    return DocActorProto::isAcceptableDrop( md, params, CoreLibConstants::URL_OUT_ATTR().getId() );
 }
 
 void WriteDocActorProto::construct() {
@@ -94,93 +96,100 @@ void WriteDocActorProto::construct() {
     attrs << new Attribute(BioActorLibrary::FILE_MODE_ATTR(), CoreDataTypes::NUM_TYPE(), false, SaveDoc_Roll);
 
     QMap< QString, PropertyDelegate* > delegateMap;
-    delegateMap[CoreLibConstants::URL_OUT_ATTR_ID] = new URLDelegate(prepareDocumentFilter(), QString(), false );
+    delegateMap[CoreLibConstants::URL_OUT_ATTR().getId()] = new URLDelegate(prepareDocumentFilter(), QString(), false );
     delegateMap[BioActorLibrary::FILE_MODE_ATTR_ID] = new FileModeDelegate(attrs.size() > 2);
 
     setEditor(new DelegateEditor(delegateMap));
-    setValidator(new ScreenedParamValidator(CoreLibConstants::URL_OUT_ATTR_ID, ports.first()->getId(), CoreLibConstants::URL_SLOT_ID));
-    setPortValidator(CoreLibConstants::DATA_PORT_ID, new ScreenedSlotValidator(CoreLibConstants::URL_SLOT_ID));
+    setValidator(new ScreenedParamValidator(CoreLibConstants::URL_OUT_ATTR().getId(), ports.first()->getId(), CoreLibConstants::URL_SLOT().getId()));
+    setPortValidator(outPortId, new ScreenedSlotValidator(CoreLibConstants::URL_SLOT().getId()));
 }
 
 /****************************
  * WriteGenbankPrompter
  *****************************/
 QString WriteGenbankPrompter::composeRichDoc() {
-    BusPort* input = qobject_cast<BusPort*>(target->getPort(CoreLibConstants::DATA_PORT_ID));
-
-    Actor* seqProducer = input->getProducer(BioActorLibrary::SEQ_SLOT_ID);
+    QString outPortId = target->getInputPorts().first()->getId();
+    IntegralBusPort* input = qobject_cast<IntegralBusPort*>(target->getPort(outPortId));
+    Actor* seqProducer = input->getProducer(BioActorLibrary::SEQ_SLOT().getId());
     QString seqName = seqProducer ? tr(" sequence from <u>%1</u>").arg(seqProducer->getLabel()) : "";
-    QString annName = getProducers(CoreLibConstants::DATA_PORT_ID, BioActorLibrary::FEATURE_TABLE_SLOT_ID);
+    QString annName = getProducers(outPortId, BioActorLibrary::FEATURE_TABLE_SLOT().getId());
     if (!annName.isEmpty()) {
         annName = tr(" set of annotations from <u>%1</u>").arg(annName);
     }
-
-    QString url = getScreenedURL( qobject_cast<BusPort*>(target->getPort( CoreLibConstants::DATA_PORT_ID )), 
-        CoreLibConstants::URL_OUT_ATTR_ID, CoreLibConstants::URL_SLOT_ID );
-
+    
+    QString url = getScreenedURL( qobject_cast<IntegralBusPort*>(target->getPort(outPortId)), 
+        CoreLibConstants::URL_OUT_ATTR().getId(), CoreLibConstants::URL_SLOT().getId() );
+    
     QString data;
     if (seqName.isEmpty() && annName.isEmpty()) {
-        return url;
+        QString doc = tr("Write sequence(s) in Genbank format to <u>%1</u>.").arg(url);
+        return doc;
     } else if (!seqName.isEmpty() && !annName.isEmpty()) {
-        data = tr("For each %1 and %2").arg(seqName).arg(annName);
+        data = tr("each %1 and %2").arg(seqName).arg(annName);
     } else {
-        data = tr("For each ") + seqName + annName;
+        data = tr("each ") + seqName + annName;
     }
-
-    QString extra;
-    //     Actor* acnProducer = input->getProducer(CoreLib::GENBANK_ACN_SLOT.getId());
-    //     if (!acnProducer) {
-    //         extra = tr("<br>Autogenerate ACN.");
-    //     }
-
-    QString doc = tr("%1, add Genbank entry to document <u>%2</u>.%3")
-        .arg(data) //sequence from Read Fasta 1
-        .arg(url) 
-        .arg(extra);
-
-    return doc;
+    
+    return tr("Write %1 in Genbank format, to <u>%2</u>.")
+        .arg(data)
+        .arg(url);
 }
 
 /****************************
  * WriteFastaPrompter
  *****************************/
 QString WriteFastaPrompter::composeRichDoc() {
-    BusPort* input = qobject_cast<BusPort*>(target->getPort(CoreLibConstants::DATA_PORT_ID));
-    QString url = getScreenedURL( qobject_cast<BusPort*>(target->getPort( CoreLibConstants::DATA_PORT_ID )), 
-        CoreLibConstants::URL_OUT_ATTR_ID, CoreLibConstants::URL_SLOT_ID );
+    QString outPortId = target->getInputPorts().first()->getId();
+    IntegralBusPort* input = qobject_cast<IntegralBusPort*>(target->getPort(outPortId));
+    QString url = getScreenedURL( qobject_cast<IntegralBusPort*>(target->getPort(outPortId)),
+        CoreLibConstants::URL_OUT_ATTR().getId(), CoreLibConstants::URL_SLOT().getId() );
 
-    Actor* seqProducer = input->getProducer(BioActorLibrary::SEQ_SLOT_ID);
+    Actor* seqProducer = input->getProducer(BioActorLibrary::SEQ_SLOT().getId());
     if (!seqProducer) {
-        return url;
+        QString doc = tr("Writes sequence(s) in %1 format to <u>%2</u>.").arg(format).arg(url);
+        return doc;
     }
 
-    QString doc = tr("For each sequence from <u>%1</u>, add entry to document <u>%2</u>.")
+    QString doc = tr("Writes sequence(s) from <u>%1</u> in %2 format to  <u>%3</u>.")
         .arg(seqProducer->getLabel())
+        .arg(format)
         .arg(url);
 
     return doc;
 }
 
+ActorDocument* WriteFastaPrompter::createDescription(Actor* a) {
+    WriteFastaPrompter* doc = new WriteFastaPrompter(format, a);
+    doc->connect(a, SIGNAL(si_labelChanged()), SLOT(sl_actorModified()));
+    doc->connect(a, SIGNAL(si_modified()), SLOT(sl_actorModified()));
+    foreach(Workflow::Port* input, a->getInputPorts()) {
+        doc->connect(input, SIGNAL(bindingChanged()), SLOT(sl_actorModified()));
+    }
+    return doc;
+}
+
 /****************************
-* WriteDocPrompter
-*****************************/
+ * WriteDocPrompter
+ *****************************/
 QString WriteDocPrompter::composeRichDoc() {
-    QString url = getScreenedURL( qobject_cast<BusPort*>(target->getPort( CoreLibConstants::DATA_PORT_ID )), 
-        CoreLibConstants::URL_OUT_ATTR_ID, CoreLibConstants::URL_SLOT_ID );
+    QString outPortId = target->getInputPorts().first()->getId();
+    QString url = getScreenedURL( qobject_cast<IntegralBusPort*>(target->getPort(outPortId)), 
+        CoreLibConstants::URL_OUT_ATTR().getId(), CoreLibConstants::URL_SLOT().getId() );
     
-    QString producers = getProducers(CoreLibConstants::DATA_PORT_ID, slot);
+    QString producers = getProducers(outPortId, slot);
     if (producers.isEmpty()) {
-        return url;
+        QString unsetStr = "<font color='red'>"+tr("unset")+"</font>";
+        return spec.arg(unsetStr).arg(url);
     }
     return spec.arg(producers).arg(url);
 }
 
 /****************************
-* ReadDocPrompter
-*****************************/
+ * ReadDocPrompter
+ *****************************/
 QString ReadDocPrompter::composeRichDoc() {
-    return spec.arg(getURL(CoreLibConstants::URL_IN_ATTR_ID));
+    return spec.arg(getURL(CoreLibConstants::URL_IN_ATTR().getId()));
 }
 
 }//namespace Workflow
-}//namespace GB2
+}//namespace U2
