@@ -8,22 +8,33 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_WORKFLOW_DOC_WORKERS_H_
-#define _GB2_WORKFLOW_DOC_WORKERS_H_
+#ifndef _U2_WORKFLOW_DOC_WORKERS_H_
+#define _U2_WORKFLOW_DOC_WORKERS_H_
 
 #include "BaseDocWorker.h"
 #include "CoreLib.h"
-#include <workflow_support/CoreLibConstants.h>
+#include <U2Lang/CoreLibConstants.h>
+#include <U2Core/IOAdapter.h>
 
-namespace GB2 {
+
+namespace U2 {
 namespace LocalWorkflow {
 
 class TextReader : public BaseDocReader {
     Q_OBJECT
 public:
-    TextReader(Actor* a) : BaseDocReader(a, CoreLibConstants::TEXT_TYPESET_ID, BaseDocumentFormats::PLAIN_TEXT){}
+    TextReader(Actor* a) : BaseDocReader(a, CoreLibConstants::TEXT_TYPESET_ID, BaseDocumentFormats::PLAIN_TEXT), io(NULL), done(false){}
+    void init();
+    bool isDone();
+    bool isReady();
+    Task *tick();
 protected:
     virtual void doc2data(Document* doc);
+private:
+    IOAdapter *io;
+    QStringList urls;
+    QString url;
+    bool done;
 };
 
 class TextWriter : public BaseDocWriter {
@@ -64,6 +75,15 @@ public:
     static void data2document(Document*, const QVariantMap&);
 };
 
+class RawSeqWriter : public BaseDocWriter {
+    Q_OBJECT
+public:
+    RawSeqWriter(Actor* a) : BaseDocWriter(a, BaseDocumentFormats::RAW_DNA_SEQUENCE){}
+protected:
+    virtual void data2doc(Document*, const QVariantMap&);
+public:
+    static void data2document(Document*, const QVariantMap&);
+};
 
 
 // generic sequence writer
@@ -92,8 +112,8 @@ public:
     static void init();
 };
 
-}//Workflow namespace
-}//GB2 namespace
+} // Workflow namespace
+} // U2 namespace
 
 #endif
 
