@@ -11,53 +11,52 @@
 #include "SWWorker.h"
 #include "FindWorker.h"
 
-#include <workflow/IntegralBusModel.h>
-#include <workflow/WorkflowEnv.h>
-#include <workflow/WorkflowRegistry.h>
-#include <workflow_support/CoreDataTypes.h>
-#include <workflow_library/BioDatatypes.h>
-#include <workflow_library/BioActorLibrary.h>
-#include <workflow_support/DelegateEditors.h>
-#include <workflow_support/CoreLibConstants.h>
+#include <U2Lang/IntegralBusModel.h>
+#include <U2Lang/WorkflowEnv.h>
+#include <U2Lang/ActorPrototypeRegistry.h>
+#include <U2Lang/CoreDataTypes.h>
+#include <U2Lang/BioDatatypes.h>
+#include <U2Lang/BioActorLibrary.h>
+#include <U2Designer/DelegateEditors.h>
+#include <U2Lang/CoreLibConstants.h>
 
-#include <datatype/DNASequence.h>
-#include <core_api/DNATranslation.h>
-#include <core_api/DNAAlphabet.h>
-#include <core_api/AppContext.h>
-#include <core_api/Log.h>
-#include <core_api/SmithWatermanTaskFactoryRegistry.h>
-#include <core_api/SubstMatrixRegistry.h>
-#include <core_api/SWResultFilterRegistry.h>
-#include <core_api/PluginModel.h>
-#include <util_tasks/FailTask.h>
-#include <util_tasks/TaskSignalMapper.h>
-#include <util_tasks/SequenceWalkerTask.h>
+#include <U2Core/DNASequence.h>
+#include <U2Core/DNATranslation.h>
+#include <U2Core/DNAAlphabet.h>
+#include <U2Core/AppContext.h>
+#include <U2Core/L10n.h>
+#include <U2Core/Log.h>
+#include <U2Algorithm/SmithWatermanTaskFactoryRegistry.h>
+#include <U2Algorithm/SubstMatrixRegistry.h>
+#include <U2Algorithm/SWResultFilterRegistry.h>
+#include <U2Core/PluginModel.h>
+#include <U2Core/FailTask.h>
+#include <U2Core/TaskSignalMapper.h>
+#include <U2Core/SequenceWalkerTask.h>
 
 #include "CoreLib.h"
 
-/* TRANSLATOR GB2::LocalWorkflow::SWWorker */
-/* TRANSLATOR GB2::LocalWorkflow::FindWorker */
+/* TRANSLATOR U2::LocalWorkflow::SWWorker */
+/* TRANSLATOR U2::LocalWorkflow::FindWorker */
 
-namespace GB2 {
+namespace U2 {
 namespace LocalWorkflow {
 
-static LogCategory log(ULOG_CAT_WD);
-
 /**************************
  * SWWorkerFactory
  **************************/
-static const QString NAME_ATTR("a_name");
-static const QString PATTERN_ATTR("b_pattern");
-static const QString SCORE_ATTR("c_minscore");
-static const QString MATRIX_ATTR("d_matrix");
-static const QString AMINO_ATTR("e_translate");
-static const QString STRAND_ATTR("f_strand");
-static const QString ALGO_ATTR("g_algorithm");
-static const QString FILTER_ATTR("h_filter");
-static const QString GAPOPEN_ATTR("i_gapopen");
-static const QString GAPEXT_ATTR("j_gapext");
+static const QString NAME_ATTR("result-name");
+static const QString PATTERN_ATTR("pattern");
+static const QString SCORE_ATTR("min-score");
+static const QString MATRIX_ATTR("matrix");
+static const QString AMINO_ATTR("amino");
+static const QString STRAND_ATTR("strand");
+static const QString ALGO_ATTR("algorithm");
+static const QString FILTER_ATTR("filter-strategy");
+static const QString GAPOPEN_ATTR("gap-open-score");
+static const QString GAPEXT_ATTR("gap-ext-score");
 
-const QString SWWorkerFactory::ACTOR_ID("find.smithwaterman");
+const QString SWWorkerFactory::ACTOR_ID("ssearch");
 
 void SWAlgoEditor::populate() {
     QStringList algoLst = AppContext::getSmithWatermanTaskFactoryRegistry()->getListFactoryNames();
@@ -88,10 +87,16 @@ void SWWorkerFactory::init() {
 
     QList<PortDescriptor*> p; QList<Attribute*> a;
     {
-        Descriptor ind(CoreLibConstants::IN_PORT_ID, SWWorker::tr("Input data"), SWWorker::tr("An input sequence and set of regions to search in."));
-        Descriptor oud(CoreLibConstants::OUT_PORT_ID, SWWorker::tr("Pattern annotations"), SWWorker::tr("Found regions"));
-        p << new PortDescriptor(ind, BioDataTypes::DNA_SEQUENCE_TYPE(), true);
-        p << new PortDescriptor(oud, BioDataTypes::ANNOTATION_TABLE_TYPE(), false, true);
+        Descriptor ind(CoreLibConstants::IN_SEQ_PORT_ID, SWWorker::tr("Input data"), 
+            SWWorker::tr("An input sequence and set of regions to search in."));
+        Descriptor oud(CoreLibConstants::OUT_ANNOTATIONS_PORT_ID, SWWorker::tr("Pattern annotations"), SWWorker::tr("Found regions"));
+        
+        QMap<Descriptor, DataTypePtr> inM;
+        inM[BioActorLibrary::SEQ_SLOT()] = BioDataTypes::DNA_SEQUENCE_TYPE();
+        p << new PortDescriptor(ind, DataTypePtr(new MapDataType("sw.sequence", inM)), true);
+        QMap<Descriptor, DataTypePtr> outM;
+        outM[BioActorLibrary::FEATURE_TABLE_SLOT()] = BioDataTypes::ANNOTATION_TABLE_TYPE();
+        p << new PortDescriptor(oud, DataTypePtr(new MapDataType("sw.annotations", outM)), false, true);
     }
 
     QStringList filterLst = AppContext::getSWResultFilterRegistry()->getFiltersIds();
@@ -103,7 +108,7 @@ void SWWorkerFactory::init() {
         Descriptor scd(SCORE_ATTR, SWWorker::tr("Min score"), SWWorker::tr("The search stringency."));
         Descriptor ald(ALGO_ATTR, SWWorker::tr("Algorithm"), SWWorker::tr("Algorithm version."));
         Descriptor amd(AMINO_ATTR, FindWorker::tr("Search in translation"), SWWorker::tr("Translate a supplied nucleotide sequence to protein then search in the translated sequence."));
-        Descriptor sd(STRAND_ATTR, FindWorker::tr("Search in"), SWWorker::tr("Which strands should be searched: direct, complement or both."));
+        Descriptor sd(STRAND_ATTR, L10N::searchIn(), SWWorker::tr("Which strands should be searched: direct, complement or both."));
         Descriptor mxd(MATRIX_ATTR, SWWorker::tr("Scoring matrix"), SWWorker::tr("The scoring matrix."));
         Descriptor frd(FILTER_ATTR, SWWorker::tr("Filter results"), SWWorker::tr("Result filtering strategy."));
         Descriptor god(GAPOPEN_ATTR, SWWorker::tr("Gap open score"), SWWorker::tr("Gap open score."));
@@ -111,7 +116,7 @@ void SWWorkerFactory::init() {
 
         a << new Attribute(nd, CoreDataTypes::STRING_TYPE(), true, "misc_feature");
         a << new Attribute(pd, CoreDataTypes::STRING_TYPE(), true);
-        a << new Attribute(mxd, CoreDataTypes::STRING_TYPE(), true, QString("---"));
+        a << new Attribute(mxd, CoreDataTypes::STRING_TYPE(), true, QString("Auto"));
         a << new Attribute(ald, CoreDataTypes::STRING_TYPE(), true);
         a << new Attribute(frd, CoreDataTypes::STRING_TYPE(), false, defFilter);
         a << new Attribute(scd, CoreDataTypes::NUM_TYPE(), false, 90);
@@ -123,7 +128,7 @@ void SWWorkerFactory::init() {
 
     Descriptor desc(ACTOR_ID, SWWorker::tr("Smith-Waterman search"), SWWorker::tr("Finds regions of similarity to the specified pattern in each input sequence (nucleotide or protein one). "
         "<p>Under the hood is the well-known Smith-Waterman algorithm for performing local sequence alignment."));
-    ActorPrototype* proto = new BusActorPrototype(desc, p, a);
+    ActorPrototype* proto = new IntegralBusActorPrototype(desc, p, a);
     QMap<QString, PropertyDelegate*> delegates;    
     {
         QVariantMap m; m["minimum"] = 1; m["maximum"] = 100; m["suffix"] = "%";
@@ -150,8 +155,8 @@ void SWWorkerFactory::init() {
         delegates[FILTER_ATTR] = new ComboBoxDelegate(m);
     }
     {
-        QVariantMap m; m.insert(SWWorker::tr("Auto"), QString("---"));
-        QStringList lst = AppContext::getSubstMatrixRegistry()->getMatrixNames();	
+        QVariantMap m; m.insert(SWWorker::tr("Auto"), QString("Auto"));
+        QStringList lst = AppContext::getSubstMatrixRegistry()->getMatrixNames();
         foreach(const QString& n, lst) {
             m.insert(n,n);
         } 
@@ -173,11 +178,11 @@ void SWWorkerFactory::init() {
  * SWPrompter
  **************************/
 QString SWPrompter::composeRichDoc() {
-    BusPort* input = qobject_cast<BusPort*>(target->getPort(CoreLibConstants::IN_PORT_ID));
-    //Actor* seqProducer = input->getProducer(BioActorLibrary::SEQ_SLOT_ID);
+    IntegralBusPort* input = qobject_cast<IntegralBusPort*>(target->getPort(CoreLibConstants::IN_SEQ_PORT_ID));
     //Actor* annProducer = input->getProducer(BioActorLibrary::FEATURE_TABLE_SLOT_ID);
-    Actor* seqProducer = input->getProducer(CoreLibConstants::IN_PORT_ID);
-    QString seqName = seqProducer ? tr("In each sequence from <u>%1</u>,").arg(seqProducer->getLabel()) : "";
+    Actor* seqProducer = input->getProducer(BioActorLibrary::SEQ_SLOT().getId());
+    QString unsetStr = "<font color='red'>"+tr("unset")+"</font>";
+    QString seqName = tr("In each sequence from <u>%1</u>,").arg(seqProducer ? seqProducer->getLabel() : unsetStr);
     //QString annName = annProducer ? tr(" within a set of regions from <u>%1</u>").arg(annProducer->getLabel()) : "";
 
     SmithWatermanSettings cfg;
@@ -222,8 +227,8 @@ SWWorker::SWWorker(Actor* a) : BaseWorker(a), input(NULL), output(NULL), algo(fa
 }
 
 void SWWorker::init() {
-    input = ports.value(CoreLibConstants::IN_PORT_ID);
-    output = ports.value(CoreLibConstants::OUT_PORT_ID);
+    input = ports.value(CoreLibConstants::IN_SEQ_PORT_ID);
+    output = ports.value(CoreLibConstants::OUT_ANNOTATIONS_PORT_ID);
 }
 
 bool SWWorker::isReady() {
@@ -247,45 +252,36 @@ Task* SWWorker::tick() {
     QString filter = actor->getParameter(FILTER_ATTR)->getAttributeValue<QString>();
     cfg.resultFilter = AppContext::getSWResultFilterRegistry()->getFilter(filter);
     if(cfg.resultFilter == NULL){
-        log.error(tr("Incorrect value:  filter name incorrect, default value used")); //details level won't work
+        algoLog.error(tr("Incorrect value:  filter name incorrect, default value used")); //details level won't work
         cfg.resultFilter = AppContext::getSWResultFilterRegistry()->getFilter("none");
     }
     
     resultName = actor->getParameter(NAME_ATTR)->getAttributeValue<QString>();
     if(resultName.isEmpty()){
-        log.error(tr("Incorrect value: result name is empty, default value used")); //details level won't work
+        algoLog.error(tr("Incorrect value: result name is empty, default value used")); //details level won't work
         resultName = "misc_feature";
     }
     cfg.ptrn = actor->getParameter(PATTERN_ATTR)->getAttributeValue<QString>().toAscii().toUpper();
     QString algName = actor->getParameter(ALGO_ATTR)->getAttributeValue<QString>();
     algo = AppContext::getSmithWatermanTaskFactoryRegistry()->getFactory(algName);
 
-    if(cfg.percentOfScore < 0 || cfg.percentOfScore > 100){
-        log.error(tr("Incorrect value: score value must lay between 0 and 100"));
-        return new FailTask(tr("Incorrect value: score value must lay between 0 and 100"));
-    }
-    if(cfg.ptrn.isEmpty()){
-        log.error(tr("Incorrect value: search pattern, pattern is empty"));
-        return new FailTask(tr("Incorrect value: search pattern, pattern is empty"));
-    }
-
-    DNASequence seq = inputMessage.getData().value<DNASequence>();
+    DNASequence seq = inputMessage.getData().toMap().value(BioActorLibrary::SEQ_SLOT().getId()).value<DNASequence>();
     
     if (!algo) {
         return new FailTask(tr("SmithWaterman algorithm not found: %1").arg(algName));
     }
     if(cfg.percentOfScore < 0 || cfg.percentOfScore > 100){
-        log.error(tr("Incorrect value: score value must lay between 0 and 100"));
+        algoLog.error(tr("Incorrect value: score value must lay between 0 and 100"));
         return new FailTask(tr("Incorrect value: score value must lay between 0 and 100"));
     }
     if(cfg.ptrn.isEmpty()){
-        log.error(tr("Incorrect value: search pattern, pattern is empty"));
+        algoLog.error(tr("Incorrect value: search pattern, pattern is empty"));
         return new FailTask(tr("Incorrect value: search pattern, pattern is empty"));
     }
     
     foreach(char c, cfg.ptrn){
         if(!seq.alphabet->contains(c)){
-            log.error(tr("Incorrect value: pattern alphabet doesn't match sequence alphabet "));
+            algoLog.error(tr("Incorrect value: pattern alphabet doesn't match sequence alphabet "));
             return new FailTask(tr("Incorrect value: pattern alphabet doesn't match sequence alphabet "));
         }
     }
@@ -298,34 +294,40 @@ Task* SWWorker::tick() {
             if (!compTTs.isEmpty()) {
                 config.complTT = compTTs.first();
             } else {
-                log.error(tr("Could not find complement translation for %1, searching only direct strand").arg(seq.getName()));
+                algoLog.error(tr("Could not find complement translation for %1, searching only direct strand").arg(seq.getName()));
                 config.strand = StrandOption_DirectOnly;
             }
         }
         if (actor->getParameter(AMINO_ATTR)->getAttributeValue<bool>()) {
             DNATranslationType tt = (seq.alphabet->getType() == DNAAlphabet_NUCL) ? DNATranslationType_NUCL_2_AMINO : DNATranslationType_RAW_2_AMINO;
             QList<DNATranslation*> TTs = AppContext::getDNATranslationRegistry()->lookupTranslation(seq.alphabet, tt);
-			if (!TTs.isEmpty()) {
-				config.aminoTT = TTs.first(); //FIXME let user choose or use hints ?
-			}
+            if (!TTs.isEmpty()) {
+                config.aminoTT = TTs.first(); //FIXME let user choose or use hints ?
+            }
+        }
+        if(!seq.alphabet->containsAll(config.ptrn.constData(),config.ptrn.length())) {
+            return fail(tr("Pattern symbols not matching to alphabet"));
         }
-		if(!seq.alphabet->containsAll(config.ptrn.constData(),config.ptrn.length())) {
-			return fail(tr("Pattern symbols not matching to alphabet"));
-		}
         if(config.pSm.getName().isEmpty() && mtrx.toLower() != "auto"){
-            log.details(tr("Invalid value: weight matrix with given name not exists"));
+            algoLog.details(tr("Invalid value: weight matrix with given name not exists"));
             return new FailTask(tr("Invalid value: weight matrix with given name not exists"));
         }
         if (config.pSm.isEmpty()) {
-			QString matrixName;
+            QString matrixName;
             QStringList lst = AppContext::getSubstMatrixRegistry()->selectMatrixNamesByAlphabet(seq.alphabet);
             if (!lst.isEmpty()) {
                 matrixName = lst.first();
                 config.pSm = AppContext::getSubstMatrixRegistry()->getMatrix(matrixName);
             }
-			if (config.pSm.isEmpty()) {
-				return fail(tr("Can't find weight matrix name: '%1'!").arg(matrixName.isEmpty() ? tr("<empty>") : matrixName));
-			}
+            if (config.pSm.isEmpty()) {
+                return fail(tr("Can't find weight matrix name: '%1'!").arg(matrixName.isEmpty() ? tr("<empty>") : matrixName));
+            }
+        }
+
+        if(mtrx.toLower() != "auto") {
+            if(seq.alphabet->getType() != cfg.pSm.getAlphabet()->getType()) {
+                return new FailTask(tr("Wrong matrix selected. Alphabets do not match"));
+            }
         }
 
         config.globalRegion.len = seq.length();
@@ -333,8 +335,6 @@ Task* SWWorker::tick() {
         config.resultCallback = rcb;
         config.resultListener = new SmithWatermanResultListener(); //FIXME: where to delete??
 
-
-
         Task* task = algo->getTaskInstance(config, tr("smith_waterman_task"));
         rcb->setParent(task);
         callbacks.insert(task, rcb);
@@ -343,20 +343,20 @@ Task* SWWorker::tick() {
         return task;
 
     }
-	return fail(tr("Null sequence supplied to Smith-Waterman: %1").arg(seq.getName()));
+    return fail(tr("Null sequence supplied to Smith-Waterman: %1").arg(seq.getName()));
 }
 
 Task* SWWorker::fail(const QString& err) {
-    if (failFast) {
+    //if (failFast) {
         return new FailTask(err);
-    } else {
-        log.error(err);
+    /*} else {
+        algoLog.error(err);
         output->put(Message(BioDataTypes::ANNOTATION_TABLE_TYPE(), QVariant()));
         if (input->isEnded()) {
             output->setEnded();
         }
         return NULL;
-    }
+    }*/
 }
 
 void SWWorker::sl_taskFinished(Task* t) {
@@ -370,7 +370,7 @@ void SWWorker::sl_taskFinished(Task* t) {
         if (input->isEnded()) {
             output->setEnded();
         }
-        log.info(tr("Found %1 matches of pattern '%2'").arg(res.size()).arg(QString(cfg.ptrn)));
+        algoLog.info(tr("Found %1 matches of pattern '%2'").arg(res.size()).arg(QString(cfg.ptrn)));
     }
 }
 
@@ -382,4 +382,4 @@ void SWWorker::cleanup() {
 }
 
 } //namespace LocalWorkflow
-} //namespace GB2
+} //namespace U2
