@@ -11,9 +11,9 @@
 #ifndef BALLPLUGIN_H
 #define BALLPLUGIN_H
 
-#include <core_api/PluginModel.h>
+#include <U2Core/PluginModel.h>
 
-namespace GB2
+namespace U2
 {
 
 class BallPlugin : public Plugin
