@@ -11,17 +11,17 @@
 #ifndef SAS_H
 #define SAS_H
 
-#include <molecular_geometry/MolecularSurface.h>
+#include <U2Algorithm/MolecularSurface.h>
 
-namespace GB2
+namespace U2
 {
 
 class SolventAccessibleSurface : public MolecularSurface
 {
 public:
     SolventAccessibleSurface();
-    virtual void calculate(const QList<SharedAtom>& atoms);
-    virtual void calculate(const BioStruct3D& bioStruct);
+    virtual qint64 estimateMemoryUsage(int numberOfAtoms);
+    virtual void calculate(const QList<SharedAtom>& atoms, int& progress);
 };
 
 class SolventAccessibleSurfaceFactory : public MolecularSurfaceFactory
