@@ -11,23 +11,26 @@
 #ifndef SOLVENTEXCLUDEDSURFACE_H
 #define SOLVENTEXCLUDEDSURFACE_H
 
-#include <molecular_geometry/MolecularSurface.h>
+#include <U2Algorithm/MolecularSurface.h>
 
-namespace GB2
+namespace U2
 {
 
+class Surface;
+
 class SolventExcludedSurface : public MolecularSurface
 {
 public:
     SolventExcludedSurface();
-    virtual void calculate(const QList<SharedAtom>& atoms);
-    virtual void calculate(const BioStruct3D& bioStruct);
+    virtual void calculate(const QList<SharedAtom>& atoms, int& progress);
+    virtual qint64 estimateMemoryUsage(int numberOfAtoms);
 };
 
 class SolventExcludedSurfaceFactory : public MolecularSurfaceFactory
 {
 public:
     virtual MolecularSurface *createInstance()const;
+    bool hasConstraints(const BioStruct3D& biostruc) const;
 };
 
 } // namespace
