@@ -12,16 +12,17 @@
 #define _DIST_MATRIX_MODEL_WIDGET_H_
 
 #include "ui/ui_BowtieSettings.h"
-#include "util_dna_assembly/DnaAssemblyGUIExtension.h"
+#include "U2View/DnaAssemblyGUIExtension.h"
 
-namespace GB2{
+namespace U2{
 
-class BowtieSettingsWidget : public DnaAssemblyGUIExtensionWidget, Ui_BowtieSettings {
+class BowtieSettingsWidget : public DnaAssemblyAlgorithmMainWidget, Ui_BowtieSettings {
     Q_OBJECT
 public:
     BowtieSettingsWidget(QWidget* parent);
     virtual QMap<QString,QVariant> getDnaAssemblyCustomSettings();
-    DNA_ASSEMBLY_GUI_EXTENSION_FACTORY(BowtieSettingsWidget)
+	virtual void buildIndexUrl(const GUrl& url) {};
+	virtual bool isIndexOk() {return true;};
 };
 
 }
