@@ -11,55 +11,108 @@
 #include "BowtieWorker.h"
 #include "BowtiePlugin.h"
 
-#include <workflow/IntegralBusModel.h>
-#include <workflow/WorkflowEnv.h>
-#include <workflow/WorkflowRegistry.h>
-#include <workflow_support/CoreDataTypes.h>
-#include <workflow_library/BioDatatypes.h>
-#include <workflow_library/BioActorLibrary.h>
-#include <workflow_support/DelegateEditors.h>
-#include <workflow_support/CoreLibConstants.h>
-#include <core_api/Log.h>
-#include <util_gui/DialogUtils.h>
+#include <U2Lang/IntegralBusModel.h>
+#include <U2Lang/WorkflowEnv.h>
+#include <U2Lang/ActorPrototypeRegistry.h>
+#include <U2Lang/CoreDataTypes.h>
+#include <U2Lang/BioDatatypes.h>
+#include <U2Lang/BioActorLibrary.h>
+#include <U2Designer/DelegateEditors.h>
+#include <U2Lang/CoreLibConstants.h>
+#include <U2Core/Log.h>
+#include <U2Misc/DialogUtils.h>
+#include <U2Core/DNAAlphabet.h>
 
-/* TRANSLATOR GB2::LocalWorkflow::BowtieWorker */
+/* TRANSLATOR U2::LocalWorkflow::BowtieWorker */
 
-namespace GB2 {
+namespace U2 {
 namespace LocalWorkflow {
 
-static const QString READS_PORT("reads");
-static const QString EBWT_PORT("ebwt");
+static const QString EBWT_PORT("in-ebwt");
+static const QString EBWT_OUT_PORT_ID("out-ebwt");
 
-const QString BowtieWorkerFactory::ACTOR_ID("bowtie.assembly");
-const QString BowtieBuildWorkerFactory::ACTOR_ID("bowtie.indexer");
-const QString BowtieIndexReaderWorkerFactory::ACTOR_ID("bowtie.index.reader");
+const QString BowtieWorkerFactory::ACTOR_ID("bowtie");
+const QString BowtieBuildWorkerFactory::ACTOR_ID("bowtie-build-index");
+const QString BowtieIndexReaderWorkerFactory::ACTOR_ID("bowtie-read-index");
 
-const QString REFSEQ_URL_ATTR("ref-seq-url");
-const QString EBWT_URL_ATTR("ebwt");
+const QString REFSEQ_URL_ATTR("url-reference");
+const QString EBWT_URL_ATTR("url-ebwt");
 const QString USE_PREBUILT_INDEX_ATTR("use-prebuilt-index");
-const QString N_MODE_MISMATCHES_ATTR("n-mismatches");
-const QString V_MODE_MISMATCHES_ATTR("v-mismatches");
-const QString MAQERR_ATTR("maqerr");
-const QString SEEDLEN_ATTR("seedlen");
-const QString NOMAQROUND_ATTR("nomaqround");
-const QString NOFW_ATTR("nofw");
-const QString NORC_ATTR("norc");
-const QString MAXBTS_ATTR("maxbts");
-const QString TRYHARD_ATTR("tryhard");
-const QString CHUNKMBS_ATTR("chunkmbs");
+const QString N_MODE_MISMATCHES_ATTR("mismatches-num");
+const QString V_MODE_MISMATCHES_ATTR("report-with-mismatches");
+const QString MAQERR_ATTR("maq-err");
+const QString SEEDLEN_ATTR("seed-length");
+const QString NOMAQROUND_ATTR("no-maq-rounding");
+const QString NOFW_ATTR("no-forward");
+const QString NORC_ATTR("no-reverse-complemented");
+const QString MAXBTS_ATTR("max-backtracks");
+const QString TRYHARD_ATTR("try-hard");
+const QString CHUNKMBS_ATTR("chunk-mbs");
 const QString SEED_ATTR("seed");
 
-static LogCategory log(ULOG_CAT_WD);
+/************************************************************************/
+/* BowtieCommunicationChanelReader                                      */
+/************************************************************************/
+
+BowtieCommunicationChanelReader::BowtieCommunicationChanelReader(CommunicationChannel* reads) {
+	assert(reads != NULL);
+	this->reads = reads;
+}
+
+bool BowtieCommunicationChanelReader::isEnd() {
+	return !reads->hasMessage() || reads->isEnded();
+}
+
+DNASequence BowtieCommunicationChanelReader::read() {
+    return reads->get().getData().toMap().value(BioActorLibrary::SEQ_SLOT().getId()).value<DNASequence>();
+}
+
+/************************************************************************/
+/* BowtieMAlignmentWriter                                               */
+/************************************************************************/
+BowtieMAlignmentWriter::BowtieMAlignmentWriter() {
+	//do nothing
+}
+
+void BowtieMAlignmentWriter::close() { 
+	//TODO: add some heuristic alphabet selection. 
+	result.setAlphabet(AppContext::getDNAAlphabetRegistry()->findById(BaseDNAAlphabetIds::NUCL_DNA_DEFAULT()));
+}
+
+MAlignment& BowtieMAlignmentWriter::getResult() {
+	return result;
+}
+
+void BowtieMAlignmentWriter::write(const DNASequence& seq, int offset) {
+	MAlignmentRow row;
+	row.setName(seq.getName());
+	row.setSequence(seq.seq, offset);
+	row.setQuality(seq.quality);
+	result.addRow(row);
+}
+
+/************************************************************************/
+/*                                                                      */
+/************************************************************************/
+
+static const Descriptor EBWT_SLOT("ebwt-index", BowtieWorker::tr("EBWT index"), BowtieWorker::tr("EBWT Index for bowtie"));
 
 void BowtieWorkerFactory::init() {
 	QList<PortDescriptor*> p; QList<Attribute*> a;
-	Descriptor readsd(READS_PORT, BowtieWorker::tr("Short read sequences"), BowtieWorker::tr("Short reads to be aligned."));
+    Descriptor readsd(CoreLibConstants::IN_SEQ_PORT_ID, BowtieWorker::tr("Short read sequences"), 
+        BowtieWorker::tr("Short reads to be aligned."));
 	Descriptor ebwtd(EBWT_PORT, BowtieWorker::tr("EBWT index"), BowtieWorker::tr("EBWT index of reference sequence."));
-	Descriptor oud(CoreLibConstants::OUT_PORT_ID, BowtieWorker::tr("Short reads alignment"), BowtieWorker::tr("Result of alignment."));
+	Descriptor oud(CoreLibConstants::OUT_MSA_PORT_ID, BowtieWorker::tr("Short reads alignment"), BowtieWorker::tr("Result of alignment."));
 	
-	p << new PortDescriptor(readsd, BioDataTypes::DNA_SEQUENCE_TYPE(), true /*input*/);
-	p << new PortDescriptor(ebwtd, BowtiePlugin::EBWT_INDEX_TYPE(), true /*input*/, true /*multi*/, BusPort::BLIND_INPUT);
-	p << new PortDescriptor(oud, BioDataTypes::MULTIPLE_ALIGNMENT_TYPE(), false /*input*/, true /*multi*/);
+	QMap<Descriptor, DataTypePtr> inSeqM;
+    inSeqM[BioActorLibrary::SEQ_SLOT()] = BioDataTypes::DNA_SEQUENCE_TYPE();
+    p << new PortDescriptor(readsd, DataTypePtr(new MapDataType("bowtie.in.sequence", inSeqM)), true /*input*/);
+	QMap<Descriptor, DataTypePtr> inEbwtM;
+    inEbwtM[EBWT_SLOT] = BowtiePlugin::EBWT_INDEX_TYPE();
+    p << new PortDescriptor(ebwtd, DataTypePtr(new MapDataType("bowtie.in.ebwt", inEbwtM)), true /*input*/, false /*multi*/, IntegralBusPort::BLIND_INPUT);
+	QMap<Descriptor, DataTypePtr> outM;
+    outM[BioActorLibrary::MA_SLOT()] = BioDataTypes::MULTIPLE_ALIGNMENT_TYPE();
+    p << new PortDescriptor(oud, DataTypePtr(new MapDataType("bowtie.out.out.ma", outM)), false /*input*/, false /*multi*/);
 	
 	//Descriptor refseq(REFSEQ_URL_ATTR, BowtieWorker::tr("Reference"), 
 	//	BowtieWorker::tr("Reference sequence url. The short reads will be aligned to this reference genome."));
@@ -110,7 +163,7 @@ void BowtieWorkerFactory::init() {
 	a << new Attribute(chunkmbs, CoreDataTypes::NUM_TYPE(), false /*not required*/, 64);
 	a << new Attribute(seed, CoreDataTypes::NUM_TYPE(), false /*not required*/, -1);
 
-	ActorPrototype* proto = new BusActorPrototype(desc, p, a);
+	ActorPrototype* proto = new IntegralBusActorPrototype(desc, p, a);
 
 	QMap<QString, PropertyDelegate*> delegates;    
 
@@ -141,8 +194,8 @@ void BowtieWorkerFactory::init() {
 }
 
 QString BowtiePrompter::composeRichDoc() {
-	Actor* readsProducer = qobject_cast<BusPort*>(target->getPort(READS_PORT))->getProducer(READS_PORT);
-	Actor* ebwtProducer = qobject_cast<BusPort*>(target->getPort(EBWT_PORT))->getProducer(EBWT_PORT);
+    Actor* readsProducer = qobject_cast<IntegralBusPort*>(target->getPort(CoreLibConstants::IN_SEQ_PORT_ID))->getProducer(CoreLibConstants::IN_SEQ_PORT_ID);
+	Actor* ebwtProducer = qobject_cast<IntegralBusPort*>(target->getPort(EBWT_PORT))->getProducer(EBWT_PORT);
 	
 	QString readsName = readsProducer ? tr(" from <u>%1</u>").arg(readsProducer->getLabel()) : "";
 	QString ebwtName = ebwtProducer ? tr(" from <u>%1</u>").arg(ebwtProducer->getLabel()) : "";
@@ -154,9 +207,11 @@ QString BowtiePrompter::composeRichDoc() {
 }
 
 void BowtieWorker::init() {
-	reads = ports.value(READS_PORT);
+	reader = NULL;
+	writer = NULL;
+    reads = ports.value(CoreLibConstants::IN_SEQ_PORT_ID);
 	ebwt = ports.value(EBWT_PORT);
-	output = ports.value(CoreLibConstants::OUT_PORT_ID);
+	output = ports.value(CoreLibConstants::OUT_MSA_PORT_ID);
 	//settings.refSeqUrl = actor->getParameter(REFSEQ_URL_ATTR)->getAttributeValue<QString>();
 	//settings.setCustomValue(BowtieTask::OPTION_PREBUILT_INDEX, actor->getParameter(USE_PREBUILT_INDEX_ATTR)->getAttributeValue<bool>());
 	settings.setCustomValue(BowtieTask::OPTION_PREBUILT_INDEX, true);
@@ -178,41 +233,59 @@ bool BowtieWorker::isReady() {
 }
 
 Task* BowtieWorker::tick() {
-	while (!reads->isEnded()) {
-		DNASequence read = reads->get().getData().value<DNASequence>();
-		log.trace(BowtieWorker::tr("Loaded short read %1").arg(read.getName())); 
-		settings.shortReads.append(read);
+	if (reads->hasMessage())  {  
+		/*while (!reads->isEnded()) {
+			DNASequence read = reads->get().getData().value<DNASequence>();
+			log.trace(BowtieWorker::tr("Loaded short read %1").arg(read.getName())); 
+			settings.shortReads.append(read);
+		}*/
+
+		if( reads->isEnded()) {
+			algoLog.error(BowtieWorker::tr("Short reads list is empty."));
+			return NULL;
+		}
+
+		reader = new BowtieCommunicationChanelReader(reads);
+		writer = new BowtieMAlignmentWriter();
+		
+        settings.refSeqUrl = GUrl(ebwt->get().getData().toMap().value(EBWT_SLOT.getId()).value<QString>());
+
+		settings.setCustomValue(BowtieTask::OPTION_READS_READER, QVariant::fromValue(BowtieReadsReaderContainer(reader)));
+		settings.setCustomValue(BowtieTask::OPTION_READS_WRITER, QVariant::fromValue(BowtieReadsWriterContainer(writer)));
+
+		if( settings.refSeqUrl.isEmpty()) {
+			algoLog.trace(BowtieWorker::tr("Reference sequence URL is empty")); 
+			return NULL;
+		}
+
+		Task* t = new BowtieTask(settings);
+		connect(t, SIGNAL(si_stateChanged()), SLOT(sl_taskFinished()));
+		return t;
 	}
-
-	settings.refSeqUrl = GUrl(ebwt->get().getData().value<QString>());
-
-	if( settings.shortReads.isEmpty() ) {
-		log.error(BowtieWorker::tr("Short reads list is empty."));
-		return NULL;
-	}
-
-	if( settings.refSeqUrl.isEmpty()) {
-		log.trace(BowtieWorker::tr("Reference sequence URL is empty")); 
-		return NULL;
-	}
-
-	Task* t = new BowtieTask(settings);
-	connect(t, SIGNAL(si_stateChanged()), SLOT(sl_taskFinished()));
-	return t;
+	return NULL;
 }
 
+void BowtieWorker::cleanup() {
+	delete reader;
+	delete writer;
+	writer = NULL;
+	reader = NULL;
+}
+
+
 void BowtieWorker::sl_taskFinished() {
 	BowtieTask* t = qobject_cast<BowtieTask*>(sender());
 	if (t->getState() != Task::State_Finished) {
 		return;
 	}
 
-	QVariant v = qVariantFromValue<MAlignment>(t->getResult());
+	QVariant v = qVariantFromValue<MAlignment>((dynamic_cast<BowtieMAlignmentWriter*>(writer))->getResult());
 	output->put(Message(BioDataTypes::MULTIPLE_ALIGNMENT_TYPE(), v));
-	if (reads->isEnded() && ebwt->isEnded()) {
+	if (reads->isEnded()) {
 		output->setEnded();
 	}
-	log.trace(tr("Bowtie alignment finished. Result name is %1").arg(t->getResult().getName()));
+		
+	algoLog.trace(tr("Bowtie alignment finished. Result name is %1").arg(t->getResult().getName()));
 }
 
 bool BowtieWorker::isDone() {
@@ -225,11 +298,15 @@ bool BowtieWorker::isDone() {
 
 void BowtieBuildWorkerFactory::init() {
 	QList<PortDescriptor*> p; QList<Attribute*> a;
-	Descriptor oud(CoreLibConstants::OUT_PORT_ID, BowtieBuildWorker::tr("EBWT index"), BowtieBuildWorker::tr("Result ebwt index."));
-	p << new PortDescriptor(oud, BowtiePlugin::EBWT_INDEX_TYPE(), false /*input*/, true /*multi*/);
-	Descriptor refseq(REFSEQ_URL_ATTR, BowtieBuildWorker::tr("Reference"), 
+	Descriptor oud(EBWT_OUT_PORT_ID, BowtieBuildWorker::tr("EBWT index"), BowtieBuildWorker::tr("Result ebwt index."));
+	
+    QMap<Descriptor, DataTypePtr> outM;
+    outM[EBWT_SLOT] = BowtiePlugin::EBWT_INDEX_TYPE();
+    p << new PortDescriptor(oud, DataTypePtr(new MapDataType("bowtie.build.index.out", outM)), false /*input*/, true /*multi*/);
+	
+    Descriptor refseq(REFSEQ_URL_ATTR, BowtieBuildWorker::tr("Reference"), 
 		BowtieBuildWorker::tr("Reference sequence url. The short reads will be aligned to this reference genome."));
-	Descriptor desc(ACTOR_ID, BowtieBuildWorker::tr("Bowtie-build indexer"), 
+	Descriptor desc(ACTOR_ID, BowtieBuildWorker::tr("Bowtie build indexer"), 
 		BowtieWorker::tr("Bowtie-build builds a Bowtie index from a set of DNA sequences. bowtie-build outputs a set of 6 files with suffixes .1.ebwt, .2.ebwt, .3.ebwt, .4.ebwt, .rev.1.ebwt, and .rev.2.ebwt. These files together constitute the index: they are all that is needed to align reads to that reference. The original sequence files are no longer used by Bowtie once the index is built."));
 	Descriptor ebwt(EBWT_URL_ATTR, BowtieBuildWorker::tr("EBWT"), 
 		BowtieBuildWorker::tr("Output index url."));
@@ -237,12 +314,12 @@ void BowtieBuildWorkerFactory::init() {
 	a << new Attribute(refseq, CoreDataTypes::STRING_TYPE(), true /*required*/, QString());
 	a << new Attribute(ebwt, CoreDataTypes::STRING_TYPE(), true /*required*/, QString());
 
-	ActorPrototype* proto = new BusActorPrototype(desc, p, a);
+	ActorPrototype* proto = new IntegralBusActorPrototype(desc, p, a);
 
 	QMap<QString, PropertyDelegate*> delegates;    
 
 	delegates[REFSEQ_URL_ATTR] = new URLDelegate(DialogUtils::prepareDocumentsFileFilter(true), QString(), true);
-	delegates[EBWT_URL_ATTR] = new URLDelegate(DialogUtils::prepareDocumentsFileFilter(true), QString(), true);
+	delegates[EBWT_URL_ATTR] = new URLDelegate(DialogUtils::prepareDocumentsFileFilter(true), QString(), false);
 
 	proto->setEditor(new DelegateEditor(delegates));
 	proto->setPrompter(new BowtieBuildPrompter());
@@ -263,7 +340,7 @@ QString BowtieBuildPrompter::composeRichDoc() {
 }
 
 void BowtieBuildWorker::init() {
-	output = ports.value(CoreLibConstants::OUT_PORT_ID);
+	output = ports.value(EBWT_OUT_PORT_ID);
 	refSeqUrl = actor->getParameter(REFSEQ_URL_ATTR)->getAttributeValue<QString>();
 	ebwtUrl = actor->getParameter(EBWT_URL_ATTR)->getAttributeValue<QString>();
 }
@@ -275,11 +352,11 @@ bool BowtieBuildWorker::isReady() {
 Task* BowtieBuildWorker::tick() {
 
 	if( refSeqUrl.isEmpty()) {
-		log.trace(BowtieBuildWorker::tr("Reference sequence URL is empty")); 
+		algoLog.trace(BowtieBuildWorker::tr("Reference sequence URL is empty")); 
 		return NULL;
 	}
 	if( ebwtUrl.isEmpty()) {
-		log.trace(BowtieBuildWorker::tr("Reference sequence URL is empty")); 
+		algoLog.trace(BowtieBuildWorker::tr("Reference sequence URL is empty")); 
 		return NULL;
 	}
 
@@ -299,7 +376,7 @@ void BowtieBuildWorker::sl_taskFinished() {
 	QVariant v = qVariantFromValue<QString>(t->getEbwtPath());
 	output->put(Message(BowtiePlugin::EBWT_INDEX_TYPE(), v));
 	output->setEnded();
-	log.trace(tr("Bowtie index building finished. Result name is %1").arg(t->getEbwtPath()));
+	algoLog.trace(tr("Bowtie index building finished. Result name is %1").arg(t->getEbwtPath()));
 }
 
 bool BowtieBuildWorker::isDone() {
@@ -312,20 +389,24 @@ bool BowtieBuildWorker::isDone() {
 
 void BowtieIndexReaderWorkerFactory::init() {
 	QList<PortDescriptor*> p; QList<Attribute*> a;
-	Descriptor oud(CoreLibConstants::OUT_PORT_ID, BowtieIndexReaderWorker::tr("EBWT index"), BowtieIndexReaderWorker::tr("Result of alignment."));
-	p << new PortDescriptor(oud, BowtiePlugin::EBWT_INDEX_TYPE(), false /*input*/, true /*multi*/);
-	Descriptor desc(ACTOR_ID, BowtieIndexReaderWorker::tr("Bowtie index reader"), 
+	Descriptor oud(EBWT_OUT_PORT_ID, BowtieIndexReaderWorker::tr("EBWT index"), BowtieIndexReaderWorker::tr("Result of alignment."));
+	
+    QMap<Descriptor, DataTypePtr> outM;
+    outM[EBWT_SLOT] = BowtiePlugin::EBWT_INDEX_TYPE();
+    p << new PortDescriptor(oud, DataTypePtr(new MapDataType("bowtie.index.reader.out", outM)), false /*input*/, true /*multi*/);
+	
+    Descriptor desc(ACTOR_ID, BowtieIndexReaderWorker::tr("Bowtie index reader"), 
 		BowtieWorker::tr("Read a set of 6 files with suffixes .1.ebwt, .2.ebwt, .3.ebwt, .4.ebwt, .rev.1.ebwt, and .rev.2.ebwt. These files together constitute the index: they are all that is needed to align reads to that reference."));
 	Descriptor ebwt(EBWT_URL_ATTR, BowtieIndexReaderWorker::tr("EBWT"), 
-		BowtieIndexReaderWorker::tr("Output index url."));
+		BowtieIndexReaderWorker::tr("Select one of index files"));
 
 	a << new Attribute(ebwt, CoreDataTypes::STRING_TYPE(), true /*required*/, QString());
 
-	ActorPrototype* proto = new BusActorPrototype(desc, p, a);
+	ActorPrototype* proto = new IntegralBusActorPrototype(desc, p, a);
 
 	QMap<QString, PropertyDelegate*> delegates;    
 
-	delegates[EBWT_URL_ATTR] = new URLDelegate(DialogUtils::prepareDocumentsFileFilter(true), QString(), true);
+	delegates[EBWT_URL_ATTR] = new URLDelegate(DialogUtils::prepareDocumentsFileFilter(true), QString(), false, false, false);
 
 	proto->setEditor(new DelegateEditor(delegates));
 	proto->setPrompter(new BowtieIndexReaderPrompter());
@@ -346,7 +427,7 @@ QString BowtieIndexReaderPrompter::composeRichDoc() {
 }
 
 void BowtieIndexReaderWorker::init() {
-	output = ports.value(CoreLibConstants::OUT_PORT_ID);
+	output = ports.value(EBWT_OUT_PORT_ID);
 	ebwtUrl = actor->getParameter(EBWT_URL_ATTR)->getAttributeValue<QString>();
 }
 
@@ -357,7 +438,7 @@ bool BowtieIndexReaderWorker::isReady() {
 Task* BowtieIndexReaderWorker::tick() {
 
 	if( ebwtUrl.isEmpty()) {
-		log.trace(BowtieIndexReaderWorker::tr("Reference sequence URL is empty")); 
+		algoLog.trace(BowtieIndexReaderWorker::tr("Reference sequence URL is empty")); 
 		return NULL;
 	}
 	Task* t = new Task("Bowtie index reader", TaskFlags_NR_FOSCOE);
@@ -370,7 +451,7 @@ void BowtieIndexReaderWorker::sl_taskFinished() {
 	output->put(Message(BowtiePlugin::EBWT_INDEX_TYPE(), v));
 	output->setEnded();
 	done = true;
-	log.trace(tr("Reading bowtie index finished. Result name is %1").arg(ebwtUrl.getURLString()));
+	algoLog.trace(tr("Reading bowtie index finished. Result name is %1").arg(ebwtUrl.getURLString()));
 }
 
 bool BowtieIndexReaderWorker::isDone() {
@@ -378,4 +459,4 @@ bool BowtieIndexReaderWorker::isDone() {
 }
 
 } //namespace LocalWorkflow
-} //namespace GB2
+} //namespace U2
