@@ -20,4 +20,4 @@
 #define finline __forceinline
 
 //define SEQAN_SWITCH_USE_FORWARDS to use generated forwards 
-#define SEQAN_SWITCH_USE_FORWARDS
+//#define SEQAN_SWITCH_USE_FORWARDS
