@@ -1020,6 +1020,7 @@ protected:
 		for(size_t i = 0; i < ranges.size(); i++) {
 			Range& r = ranges[i];
 			r.fw = fw;
+			r.cost |= (r.stratum << 14);
 			r.mate1 = !off1;
 			const uint32_t result = offs[i];
 			// Just copy the known range's top and bot for now
@@ -1028,16 +1029,16 @@ protected:
 			bool ebwtLFw = matchRight ? range.ebwt->fw() : true;
 			bool ebwtRFw = matchRight ? true : range.ebwt->fw();
 			if(report(
-			        matchRight ? range : r, // range for upstream mate
-			        matchRight ? r : range, // range for downstream mate
-			        tidx,                   // ref idx
-			        matchRight ? toff : result, // upstream offset
-			        matchRight ? result : toff, // downstream offset
-			        tlen,       // length of ref
-			        !doneFw_,   // whether the pair is being mapped to fw strand
-			        ebwtLFw,
-			        ebwtRFw,
-			        range.ebwt->rmap())) return true;
+				matchRight ? range : r, // range for upstream mate
+				matchRight ? r : range, // range for downstream mate
+				tidx,                   // ref idx
+				matchRight ? toff : result, // upstream offset
+				matchRight ? result : toff, // downstream offset
+				tlen,       // length of ref
+				!doneFw_,   // whether the pair is being mapped to fw strand
+				ebwtLFw,
+				ebwtRFw,
+				range.ebwt->rmap())) return true;
 		}
 		return false;
 	}
@@ -1941,6 +1942,7 @@ protected:
 		for(size_t i = 0; i < ranges.size(); i++) {
 			Range& r = ranges[i];
 			r.fw = fw;
+			r.cost |= (r.stratum << 14);
 			r.mate1 = !range.mate1;
 			const uint32_t result = offs[i];
 			// Just copy the known range's top and bot for now
