@@ -75,33 +75,33 @@ using namespace seqan;
 #endif
 
 /**
-* Abstract parent class for blockwise suffix-array building schemes.
-*/
+ * Abstract parent class for blockwise suffix-array building schemes.
+ */
 template<typename TStr>
 class BlockwiseSA {
 public:
 	BlockwiseSA(const TStr& __text,
-		uint32_t __bucketSz,
-		bool __sanityCheck = false,
-		bool __passMemExc = false,
-		bool __verbose = false,
-		ostream& __logger = cout) :
+	            uint32_t __bucketSz,
+	            bool __sanityCheck = false,
+	            bool __passMemExc = false,
+	            bool __verbose = false,
+	            ostream& __logger = cout) :
 	_text(__text),
-		_bucketSz(max<uint32_t>(__bucketSz, 2u)),
-		_sanityCheck(__sanityCheck),
-		_passMemExc(__passMemExc),
-		_verbose(__verbose),
-		_itrBucket(),
-		_itrBucketPos(0xffffffff),
-		_itrPushedBackSuffix(0xffffffff),
-		_logger(__logger)
+	_bucketSz(max<uint32_t>(__bucketSz, 2u)),
+	_sanityCheck(__sanityCheck),
+	_passMemExc(__passMemExc),
+	_verbose(__verbose),
+	_itrBucket(),
+	_itrBucketPos(0xffffffff),
+	_itrPushedBackSuffix(0xffffffff),
+	_logger(__logger)
 	{ }
 
 	virtual ~BlockwiseSA() { }
 
 	/**
-	* Get the next suffix; compute the next bucket if necessary.
-	*/
+	 * Get the next suffix; compute the next bucket if necessary.
+	 */
 	uint32_t nextSuffix() {
 		if(_itrPushedBackSuffix != 0xffffffff) {
 			uint32_t tmp = _itrPushedBackSuffix;
@@ -109,7 +109,7 @@ public:
 			return tmp;
 		}
 		while(_itrBucketPos >= length(_itrBucket) ||
-			length(_itrBucket) == 0)
+		      length(_itrBucket) == 0)
 		{
 			if(!hasMoreBlocks()) {
 				throw out_of_range("No more suffixes");
@@ -121,8 +121,8 @@ public:
 	}
 
 	/**
-	* Return true iff the next call to nextSuffix will succeed.
-	*/
+	 * Return true iff the next call to nextSuffix will succeed.
+	 */
 	bool hasMoreSuffixes() {
 		if(_itrPushedBackSuffix != 0xffffffff) return true;
 		try {
@@ -135,9 +135,9 @@ public:
 	}
 
 	/**
-	* Reset the suffix iterator so that the next call to nextSuffix()
-	* returns the lexicographically-first suffix.
-	*/
+	 * Reset the suffix iterator so that the next call to nextSuffix()
+	 * returns the lexicographically-first suffix.
+	 */
 	void resetSuffixItr() {
 		clear(_itrBucket);
 		_itrBucketPos = 0xffffffff;
@@ -147,14 +147,14 @@ public:
 	}
 
 	/**
-	* Returns true iff the next call to nextSuffix() returns the
-	* lexicographically-first suffix.
-	*/
+	 * Returns true iff the next call to nextSuffix() returns the
+	 * lexicographically-first suffix.
+	 */
 	bool suffixItrIsReset() {
 		return length(_itrBucket)   == 0 &&
-			_itrBucketPos        == 0xffffffff &&
-			_itrPushedBackSuffix == 0xffffffff &&
-			isReset();
+		       _itrBucketPos        == 0xffffffff &&
+		       _itrPushedBackSuffix == 0xffffffff &&
+		       isReset();
 	}
 
 	const TStr& text()  const { return _text; }
@@ -171,9 +171,9 @@ protected:
 	virtual bool isReset() = 0;
 
 	/**
-	* Grab the next block of sorted suffixes.  The block is guaranteed
-	* to have at most _bucketSz elements.
-	*/
+	 * Grab the next block of sorted suffixes.  The block is guaranteed
+	 * to have at most _bucketSz elements.
+	 */
 	virtual void nextBlock() = 0;
 	/// Return true iff more blocks are available
 	virtual bool hasMoreBlocks() const = 0;
@@ -197,41 +197,41 @@ protected:
 };
 
 /**
-* Abstract parent class for a blockwise suffix array builder that
-* always doles out blocks in lexicographical order.
-*/
+ * Abstract parent class for a blockwise suffix array builder that
+ * always doles out blocks in lexicographical order.
+ */
 template<typename TStr>
 class InorderBlockwiseSA : public BlockwiseSA<TStr> {
 public:
 	InorderBlockwiseSA(const TStr& __text,
-		uint32_t __bucketSz,
-		bool __sanityCheck = false,
-		bool __passMemExc = false,
-		bool __verbose = false,
-		ostream& __logger = cout) :
+	                   uint32_t __bucketSz,
+	                   bool __sanityCheck = false,
+	   	               bool __passMemExc = false,
+	                   bool __verbose = false,
+	                   ostream& __logger = cout) :
 	BlockwiseSA<TStr>(__text, __bucketSz, __sanityCheck, __passMemExc, __verbose, __logger)
 	{ }
 };
 
 /**
-* Build the SA a block at a time according to the scheme outlined in
-* Karkkainen's "Fast BWT" paper.
-*/
+ * Build the SA a block at a time according to the scheme outlined in
+ * Karkkainen's "Fast BWT" paper.
+ */
 template<typename TStr>
 class KarkkainenBlockwiseSA : public InorderBlockwiseSA<TStr> {
 public:
 	typedef DifferenceCoverSample<TStr> TDC;
 
 	KarkkainenBlockwiseSA(const TStr& __text,
-		uint32_t __bucketSz,
-		uint32_t __dcV,
-		uint32_t __seed = 0,
-		bool __sanityCheck = false,
-		bool __passMemExc = false,
-		bool __verbose = false,
-		ostream& __logger = cout) :
+	                      uint32_t __bucketSz,
+	                      uint32_t __dcV,
+	                      uint32_t __seed = 0,
+	      	              bool __sanityCheck = false,
+	   	                  bool __passMemExc = false,
+	      	              bool __verbose = false,
+	      	              ostream& __logger = cout) :
 	InorderBlockwiseSA<TStr>(__text, __bucketSz, __sanityCheck, __passMemExc, __verbose, __logger),
-		_sampleSuffs(), _cur(0), _dcV(__dcV), _dc(NULL), _built(false)
+	_sampleSuffs(), _cur(0), _dcV(__dcV), _dc(NULL), _built(false)
 	{ _randomSrc.init(__seed); reset(); }
 
 	~KarkkainenBlockwiseSA() {
@@ -239,11 +239,11 @@ public:
 	}
 
 	/**
-	* Allocate an amount of memory that simulates the peak memory
-	* usage of the DifferenceCoverSample with the given text and v.
-	* Throws bad_alloc if it's not going to fit in memory.  Returns
-	* the approximate number of bytes the Cover takes at all times.
-	*/
+	 * Allocate an amount of memory that simulates the peak memory
+	 * usage of the DifferenceCoverSample with the given text and v.
+	 * Throws bad_alloc if it's not going to fit in memory.  Returns
+	 * the approximate number of bytes the Cover takes at all times.
+	 */
 	static size_t simulateAllocs(const TStr& text, uint32_t bucketSz) {
 		size_t len = length(text);
 		// _sampleSuffs and _itrBucket are in memory at the peak
@@ -270,11 +270,11 @@ public:
 protected:
 
 	/**
-	* Initialize the state of the blockwise suffix sort.  If the
-	* difference cover sample and the sample set have not yet been
-	* built, build them.  Then reset the block cursor to point to
-	* the first block.
-	*/
+	 * Initialize the state of the blockwise suffix sort.  If the
+	 * difference cover sample and the sample set have not yet been
+	 * built, build them.  Then reset the block cursor to point to
+	 * the first block.
+	 */
 	virtual void reset() {
 		if(!_built) {
 			build();
@@ -291,8 +291,8 @@ protected:
 private:
 
 	/**
-	* Calculate the difference-cover sample and sample suffixes.
-	*/
+	 * Calculate the difference-cover sample and sample suffixes.
+	 */
 	void build() {
 		// Calculate difference-cover sample
 		assert(_dc == NULL);
@@ -306,33 +306,33 @@ private:
 			buildSamples();
 		} else {
 			VMSG_NL("Skipping building samples since text length " <<
-				length(this->text()) << " is less than bucket size: " <<
-				this->bucketSz());
+			        length(this->text()) << " is less than bucket size: " <<
+			        this->bucketSz());
 		}
 		_built = true;
 	}
 
 	/**
-	* Calculate the lcp between two suffixes using the difference
-	* cover as a tie-breaker.  If the tie-breaker is employed, then
-	* the calculated lcp may be an underestimate.
-	*
-	* Defined in blockwise_sa.cpp
-	*/
+	 * Calculate the lcp between two suffixes using the difference
+	 * cover as a tie-breaker.  If the tie-breaker is employed, then
+	 * the calculated lcp may be an underestimate.
+	 *
+	 * Defined in blockwise_sa.cpp
+	 */
 	inline bool tieBreakingLcp(uint32_t aOff,
-		uint32_t bOff,
-		uint32_t& lcp,
-		bool& lcpIsSoft);
+	                           uint32_t bOff,
+	                           uint32_t& lcp,
+	                           bool& lcpIsSoft);
 
 	/**
-	* Compare two suffixes using the difference-cover sample.
-	*/
+	 * Compare two suffixes using the difference-cover sample.
+	 */
 	inline bool suffixCmp(uint32_t cmp,
-		uint32_t i,
-		int64_t& j,
-		int64_t& k,
-		bool& kSoft,
-		const String<uint32_t>& z);
+	                      uint32_t i,
+	                      int64_t& j,
+	                      int64_t& k,
+	                      bool& kSoft,
+	                      const String<uint32_t>& z);
 
 	void buildSamples();
 
@@ -345,8 +345,8 @@ private:
 };
 
 /**
-* Qsort the set of suffixes whose offsets are in 'bucket'.
-*/
+ * Qsort the set of suffixes whose offsets are in 'bucket'.
+ */
 template<typename TStr>
 void KarkkainenBlockwiseSA<TStr>::qsort(String<uint32_t>& bucket) {
 	typedef typename Value<TStr>::Type TAlphabet;
@@ -360,25 +360,24 @@ void KarkkainenBlockwiseSA<TStr>::qsort(String<uint32_t>& bucket) {
 		// Extract the 'host' array because it's faster to work
 		// with than the String<> container
 		uint8_t *host = (uint8_t*)t.data_begin;
-		
 		mkeyQSortSufDcU8(t, host, len, s, slen, *_dc,
-			ValueSize<TAlphabet>::VALUE,
-			this->verbose(), this->sanityCheck());
+		                 ValueSize<TAlphabet>::VALUE,
+		                 this->verbose(), this->sanityCheck());
 	} else {
 		VMSG_NL("  (Not using difference cover)");
 		// We don't have a difference cover - just do a normal
 		// suffix sort
 		mkeyQSortSuf(t, s, slen, ValueSize<TAlphabet>::VALUE,
-			this->verbose(), this->sanityCheck());
+		             this->verbose(), this->sanityCheck());
 	}
 }
 
 /**
-* Qsort the set of suffixes whose offsets are in 'bucket'.  This
-* specialization for packed strings does not attempt to extract and
-* operate directly on the host string; the fact that the string is
-* packed means that the array cannot be sorted directly.
-*/
+ * Qsort the set of suffixes whose offsets are in 'bucket'.  This
+ * specialization for packed strings does not attempt to extract and
+ * operate directly on the host string; the fact that the string is
+ * packed means that the array cannot be sorted directly.
+ */
 #ifdef _MSC_VER
 extern template
 #else 
@@ -396,23 +395,23 @@ void KarkkainenBlockwiseSA<String<Dna, Packed<> > >::qsort(String<uint32_t>& buc
 		// Can't use the text's 'host' array because the backing
 		// store for the packed string is not one-char-per-elt.
 		mkeyQSortSufDcU8(t, t, len, s, slen, *_dc,
-			ValueSize<Dna>::VALUE,
-			this->verbose(), this->sanityCheck());
+		                 ValueSize<Dna>::VALUE,
+		                 this->verbose(), this->sanityCheck());
 	} else {
 		VMSG_NL("  (Not using difference cover)");
 		// We don't have a difference cover - just do a normal
 		// suffix sort
 		mkeyQSortSuf(t, s, slen, ValueSize<Dna>::VALUE,
-			this->verbose(), this->sanityCheck());
+		             this->verbose(), this->sanityCheck());
 	}
-}
-*/
+}*/
+
 /**
-* Select a set of bucket-delineating sample suffixes such that no
-* bucket is greater than the requested upper limit.  Some care is
-* taken to make each bucket's size close to the limit without
-* going over.
-*/
+ * Select a set of bucket-delineating sample suffixes such that no
+ * bucket is greater than the requested upper limit.  Some care is
+ * taken to make each bucket's size close to the limit without
+ * going over.
+ */
 template<typename TStr>
 void KarkkainenBlockwiseSA<TStr>::buildSamples() {
 	BowtieContext* ctx = BowtieContext::getContext();
@@ -445,8 +444,8 @@ void KarkkainenBlockwiseSA<TStr>::buildSamples() {
 				throw e; // rethrow immediately
 			} else {
 				cerr << "Could not allocate sample suffix container of " << (numSamples * 4) << " bytes." << endl
-					<< "Please try using a smaller number of blocks by specifying a larger --bmax or" << endl
-					<< "a smaller --bmaxdivn" << endl;
+				     << "Please try using a smaller number of blocks by specifying a larger --bmax or" << endl
+				     << "a smaller --bmaxdivn" << endl;
 				throw 1;
 			}
 		}
@@ -495,8 +494,8 @@ void KarkkainenBlockwiseSA<TStr>::buildSamples() {
 				throw e; // rethrow immediately
 			} else {
 				cerr << "Could not allocate sizes, representatives (" << ((numBuckets*8)>>10) << " KB) for blocks." << endl
-					<< "Please try using a smaller number of blocks by specifying a larger --bmax or a" << endl
-					<< "smaller --bmaxdivn." << endl;
+				     << "Please try using a smaller number of blocks by specifying a larger --bmax or a" << endl
+				     << "smaller --bmaxdivn." << endl;
 				throw 1;
 			}
 		}
@@ -528,7 +527,7 @@ void KarkkainenBlockwiseSA<TStr>::buildSamples() {
 					bucketSzs[r]++;
 					assert_lt(bucketSzs[r], len);
 					if(bucketReps[r] == 0xffffffff ||
-						(_randomSrc.nextU32() & 100) == 0)
+					   (_randomSrc.nextU32() & 100) == 0)
 					{
 						bucketReps[r] = i; // clobbers previous one, but that's OK
 					}
@@ -594,16 +593,16 @@ void KarkkainenBlockwiseSA<TStr>::buildSamples() {
 	}
 	ctx->ti.progress = (ctx->build.secondEbwtRound ? 50.0:0.0) + ( ctx->build.doubleEbwt ? 0.5:1.0 ) * 30;
 	// Do *not* force a do-over
-	//	if(limit == 0) {
-	//		VMSG_NL("Iterated too many times; trying again...");
-	//		buildSamples();
-	//	}
+//	if(limit == 0) {
+//		VMSG_NL("Iterated too many times; trying again...");
+//		buildSamples();
+//	}
 	VMSG_NL("Avg bucket size: " << ((float)(len-length(_sampleSuffs)) / (length(_sampleSuffs)+1)) << " (target: " << bsz << ")");
 }
 
 /**
-* Do a simple LCP calculation on two strings.
-*/
+ * Do a simple LCP calculation on two strings.
+ */
 template<typename T> inline
 static uint32_t suffixLcp(const T& t, uint32_t aOff, uint32_t bOff) {
 	uint32_t c = 0;
@@ -615,16 +614,16 @@ static uint32_t suffixLcp(const T& t, uint32_t aOff, uint32_t bOff) {
 }
 
 /**
-* Calculate the lcp between two suffixes using the difference
-* cover as a tie-breaker.  If the tie-breaker is employed, then
-* the calculated lcp may be an underestimate.  If the tie-breaker is
-* employed, lcpIsSoft will be set to true (otherwise, false).
-*/
+ * Calculate the lcp between two suffixes using the difference
+ * cover as a tie-breaker.  If the tie-breaker is employed, then
+ * the calculated lcp may be an underestimate.  If the tie-breaker is
+ * employed, lcpIsSoft will be set to true (otherwise, false).
+ */
 template<typename TStr> inline
 bool KarkkainenBlockwiseSA<TStr>::tieBreakingLcp(uint32_t aOff,
-												 uint32_t bOff,
-												 uint32_t& lcp,
-												 bool& lcpIsSoft)
+                                                 uint32_t bOff,
+                                                 uint32_t& lcp,
+                                                 bool& lcpIsSoft)
 {
 	const TStr& t = this->text();
 	uint32_t c = 0;
@@ -635,9 +634,9 @@ bool KarkkainenBlockwiseSA<TStr>::tieBreakingLcp(uint32_t aOff,
 	uint32_t dcDist = _dc->tieBreakOff(aOff, bOff);
 	lcpIsSoft = false; // hard until proven soft
 	while(c < dcDist &&    // we haven't hit the tie breaker
-		c < tlen-aOff && // we haven't fallen off of LHS suffix
-		c < tlen-bOff && // we haven't fallen off of RHS suffix
-		t[aOff+c] == t[bOff+c]) // we haven't hit a mismatch
+	      c < tlen-aOff && // we haven't fallen off of LHS suffix
+	      c < tlen-bOff && // we haven't fallen off of RHS suffix
+	      t[aOff+c] == t[bOff+c]) // we haven't hit a mismatch
 		c++;
 	lcp = c;
 	if(c == tlen-aOff) {
@@ -658,14 +657,14 @@ bool KarkkainenBlockwiseSA<TStr>::tieBreakingLcp(uint32_t aOff,
 }
 
 /**
-* Lookup a suffix LCP in the given z array; if the element is not
-* filled in then calculate it from scratch.
-*/
+ * Lookup a suffix LCP in the given z array; if the element is not
+ * filled in then calculate it from scratch.
+ */
 template<typename T>
 static uint32_t lookupSuffixZ(const T& t,
-							  uint32_t zOff,
-							  uint32_t off,
-							  const String<uint32_t>& z)
+                              uint32_t zOff,
+                              uint32_t off,
+                              const String<uint32_t>& z)
 {
 	if(zOff < length(z)) {
 		uint32_t ret = z[zOff];
@@ -677,16 +676,16 @@ static uint32_t lookupSuffixZ(const T& t,
 }
 
 /**
-* true -> i < cmp
-* false -> i > cmp
-*/
+ * true -> i < cmp
+ * false -> i > cmp
+ */
 template<typename TStr> inline
 bool KarkkainenBlockwiseSA<TStr>::suffixCmp(uint32_t cmp,
-											uint32_t i,
-											int64_t& j,
-											int64_t& k,
-											bool& kSoft,
-											const String<uint32_t>& z)
+                                            uint32_t i,
+                                            int64_t& j,
+                                            int64_t& k,
+                                            bool& kSoft,
+                                            const String<uint32_t>& z)
 {
 	const TStr& t = this->text();
 	uint32_t len = length(t);
@@ -771,10 +770,10 @@ bool KarkkainenBlockwiseSA<TStr>::suffixCmp(uint32_t cmp,
 
 	// Now we're ready to do a comparison on the next char
 	if(l+i != len && (
-		l == len-cmp || // departure from paper algorithm:
-		// falling off pattern implies
-		// pattern is *greater* in our case
-		t[i + l] < t[cmp + l]))
+	   l == len-cmp || // departure from paper algorithm:
+	                   // falling off pattern implies
+	                   // pattern is *greater* in our case
+	   t[i + l] < t[cmp + l]))
 	{
 		// Case 2: Text suffix is less than upper sample suffix
 		if(this->sanityCheck()) assert(dollarLt(suffix(t, i), suffix(t, cmp)));
@@ -788,9 +787,9 @@ bool KarkkainenBlockwiseSA<TStr>::suffixCmp(uint32_t cmp,
 }
 
 /**
-* Retrieve the next block.  This is the most performance-critical part
-* of the blockwise suffix sorting process.
-*/
+ * Retrieve the next block.  This is the most performance-critical part
+ * of the blockwise suffix sorting process.
+ */
 template<typename TStr>
 void KarkkainenBlockwiseSA<TStr>::nextBlock() {
 	typedef typename Value<TStr>::Type TAlphabet;
@@ -820,10 +819,10 @@ void KarkkainenBlockwiseSA<TStr>::nextBlock() {
 			if(this->_passMemExc) {
 				throw e; // rethrow immediately
 			} else {
-				ostringstream err; err << "Could not allocate a master suffix-array block of " << ((len+1) * 4) << " bytes" << endl
-					<< "Please try using a larger number of blocks by specifying a smaller --bmax or" << endl
-					<< "a larger --bmaxdivn" << endl;
-				throw BowtieException(err.str());
+				cerr << "Could not allocate a master suffix-array block of " << ((len+1) * 4) << " bytes" << endl
+				     << "Please try using a larger number of blocks by specifying a smaller --bmax or" << endl
+				     << "a larger --bmaxdivn" << endl;
+				throw 1;
 			}
 		}
 	} else {
