@@ -70,13 +70,15 @@ if(this->verbose()) { \
 /**
  *
  */
-// struct sampleEntry {
-// 	uint32_t maxV;
-// 	uint32_t numSamples;
-// 	uint32_t samples[128];
-// };
+/*struct sampleEntry {
+	uint32_t maxV;
+	uint32_t numSamples;
+	uint32_t samples[128];
+};*/
 
 typedef BowtieContext::Build::sampleEntry sampleEntry;
+/// Array of Colbourn and Ling calculated difference covers up to
+/// r = 16 (maxV = 5953)
 
 /**
  * Check that the given difference cover 'ds' actually covers all
