@@ -13,11 +13,12 @@
 #include "BowtieIOAdapter.h"
 #include "BowtieContext.h"
 
-#include <core_api/DNAAlphabet.h>
-#include <core_api/Task.h>
-#include <core_api/Log.h>
-#include <util_algorithm/GAutoDeleteList.h>
-#include <datatype/MAlignment.h>
+#include <U2Core/DNAAlphabet.h>
+#include <U2Core/Task.h>
+#include <U2Core/Log.h>
+#include <U2Core/GUrl.h>
+#include <U2Core/GAutoDeleteList.h>
+#include <U2Core/MAlignment.h>
 
 #include <algorithm>
 #include <QtCore/QVector>
@@ -586,14 +587,14 @@ static void exactSearch(PairedPatternSource& _patsrc,
 		// Load the rest of (vast majority of) the backward Ebwt into
 		// memory
 		Timer _t(cerr, "Time loading forward index: ", ctx->timing);
-		ebwt.loadIntoMemory(color ? 1 : 0, !ctx->noRefNames, ctx->startVerbose);
+		ebwt.loadIntoMemory(color ? 1 : 0, -1, !ctx->noRefNames, ctx->startVerbose);
 	}
 
 	BitPairReference *refs = NULL;
 	bool pair = ctx->mates1.size() > 0 || ctx->mates12.size() > 0;
 	if(color || (pair && ctx->mixedThresh < 0xffffffff)) {
 		Timer _t(cerr, "Time loading reference: ", ctx->timing);
-		refs = new BitPairReference(ctx->adjustedEbwtFileBase, color, ctx->sanityCheck, NULL, &os, false, ctx->useMm, ctx->useShmem, ctx->mmSweep, ctx->verbose, ctx->startVerbose);
+		refs = new BitPairReference(ctx->adjustedEbwtFileBase, color, ctx->sanityCheck, NULL, &os, false, true, ctx->useMm, ctx->useShmem, ctx->mmSweep, ctx->verbose, ctx->startVerbose);
 		if(!refs->loaded()) throw BowtieException("Bit pair reference not loaded");
 	}
 	ctx->exactSearch_refs   = refs;
@@ -809,19 +810,19 @@ static void mismatchSearchFull(PairedPatternSource& _patsrc,
 	{
 		// Load the other half of the index into memory
 		Timer _t(cerr, "Time loading forward index: ", ctx->timing);
-		ebwtFw.loadIntoMemory(ctx->color ? 1 : 0, !ctx->noRefNames, ctx->startVerbose);
+		ebwtFw.loadIntoMemory(ctx->color ? 1 : 0, -1, !ctx->noRefNames, ctx->startVerbose);
 	}
 	{
 		// Load the other half of the index into memory
 		Timer _t(cerr, "Time loading mirror index: ", ctx->timing);
-		ebwtBw.loadIntoMemory(ctx->color ? 1 : 0, !ctx->noRefNames, ctx->startVerbose);
+		ebwtBw.loadIntoMemory(ctx->color ? 1 : 0, -1, !ctx->noRefNames, ctx->startVerbose);
 	}
 	// Create range caches, which are shared among all aligners
 	BitPairReference *refs = NULL;
 	bool pair = ctx->mates1.size() > 0 || ctx->mates12.size() > 0;
 	if(ctx->color || (pair && ctx->mixedThresh < 0xffffffff)) {
 		Timer _t(cerr, "Time loading reference: ", ctx->timing);
-		refs = new BitPairReference(ctx->adjustedEbwtFileBase, ctx->color, ctx->sanityCheck, NULL, &os, false, ctx->useMm, ctx->useShmem, ctx->mmSweep, ctx->verbose, ctx->startVerbose);
+                refs = new BitPairReference(ctx->adjustedEbwtFileBase, ctx->color, ctx->sanityCheck, NULL, &os, false, true, ctx->useMm, ctx->useShmem, ctx->mmSweep, ctx->verbose, ctx->startVerbose);
 		if(!refs->loaded()) throw BowtieException("Bit pair reference not loaded");
 	}
 	ctx->mismatchSearch_refs = refs;
@@ -861,7 +862,7 @@ static void mismatchSearchFull(PairedPatternSource& _patsrc,
 	/* Load the forward index into memory if necessary */ \
 	if(!ebwtFw.isInMemory()) { \
 	Timer _t(cerr, "Time loading forward index: ", ctx->timing); \
-	ebwtFw.loadIntoMemory(ctx->color ? 1 : 0, !ctx->noRefNames, ctx->startVerbose); \
+	ebwtFw.loadIntoMemory(ctx->color ? 1 : 0, -1, !ctx->noRefNames, ctx->startVerbose); \
 	} \
 	assert(ebwtFw.isInMemory()); \
 	_patsrc.reset(); /* rewind pattern source to first pattern */ \
@@ -1139,19 +1140,19 @@ static void twoOrThreeMismatchSearchFull(
 	{
 		// Load the other half of the index into memory
 		Timer _t(cerr, "Time loading forward index: ", ctx->timing);
-		ebwtFw.loadIntoMemory(ctx->color ? 1 : 0, !ctx->noRefNames, ctx->startVerbose);
+		ebwtFw.loadIntoMemory(ctx->color ? 1 : 0, -1, !ctx->noRefNames, ctx->startVerbose);
 	}
 	{
 		// Load the other half of the index into memory
 		Timer _t(cerr, "Time loading mirror index: ", ctx->timing);
-		ebwtBw.loadIntoMemory(ctx->color ? 1 : 0, !ctx->noRefNames, ctx->startVerbose);
+		ebwtBw.loadIntoMemory(ctx->color ? 1 : 0, -1, !ctx->noRefNames, ctx->startVerbose);
 	}
 	// Create range caches, which are shared among all aligners
 	BitPairReference *refs = NULL;
 	bool pair = ctx->mates1.size() > 0 || ctx->mates12.size() > 0;
 	if(ctx->color || (pair && ctx->mixedThresh < 0xffffffff)) {
 		Timer _t(cerr, "Time loading reference: ", ctx->timing);
-		refs = new BitPairReference(ctx->adjustedEbwtFileBase, ctx->color, ctx->sanityCheck, NULL, &os, false, ctx->useMm, ctx->useShmem, ctx->mmSweep, ctx->verbose, ctx->startVerbose);
+		refs = new BitPairReference(ctx->adjustedEbwtFileBase, ctx->color, ctx->sanityCheck, NULL, &os, false, true, ctx->useMm, ctx->useShmem, ctx->mmSweep, ctx->verbose, ctx->startVerbose);
 		if(!refs->loaded()) BowtieException("Bit pair reference not loaded");
 	}
 	ctx->twoOrThreeMismatchSearch_refs     = refs;
@@ -1553,7 +1554,7 @@ static void seededQualCutoffSearchFull(
 	bool pair = ctx->mates1.size() > 0 || ctx->mates12.size() > 0;
 	if(ctx->color || (pair && ctx->mixedThresh < 0xffffffff)) {
 		Timer _t(cerr, "Time loading reference: ", ctx->timing);
-		refs = new BitPairReference(ctx->adjustedEbwtFileBase, ctx->color, ctx->sanityCheck, NULL, &os, false, ctx->useMm, ctx->useShmem, ctx->mmSweep, ctx->verbose, ctx->startVerbose);
+		refs = new BitPairReference(ctx->adjustedEbwtFileBase, ctx->color, ctx->sanityCheck, NULL, &os, false, true, ctx->useMm, ctx->useShmem, ctx->mmSweep, ctx->verbose, ctx->startVerbose);
 		if(!refs->loaded()) BowtieException("Bit pair reference not loaded");
 	}
 	ctx->seededQualSearch_refs = refs;
@@ -1568,7 +1569,7 @@ static void seededQualCutoffSearchFull(
 	{
 		// Load the other half of the index into memory
 		Timer _t(cerr, "Time loading mirror index: ", ctx->timing);
-		ebwtBw.loadIntoMemory(ctx->color ? 1 : 0, !ctx->noRefNames, ctx->startVerbose);
+		ebwtBw.loadIntoMemory(ctx->color ? 1 : 0, -1, !ctx->noRefNames, ctx->startVerbose);
 	}
 	CHUD_START();
 	{
@@ -1675,8 +1676,9 @@ patsrcFromStrings(int format,
 static string argstr;
 
 template<typename TStr>
-static void driver(const QList<GB2::DNASequence>& reads,
-				   GB2::MAlignment& resultMA,
+static void driver(U2::BowtieReadsReader* reader,
+				   U2::BowtieReadsWriter* writer,
+                   const U2::GUrl& resultFileUrl,
 				   const char * type,
 				   const string& ebwtFileBase,
 				   const string& query,
@@ -1787,7 +1789,7 @@ static void driver(const QList<GB2::DNASequence>& reads,
 			assert_eq(1, tmpSeq.size());
 		}
 		if(quals->empty()) quals = NULL;
-		patsrc = new DNASequencesPatternSource(ctx->seed, reads);
+		patsrc = new DNASequencesPatternSource(ctx->seed, reader);
 		assert(patsrc != NULL);
 		patsrcs_a.push_back(patsrc);
 		patsrcs_b.push_back(NULL);
@@ -1849,6 +1851,7 @@ static void driver(const QList<GB2::DNASequence>& reads,
 	}
 	Ebwt<TStr> ebwt(ctx->adjustedEbwtFileBase,
 		ctx->color,  // index is colorspace
+                -1,     // don't care about entireReverse
 		true,     // index is for the forward direction
 		/* overriding: */ ctx->offRate,
 		/* overriding: */ ctx->isaRate,
@@ -1869,6 +1872,7 @@ static void driver(const QList<GB2::DNASequence>& reads,
 		}
 		ebwtBw = new Ebwt<TStr>(ctx->adjustedEbwtFileBase + ".rev",
 			ctx->color,  // index is colorspace
+			-1,     // don't care about entireReverse
 			false, // index is for the reverse direction
 			/* overriding: */ ctx->offRate,
 			/* overriding: */ ctx->isaRate,
@@ -1882,6 +1886,25 @@ static void driver(const QList<GB2::DNASequence>& reads,
 			false /*passMemExc*/,
 			ctx->sanityCheck);
 	}
+	if(!os.empty()) {
+		for(size_t i = 0; i < os.size(); i++) {
+			size_t olen = seqan::length(os[i]);
+			int longestStretch = 0;
+			int curStretch = 0;
+			for(size_t j = 0; j < olen; j++) {
+				if((int)os[i][j] < 4) {
+					curStretch++;
+					if(curStretch > longestStretch) longestStretch = curStretch;
+				} else {
+					curStretch = 0;
+				}
+			}
+                        if(longestStretch < (ctx->color ? 2 : 1)) {
+				os.erase(os.begin() + i);
+				i--;
+			}
+		}
+	}
 	if(ctx->sanityCheck && !os.empty()) {
 		// Sanity check number of patterns and pattern lengths in Ebwt
 		// against original strings
@@ -1889,10 +1912,7 @@ static void driver(const QList<GB2::DNASequence>& reads,
 		for(size_t i = 0; i < os.size(); i++) {
 			assert_eq(length(os[i]), ebwt.plen()[i] + (ctx->color ? 1 : 0));
 		}
-	}
-	// Sanity-check the restored version of the Ebwt
-	if(ctx->sanityCheck && !os.empty()) {
-		ebwt.loadIntoMemory(ctx->color ? 1 : 0, !ctx->noRefNames, ctx->startVerbose);
+		ebwt.loadIntoMemory(ctx->color ? 1 : 0, -1, !ctx->noRefNames, ctx->startVerbose);
 		ebwt.checkOrigs(os, ctx->color, false);
 		ebwt.evictFromMemory();
 	}
@@ -1911,7 +1931,7 @@ static void driver(const QList<GB2::DNASequence>& reads,
 		}
 		vector<string>* refnames = &ebwt.refnames();
 		if(ctx->noRefNames) refnames = NULL;
-		sink = new MAlignmentHitSink(resultMA,
+		sink = new MAlignmentHitSink(writer,
 			fout, PASS_DUMP_FILES, false, ctx->sampleMax,
 			table, refnames);
 
@@ -1977,8 +1997,9 @@ static void driver(const QList<GB2::DNASequence>& reads,
 	}
 }
 
-void driverAdapter(const QList<GB2::DNASequence>& reads,
-				   GB2::MAlignment& resultMA,
+void driverAdapter(U2::BowtieReadsReader* reader,
+				   U2::BowtieReadsWriter* writer,
+                   const U2::GUrl& resultUrl,
 				   const char * type,
 				   const string& ebwtFileBase,
 				   const string& query,
@@ -1986,5 +2007,5 @@ void driverAdapter(const QList<GB2::DNASequence>& reads,
 				   const vector<string>& qualities,
 				   const string& outfile) 
 {
-	driver<String<Dna, Alloc<> > >(reads, resultMA, type, ebwtFileBase, query, queries, qualities, outfile);	
-}
\ No newline at end of file
+	driver<String<Dna, Alloc<> > >(reader, writer, resultUrl, type, ebwtFileBase, query, queries, qualities, outfile);	
+}
