@@ -166,13 +166,22 @@ public:
 	bool                mfw;     /// orientation of mate in alignment
 	uint16_t            mlen;    /// length of mate
 	int8_t              stratum; /// stratum of hit (= mismatches in seed)
-	uint16_t            cost;    /// total cost, factoring in stratum and quality penalty
+	uint32_t            cost;    /// total cost, factoring in stratum and quality penalty
 	uint8_t             mate;    /// matedness; 0 = not a mate
 	                             ///            1 = upstream mate
 	                             ///            2 = downstream mate
 	bool                color;   /// read is in colorspace?
 	uint32_t            seed;    /// pseudo-random seed for aligned read
 
+	/**
+	 * Return true if this Hit is internally consistent.  Otherwise,
+	 * throw an assertion.
+	 */
+	bool repOk() const {
+		assert_geq(cost, (uint32_t)(stratum << 14));
+		return true;
+	}
+
 	size_t length() const { return seqan::length(patSeq); }
 
 	Hit& operator = (const Hit &other) {
@@ -276,6 +285,7 @@ public:
 		// Iterate through the pattern from 5' to 3', calculate the
 		// shifted quality value, obtain the reference character, and
 		// increment the appropriate counter
+		assert(h.repOk());
 		for(int i = 0; i < (int)h.length(); i++) {
 			int ii = i;
 			if(!h.fw) {
@@ -501,6 +511,7 @@ public:
 		char buf[4096];
 		for(size_t i = start; i < end; i++) {
 			const Hit& h = hs[i];
+			assert(h.repOk());
 			bool diff = false;
 			if(i > start) {
 				diff = (refIdxToStreamIdx(h.h.first) != refIdxToStreamIdx(hs[i-1].h.first));
@@ -871,6 +882,7 @@ protected:
 
 	/// Implementation of hit-report
 	virtual void reportHit(const Hit& h) {
+		assert(h.repOk());
 		mainlock();
 		commitHit(h);
 		first_ = false;
@@ -1066,7 +1078,7 @@ public:
 		_numValidHits(U64(0)),
 		_hits(),
 		_bufferedHits(),
-		hitsForThisRead_(0),
+		hitsForThisRead_(),
 		_max(max),
 		_n(n)
 	{
@@ -1142,6 +1154,7 @@ public:
 	 * return true iff the caller should continue to report more hits.
 	 */
 	virtual bool reportHit(const Hit& h, int stratum) {
+		assert(h.repOk());
 		_numValidHits++;
 		return true;
 	}
