@@ -8,15 +8,13 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_SEC_STRUCT_PREDICT_PLUGIN_H_
-#define _GB2_SEC_STRUCT_PREDICT_PLUGIN_H_
+#ifndef _U2_SEC_STRUCT_PREDICT_PLUGIN_H_
+#define _U2_SEC_STRUCT_PREDICT_PLUGIN_H_
 
-#include <core_api/PluginModel.h>
-#include <datatype/AnnotationData.h>
+#include <U2Core/PluginModel.h>
+#include <U2Core/AnnotationData.h>
 
-namespace GB2 {
-
-#define ULOG_CAT_PLUGIN_SEC_STRUCT_PREDICT "Plugin: GORIV"
+namespace U2 {
 
 class SecStructPredictPlugin : public Plugin {
 	Q_OBJECT
@@ -29,6 +27,6 @@ public:
 
 } //namespace
 
-#endif // _GB2_SEC_STRUCT_PREDICT_PLUGIN_H_
+#endif // _U2_SEC_STRUCT_PREDICT_PLUGIN_H_
 
 
