@@ -12,21 +12,21 @@
 #include "hmmer2/funcs.h"
 #include "TaskLocalStorage.h"
 
-#include <core_api/IOAdapter.h>
-#include <core_api/L10n.h>
-#include <core_api/Task.h>
-#include <core_api/GUrlUtils.h>
-#include <core_api/AppContext.h>
-#include <core_api/Settings.h>
-#include <util_text/TextUtils.h>
-#include <util_tasks/SaveDocumentTask.h>
-#include <util_gui/DialogUtils.h>
+#include <U2Core/IOAdapter.h>
+#include <U2Core/L10n.h>
+#include <U2Core/Task.h>
+#include <U2Core/GUrlUtils.h>
+#include <U2Core/AppContext.h>
+#include <U2Core/Settings.h>
+#include <U2Core/TextUtils.h>
+#include <U2Core/SaveDocumentTask.h>
+#include <U2Misc/DialogUtils.h>
 
 #include <memory>
 #include <QtCore/QtAlgorithms>
-namespace GB2 {
+namespace U2 {
 
-/* TRANSLATOR GB2::IOAdapter */    
+/* TRANSLATOR U2::IOAdapter */    
 
 static const char * prob2ascii(float p, float null) {
   HMMERTaskLocalData *tld = getHMMERTaskLocalData();
