@@ -17,7 +17,7 @@
 #include <QtCore/QHash>
 #include <QtCore/QMutex>
 
-namespace GB2 {
+namespace U2 {
 
 // this struct is stored in TLS
 struct ContextIdContainer {
@@ -50,4 +50,4 @@ private:
 };
 } //namespace
 
-#endif
\ No newline at end of file
+#endif
