@@ -8,8 +8,8 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_UHMM_BUILD_H_
-#define _GB2_UHMM_BUILD_H_
+#ifndef _U2_UHMM_BUILD_H_
+#define _U2_UHMM_BUILD_H_
 
 struct plan7_s;
 struct msa_struct;
@@ -17,7 +17,7 @@ struct msa_struct;
 #include <QtCore/QString>
 #include <QtCore/QObject>
 
-namespace GB2 {
+namespace U2 {
 
 class TaskStateInfo;
 
