@@ -14,11 +14,11 @@
 #include <HMMIO.h>
 #include <TaskLocalStorage.h>
 
-#include <core_api/Counter.h>
+#include <U2Core/Counter.h>
 
 #include <QtCore/QFileInfo>
 
-namespace GB2 {
+namespace U2 {
 
 HMMCalibrateTask::HMMCalibrateTask(plan7_s* hmm, const UHMMCalibrateSettings& s) 
     : HMMCalibrateAbstractTask("", hmm, s)
