@@ -15,7 +15,7 @@
 #include <hmmer2/structs.h>
 #include <QtCore/QList>
 
-namespace GB2 {
+namespace U2 {
     class LRegion;
     class TaskStateInfo;
 }
@@ -25,13 +25,13 @@ struct HMMSeqGranulation {
     int overlap;
     int chunksize;
     int exOverlap;
-    QList<GB2::LRegion> regions;
+    QList<U2::LRegion> regions;
 };
 
-typedef QList<float> (*hmmScoringFunction)( unsigned char * dsq, int seqlen, plan7_s* hmm, HMMSeqGranulation * gr, GB2::TaskStateInfo& ti );
+typedef QList<float> (*hmmScoringFunction)( unsigned char * dsq, int seqlen, plan7_s* hmm, HMMSeqGranulation * gr, U2::TaskStateInfo& ti );
 
 void main_loop_opt( struct plan7_s * hmm, const char * seq_, int seqlen, struct threshold_s *thresh, int do_forward,
                    int do_null2, int do_xnu, struct histogram_s * histogram, struct tophit_s * ghit, struct tophit_s * dhit, 
-                   int * ret_nseq, GB2::TaskStateInfo & ti, hmmScoringFunction scoring_f );
+                   int * ret_nseq, U2::TaskStateInfo & ti, hmmScoringFunction scoring_f );
 
 #endif
