@@ -18,28 +18,27 @@
 
 #include <hmmer2/funcs.h>
 
-#include <datatype/DNASequence.h>
-#include <util_text/TextUtils.h>
+#include <U2Core/DNASequence.h>
+#include <U2Core/TextUtils.h>
 
-#include <core_api/AppContext.h>
-#include <core_api/IOAdapter.h>
-#include <core_api/DocumentModel.h>
-#include <core_api/DocumentFormats.h>
-#include <core_api/GObject.h>
+#include <U2Core/AppContext.h>
+#include <U2Core/IOAdapter.h>
+#include <U2Core/DocumentModel.h>
+#include <U2Core/BaseDocumentFormats.h>
+#include <U2Core/GObject.h>
 
-#include <util_tasks/SaveDocumentTask.h>
-#include <util_tasks/LoadDocumentTask.h>
+#include <U2Core/SaveDocumentTask.h>
+#include <U2Core/LoadDocumentTask.h>
 
-#include <gobjects/GObjectTypes.h>
-#include <gobjects/AnnotationTableObject.h>
-#include <gobjects/DNASequenceObject.h>
-#include <gobjects/TextObject.h>
-#include <test_framework/xmltest/DocumentModelTests.h>
-#include <test_framework/GTestFrameworkComponents.h>
+#include <U2Core/GObjectTypes.h>
+#include <U2Core/AnnotationTableObject.h>
+#include <U2Core/DNASequenceObject.h>
+#include <U2Core/TextObject.h>
+#include <U2Test/GTestFrameworkComponents.h>
 
 #include <memory>
 
-namespace GB2 {
+namespace U2 {
 
 
 #define HMM_FILE_ATTR "hmmfile"
@@ -76,7 +75,7 @@ class LoadDocumentTask;
 
 //**********uHMMER Search********************
 
-/* TRANSLATOR GB2::GTest */    
+/* TRANSLATOR U2::GTest */    
 
 void GTest_uHMMERSearch::init(XMLTestFormat *tf, const QDomElement& el) {
     Q_UNUSED(tf);
