@@ -8,15 +8,14 @@
 *     for details.
 *****************************************************************/
 
-
 #include <QtCore/QByteArray>
 
-#include <core_api/L10n.h>
-#include <util_text/TextUtils.h>
+#include <U2Core/L10n.h>
+#include <U2Core/TextUtils.h>
 
 #include "uHMMFormatReader.h"
 
-using namespace GB2;
+using namespace U2;
 
 const int BUF_SZ        = 1024;
 const int BAD_READ      = -1;
@@ -301,7 +300,7 @@ static void readLine( IOAdapter* io, QByteArray& to, QStringList* tokens = NULL
     skipBlankLines( io );
 }
 
-namespace GB2 {
+namespace U2 {
 
 const QString UHMMFormatReader::HMM_FORMAT_READER_ERROR_PREFIX  = UHMMFormatReader::tr( "HMM reader error occurred: " );
 const QString UHMMFormatReader::READ_FAILED                     = UHMMFormatReader::tr( "reading file failed" );
@@ -862,4 +861,4 @@ P7_HMM * UHMMFormatReader::readHMMER2ASCII() {
     return hmm;
 }
 
-} // GB2
+} // U2
