@@ -8,12 +8,11 @@
 *     for details.
 *****************************************************************/
 
-
-#include <gobjects/GObjectTypes.h>
+#include <U2Core/GObjectTypes.h>
 
 #include "uHMMObject.h"
 
-namespace GB2 {
+namespace U2 {
 
 const QString UHMMObject::OT_ID    = "OT_HMM";
 const QString UHMMObject::OT_NAME  = "Hidden Markov model";
@@ -51,4 +50,4 @@ GObject* UHMMObject::clone() const {
     return cln;
 }
 
-} // GB2
+} // U2
