@@ -8,18 +8,17 @@
 *     for details.
 *****************************************************************/
 
-
 #ifndef _GB2_HMMER3_UHMM_OBJECT_H_
 #define _GB2_HMMER3_UHMM_OBJECT_H_
 
 #include <QtCore/QString>
 
-#include <core_api/core_api.h>
-#include <core_api/GObject.h>
+#include <U2Core/global.h>
+#include <U2Core/GObject.h>
 
 #include <hmmer3/hmmer.h>
 
-namespace GB2 {
+namespace U2 {
 
 class UHMMObject : public GObject {
     Q_OBJECT
@@ -44,6 +43,6 @@ private:
     
 }; // UHMMObject
 
-} // GB2
+} // U2
 
 #endif // _GB2_HMMER3_UHMM_OBJECT_H_
