@@ -52,7 +52,7 @@ esl_exception(int code, char *file, int line, char *format, ...)
 }
 
 void
-esl_fatal(char *format, ...)
+esl_fatal(const char *format, ...)
 {
     va_list argp;
     char buf[EXCEPTION_MSG_SZ];
@@ -1491,10 +1491,10 @@ esl_composition_SW50(double *f)
 
 /*****************************************************************
 * Easel - a library of C functions for biological sequence analysis
-* Version h3.0b3; November 2009
-* Copyright (C) 2009 Howard Hughes Medical Institute.
+* Version h3.0; March 2010
+* Copyright (C) 2010 Howard Hughes Medical Institute.
 * Other copyrights also apply. See the COPYRIGHT file for a full list.
 * 
 * Easel is distributed under the Janelia Farm Software License, a BSD
 * license. See the LICENSE file for more details.
-*****************************************************************/  
+*****************************************************************/
