@@ -24,7 +24,6 @@
 #include <stdlib.h>
 #include <float.h>
 #include <stdarg.h>		/* for va_list */
-
 #include <hmmer3/hmmer3_funcs.h>
 
 // ! CODE ADDED: compatibility with windows !
@@ -338,7 +337,7 @@ typedef uint8_t ESL_DSQ;
 extern void esl_exception(int code, char *file, int line, char *format, ...);
 //extern void esl_exception_SetHandler(esl_exception_handler_f);
 //extern void esl_exception_ResetDefaultHandler(void);
-extern void esl_fatal(char *format, ...);
+extern void esl_fatal(const char *format, ...);
 //extern void esl_nonfatal_handler(int code, char *file, int line, char *format, va_list argp);
 
 /* 2. Memory allocation/deallocation conventions. */
