@@ -979,9 +979,9 @@ esl_abc_dsqrlen(const ESL_ALPHABET *abc, const ESL_DSQ *dsq)
 * Incept:    SRE, Sun Mar 30 13:14:05 2008 [Casa de Gatos]
 *
 * Purpose:   Dealigns <s> in place by removing characters aligned to
-*            gaps in the reference digital aligned sequence
-*            <ref_ax>. Gaps in <ref_ax> are defined by its digital
-*            alphabet <abc>. 
+*            gaps (or missing data symbols) in the reference digital
+*            aligned sequence <ref_ax>. Gaps and missing data symbols
+*            in <ref_ax> are defined by its digital alphabet <abc>.
 *            
 *            <s> is typically going to be some kind of textual
 *            annotation string (secondary structure, consensus, or
@@ -1009,7 +1009,7 @@ esl_abc_CDealign(const ESL_ALPHABET *abc, char *s, const ESL_DSQ *ref_ax, int64_
     if (s == NULL) return eslOK;
 
     for (n=0, apos=1; ref_ax[apos] != eslDSQ_SENTINEL; apos++)
-        if (! esl_abc_XIsGap(abc, ref_ax[apos]))
+        if (! esl_abc_XIsGap(abc, ref_ax[apos]) && ! esl_abc_XIsMissing(abc, ref_ax[apos]) )
             s[n++] = s[apos-1];	/* apos-1 because we assume s was 0..alen-1, whereas ref_ax was 1..alen */
     s[n] = '\0';
 
@@ -1022,9 +1022,9 @@ esl_abc_CDealign(const ESL_ALPHABET *abc, char *s, const ESL_DSQ *ref_ax, int64_
 * Incept:    SRE, Sun Mar 30 13:19:16 2008 [Casa de Gatos]
 *
 * Purpose:   Dealigns <x> in place by removing characters aligned to
-*            gaps in the reference digital aligned sequence
-*            <ref_ax>. Gaps in <ref_ax> are defined by its digital
-*            alphabet <abc>. 
+*            gaps (or missing data) in the reference digital aligned
+*            sequence <ref_ax>. Gaps and missing data symbols in
+*            <ref_ax> are defined by its digital alphabet <abc>.
 *
 * Returns:   Returns <eslOK> on success; optionally returns the number
 *            of characters in the dealigned <x> in <*opt_rlen>.
@@ -1041,7 +1041,7 @@ esl_abc_XDealign(const ESL_ALPHABET *abc, ESL_DSQ *x, const ESL_DSQ *ref_ax, int
 
     x[0] = eslDSQ_SENTINEL;
     for (n=1, apos=1; ref_ax[apos] != eslDSQ_SENTINEL; apos++)
-        if (! esl_abc_XIsGap(abc, ref_ax[apos]))
+        if (! esl_abc_XIsGap(abc, ref_ax[apos]) && ! esl_abc_XIsMissing(abc, ref_ax[apos]) )
             x[n++] = x[apos];
     x[n] = eslDSQ_SENTINEL;
 
@@ -1582,13 +1582,12 @@ esl_abc_ValidateSeq(const ESL_ALPHABET *a, const char *seq, int64_t L, char *err
 }
 /*---------------- end, other API functions ---------------------*/
 
-/*****************************************************************  
+/*****************************************************************
 * Easel - a library of C functions for biological sequence analysis
-* Version h3.0b2; June 2009
-* Copyright (C) 2009 Howard Hughes Medical Institute.
+* Version h3.0; March 2010
+* Copyright (C) 2010 Howard Hughes Medical Institute.
 * Other copyrights also apply. See the COPYRIGHT file for a full list.
 * 
 * Easel is distributed under the Janelia Farm Software License, a BSD
 * license. See the LICENSE file for more details.
 *****************************************************************/
-
