@@ -72,96 +72,92 @@ ERROR:
 }
 
 /* Function:  esl_mixdchlet_PerfectBipartiteMatchExists()
- * Synopsis:  Given a 2D table representing presence of edges between vertices represented by
- * 			the rows and columns, test whether a perfect matching exists.
- * 			Note 1: this doesn't find a perfect matching, just checks if one exists.
- * 			Note 2: written as a private function for use by esl_mixdchlet_Compare
- * Incept:    TW, Fri Nov  6 14:23:23 EST 2009 [janelia]
- *
- * Args:      A      - 2-dimensional square table representing presence of edges between vertices
- *            N      - size of that table
-
- * Returns:   <eslOK> if a perfect matching exists; <eslFAIL> otherwise.
- */
+* Synopsis:  Given a 2D table representing presence of edges between vertices represented by
+* 			the rows and columns, test whether a perfect matching exists.
+* 			Note 1: this doesn't find a perfect matching, just checks if one exists.
+* 			Note 2: written as a private function for use by esl_mixdchlet_Compare
+* Incept:    TW, Fri Nov  6 14:23:23 EST 2009 [janelia]
+*
+* Args:      A      - 2-dimensional square table representing presence of edges between vertices
+*            N      - size of that table
+*
+* Returns:   <eslOK> if a perfect matching exists; <eslFAIL> otherwise.
+*/
 int
-esl_mixdchlet_PerfectBipartiteMatchExists (int** A, int N ) {
-	/*
-	Basic idea:
-		-Scan through the rows, and create a matching edge any time a row has only
-		one matching column (i.e. a single column with eslOK value)
-		    * This is conservative: if the row isn't matched with this column, no perfect matching is possible.
-		-Repeat, this time scanning columns.
-	    -Repeat  rows then columns - until no rows or columns are found with a single eslOK value.
+esl_mixdchlet_PerfectBipartiteMatchExists(int **A, int N ) 
+{
+    /*
+    Basic idea:
+    -Scan through the rows, and create a matching edge any time a row has only
+    one matching column (i.e. a single column with eslOK value)
+    * This is conservative: if the row isn't matched with this column, no perfect matching is possible.
+    -Repeat, this time scanning columns.
+    -Repeat  rows then columns - until no rows or columns are found with a single eslOK value.
 
-		-If a row or column is found with no possible matches, then no complete matching is possible.
-		-If a point is reached where all rows and all columns have more than one match, I'm pretty sure a
-		 perfect matching is guaranteed.
-			- This is unproven; the intuition is that for any imperfect matching an augmenting path
-			  should (I think) exist: it will contain an edge from one unmatched element to a matched
-			  element, followed by the existing edge from that element to it's mate, followed by a 2nd
-			  edge from that mate to another, and so on.
+    -If a row or column is found with no possible matches, then no complete matching is possible.
+    -If a point is reached where all rows and all columns have more than one match, I'm pretty sure a
+    perfect matching is guaranteed.
+    - This is unproven; the intuition is that for any imperfect matching an augmenting path
+    should (I think) exist: it will contain an edge from one unmatched element to a matched
+    element, followed by the existing edge from that element to it's mate, followed by a 2nd
+    edge from that mate to another, and so on.
 
-		 It's a O(n^3) algorithm, though it'll typically run fast in practice
-	   */
-	  
-	  // ! CODE CHANGED: current c++ standard doesn't support arrays with not constant size !
-	  int * matched_row = (int*)malloc( sizeof( int ) * N );
-	  int * matched_col = (int*)malloc( sizeof( int ) * N );
+    It's a O(n^3) algorithm, though it'll typically run fast in practice
+    */
+    int * matched_row = new int[N];
+    int * matched_col = new int[N];
+    esl_vec_ISet(matched_row, N, 0);
+    esl_vec_ISet(matched_col, N, 0);
 
-	  esl_vec_ISet(matched_row, N, 0);
-	  esl_vec_ISet(matched_col, N, 0);
+    int i,j;
+    int unassigned = N;
+    int do_row = 1; // otherwise, do_column
+    while (unassigned > 0) {
+        int changed = 0;
 
-	  int i,j;
-	  int unassigned = N;
-	  int do_row = 1; // otherwise, do_column
-	  while (unassigned > 0) {
-		  int changed = 0;
+        for (i=0; i<N; i++) {
+            int match_cnt = 0;
+            int match = -1;
 
-		  for (i=0; i<N; i++) {
-			  int match_cnt = 0;
-			  int match = -1;
+            if ( 1 == (do_row == 1 ? matched_row[i] : matched_col[i]) ) continue;
 
-			  if ( 1 == (do_row == 1 ? matched_row[i] : matched_col[i]) ) continue;
+            for (j=0; j<N; j++) {
+                if ( eslOK == (do_row == 1 ? A[i][j] : A[j][i] ) ) {
+                    match_cnt++;
+                    match = j;
+                }
+            }
 
-			  for (j=0; j<N; j++) {
-				  if ( eslOK == (do_row == 1 ? A[i][j] : A[j][i] ) ) {
-					  match_cnt++;
-					  match = j;
-				  }
-			  }
+            if (match_cnt == 0) {
+                delete[] matched_row; delete[] matched_col;
+                return eslFAIL;  // mixtures can't possibly match
+            }
+            if (match_cnt == 1) { // found a pair s.t. only this col can match this row within tol.
+                changed++;
+                if (do_row == 1  ) {
+                    matched_row[i] = matched_col[match] = 1;
+                    for (j=0; j<N; j++)
+                        A[j][match] = eslFAIL; // don't allow the matched col to match other rows, too.
+                } else {
+                    matched_col[i] = matched_row[match] = 1;
+                    for (j=0; j<N; j++)
+                        A[match][j] = eslFAIL; // don't allow the matched rwo to match other cols, too.
+                }
+            }
+            //if (match_cnt > 1), leave it for a later pass
+        }
+        unassigned -= changed;
 
-			  if (match_cnt == 0) return eslFAIL;  // mixtures can't possibly match
-			  if (match_cnt == 1) { // found a pair s.t. only this col can match this row within tol.
-				  changed++;
-				  if (do_row == 1  ) {
-					  matched_row[i] = matched_col[match] = 1;
-					  for (j=0; j<N; j++)
-						  A[j][match] = eslFAIL; // don't allow the matched col to match other rows, too.
-				  } else {
-					  matched_col[i] = matched_row[match] = 1;
-					  for (j=0; j<N; j++)
-						  A[match][j] = eslFAIL; // don't allow the matched rwo to match other cols, too.
-				  }
-			  }
-			  //if (match_cnt > 1), leave it for a later pass
-		  }
-		  unassigned -= changed;
+        if (changed == 0) { // All had multiple hits, so (I think) we are guaranteed of being able to pick some mapping that will be legal
+            delete[] matched_row; delete[] matched_col;
+            return eslOK;
+        }
+        do_row = 1 - do_row; // flip value
 
-
-		  if (changed == 0) { // All had multiple hits, so (I think) we are guaranteed of being able to pick some mapping that will be legal
-			  // ! CODE ADDED !
-			  free( matched_row );
-			  free( matched_col );
-			  return eslOK;
-		  }
-		  do_row = 1 - do_row; // flip value
-
-	  }
-	  //got here, all mapping must've been done
-	  // ! CODE ADDED !
-	  free( matched_row );
-	  free( matched_col );
-	  return eslOK;
+    }
+    //got here, all mapping must've been done
+    delete[] matched_row; delete[] matched_col;
+    return eslOK;
 }
 
 /* Function:  esl_mixdchlet_Compare()
@@ -315,7 +311,9 @@ esl_mixdchlet_MPParameters(double *c, int K, ESL_MIXDCHLET *pri, double *mix, do
     double totc;
     double tota;
 
-    if (K != pri->K) ESL_EXCEPTION(eslEINCOMPAT, "cvec's K != mixture Dirichlet's K");
+    if (K != pri->K) {
+        ESL_EXCEPTION(eslEINCOMPAT, "cvec's K != mixture Dirichlet's K");
+    }
 
     /* Calculate mix[], the posterior probability
     * P(q | c) of mixture component q given the count vector c.
@@ -401,7 +399,7 @@ esl_dirichlet_LogProbData(double *c, double *alpha, int K, double *ret_answer)
 *
 * Purpose:   Given an observed count vector $c[0..K-1]$, 
 *            and a mixture Dirichlet density parameterized by
- *			  $\alpha_1[0..K-1]$ ... $\alpha_N[0..K-1]$,
+*			  $\alpha_1[0..K-1]$ ... $\alpha_N[0..K-1]$,
 *            calculate $\log \sum_i pq_i * P(c \mid \alpha_i)$.
 *            
 *
@@ -421,7 +419,7 @@ esl_dirichlet_LogProbData_Mixture(double *c, ESL_MIXDCHLET *d, double *ret_answe
     int     q;             /* counter over mixture components */
     int     status;
 
-    ESL_ALLOC_WITH_TYPE(mixq, double*, sizeof(double)*d->N);
+    ESL_ALLOC_WITH_TYPE(mixq,double*, sizeof(double)*d->N);
 
     for (q = 0; q < d->N; q++) {
         esl_dirichlet_LogProbData(c, d->alpha[q], d->K, &val);
@@ -439,38 +437,39 @@ ERROR:
     return status;
 }
 
+/* esl_dirichlet_LogProbDataSet_Mixture()
+* Incept:    TW, Wed Nov  4 14:10:22 EST 2009 [janelia]
+*
+* Purpose:   Given an observed set of count vectors $c[0..N-1][0..K-1]$, 
+*            and a mixture Dirichlet density parameterized by
+*			  $\alpha_1[0..K-1]$ ... $\alpha_N[0..K-1]$,
+*            calculate $ \sum_n \log \sum_i pq_i * P(c[n] \mid \alpha_i)$.
+*            This is a convenience function, which simply wraps
+*            esl_dirichlet_LogProbData_Mixture
+*            
+*
+* Args:      ntrials      - number of count vectors (aka N)
+*            counts      - count vector set, [0..N-1][0..K-1]
+*            md      - Dirichlet parameters
+*            ret_answer - RETURN: log P(c | \alpha)
+*
+* Returns:   <eslOK> on success, and puts result $\log P(c \mid \alpha)$
+*            in <ret_answer>.
+*/
+static int 
+esl_dirichlet_LogProbDataSet_Mixture(int ntrials, double** counts, ESL_MIXDCHLET* md, double *ret_answer) 
+{
+    double val;
+    int i;
 
-/* Function:  esl_dirichlet_LogProbDataSet_Mixture()
- * Incept:    TW, Wed Nov  4 14:10:22 EST 2009 [janelia]
- *
- * Purpose:   Given an observed set of count vectors $c[0..N-1][0..K-1]$, 
- *            and a mixture Dirichlet density parameterized by
- *			  $\alpha_1[0..K-1]$ ... $\alpha_N[0..K-1]$,
- *            calculate $ \sum_n \log \sum_i pq_i * P(c[n] \mid \alpha_i)$.
- *            This is a convenience function, which simply wraps
- *            esl_dirichlet_LogProbData_Mixture
- *            
- *
- * Args:      ntrials      - number of count vectors (aka N)
- *            counts      - count vector set, [0..N-1][0..K-1]
- *            md      - Dirichlet parameters
- *            ret_answer - RETURN: log P(c | \alpha)
- *
- * Returns:   <eslOK> on success, and puts result $\log P(c \mid \alpha)$
- *            in <ret_answer>.
- */
-static int esl_dirichlet_LogProbDataSet_Mixture (int ntrials, double** counts, ESL_MIXDCHLET* md, double *ret_answer) {
-        *ret_answer = 0;
-        double val;
-        int i;
-        for (i = 0; i < ntrials; i++) {
-          esl_dirichlet_LogProbData_Mixture(counts[i], md, &val);
-          *ret_answer += val;
-        }
-        return eslOK;
+    *ret_answer = 0;
+    for (i = 0; i < ntrials; i++) {
+        esl_dirichlet_LogProbData_Mixture(counts[i], md, &val);
+        *ret_answer += val;
+    }
+    return eslOK;
 }
 
-
 /* Function:  esl_dirichlet_LogProbProbs()
 * Incept:    SRE, Sat Apr  9 14:35:17 2005 [St. Louis]
 *
@@ -1016,8 +1015,8 @@ esl_dirichlet_SampleBeta(ESL_RANDOMNESS *r, double theta1, double theta2, double
 
 /*****************************************************************
 * Easel - a library of C functions for biological sequence analysis
- * Version h3.0b3; November 2009
-* Copyright (C) 2009 Howard Hughes Medical Institute.
+* Version h3.0; March 2010
+* Copyright (C) 2010 Howard Hughes Medical Institute.
 * Other copyrights also apply. See the COPYRIGHT file for a full list.
 * 
 * Easel is distributed under the Janelia Farm Software License, a BSD
