@@ -27,6 +27,7 @@
 #include <string.h>
 #include <math.h>
 #include <float.h>
+#include <limits.h>
 
 #include "easel.h"
 #include "esl_stats.h"
@@ -177,105 +178,155 @@ esl_histogram_Destroy(ESL_HISTOGRAM *h)
   return;
 }
 
+/* Function:  esl_histogram_Score2Bin()
+* Synopsis:  Given a real-valued <x>; calculate integer bin <b>
+* Incept:    SRE, Sun Dec 13 20:24:42 2009 [Yokohama]
+*
+* Purpose:   For a real-valued <x>, figure out what bin it would
+*            go into in the histogram <h>; return this value in
+*            <*ret_b>.
+*
+* Returns:   <eslOK> on success.
+*
+* Throws:    <eslERANGE> if bin <b> would exceed the range of
+*            an integer; for instance, if <x> isn't finite.
+*
+* Xref:      J5/122. Replaces earlier macro implementation;
+*            we needed to range check <x> better.
+*/
+int
+esl_histogram_Score2Bin(ESL_HISTOGRAM *h, double x, int *ret_b)
+{
+    int status;
+
+    if (! isfin(x)) ESL_XEXCEPTION(eslERANGE, "value added to histogram is not finite");
+
+    x = ceil( ((x - h->bmin) / h->w) - 1.); 
+
+    /* x is now the bin number as a double, which we will convert to
+    * int. Because x is a double (64-bit), we know all ints are exactly
+    * represented.  Check for under/overflow before conversion.
+    */
+    if (x < (double) INT_MIN || x > (double) INT_MAX) 
+        ESL_XEXCEPTION(eslERANGE, "value %f isn't going to fit in histogram", x);
+
+    *ret_b = (int) x;
+    return eslOK;
+
+ERROR:
+    *ret_b = 0;
+    return status;
+}
+
 /* Function:  esl_histogram_Add()
- * Synopsis:  Add a sample to the histogram.
- * Incept:    SRE, Sat Jul  2 19:41:45 2005 [St. Louis]
- *
- * Purpose:   Adds score <x> to a histogram <h>.
- *           
- *            The histogram will be automatically reallocated as
- *            needed if the score is smaller or larger than the
- *            current allocated bounds.  
- *
- * Returns:   <eslOK> on success.
- *
- * Throws:    <eslEMEM> on reallocation failure.
- *            Throws <eslEINVAL> for cases where something has been done
- *            to the histogram that requires it to be 'finished', and
- *            adding more data is prohibited; for example, 
- *            if tail or censoring information has already been set.
- *            On either failure, initial state of <h> is preserved.
- */
+* Synopsis:  Add a sample to the histogram.
+* Incept:    SRE, Sat Jul  2 19:41:45 2005 [St. Louis]
+*
+* Purpose:   Adds score <x> to a histogram <h>.
+*           
+*            The histogram will be automatically reallocated as
+*            needed if the score is smaller or larger than the
+*            current allocated bounds.  
+*
+* Returns:   <eslOK> on success.
+*
+* Throws:    <eslEMEM> on reallocation failure.
+*
+*            <eslERANGE> if <x> is beyond the reasonable range for
+*            the histogram to store -- either because it isn't finite,
+*            or because the histogram would need to allocate a number
+*            of bins that exceeds <INT_MAX>.
+*
+*            Throws <eslEINVAL> for cases where something has been done
+*            to the histogram that requires it to be 'finished', and
+*            adding more data is prohibited; for example, 
+*            if tail or censoring information has already been set.
+*            On either failure, initial state of <h> is preserved.
+*/
 int
 esl_histogram_Add(ESL_HISTOGRAM *h, double x)
 {
-  int   status;
-  void *tmp;
-  int b;			/* what bin we're in                       */
-  int nnew;			/* # of new bins created by a reallocation */
-  int bi;
+    int   status;
+    void *tmp;
+    int b;			/* what bin we're in                       */
+    int nnew;			/* # of new bins created by a reallocation */
+    int bi;
 
-  /* Censoring info must only be set on a finished histogram;
-   * don't allow caller to add data after configuration has been declared
-   */
-  if (h->is_done)
-    ESL_EXCEPTION(eslEINVAL, "can't add more data to this histogram");
+    /* Censoring info must only be set on a finished histogram;
+    * don't allow caller to add data after configuration has been declared
+    */
+    if (h->is_done)
+        ESL_EXCEPTION(eslEINVAL, "can't add more data to this histogram");
 
-  /* If we're a full histogram, check whether we need to reallocate
-   * the full data vector.
-   */
-  if (h->is_full && h->nalloc == h->n) 
+    /* If we're a full histogram, check whether we need to reallocate
+    * the full data vector.
+    */
+    if (h->is_full && h->nalloc == h->n) 
     {
-      ESL_RALLOC_WITH_TYPE(h->x, double*, tmp, sizeof(double) * h->nalloc * 2);
-      h->nalloc *= 2;
+        ESL_RALLOC_WITH_TYPE(h->x,double*, tmp, sizeof(double) * h->nalloc * 2);
+        h->nalloc *= 2;
     }
 
-  /* Which bin will we want to put x into?
-   */
-  b = esl_histogram_Score2Bin(h,x);
+    /* Which bin will we want to put x into?
+    */
+    if ((status = esl_histogram_Score2Bin(h,x, &b)) != eslOK) return status;
 
-  /* Make sure we have that bin. Realloc as needed.
-   * If that reallocation succeeds, we can no longer fail;
-   * so we can change the state of h.
-   */
-  if (b < 0)    /* Reallocate below? */
+    /* Make sure we have that bin. Realloc as needed.
+    * If that reallocation succeeds, we can no longer fail;
+    * so we can change the state of h.
+    */
+    if (b < 0)    /* Reallocate below? */
     {				
-      nnew = -b*2;	/* overallocate by 2x */
-      ESL_RALLOC_WITH_TYPE(h->obs, uint64_t*, tmp, sizeof(uint64_t) * (nnew+ h->nb));
-      
-      memmove(h->obs+nnew, h->obs, sizeof(uint64_t) * h->nb);
-      h->nb    += nnew;
-      b        += nnew;
-      h->bmin  -= nnew*h->w;
-      h->imin  += nnew;
-      h->cmin  += nnew;
-      if (h->imax > -1) h->imax += nnew;
-      for (bi = 0; bi < nnew; bi++) h->obs[bi] = 0;
+        nnew = -b*2;	/* overallocate by 2x */
+        if (nnew > INT_MAX - h->nb)
+            ESL_EXCEPTION(eslERANGE, "value %f requires unreasonable histogram bin number", x);
+        ESL_RALLOC_WITH_TYPE(h->obs,uint64_t*, tmp, sizeof(uint64_t) * (nnew+ h->nb));
+
+        memmove(h->obs+nnew, h->obs, sizeof(uint64_t) * h->nb);
+        h->nb    += nnew;
+        b        += nnew;
+        h->bmin  -= nnew*h->w;
+        h->imin  += nnew;
+        h->cmin  += nnew;
+        if (h->imax > -1) h->imax += nnew;
+        for (bi = 0; bi < nnew; bi++) h->obs[bi] = 0;
     }
-  else if (b >= h->nb)  /* Reallocate above? */
+    else if (b >= h->nb)  /* Reallocate above? */
     {
-      nnew = (b-h->nb+1) * 2; /* 2x overalloc */
-      ESL_RALLOC_WITH_TYPE(h->obs, uint64_t*, tmp, sizeof(uint64_t) * (nnew+ h->nb));
-      for (bi = h->nb; bi < h->nb+nnew; bi++) h->obs[bi] = 0;
-      if (h->imin == h->nb) { /* boundary condition of no data yet*/
-	h->imin+=nnew; 
-	h->cmin+=nnew;
-      }
-      h->bmax  += nnew*h->w;
-      h->nb    += nnew;
+        nnew = (b-h->nb+1) * 2; /* 2x overalloc */
+        if (nnew > INT_MAX - h->nb) 
+            ESL_EXCEPTION(eslERANGE, "value %f requires unreasonable histogram bin number", x);
+        ESL_RALLOC_WITH_TYPE(h->obs,uint64_t*, tmp, sizeof(uint64_t) * (nnew+ h->nb));
+        for (bi = h->nb; bi < h->nb+nnew; bi++) h->obs[bi] = 0;
+        if (h->imin == h->nb) { /* boundary condition of no data yet*/
+            h->imin+=nnew; 
+            h->cmin+=nnew;
+        }
+        h->bmax  += nnew*h->w;
+        h->nb    += nnew;
     }
 
-  /* If we're a full histogram, then we keep the raw x value,
-   * reallocating as needed.
-   */
-  if (h->is_full)  h->x[h->n] = x;
-  h->is_sorted = FALSE;		/* not any more! */
+    /* If we're a full histogram, then we keep the raw x value,
+    * reallocating as needed.
+    */
+    if (h->is_full)  h->x[h->n] = x;
+    h->is_sorted = FALSE;		/* not any more! */
 
-  /* Bump the bin counter, and all the data sample counters.
-   */
-  h->obs[b]++;
-  h->n++;
-  h->Nc++;
-  h->No++;
+    /* Bump the bin counter, and all the data sample counters.
+    */
+    h->obs[b]++;
+    h->n++;
+    h->Nc++;
+    h->No++;
 
-  if (b > h->imax) h->imax = b;
-  if (b < h->imin) { h->imin = b; h->cmin = b; }
-  if (x > h->xmax) h->xmax = x;
-  if (x < h->xmin) h->xmin = x;
-  return eslOK;
+    if (b > h->imax) h->imax = b;
+    if (b < h->imin) { h->imin = b; h->cmin = b; }
+    if (x > h->xmax) h->xmax = x;
+    if (x < h->xmin) h->xmin = x;
+    return eslOK;
 
- ERROR:
-  return status;
+ERROR:
+    return status;
 }
   
 
@@ -361,60 +412,64 @@ esl_histogram_DeclareRounding(ESL_HISTOGRAM *h)
 
 
 /* Function:  esl_histogram_SetTail()
- * Synopsis:  Declare only tail $>$ some threshold is considered "observed".
- * Incept:    SRE, Tue Aug 23 09:01:10 2005 [St. Louis]
- *
- * Purpose:   Suggest a threshold <phi> to split a histogram <h>
- *            into "unobserved" data (values $\leq \phi$) and "observed" 
- *            data (values $> \phi$). 
- *
- *            The suggested <phi> is revised downwards to a $\phi$ at the next 
- *            bin lower bound, because operations on binned data in <h>
- *            need to know unambiguously whether all the data in a given bin
- *            will be counted as observed or unobserved. 
- *
- *            The probability mass that is in the resulting right tail
- *            is optionally returned in <ret_newmass>. You need to know
- *            this number if you're fitting a distribution solely to the
- *            tail (an exponential tail, for example).
- *
- *            Any data point $x_i \leq \phi$ is then considered to be
- *            in a censored (unobserved) region for purposes of parameter
- *            fitting, calculating expected binned counts,
- *            and binned goodness-of-fit tests. 
- *            
- *            No more data can be added to the histogram after
- *            censoring information has been set.
- *            
- *            This function defines a "virtual" left-censoring: the
- *            histogram actually contains complete data, but appropriate
- *            flags are set to demarcate the "observed" data in the right
- *            tail.
- *            
- * Returns:   <eslOK> on success.
- */
+* Synopsis:  Declare only tail $>$ some threshold is considered "observed".
+* Incept:    SRE, Tue Aug 23 09:01:10 2005 [St. Louis]
+*
+* Purpose:   Suggest a threshold <phi> to split a histogram <h>
+*            into "unobserved" data (values $\leq \phi$) and "observed" 
+*            data (values $> \phi$). 
+*
+*            The suggested <phi> is revised downwards to a $\phi$ at the next 
+*            bin lower bound, because operations on binned data in <h>
+*            need to know unambiguously whether all the data in a given bin
+*            will be counted as observed or unobserved. 
+*
+*            The probability mass that is in the resulting right tail
+*            is optionally returned in <ret_newmass>. You need to know
+*            this number if you're fitting a distribution solely to the
+*            tail (an exponential tail, for example).
+*
+*            Any data point $x_i \leq \phi$ is then considered to be
+*            in a censored (unobserved) region for purposes of parameter
+*            fitting, calculating expected binned counts,
+*            and binned goodness-of-fit tests. 
+*            
+*            No more data can be added to the histogram after
+*            censoring information has been set.
+*            
+*            This function defines a "virtual" left-censoring: the
+*            histogram actually contains complete data, but appropriate
+*            flags are set to demarcate the "observed" data in the right
+*            tail.
+*            
+* Returns:   <eslOK> on success.
+*
+* Throws:    <eslERANGE> if <phi> is an unreasonable value that
+*            can't be converted to an integer bin value.
+*/
 int
 esl_histogram_SetTail(ESL_HISTOGRAM *h, double phi, double *ret_newmass)
 {
-  int b;
+    int b;
+    int status;
 
-  /* Usually, put true phi at the next bin lower bound, but
-   * watch for a special case where phi is already exactly equal to a 
-   * bin upper bound.
-   */
-  h->cmin = esl_histogram_Score2Bin(h,phi);
-  if (phi == esl_histogram_Bin2UBound(h,h->cmin)) h->phi = phi;
-  else   h->phi  = esl_histogram_Bin2LBound(h, h->cmin);
+    /* Usually, put true phi at the next bin lower bound, but
+    * watch for a special case where phi is already exactly equal to a 
+    * bin upper bound.
+    */
+    if ((status = esl_histogram_Score2Bin(h,phi, &(h->cmin))) != eslOK) return status;
+    if (phi == esl_histogram_Bin2UBound(h,h->cmin)) h->phi = phi;
+    else   h->phi  = esl_histogram_Bin2LBound(h, h->cmin);
 
-  h->z    = 0;
-  for (b = h->imin; b < h->cmin; b++)
-    h->z += h->obs[b];
-  h->Nc         = h->n;		/* (redundant) */
-  h->No         = h->n - h->z;
-  h->dataset_is = ESL_HISTOGRAM::VIRTUAL_CENSORED;
-  h->is_done    = TRUE;
-  if (ret_newmass != NULL) *ret_newmass = (double) h->No / (double) h->Nc;
-  return eslOK;
+    h->z    = 0;
+    for (b = h->imin; b < h->cmin; b++)
+        h->z += h->obs[b];
+    h->Nc         = h->n;		/* (redundant) */
+    h->No         = h->n - h->z;
+    h->dataset_is = ESL_HISTOGRAM::VIRTUAL_CENSORED;
+    h->is_done    = TRUE;
+    if (ret_newmass != NULL) *ret_newmass = (double) h->No / (double) h->Nc;
+    return eslOK;
 }
 
 /* Function:  esl_histogram_SetTailByMass()
@@ -746,67 +801,70 @@ esl_histogram_SetExpect(ESL_HISTOGRAM *h,
 }
 
 /* Function:  esl_histogram_SetExpectedTail()
- * Synopsis:  Set expected counts for right tail.
- * Incept:    SRE, Mon Jan 30 08:57:57 2006 [St. Louis]
- *
- * Purpose:   Given a histogram <h>, and a pointer to a generic function
- *            <(*cdf)()> that describes the expected cumulative
- *            distribution function for the right (high-scoring) tail
- *            starting at <base_val> (all expected <x> $>$ <base_val>) and
- *            containing a fraction <pmass> of the complete data
- *            distribution (<pmass> $\geq 0$ and $\leq 1$);
- *            set the expected binned counts for all complete bins
- *            $\geq$ <base_val>. 
- *            
- *            If <base_val> falls within a bin, that bin is considered
- *            to be incomplete, and the next higher bin is the starting
- *            point. 
- *           
- * Args:      h          - finished histogram
- *            base_val   - threshold for the tail: all expected x > base_val
- *            pmass      - fractional mass in the tail: 0 <= pmass <= 1
- *            cdf        - generic-interface CDF function describing the tail
- *            params     - void pointer to parameters for (*cdf)()
- *
- * Returns:   <eslOK> on success.
- *
- * Throws:    <eslEMEM> on memory allocation failure.
- */
+* Synopsis:  Set expected counts for right tail.
+* Incept:    SRE, Mon Jan 30 08:57:57 2006 [St. Louis]
+*
+* Purpose:   Given a histogram <h>, and a pointer to a generic function
+*            <(*cdf)()> that describes the expected cumulative
+*            distribution function for the right (high-scoring) tail
+*            starting at <base_val> (all expected <x> $>$ <base_val>) and
+*            containing a fraction <pmass> of the complete data
+*            distribution (<pmass> $\geq 0$ and $\leq 1$);
+*            set the expected binned counts for all complete bins
+*            $\geq$ <base_val>. 
+*            
+*            If <base_val> falls within a bin, that bin is considered
+*            to be incomplete, and the next higher bin is the starting
+*            point. 
+*           
+* Args:      h          - finished histogram
+*            base_val   - threshold for the tail: all expected x > base_val
+*            pmass      - fractional mass in the tail: 0 <= pmass <= 1
+*            cdf        - generic-interface CDF function describing the tail
+*            params     - void pointer to parameters for (*cdf)()
+*
+* Returns:   <eslOK> on success.
+*
+* Throws:    <eslEMEM> on memory allocation failure.
+*            <eslERANGE> if <base_val> isn't a reasonable value within
+*              the histogram (it converts to a bin value outside
+*              integer range).
+*/
 int
 esl_histogram_SetExpectedTail(ESL_HISTOGRAM *h, double base_val, double pmass,
-			      double (*cdf)(double x, void *params), 
-			      void *params)
+                              double (*cdf)(double x, void *params), 
+                              void *params)
 {
-  int status;
-  int b;
-  double ai, bi;
+    int status;
+    int b;
+    double ai, bi;
 
-  if (h->expect == NULL)  ESL_ALLOC_WITH_TYPE(h->expect, double*, sizeof(double) * h->nb);
+    if (h->expect == NULL)  ESL_ALLOC_WITH_TYPE(h->expect,double*, sizeof(double) * h->nb);
 
-  h->emin = 1 + esl_histogram_Score2Bin(h, base_val);
-  esl_vec_DSet(h->expect, h->emin, 0.);
+    if ((status = esl_histogram_Score2Bin(h, base_val, &(h->emin))) != eslOK) return status;
+    h->emin += 1;
+    esl_vec_DSet(h->expect, h->emin, 0.);
 
-  for (b = h->emin; b < h->nb; b++)
+    for (b = h->emin; b < h->nb; b++)
     {
-      ai = esl_histogram_Bin2LBound(h, b);
-      bi = esl_histogram_Bin2UBound(h, b);
-      h->expect[b] = pmass * (double) h->Nc * 
-	             ( (*cdf)(bi, params) - (*cdf)(ai, params) );
+        ai = esl_histogram_Bin2LBound(h, b);
+        bi = esl_histogram_Bin2UBound(h, b);
+        h->expect[b] = pmass * (double) h->Nc * 
+            ( (*cdf)(bi, params) - (*cdf)(ai, params) );
     }
-  
-  h->tailbase   = base_val;
-  h->tailmass   = pmass;
-  h->is_tailfit = TRUE;
-  h->is_done    = TRUE;
-  return eslOK;
 
- ERROR:
-  return status;
+    h->tailbase   = base_val;
+    h->tailmass   = pmass;
+    h->is_tailfit = TRUE;
+    h->is_done    = TRUE;
+    return eslOK;
+
+ERROR:
+    return status;
 }
 
 
 
-
 /*****************************************************************
  * 5. Output and display of binned data.
  *****************************************************************/ 
@@ -1625,5 +1683,12 @@ main(int argc, char **argv)
 /*::cexcerpt::histogram_example5::end::*/
 #endif /*eslHISTOGRAM_EXAMPLE5*/
 
-
-
+/*****************************************************************
+* Easel - a library of C functions for biological sequence analysis
+* Version h3.0; March 2010
+* Copyright (C) 2010 Howard Hughes Medical Institute.
+* Other copyrights also apply. See the COPYRIGHT file for a full list.
+* 
+* Easel is distributed under the Janelia Farm Software License, a BSD
+* license. See the LICENSE file for more details.
+*****************************************************************/
