@@ -219,72 +219,75 @@ esl_keyhash_Dump(FILE *fp, const ESL_KEYHASH *kh)
  *****************************************************************/ 
 
 /* Function: esl_key_Store()
- * Synopsis: Store a key and get a key index for it.
- * Incept:   SRE, Sun Jan 30 09:21:13 2005 [St. Louis]
- *
- * Purpose:  Store a string <key> in the key index hash table <kh>.
- *           Associate it with a unique key index, counting from
- *           0. It's this index that lets us map the hashed keys to
- *           integer-indexed C arrays, clumsily emulating Perl's
- *           hashes. Optionally returns the index through <opt_index>.
- *
- * Returns:  <eslOK> on success; stores <key> in <kh>; <opt_index> is 
- *           returned, set to the next higher index value.
- *           Returns <eslEDUP> if <key> was already stored in the table;
- *           <opt_index> is set to the existing index for <key>.
- *
- * Throws:   <eslEMEM> on allocation failure, and sets <opt_index> to -1.
- */
+* Synopsis: Store a key and get a key index for it.
+* Incept:   SRE, Sun Jan 30 09:21:13 2005 [St. Louis]
+*
+* Purpose:  Store a string <key> in the key index hash table <kh>.
+*           Associate it with a unique key index, counting from
+*           0. It's this index that lets us map the hashed keys to
+*           integer-indexed C arrays, clumsily emulating Perl's
+*           hashes. Optionally returns the index through <opt_index>.
+*
+* Returns:  <eslOK> on success; stores <key> in <kh>; <opt_index> is 
+*           returned, set to the next higher index value.
+*           Returns <eslEDUP> if <key> was already stored in the table;
+*           <opt_index> is set to the existing index for <key>.
+*
+* Throws:   <eslEMEM> on allocation failure, and sets <opt_index> to -1.
+*/
 int
 esl_key_Store(ESL_KEYHASH *kh, const char *key, int *opt_index)
 {
-  uint32_t val = jenkins_hash(key, kh->hashsize);
-  int n        = strlen(key);
-  int idx;
-  int status;
+    uint32_t val = jenkins_hash(key, kh->hashsize);
+    int n        = strlen(key);
+    int idx;
+    int status;
 
-  /* Was this key already stored?  */
-  for (idx = kh->hashtable[val]; idx != -1; idx = kh->nxt[idx])
-    if (strcmp(key, kh->smem + kh->key_offset[idx]) == 0) { *opt_index = idx; return eslEDUP; }
+    /* Was this key already stored?  */
+    for (idx = kh->hashtable[val]; idx != -1; idx = kh->nxt[idx])
+        if (strcmp(key, kh->smem + kh->key_offset[idx]) == 0) 
+        { 
+            if (opt_index != NULL) *opt_index = idx; 
+            return eslEDUP; 
+        }
 
-  /* Reallocate key ptr/index memory if needed */
-  if (kh->nkeys == kh->kalloc) 
-    { 
-      void *p;
-      ESL_RALLOC_WITH_TYPE(kh->key_offset, int*, p, sizeof(int)*kh->kalloc*2);
-      ESL_RALLOC_WITH_TYPE(kh->nxt, int*,        p, sizeof(int)*kh->kalloc*2);
-      kh->kalloc *= 2;
-    }
+        /* Reallocate key ptr/index memory if needed */
+        if (kh->nkeys == kh->kalloc) 
+        { 
+            void *p;
+            ESL_RALLOC_WITH_TYPE(kh->nxt,int*, p, sizeof(int)*kh->kalloc*2);
+            kh->kalloc *= 2;
+        }
 
-  /* Reallocate key string memory if needed */
-  while (kh->sn + n + 1 > kh->salloc)
-    {
-      void *p;
-      ESL_RALLOC_WITH_TYPE(kh->smem, char*, p, sizeof(char) * kh->salloc * 2);
-      kh->salloc *= 2;
-    }
+        /* Reallocate key string memory if needed */
+        while (kh->sn + n + 1 > kh->salloc)
+        {
+            void *p;
+            ESL_RALLOC_WITH_TYPE(kh->smem,char*, p, sizeof(char) * kh->salloc * 2);
+            kh->salloc *= 2;
+        }
 
-  /* Copy the key, assign its index */
-  idx                 = kh->nkeys;
-  kh->key_offset[idx] = kh->sn;
-  strcpy(kh->smem + kh->key_offset[idx], key);
-  kh->sn             += n+1;
-  kh->nkeys++;
+        /* Copy the key, assign its index */
+        idx                 = kh->nkeys;
+        kh->key_offset[idx] = kh->sn;
+        strcpy(kh->smem + kh->key_offset[idx], key);
+        kh->sn             += n+1;
+        kh->nkeys++;
 
-  /* Insert new element at head of the approp linked list in hashtable */
-  kh->nxt[idx]       = kh->hashtable[val];
-  kh->hashtable[val] = idx;
+        /* Insert new element at head of the approp linked list in hashtable */
+        kh->nxt[idx]       = kh->hashtable[val];
+        kh->hashtable[val] = idx;
 
-  /* Time to upsize? If we're 3x saturated, expand the hash table */
-  if (kh->nkeys > 3*((int)kh->hashsize))
-    if ((status = key_upsize(kh)) != eslOK) goto ERROR;
+        /* Time to upsize? If we're 3x saturated, expand the hash table */
+        if (kh->nkeys > 3*kh->hashsize)
+            if ((status = key_upsize(kh)) != eslOK) goto ERROR;
 
-  if (opt_index != NULL) *opt_index = idx;
-  return eslOK;
+        if (opt_index != NULL) *opt_index = idx;
+        return eslOK;
 
- ERROR:
-  if (opt_index != NULL) *opt_index = -1;
-  return status;
+ERROR:
+        if (opt_index != NULL) *opt_index = -1;
+        return status;
 }
 
 /* Function:  esl_key_Lookup()
@@ -810,11 +813,11 @@ main(int argc, char **argv)
 
 
 /*****************************************************************
- * Easel - a library of C functions for biological sequence analysis
- * Version h3.0b3; November 2009
- * Copyright (C) 2009 Howard Hughes Medical Institute.
- * Other copyrights also apply. See the COPYRIGHT file for a full list.
- * 
- * Easel is distributed under the Janelia Farm Software License, a BSD
- * license. See the LICENSE file for more details.
- *****************************************************************/
+* Easel - a library of C functions for biological sequence analysis
+* Version h3.0; March 2010
+* Copyright (C) 2010 Howard Hughes Medical Institute.
+* Other copyrights also apply. See the COPYRIGHT file for a full list.
+* 
+* Easel is distributed under the Janelia Farm Software License, a BSD
+* license. See the LICENSE file for more details.
+*****************************************************************/
