@@ -338,6 +338,72 @@ ERROR:
         return status;
 }
 
+/* Function:  esl_rsq_CShuffleKmers()
+* Synopsis:  Shuffle k-mers in a text sequence.
+* Incept:    SRE, Tue Nov 17 16:55:57 2009 [NHGRI retreat, Gettysburg]
+*
+* Purpose:   Consider a text sequence <s> as a string of nonoverlapping
+*            k-mers of length <K>. Shuffle the k-mers, given a random
+*            number generator <r>. Put the shuffled sequence in
+*            <shuffled>.
+*            
+*            If the length of <s> is not evenly divisible by <K>, the
+*            remaining residues are left (unshuffled) as a prefix to
+*            the shuffled k-mers.
+*            
+*            For example, shuffling ABCDEFGHIJK as k=3-mers might
+*            result in ABFIJKFGHCDE.
+*            
+*            Caller provides allocated storage for <shuffled>,
+*            for at least the same length as <s>. 
+*            
+*            <shuffled> may also point to the same storage as <s>,
+*            in which case <s> is shuffled in place.
+*            
+*            There is almost no formally justifiable reason why you'd
+*            use this shuffle -- it's not like it preserves any
+*            particularly well-defined statistical properties of the
+*            sequence -- but it's a quick and dirty way to sort of
+*            maybe possibly preserve some higher-than-monomer
+*            statistics.
+*
+* Args:      r        - an <ESL_RANDOMNESS> random generator
+*            s        - sequence to shuffle
+*            K        - size of k-mers to break <s> into
+*            shuffled - RESULT: the shuffled sequence
+*
+* Returns:   <eslOK> on success.
+*
+* Throws:    <eslEMEM> on allocation error.
+*/
+int
+esl_rsq_CShuffleKmers(ESL_RANDOMNESS *r, const char *s, int K, char *shuffled)
+{
+    int   L = strlen(s);
+    int   W = L / K;		/* number of kmers "words" excluding leftover prefix */
+    int   P = L % K;		/* leftover residues in prefix */
+    int   i;
+    char *swap = NULL;
+    int   status;
+
+    if (shuffled != s) strcpy(shuffled, s);
+    ESL_ALLOC_WITH_TYPE(swap,char*, sizeof(char) * K);
+    while (W > 1) 
+    {
+        i = esl_rnd_Roll(r, W);	                                  /* pick a word          */
+        strncpy(swap,                   shuffled + P + i*K,     K); /* copy it to tmp space */
+        strncpy(shuffled + P + i*K,     shuffled + P + (W-1)*K, K); /* move word W-1 to i   */
+        strncpy(shuffled + P + (W-1)*K, swap,                   K); /* move word i to W-1   */
+        W--;
+    }
+    free(swap);
+    return eslOK;
+
+ERROR:
+    free(swap);
+    return status;
+}
+
 /* Function:  esl_rsq_CReverse()
 * Synopsis:  Reverse a string.
 * Incept:    SRE, Sat Feb 24 10:06:34 2007 [Casa de Gatos]
@@ -798,6 +864,48 @@ ERROR:
         return status;
 }
 
+/* Function:  esl_rsq_XShuffleKmers()
+* Synopsis:  Shuffle k-mers in a digital sequence.
+* Incept:    SRE, Tue Nov 17 18:58:00 2009 [NHGRI retreat, Gettysburg]
+*
+* Purpose:   Same as <esl_rsq_CShuffleKmers()>, but shuffle digital 
+*            sequence <dsq> of length <L> into digital result <shuffled>.
+*
+* Args:      r        - an <ESL_RANDOMNESS> random generator
+*            dsq      - sequence to shuffle
+*            K        - size of k-mers to break <s> into
+*            shuffled - RESULT: the shuffled sequence
+*
+* Returns:   <eslOK> on success.
+*
+* Throws:    <eslEMEM> on allocation error.
+*/
+int
+esl_rsq_XShuffleKmers(ESL_RANDOMNESS *r, const ESL_DSQ *dsq, int L, int K, ESL_DSQ *shuffled)
+{
+    int   W = L / K;		/* number of kmers "words" excluding leftover prefix */
+    int   P = L % K;		/* leftover residues in prefix */
+    int   i;
+    char *swap = NULL;
+    int   status;
+
+    if (shuffled != dsq) esl_abc_dsqcpy(dsq, L, shuffled);
+    ESL_ALLOC_WITH_TYPE(swap,char*, sizeof(char) * K);
+    while (W > 1) 
+    {
+        i = esl_rnd_Roll(r, W);	                                 /* pick a word          */
+        memcpy(swap,                   shuffled + P + i*K,     K); /* copy it to tmp space */
+        memcpy(shuffled + P + i*K,     shuffled + P + (W-1)*K, K); /* move word W-1 to i   */
+        memcpy(shuffled + P + (W-1)*K, swap,                   K); /* move word i to W-1   */
+        W--;
+    }
+    free(swap);
+    return eslOK;
+
+ERROR:
+    free(swap);
+    return status;
+}
 
 /* Function:  esl_rsq_XReverse()
 * Synopsis:  Reverse a digital sequence.
@@ -1047,8 +1155,8 @@ ERROR:
 
 /*****************************************************************
 * Easel - a library of C functions for biological sequence analysis
- * Version h3.0b3; November 2009
-* Copyright (C) 2009 Howard Hughes Medical Institute.
+* Version h3.0; March 2010
+* Copyright (C) 2010 Howard Hughes Medical Institute.
 * Other copyrights also apply. See the COPYRIGHT file for a full list.
 * 
 * Easel is distributed under the Janelia Farm Software License, a BSD
