@@ -311,6 +311,7 @@ esl_sq_Copy(const ESL_SQ *src, ESL_SQ *dst)
     /* don't copy allocations (nalloc, etc); dst knows its own memory */
     dst->roff  = src->roff;
     dst->doff  = src->doff;
+    dst->hoff  = src->hoff;
     dst->eoff  = src->eoff;
     return eslOK;
 
@@ -367,6 +368,7 @@ esl_sq_Compare(ESL_SQ *sq1, ESL_SQ *sq2)
     /* Disk offset comparison */
     if (sq1->roff != -1 && sq2->roff != -1 && sq1->roff != sq2->roff) return eslFAIL;
     if (sq1->doff != -1 && sq2->doff != -1 && sq1->doff != sq2->doff) return eslFAIL;
+    if (sq1->hoff != -1 && sq2->hoff != -1 && sq1->hoff != sq2->hoff) return eslFAIL;
     if (sq1->eoff != -1 && sq2->eoff != -1 && sq1->eoff != sq2->eoff) return eslFAIL;
 
     /* alphabet comparison */
@@ -409,8 +411,9 @@ esl_sq_Reuse(ESL_SQ *sq)
     sq->C     = 0;
     sq->W     = 0;
     sq->L     = -1;
-  sq->idx   = -1;
+    sq->idx   = -1;
     sq->doff  = -1;
+    sq->hoff  = -1;
     sq->roff  = -1;
     sq->eoff  = -1;
     return eslOK;
@@ -1520,7 +1523,7 @@ esl_sq_Checksum(const ESL_SQ *sq, uint32_t *ret_checksum)
 int
 esl_sq_GetFromMSA(const ESL_MSA *msa, int which, ESL_SQ *sq)
 {
-    char   *gapchars = "-_.";	/* hardcoded for now */
+    char   *gapchars = "-_.~";	/* hardcoded for now */
     char   *acc      = NULL;
     char   *desc     = NULL;
     char   *ss       = NULL;
@@ -1573,6 +1576,7 @@ esl_sq_GetFromMSA(const ESL_MSA *msa, int which, ESL_SQ *sq)
 
     sq->roff = -1;
     sq->doff = -1;
+    sq->hoff = -1;
     sq->eoff = -1;
     return eslOK;
 
@@ -1611,7 +1615,7 @@ esl_sq_FetchFromMSA(const ESL_MSA *msa, int which, ESL_SQ **ret_sq)
     char   *acc      = NULL;
     char   *desc     = NULL;
     char   *ss       = NULL;
-    char   *gapchars = "-_.";	/* hardcoded for now; only affects text mode, not digital */
+    char   *gapchars = "-_.~";	/* hardcoded for now; only affects text mode, not digital */
     int     status;
 
     if (which >= msa->nseq || which < 0) return eslEOD;
@@ -1818,6 +1822,7 @@ sq_create_from(const char *name, const char *desc, const char *acc)
     * know it here.
     */
     sq->doff = -1;
+    sq->hoff = -1;
     sq->roff = -1;
     sq->eoff = -1;
     return sq;
@@ -1844,8 +1849,8 @@ sq_free(ESL_SQ *sq)
 
 /*****************************************************************
 * Easel - a library of C functions for biological sequence analysis
- * Version h3.0b3; November 2009
-* Copyright (C) 2009 Howard Hughes Medical Institute.
+* Version h3.0; March 2010
+* Copyright (C) 2010 Howard Hughes Medical Institute.
 * Other copyrights also apply. See the COPYRIGHT file for a full list.
 * 
 * Easel is distributed under the Janelia Farm Software License, a BSD
