@@ -121,8 +121,9 @@ typedef struct {
     int      srcalloc;	   /* allocated length for source name                 */
 
     /* Disk offset bookkeeping:                                                  */
-  int64_t  idx;	           /* ctr for which # seq this is; -1 if not counting  */
+    int64_t  idx;	           /* ctr for which # seq this is; -1 if not counting  */
     off_t    roff;	   /* record offset (start of record); -1 if none      */
+    off_t    hoff;	   /* offset to last byte of header; -1 if unknown     */
     off_t    doff;	   /* data offset (start of sequence data); -1 if none */
     off_t    eoff;	   /* offset to last byte of record; -1 if unknown     */
 
@@ -198,8 +199,8 @@ extern void          esl_sq_DestroyBlock(ESL_SQ_BLOCK *sqBlock);
 #endif /*!ESL_SQ_INCLUDED*/
 /*****************************************************************
 * Easel - a library of C functions for biological sequence analysis
- * Version h3.0b3; November 2009
-* Copyright (C) 2009 Howard Hughes Medical Institute.
+* Version h3.0; March 2010
+* Copyright (C) 2010 Howard Hughes Medical Institute.
 * Other copyrights also apply. See the COPYRIGHT file for a full list.
 * 
 * Easel is distributed under the Janelia Farm Software License, a BSD
