@@ -902,7 +902,7 @@ esl_vec_FRelEntropy(const float *p, const float *q, int n)
     for(i = 0; i < n; i++)
         if (p[i] > 0.) {
             if (q[i] == 0.) return eslINFINITY;
-            else            kl += p[i] * log(p[i]/q[i]);
+            else            kl += p[i] * log((double)(p[i]/q[i]));
         }
         return(1.44269504 * kl); /* converts to bits */
 }
@@ -1143,10 +1143,10 @@ ERROR:
     return eslOK;
 }
 
-/*****************************************************************  
+/*****************************************************************
 * Easel - a library of C functions for biological sequence analysis
- * Version h3.0b3; November 2009
-* Copyright (C) 2009 Howard Hughes Medical Institute.
+* Version h3.0; March 2010
+* Copyright (C) 2010 Howard Hughes Medical Institute.
 * Other copyrights also apply. See the COPYRIGHT file for a full list.
 * 
 * Easel is distributed under the Janelia Farm Software License, a BSD
