@@ -70,7 +70,7 @@
 // ! CODE CHANGED: added taskstateinfo to function !
 int
 p7_Calibrate(P7_HMM *hmm, P7_BUILDER *cfg_b, ESL_RANDOMNESS **byp_rng, P7_BG **byp_bg, P7_PROFILE **byp_gm, P7_OPROFILE **byp_om,
-             int percents, GB2::TaskStateInfo & ti)
+             int percents, U2::TaskStateInfo & ti)
 {
     P7_BG          *bg     = (esl_byp_IsProvided(byp_bg)  ? *byp_bg  : NULL); 
     P7_PROFILE     *gm     = (esl_byp_IsProvided(byp_gm)  ? *byp_gm  : NULL); 
@@ -264,7 +264,7 @@ p7_Lambda(P7_HMM *hmm, P7_BG *bg, double *ret_lambda)
 *            eventually - need to be sure that fix applies here too.
 */
 int
-p7_MSVMu(ESL_RANDOMNESS *r, P7_OPROFILE *om, P7_BG *bg, int L, int N, double lambda, double *ret_mmu, GB2::TaskStateInfo & ti )
+p7_MSVMu(ESL_RANDOMNESS *r, P7_OPROFILE *om, P7_BG *bg, int L, int N, double lambda, double *ret_mmu, U2::TaskStateInfo & ti )
 {
     P7_OMX  *ox      = p7_omx_Create(om->M, 0, 0); /* DP matrix: 1 row version */
     ESL_DSQ *dsq     = NULL;
@@ -280,7 +280,7 @@ p7_MSVMu(ESL_RANDOMNESS *r, P7_OPROFILE *om, P7_BG *bg, int L, int N, double lam
     ESL_ALLOC_WITH_TYPE(xv, double*,  sizeof(double)  * N);
     ESL_ALLOC_WITH_TYPE(dsq, ESL_DSQ*, sizeof(ESL_DSQ) * (L+2));
 
-    p7_oprofile_ReconfigLength(om, L);
+    p7_oprofile_ReconfigLength(om, L, L);
     p7_bg_SetLength(bg, L);
 
     for (i = 0; i < N; i++)
@@ -338,7 +338,7 @@ ERROR:
 * Throws:    (no abnormal error conditions)
 */
 int
-p7_ViterbiMu(ESL_RANDOMNESS *r, P7_OPROFILE *om, P7_BG *bg, int L, int N, double lambda, double *ret_vmu, GB2::TaskStateInfo & ti )
+p7_ViterbiMu(ESL_RANDOMNESS *r, P7_OPROFILE *om, P7_BG *bg, int L, int N, double lambda, double *ret_vmu, U2::TaskStateInfo & ti )
 {
     P7_OMX  *ox      = p7_omx_Create(om->M, 0, 0); /* DP matrix: 1 row version */
     ESL_DSQ *dsq     = NULL;
@@ -354,7 +354,7 @@ p7_ViterbiMu(ESL_RANDOMNESS *r, P7_OPROFILE *om, P7_BG *bg, int L, int N, double
     ESL_ALLOC_WITH_TYPE(xv, double*,  sizeof(double)  * N);
     ESL_ALLOC_WITH_TYPE(dsq, ESL_DSQ*, sizeof(ESL_DSQ) * (L+2));
 
-    p7_oprofile_ReconfigLength(om, L);
+    p7_oprofile_ReconfigLength(om, L, L);
     p7_bg_SetLength(bg, L);
 
     for (i = 0; i < N; i++)
@@ -449,7 +449,7 @@ ERROR:
 */
 int
 p7_Tau(ESL_RANDOMNESS *r, P7_OPROFILE *om, P7_BG *bg, int L, int N, double lambda, double tailp, double *ret_tau, 
-       int percents, GB2::TaskStateInfo & ti)
+       int percents, U2::TaskStateInfo & ti)
 {
     P7_OMX  *ox      = p7_omx_Create(om->M, 0, L);     /* DP matrix: for ForwardParser,  L rows */
     ESL_DSQ *dsq     = NULL;
@@ -464,7 +464,7 @@ p7_Tau(ESL_RANDOMNESS *r, P7_OPROFILE *om, P7_BG *bg, int L, int N, double lambd
     ESL_ALLOC_WITH_TYPE(dsq, ESL_DSQ*, sizeof(ESL_DSQ) * (L+2));
     if (ox == NULL) { status = eslEMEM; goto ERROR; }
 
-    p7_oprofile_ReconfigLength(om, L);
+    p7_oprofile_ReconfigLength(om, L, L);
     p7_bg_SetLength(bg, L);
 
     progressStart = ti.progress;
@@ -499,12 +499,12 @@ ERROR:
 }
 /*-------------- end, determining individual parameters ---------*/
 
-/*****************************************************************
+/************************************************************
 * HMMER - Biological sequence analysis with profile HMMs
- * Version 3.0b3; November 2009
-* Copyright (C) 2009 Howard Hughes Medical Institute.
+* Version 3.0; March 2010
+* Copyright (C) 2010 Howard Hughes Medical Institute.
 * Other copyrights also apply. See the COPYRIGHT file for a full list.
 * 
 * HMMER is distributed under the terms of the GNU General Public License
 * (GPLv3). See the LICENSE file for details.
-*****************************************************************/
+************************************************************/
