@@ -58,7 +58,7 @@
 #include <hmmer3/easel/esl_sq.h>		/* ESL_SQ                */
 #include <hmmer3/easel/esl_scorematrix.h>    /* ESL_SCOREMATRIX       */
 
-#include <core_api/Task.h>
+#include <U2Core/Task.h>
 
 #define HMMER3_CANCELED_ERROR "Task was canceled by user"
 #define HMMER3_UNKNOWN_ERROR "Sorry! Unknown error occurred!"
@@ -882,11 +882,11 @@ extern void p7_Fail(char *format, ...);
 
 /* evalues.c */
 extern int p7_Calibrate(P7_HMM *hmm, P7_BUILDER *cfg_b, ESL_RANDOMNESS **byp_rng, P7_BG **byp_bg, P7_PROFILE **byp_gm, P7_OPROFILE **byp_om, 
-                        int percents, GB2::TaskStateInfo & ti);
+                        int percents, U2::TaskStateInfo & ti);
 extern int p7_Lambda(P7_HMM *hmm, P7_BG *bg, double *ret_lambda);
-extern int p7_MSVMu     (ESL_RANDOMNESS *r, P7_OPROFILE *om, P7_BG *bg, int L, int N, double lambda,               double *ret_mmu, GB2::TaskStateInfo & ti);
-extern int p7_ViterbiMu (ESL_RANDOMNESS *r, P7_OPROFILE *om, P7_BG *bg, int L, int N, double lambda,               double *ret_vmu, GB2::TaskStateInfo & ti);
-extern int p7_Tau       (ESL_RANDOMNESS *r, P7_OPROFILE *om, P7_BG *bg, int L, int N, double lambda, double tailp, double *ret_tauint, int percents, GB2::TaskStateInfo & ti);
+extern int p7_MSVMu     (ESL_RANDOMNESS *r, P7_OPROFILE *om, P7_BG *bg, int L, int N, double lambda,               double *ret_mmu, U2::TaskStateInfo & ti);
+extern int p7_ViterbiMu (ESL_RANDOMNESS *r, P7_OPROFILE *om, P7_BG *bg, int L, int N, double lambda,               double *ret_vmu, U2::TaskStateInfo & ti);
+extern int p7_Tau       (ESL_RANDOMNESS *r, P7_OPROFILE *om, P7_BG *bg, int L, int N, double lambda, double tailp, double *ret_tauint, int percents, U2::TaskStateInfo & ti);
 
 /* eweight.c */
 extern int p7_EntropyWeight(const P7_HMM *hmm, const P7_BG *bg, const P7_PRIOR *pri, double infotarget, double *ret_Neff);
@@ -953,9 +953,9 @@ extern P7_BUILDER* p7_builder_Create( const UHMM3BuildSettings* settings, const
 extern int         p7_builder_SetScoreSystem( P7_BUILDER * bld, ESL_SCOREMATRIX * s_matr, double popen, double pextend );
 extern void        p7_builder_Destroy(P7_BUILDER *bld);
 
-extern int p7_Builder      (P7_BUILDER *bld, ESL_MSA *msa, P7_BG *bg, P7_HMM **opt_hmm, P7_TRACE ***opt_trarr, P7_PROFILE **opt_gm, P7_OPROFILE **opt_om, ESL_MSA **opt_postmsa, GB2::TaskStateInfo& ti );
+extern int p7_Builder      (P7_BUILDER *bld, ESL_MSA *msa, P7_BG *bg, P7_HMM **opt_hmm, P7_TRACE ***opt_trarr, P7_PROFILE **opt_gm, P7_OPROFILE **opt_om, ESL_MSA **opt_postmsa, U2::TaskStateInfo& ti );
 extern int p7_SingleBuilder(P7_BUILDER *bld, ESL_SQ *sq,   P7_BG *bg, P7_HMM **opt_hmm, P7_TRACE  **opt_tr,    P7_PROFILE **opt_gm, P7_OPROFILE **opt_om, 
-                            int percent, GB2::TaskStateInfo & ti ); 
+                            int percent, U2::TaskStateInfo & ti ); 
 
 /* p7_domaindef.c */
 extern P7_DOMAINDEF *p7_domaindef_Create (ESL_RANDOMNESS *r);
@@ -966,7 +966,7 @@ extern void          p7_domaindef_Destroy(P7_DOMAINDEF *ddef);
 
 extern int p7_domaindef_ByViterbi            (P7_PROFILE *gm, const ESL_SQ *sq, P7_GMX *gx1, P7_GMX *gx2, P7_DOMAINDEF *ddef);
 extern int p7_domaindef_ByPosteriorHeuristics(const ESL_SQ *sq, P7_OPROFILE *om, P7_OMX *oxf, P7_OMX *oxb,
-                                              P7_OMX *fwd, P7_OMX *bck, P7_DOMAINDEF *ddef, int percentBorder, GB2::TaskStateInfo & ti );
+                                              P7_OMX *fwd, P7_OMX *bck, P7_DOMAINDEF *ddef, int percentBorder, U2::TaskStateInfo & ti, int wholeSeqSz );
 
 
 /* p7_gmx.c */
@@ -1036,7 +1036,7 @@ extern int p7_pli_NewModel        (P7_PIPELINE *pli, const P7_OPROFILE *om, P7_B
 extern int p7_pli_NewModelThresholds(P7_PIPELINE *pli, const P7_OPROFILE *om);
 extern int p7_pli_NewSeq          (P7_PIPELINE *pli, const ESL_SQ *sq);
 extern int p7_Pipeline            (P7_PIPELINE *pli, P7_OPROFILE *om, P7_BG *bg, const ESL_SQ *sq, P7_TOPHITS *th, int percentPerFilters,
-                                   GB2::TaskStateInfo & ti );
+                                   U2::TaskStateInfo & ti, int wholeSeqSz );
 
 
 /* p7_prior.c */
@@ -1148,12 +1148,12 @@ extern int p7_Seqmodel(const ESL_ALPHABET *abc, ESL_DSQ *dsq, int M, char *name,
 
 #endif /*P7_HMMERH_INCLUDED*/
 
-/************************************************************
+/*****************************************************************
 * HMMER - Biological sequence analysis with profile HMMs
- * Version 3.0b3; November 2009
-* Copyright (C) 2009 Howard Hughes Medical Institute.
+* Version 3.0; March 2010
+* Copyright (C) 2010 Howard Hughes Medical Institute.
 * Other copyrights also apply. See the COPYRIGHT file for a full list.
 * 
 * HMMER is distributed under the terms of the GNU General Public License
 * (GPLv3). See the LICENSE file for details.
-************************************************************/
+*****************************************************************/
