@@ -27,7 +27,7 @@
 
 #include <hmmer3/hmmer.h>
 
-#include <core_api/Task.h>
+#include <U2Core/Task.h>
 
 
 /* In calculating Q, the number of vectors we need in a row, we have
@@ -281,11 +281,11 @@ extern P7_OPROFILE *p7_oprofile_Copy(P7_OPROFILE *om);
 extern P7_OPROFILE *p7_oprofile_Clone(const P7_OPROFILE *om);
 
 extern int          p7_oprofile_Convert(const P7_PROFILE *gm, P7_OPROFILE *om);
-extern int          p7_oprofile_ReconfigLength    (P7_OPROFILE *om, int L);
+extern int          p7_oprofile_ReconfigLength    (P7_OPROFILE *om, int L, int wholeSeqSz);
 extern int          p7_oprofile_ReconfigMSVLength (P7_OPROFILE *om, int L);
-extern int          p7_oprofile_ReconfigRestLength(P7_OPROFILE *om, int L);
-extern int          p7_oprofile_ReconfigMultihit  (P7_OPROFILE *om, int L);
-extern int          p7_oprofile_ReconfigUnihit    (P7_OPROFILE *om, int L);
+extern int          p7_oprofile_ReconfigRestLength(P7_OPROFILE *om, int L, int wholeSz);
+extern int          p7_oprofile_ReconfigMultihit  (P7_OPROFILE *om, int L, int wholeSz);
+extern int          p7_oprofile_ReconfigUnihit    (P7_OPROFILE *om, int L, int wholeSz);
 
 extern int          p7_oprofile_Dump(FILE *fp, const P7_OPROFILE *om);
 extern int          p7_oprofile_Sample(ESL_RANDOMNESS *r, const ESL_ALPHABET *abc, const P7_BG *bg, int M, int L,
@@ -303,19 +303,19 @@ extern int p7_DomainDecoding(const P7_OPROFILE *om, const P7_OMX *oxf, const P7_
 /* fwdback.c */
 // ! ADDED PERCENTS and TASKSTATEINFO !
 extern int p7_Forward       (const ESL_DSQ *dsq, int L, const P7_OPROFILE *om, P7_OMX *fwd, float *opt_sc,
-                             int percentBorder, GB2::TaskStateInfo & ti);
+                             int percentBorder, U2::TaskStateInfo & ti);
 extern int p7_ForwardParser (const ESL_DSQ *dsq, int L, const P7_OPROFILE *om, P7_OMX *fwd, float *opt_sc,
-                             int percentBorder, GB2::TaskStateInfo & ti );
+                             int percentBorder, U2::TaskStateInfo & ti );
 extern int p7_Backward      (const ESL_DSQ *dsq, int L, const P7_OPROFILE *om, const P7_OMX *fwd, P7_OMX *bck, float *opt_sc,
-                             int percentBorder, GB2::TaskStateInfo & ti);
+                             int percentBorder, U2::TaskStateInfo & ti);
 extern int p7_BackwardParser(const ESL_DSQ *dsq, int L, const P7_OPROFILE *om, const P7_OMX *fwd, P7_OMX *bck, float *opt_sc,
-                             int percentBorder, GB2::TaskStateInfo & ti );
+                             int percentBorder, U2::TaskStateInfo & ti );
 
 // here were definitions of io functions. we don't need them
 
 
 /* msvfilter.c */
-extern int p7_MSVFilter    (const ESL_DSQ *dsq, int L, const P7_OPROFILE *om, P7_OMX *ox, float *ret_sc, int percentBorder, GB2::TaskStateInfo & ti );
+extern int p7_MSVFilter    (const ESL_DSQ *dsq, int L, const P7_OPROFILE *om, P7_OMX *ox, float *ret_sc, int percentBorder, U2::TaskStateInfo & ti );
 
 /* null2.c */
 extern int p7_Null2_ByExpectation(const P7_OPROFILE *om, const P7_OMX *pp, float *null2);
@@ -330,18 +330,32 @@ extern int p7_StochasticTrace(ESL_RANDOMNESS *rng, const ESL_DSQ *dsq, int L, co
                               P7_TRACE *tr);
 
 /* vitfilter.c */
-extern int p7_ViterbiFilter(const ESL_DSQ *dsq, int L, const P7_OPROFILE *om, P7_OMX *ox, float *ret_sc, int percentBorder, GB2::TaskStateInfo & ti);
+extern int p7_ViterbiFilter(const ESL_DSQ *dsq, int L, const P7_OPROFILE *om, P7_OMX *ox, float *ret_sc, int percentBorder, U2::TaskStateInfo & ti);
 
 /* vitscore.c */
 extern int p7_ViterbiScore (const ESL_DSQ *dsq, int L, const P7_OPROFILE *om, P7_OMX *ox, float *ret_sc);
 
+/*****************************************************************
+* 4. Implementation specific initialization
+*****************************************************************/
+static inline void
+impl_Init(void)
+{
+#ifdef HAVE_FLUSH_ZERO_MODE
+    /* In order to avoid the performance penalty dealing with sub-normal
+    * values in the floating point calculations, set the processor flag
+    * so sub-normals are "flushed" immediately to zero.
+    */
+    _MM_SET_FLUSH_ZERO_MODE(_MM_FLUSH_ZERO_ON);
+#endif
+}
 
 #endif /* P7_IMPL_SSE_INCLUDED */
 
 /*****************************************************************
 * HMMER - Biological sequence analysis with profile HMMs
- * Version 3.0b3; November 2009
-* Copyright (C) 2009 Howard Hughes Medical Institute.
+* Version 3.0; March 2010
+* Copyright (C) 2010 Howard Hughes Medical Institute.
 * Other copyrights also apply. See the COPYRIGHT file for a full list.
 * 
 * HMMER is distributed under the terms of the GNU General Public License
