@@ -712,11 +712,11 @@ ERROR:
 *            here.
 */
 int
-p7_oprofile_ReconfigLength(P7_OPROFILE *om, int L)
+p7_oprofile_ReconfigLength(P7_OPROFILE *om, int L, int wholeSeqSz)
 {
     int status;
-    if ((status = p7_oprofile_ReconfigMSVLength (om, L)) != eslOK) return status;
-    if ((status = p7_oprofile_ReconfigRestLength(om, L)) != eslOK) return status;
+    if ((status = p7_oprofile_ReconfigMSVLength (om, wholeSeqSz)) != eslOK) return status;
+    if ((status = p7_oprofile_ReconfigRestLength(om, L, wholeSeqSz)) != eslOK) return status;
     return eslOK;
 }
 
@@ -759,11 +759,11 @@ p7_oprofile_ReconfigMSVLength(P7_OPROFILE *om, int L)
 * Returns:   <eslOK> on success.           
 */
 int
-p7_oprofile_ReconfigRestLength(P7_OPROFILE *om, int L)
+p7_oprofile_ReconfigRestLength(P7_OPROFILE *om, int L, int wholeSz)
 {
     float pmove, ploop;
 
-    pmove = (2.0f + om->nj) / ((float) L + 2.0f + om->nj); /* 2/(L+2) for sw; 3/(L+3) for fs */
+    pmove = (2.0f + om->nj) / ((float) wholeSz + 2.0f + om->nj); /* 2/(L+2) for sw; 3/(L+3) for fs */
     ploop = 1.0f - pmove;
 
     /* ForwardFilter() parameters: pspace floats */
@@ -801,7 +801,7 @@ p7_oprofile_ReconfigRestLength(P7_OPROFILE *om, int L)
 *            <p7_oprofile_ReconfigLength()>.
 */
 int
-p7_oprofile_ReconfigMultihit(P7_OPROFILE *om, int L)
+p7_oprofile_ReconfigMultihit(P7_OPROFILE *om, int L, int wholeSz)
 {
     om->xf[p7O_E][p7O_MOVE] = 0.5;
     om->xf[p7O_E][p7O_LOOP] = 0.5;
@@ -810,7 +810,7 @@ p7_oprofile_ReconfigMultihit(P7_OPROFILE *om, int L)
     om->xw[p7O_E][p7O_MOVE] = wordify(om, -eslCONST_LOG2);
     om->xw[p7O_E][p7O_LOOP] = wordify(om, -eslCONST_LOG2);
 
-    return p7_oprofile_ReconfigLength(om, L);
+    return p7_oprofile_ReconfigLength(om, L, wholeSz);
 }
 
 /* Function:  p7_oprofile_ReconfigUnihit()
@@ -826,7 +826,7 @@ p7_oprofile_ReconfigMultihit(P7_OPROFILE *om, int L)
 *            process individual domains.
 */
 int
-p7_oprofile_ReconfigUnihit(P7_OPROFILE *om, int L)
+p7_oprofile_ReconfigUnihit(P7_OPROFILE *om, int L, int wholeSz)
 {
     om->xf[p7O_E][p7O_MOVE] = 1.0f;
     om->xf[p7O_E][p7O_LOOP] = 0.0f;
@@ -835,7 +835,7 @@ p7_oprofile_ReconfigUnihit(P7_OPROFILE *om, int L)
     om->xw[p7O_E][p7O_MOVE] = 0;
     om->xw[p7O_E][p7O_LOOP] = -32768;
 
-    return p7_oprofile_ReconfigLength(om, L);
+    return p7_oprofile_ReconfigLength(om, L, wholeSz);
 }
 /*------------ end, conversions to P7_OPROFILE ------------------*/
 
@@ -1061,7 +1061,7 @@ oprofile_dump_fb(FILE *fp, const P7_OPROFILE *om, int width, int precision)
         for (q = 0; q < nq; q++)
         {
             fprintf(fp, "[ ");
-	  tmp.v = om->rfv[x][q];
+            tmp.v = om->rfv[x][q];
             for (z = 0; z < 4; z++) fprintf(fp, "%*.*f ", width, precision, tmp.x[z]);
             fprintf(fp, "]");
         }
@@ -1083,13 +1083,17 @@ oprofile_dump_fb(FILE *fp, const P7_OPROFILE *om, int width, int precision)
         for (k = 1, q = 0; q < nq; q++, k++)
         {
             switch (t) {
-        case p7O_BM: kb = k;                 break; 
-        case p7O_MM: kb = 1 + (nq+k-2) % nq; break; /* MM, DM, IM quads rotated by +1  */
-        case p7O_IM: kb = 1 + (nq+k-2) % nq; break;  
-        case p7O_DM: kb = 1 + (nq+k-2) % nq; break;  
-        case p7O_MD: kb = k;                 break; /* the remaining ones are straight up  */
-        case p7O_MI: kb = k;                 break; 
-        case p7O_II: kb = k;                 break; 
+        case p7O_MM:/* MM, DM, IM quads rotated by +1  */
+        case p7O_IM:
+        case p7O_DM:
+            kb = (1 + (nq+k-2)) % nq;
+            break;
+        case p7O_BM:/* the remaining ones are straight up  */
+        case p7O_MD:
+        case p7O_MI:
+        case p7O_II:
+            kb = k;
+            break;
             }
             fprintf(fp, "[ ");
             for (z = 0; z < 4; z++) 
@@ -1101,7 +1105,7 @@ oprofile_dump_fb(FILE *fp, const P7_OPROFILE *om, int width, int precision)
         for (q = 0; q < nq; q++)
         {
             fprintf(fp, "[ ");
-	  tmp.v = om->tfv[q*7 + t];
+            tmp.v = om->tfv[q*7 + t];
             for (z = 0; z < 4; z++) fprintf(fp, "%*.*f ", width, precision, tmp.x[z]);
             fprintf(fp, "]");
         }
@@ -1122,7 +1126,7 @@ oprofile_dump_fb(FILE *fp, const P7_OPROFILE *om, int width, int precision)
     for (j = nq*7, q = 0; q < nq; q++, j++)
     {
         fprintf(fp, "[ ");
-      tmp.v = om->tfv[j];
+        tmp.v = om->tfv[j];
         for (z = 0; z < 4; z++) fprintf(fp, "%*.*f ", width, precision, tmp.x[z]);
         fprintf(fp, "]");
     }
@@ -1212,7 +1216,7 @@ p7_oprofile_Sample(ESL_RANDOMNESS *r, const ESL_ALPHABET *abc, const P7_BG *bg,
     if ((status = p7_hmm_Sample(r, M, abc, &hmm))             != eslOK) goto ERROR;
     if ((status = p7_ProfileConfig(hmm, bg, gm, L, p7_LOCAL)) != eslOK) goto ERROR;
     if ((status = p7_oprofile_Convert(gm, om))                != eslOK) goto ERROR;
-    if ((status = p7_oprofile_ReconfigLength(om, L))          != eslOK) goto ERROR;
+    if ((status = p7_oprofile_ReconfigLength(om, L, L))          != eslOK) goto ERROR;
 
     if (opt_hmm != NULL) *opt_hmm = hmm; else p7_hmm_Destroy(hmm);
     if (opt_gm  != NULL) *opt_gm  = gm;  else p7_profile_Destroy(gm);
@@ -1352,7 +1356,7 @@ int
 p7_profile_SameAsMF(const P7_OPROFILE *om, P7_PROFILE *gm)
 {
     int    k,x;
-    float  tbm = roundf(om->scale_b * (log(2.0f / ((float) gm->M * (float) (gm->M+1)))));
+    float  tbm = roundf(om->scale_b * (log((double)(2.0f / ((float) gm->M * (float) (gm->M+1))))));
 
     /* Transitions */
     esl_vec_FSet(gm->tsc, p7P_NTRANS * gm->M, -eslINFINITY);
@@ -1448,12 +1452,12 @@ p7_profile_SameAsVF(const P7_OPROFILE *om, P7_PROFILE *gm)
 
 
 
-/*****************************************************************
+/************************************************************
 * HMMER - Biological sequence analysis with profile HMMs
- * Version 3.0b3; November 2009
-* Copyright (C) 2009 Howard Hughes Medical Institute.
+* Version 3.0; March 2010
+* Copyright (C) 2010 Howard Hughes Medical Institute.
 * Other copyrights also apply. See the COPYRIGHT file for a full list.
 * 
 * HMMER is distributed under the terms of the GNU General Public License
 * (GPLv3). See the LICENSE file for details.
-*****************************************************************/
+************************************************************/
