@@ -68,7 +68,7 @@ p7_ProfileConfig(const P7_HMM *hmm, const P7_BG *bg, P7_PROFILE *gm, int L, int
     float  sc[p7_MAXCODE];
     float  mthresh;
     float  Z;
-    
+
     /* Contract checks */
     if (gm->abc->type != hmm->abc->type) ESL_XEXCEPTION(eslEINVAL, "HMM and profile alphabet don't match");
     if (hmm->M > gm->allocM)             ESL_XEXCEPTION(eslEINVAL, "profile too small to hold HMM");
@@ -76,11 +76,11 @@ p7_ProfileConfig(const P7_HMM *hmm, const P7_BG *bg, P7_PROFILE *gm, int L, int
     /* Copy some pointer references and other info across from HMM  */
     gm->M      = hmm->M;
     gm->mode   = mode;
-  gm->roff   = -1;
-  gm->eoff   = -1;
-  gm->offs[p7_MOFFSET] = -1;
-  gm->offs[p7_FOFFSET] = -1;
-  gm->offs[p7_POFFSET] = -1;
+    gm->roff   = -1;
+    gm->eoff   = -1;
+    gm->offs[p7_MOFFSET] = -1;
+    gm->offs[p7_FOFFSET] = -1;
+    gm->offs[p7_POFFSET] = -1;
     if (gm->name != NULL) free(gm->name);
     if (gm->acc  != NULL) free(gm->acc);
     if (gm->desc != NULL) free(gm->desc);
@@ -110,24 +110,27 @@ p7_ProfileConfig(const P7_HMM *hmm, const P7_BG *bg, P7_PROFILE *gm, int L, int
     /* Entry scores. */
     if (p7_profile_IsLocal(gm))
     {
-        /* Local mode entry:  occ[k] /( \sum_i occ[i] * (M-k+1))
+        /* Local mode entry:  occ[k] /( \sum_i occ[i] * (M-i+1))
         * (Reduces to uniform 2/(M(M+1)) for occupancies of 1.0)  */
         Z = 0.;
         ESL_ALLOC_WITH_TYPE(occ, float*, sizeof(float) * (hmm->M+1));
+
         if ((status = p7_hmm_CalculateOccupancy(hmm, occ, NULL)) != eslOK) goto ERROR;
         for (k = 1; k <= hmm->M; k++) 
             Z += occ[k] * (float) (hmm->M-k+1);
         for (k = 1; k <= hmm->M; k++) 
-            p7P_TSC(gm, k-1, p7P_BM) = log(occ[k] / Z); /* note off-by-one: entry at Mk stored as [k-1][BM] */
+            p7P_TSC(gm, k-1, p7P_BM) = log((double)(occ[k] / Z)); /* note off-by-one: entry at Mk stored as [k-1][BM] */
+
+        free(occ);
     }
     else	/* glocal modes: left wing retraction; must be in log space for precision */
     {
-        Z = log(hmm->t[0][p7H_MD]);
-        p7P_TSC(gm, 0, p7P_BM) = log(1.0 - hmm->t[0][p7H_MD]);
+        Z = log((double)(hmm->t[0][p7H_MD]));
+        p7P_TSC(gm, 0, p7P_BM) = log((double)(1.0 - hmm->t[0][p7H_MD]));
         for (k = 1; k < hmm->M; k++) 
         {
-            p7P_TSC(gm, k, p7P_BM) = Z + log(hmm->t[k][p7H_DM]);
-            Z += log(hmm->t[k][p7H_DD]);
+            p7P_TSC(gm, k, p7P_BM) = Z + log((double)(hmm->t[k][p7H_DM]));
+            Z += log((double)(hmm->t[k][p7H_DD]));
         }
     }
 
@@ -147,29 +150,29 @@ p7_ProfileConfig(const P7_HMM *hmm, const P7_BG *bg, P7_PROFILE *gm, int L, int
     /* Transition scores. */
     for (k = 1; k < gm->M; k++) {
         tp = gm->tsc + k * p7P_NTRANS;
-        tp[p7P_MM] = log(hmm->t[k][p7H_MM]);
-        tp[p7P_MI] = log(hmm->t[k][p7H_MI]);
-        tp[p7P_MD] = log(hmm->t[k][p7H_MD]);
-        tp[p7P_IM] = log(hmm->t[k][p7H_IM]);
-        tp[p7P_II] = log(hmm->t[k][p7H_II]);
-        tp[p7P_DM] = log(hmm->t[k][p7H_DM]);
-        tp[p7P_DD] = log(hmm->t[k][p7H_DD]);
+        tp[p7P_MM] = log((double)(hmm->t[k][p7H_MM]));
+        tp[p7P_MI] = log((double)(hmm->t[k][p7H_MI]));
+        tp[p7P_MD] = log((double)(hmm->t[k][p7H_MD]));
+        tp[p7P_IM] = log((double)(hmm->t[k][p7H_IM]));
+        tp[p7P_II] = log((double)(hmm->t[k][p7H_II]));
+        tp[p7P_DM] = log((double)(hmm->t[k][p7H_DM]));
+        tp[p7P_DD] = log((double)(hmm->t[k][p7H_DD]));
     }
-    
+
     /* Match emission scores. */
     sc[hmm->abc->K]     = -eslINFINITY; /* gap character */
     sc[hmm->abc->Kp-2]  = -eslINFINITY; /* nonresidue character */
     sc[hmm->abc->Kp-1]  = -eslINFINITY; /* missing data character */
     for (k = 1; k <= hmm->M; k++) {
-    for (x = 0; x < hmm->abc->K; x++) 
-            sc[x] = log(hmm->mat[k][x] / bg->f[x]);
+        for (x = 0; x < hmm->abc->K; x++) 
+            sc[x] = log((double)(hmm->mat[k][x] / bg->f[x]));
         esl_abc_FExpectScVec(hmm->abc, sc, bg->f); 
         for (x = 0; x < hmm->abc->Kp; x++) {
             rp = gm->rsc[x] + k * p7P_NR;
             rp[p7P_MSC] = sc[x];
         }
     }
-    
+
     /* Insert emission scores */
     /* SRE, Fri Dec 5 08:41:08 2008: We currently hardwire insert scores
     * to 0, i.e. corresponding to the insertion emission probabilities
@@ -187,7 +190,8 @@ p7_ProfileConfig(const P7_HMM *hmm, const P7_BG *bg, P7_PROFILE *gm, int L, int
     for (k = 1; k <= hmm->M; k++) p7P_ISC(gm, k, gm->abc->K)    = -eslINFINITY; /* gap symbol */
     for (k = 1; k <= hmm->M; k++) p7P_ISC(gm, k, gm->abc->Kp-2) = -eslINFINITY; /* nonresidue symbol */
     for (k = 1; k <= hmm->M; k++) p7P_ISC(gm, k, gm->abc->Kp-1) = -eslINFINITY; /* missing data symbol */
-    
+
+
 #if 0
     /* original (informative) insert setting: relies on sc[K, Kp-1] initialization to -inf above */
     for (k = 1; k < hmm->M; k++) {
@@ -202,21 +206,18 @@ p7_ProfileConfig(const P7_HMM *hmm, const P7_BG *bg, P7_PROFILE *gm, int L, int
     for (x = 0; x < hmm->abc->Kp; x++)
         p7P_ISC(gm, hmm->M, x) = -eslINFINITY;   /* init I_M to impossible.   */
 #endif
-    
+
     /* Remaining specials, [NCJ][MOVE | LOOP] are set by ReconfigLength()
     */
     gm->L = 0;			/* force ReconfigLength to reconfig */
     if ((status = p7_ReconfigLength(gm, L)) != eslOK) goto ERROR;
-    free(occ);
-    
     return eslOK;
-    
+
 ERROR:
     if (occ != NULL) free(occ);
     return status;
 }
 
-
 /* Function:  p7_ReconfigLength()
 * Synopsis:  Set the target sequence length of a model.
 * Incept:    SRE, Sun Sep 25 12:38:55 2005 [St. Louis]
@@ -249,8 +250,8 @@ p7_ReconfigLength(P7_PROFILE *gm, int L)
     */
     pmove = (2.0f + gm->nj) / ((float) L + 2.0f + gm->nj); /* 2/(L+2) for sw; 3/(L+3) for fs */
     ploop = 1.0f - pmove;
-    gm->xsc[p7P_N][p7P_LOOP] =  gm->xsc[p7P_C][p7P_LOOP] = gm->xsc[p7P_J][p7P_LOOP] = log(ploop);
-    gm->xsc[p7P_N][p7P_MOVE] =  gm->xsc[p7P_C][p7P_MOVE] = gm->xsc[p7P_J][p7P_MOVE] = log(pmove);
+    gm->xsc[p7P_N][p7P_LOOP] =  gm->xsc[p7P_C][p7P_LOOP] = gm->xsc[p7P_J][p7P_LOOP] = log((double)ploop);
+    gm->xsc[p7P_N][p7P_MOVE] =  gm->xsc[p7P_C][p7P_MOVE] = gm->xsc[p7P_J][p7P_MOVE] = log((double)pmove);
     gm->L = L;
     return eslOK;
 }
@@ -565,12 +566,12 @@ p7_ReconfigUnihit(P7_PROFILE *gm, int L)
 
 
 
-/*****************************************************************
+/************************************************************
 * HMMER - Biological sequence analysis with profile HMMs
- * Version 3.0b3; November 2009
-* Copyright (C) 2009 Howard Hughes Medical Institute.
+* Version 3.0; March 2010
+* Copyright (C) 2010 Howard Hughes Medical Institute.
 * Other copyrights also apply. See the COPYRIGHT file for a full list.
 * 
 * HMMER is distributed under the terms of the GNU General Public License
 * (GPLv3). See the LICENSE file for details.
-*****************************************************************/
+************************************************************/
