@@ -246,13 +246,14 @@ p7_builder_Destroy(P7_BUILDER *bld)
 * 2. Standardized model construction API.
 *****************************************************************/
 
+static int    validate_msa         (P7_BUILDER *bld, ESL_MSA *msa);
 static int    relative_weights     (P7_BUILDER *bld, ESL_MSA *msa);
 static int    build_model          (P7_BUILDER *bld, ESL_MSA *msa, P7_HMM **ret_hmm, P7_TRACE ***opt_tr);
 static int    effective_seqnumber  (P7_BUILDER *bld, const ESL_MSA *msa, P7_HMM *hmm, const P7_BG *bg);
 static int    parameterize         (P7_BUILDER *bld, P7_HMM *hmm);
 static int    annotate             (P7_BUILDER *bld, const ESL_MSA *msa, P7_HMM *hmm);
 static int    calibrate            (P7_BUILDER *bld, P7_HMM *hmm, P7_BG *bg, P7_PROFILE **opt_gm, P7_OPROFILE **opt_om, 
-                                    int percents, GB2::TaskStateInfo & ti);
+                                    int percents, U2::TaskStateInfo & ti);
 static int    make_post_msa        (P7_BUILDER *bld, const ESL_MSA *premsa, const P7_HMM *hmm, P7_TRACE **tr, ESL_MSA **opt_postmsa);
 
 /* Function:  p7_Builder()
@@ -294,8 +295,9 @@ static int    make_post_msa        (P7_BUILDER *bld, const ESL_MSA *premsa, cons
 */
 int
 p7_Builder(P7_BUILDER *bld, ESL_MSA *msa, P7_BG *bg,
-           P7_HMM **opt_hmm, P7_TRACE ***opt_trarr, P7_PROFILE **opt_gm, P7_OPROFILE **opt_om, ESL_MSA **opt_postmsa, GB2::TaskStateInfo& ti )
+           P7_HMM **opt_hmm, P7_TRACE ***opt_trarr, P7_PROFILE **opt_gm, P7_OPROFILE **opt_om, ESL_MSA **opt_postmsa, U2::TaskStateInfo& ti )
 {
+    uint32_t    checksum = 0;	/* checksum calculated for the input MSA. hmmalign --mapali verifies against this. */
     P7_HMM *hmm = NULL;
     P7_TRACE  **tr     = NULL;
     P7_TRACE ***tr_ptr = (opt_trarr != NULL || opt_postmsa != NULL) ? &tr : NULL;
@@ -303,7 +305,9 @@ p7_Builder(P7_BUILDER *bld, ESL_MSA *msa, P7_BG *bg,
 
     if( ti.cancelFlag ) { status = eslCANCELED; goto ERROR; }
     ti.progress = 0;
-
+    
+    if ((status =  validate_msa         (bld, msa))                       != eslOK) goto ERROR;
+    if ((status =  esl_msa_Checksum     (msa, &checksum))                 != eslOK) ESL_XFAIL(status, bld->errbuf, "Failed to calculate checksum"); 
     if ((status =  relative_weights   (bld, msa))                     != eslOK) goto ERROR;
     if ((status =  esl_msa_MarkFragments(msa, bld->fragthresh))         != eslOK) goto ERROR;
     ti.progress += 10;
@@ -331,7 +335,10 @@ p7_Builder(P7_BUILDER *bld, ESL_MSA *msa, P7_BG *bg,
     if ((status =  make_post_msa      (bld, msa, hmm, tr, opt_postmsa)) != eslOK) goto ERROR;
     ti.progress += 5;
     if( ti.cancelFlag ) { status = eslCANCELED; goto ERROR; }
-
+    
+    hmm->checksum = checksum;
+    hmm->flags   |= p7H_CHKSUM;
+    
     if (opt_hmm   != NULL) *opt_hmm = hmm; else p7_hmm_Destroy(hmm);
     if (opt_trarr != NULL) *opt_trarr = tr;  else p7_trace_DestroyArray(tr, msa->nseq);
     return eslOK;
@@ -370,7 +377,7 @@ ERROR:
 */
 int
 p7_SingleBuilder(P7_BUILDER *bld, ESL_SQ *sq, P7_BG *bg, P7_HMM **opt_hmm,
-                 P7_TRACE **opt_tr, P7_PROFILE **opt_gm, P7_OPROFILE **opt_om, int percent, GB2::TaskStateInfo & ti )
+                 P7_TRACE **opt_tr, P7_PROFILE **opt_gm, P7_OPROFILE **opt_om, int percent, U2::TaskStateInfo & ti )
 {
     P7_HMM *hmm = NULL;
     P7_TRACE *tr  = NULL;
@@ -421,6 +428,36 @@ ERROR:
 * 3. Internal functions
 *****************************************************************/
 
+/* validate_msa:
+* SRE, Thu Dec  3 16:10:31 2009 [J5/119; bug #h70 fix]
+* 
+* HMMER uses a convention for missing data characters: they
+* indicate that a sequence is a fragment.  (See
+* esl_msa_MarkFragments()).
+*
+* Because of the way these fragments will be handled in tracebacks,
+* we reject any alignment that uses missing data characters in any
+* other way.
+* 
+* This validation step costs negligible time.
+*/
+static int
+validate_msa(P7_BUILDER *bld, ESL_MSA *msa)
+{
+    int     idx;
+    int64_t apos;
+
+    for (idx = 0; idx < msa->nseq; idx++)
+    {
+        apos = 1;
+        while (  esl_abc_XIsMissing(msa->abc, msa->ax[idx][apos]) && apos <= msa->alen) apos++;
+        while (! esl_abc_XIsMissing(msa->abc, msa->ax[idx][apos]) && apos <= msa->alen) apos++;
+        while (  esl_abc_XIsMissing(msa->abc, msa->ax[idx][apos]) && apos <= msa->alen) apos++;
+        if (apos != msa->alen+1) ESL_FAIL(eslEINVAL, bld->errbuf, "msa %s; sequence %s\nhas missing data chars (~) other than at fragment edges", msa->name, msa->sqname[idx]);
+    }
+
+    return eslOK;
+}
 
 /* set_relative_weights():
 * Set msa->wgt vector, using user's choice of relative weighting algorithm.
@@ -428,21 +465,17 @@ ERROR:
 static int
 relative_weights(P7_BUILDER *bld, ESL_MSA *msa)
 {
-    int status;
+    int status = eslOK;
 
-    if      (bld->wgt_strategy == p7_WGT_NONE)                    { esl_vec_DSet(msa->wgt, msa->nseq, 1.); status = eslOK; }
-    else if (bld->wgt_strategy == p7_WGT_GIVEN)                   status = eslOK;
+    if      (bld->wgt_strategy == p7_WGT_NONE)                    { esl_vec_DSet(msa->wgt, msa->nseq, 1.); }
+    else if (bld->wgt_strategy == p7_WGT_GIVEN)                   ;
     else if (bld->wgt_strategy == p7_WGT_PB)                      status = esl_msaweight_PB(msa); 
     else if (bld->wgt_strategy == p7_WGT_GSC)                     status = esl_msaweight_GSC(msa); 
     else if (bld->wgt_strategy == p7_WGT_BLOSUM)                  status = esl_msaweight_BLOSUM(msa, bld->wid); 
+    else ESL_EXCEPTION(eslEINCONCEIVABLE, "no such weighting strategy");
 
-    //cppcheck-suppress uninitvar
-    if (status != eslOK) ESL_XFAIL(status, bld->errbuf, "failed to set relative weights in alignment");
-
+    if (status != eslOK) ESL_FAIL(status, bld->errbuf, "failed to set relative weights in alignment");
     return eslOK;
-
-ERROR:
-    return status;
 }
 
 
@@ -568,9 +601,7 @@ annotate(P7_BUILDER *bld, const ESL_MSA *msa, P7_HMM *hmm)
     if ((status = p7_hmm_SetDescription(hmm, msa->desc))          != eslOK) ESL_XFAIL(status, bld->errbuf, "Failed to record MSA description");
     //  if ((status = p7_hmm_AppendComlog(hmm, go->argc, go->argv))   != eslOK) ESL_XFAIL(status, errbuf, "Failed to record command log");
     if ((status = p7_hmm_SetCtime(hmm))                           != eslOK) ESL_XFAIL(status, bld->errbuf, "Failed to record timestamp");
-    if ((status = esl_msa_Checksum(msa, &(hmm->checksum)))        != eslOK) ESL_XFAIL(status, bld->errbuf, "Failed to record checksum"); 
     if ((status = p7_hmm_SetComposition(hmm))                     != eslOK) ESL_XFAIL(status, bld->errbuf, "Failed to determine model composition");
-    hmm->flags |= p7H_CHKSUM;
     hmm->flags |= p7H_COMPO;
 
     if (msa->cutset[eslMSA_GA1] && msa->cutset[eslMSA_GA2]) { hmm->cutoff[p7_GA1] = msa->cutoff[eslMSA_GA1]; hmm->cutoff[p7_GA2] = msa->cutoff[eslMSA_GA2]; hmm->flags |= p7H_GA; }
@@ -590,7 +621,7 @@ ERROR:
 * of them, it can pass non-<NULL> <opt_gm>, <opt_om> pointers.
 */
 static int
-calibrate(P7_BUILDER *bld, P7_HMM *hmm, P7_BG *bg, P7_PROFILE **opt_gm, P7_OPROFILE **opt_om, int percents, GB2::TaskStateInfo & ti)
+calibrate(P7_BUILDER *bld, P7_HMM *hmm, P7_BG *bg, P7_PROFILE **opt_gm, P7_OPROFILE **opt_om, int percents, U2::TaskStateInfo & ti)
 {
     int status;
 
@@ -636,12 +667,12 @@ ERROR:
 
 
 
-/*****************************************************************
+/************************************************************
 * HMMER - Biological sequence analysis with profile HMMs
- * Version 3.0b3; November 2009
-* Copyright (C) 2009 Howard Hughes Medical Institute.
+* Version 3.0; March 2010
+* Copyright (C) 2010 Howard Hughes Medical Institute.
 * Other copyrights also apply. See the COPYRIGHT file for a full list.
 * 
 * HMMER is distributed under the terms of the GNU General Public License
 * (GPLv3). See the LICENSE file for details.
-*****************************************************************/
+************************************************************/
