@@ -386,7 +386,7 @@ p7_domaindef_ByViterbi(P7_PROFILE *gm, const ESL_SQ *sq, P7_GMX *gx1, P7_GMX *gx
 int
 p7_domaindef_ByPosteriorHeuristics(const ESL_SQ *sq, P7_OPROFILE *om, 
                                    P7_OMX *oxf, P7_OMX *oxb, P7_OMX *fwd, P7_OMX *bck, 
-                                   P7_DOMAINDEF *ddef, int percentBorder, GB2::TaskStateInfo & ti )
+                                   P7_DOMAINDEF *ddef, int percentBorder, U2::TaskStateInfo & ti, int wholeSeqSz )
 {
     int i, j;
     int triggered;
@@ -403,7 +403,7 @@ p7_domaindef_ByPosteriorHeuristics(const ESL_SQ *sq, P7_OPROFILE *om,
     esl_vec_FSet(ddef->n2sc, sq->n+1, 0.0);          /* ddef->n2sc null2 scores are initialized                        */
     ddef->nexpected = ddef->btot[sq->n];             /* posterior expectation for # of domains (same as etot[sq->n])   */
 
-    p7_oprofile_ReconfigUnihit(om, saveL);	   /* process each domain in unilocal mode                           */
+    p7_oprofile_ReconfigUnihit(om, saveL, wholeSeqSz);	   /* process each domain in unilocal mode                           */
     i     = -1;
     triggered = FALSE;
     
@@ -441,13 +441,13 @@ p7_domaindef_ByPosteriorHeuristics(const ESL_SQ *sq, P7_OPROFILE *om,
                 * here; we will consolidate later if null2 strategy
                 * works
                 */
-                p7_oprofile_ReconfigMultihit(om, saveL);
+                p7_oprofile_ReconfigMultihit(om, saveL, wholeSeqSz);
                 p7_Forward(sq->dsq+i-1, j-i+1, om, fwd, NULL, 0, ti );
                 // ! ADDED CODE !
 				if( ti.cancelFlag ){ return eslCANCELED; }
 
                 region_trace_ensemble(ddef, om, sq->dsq, i, j, fwd, bck, &nc);
-                p7_oprofile_ReconfigUnihit(om, saveL);
+                p7_oprofile_ReconfigUnihit(om, saveL, wholeSeqSz);
                 /* ddef->n2sc is now set on i..j by the traceback-dependent method */
 
                 last_j2 = 0;
@@ -481,7 +481,7 @@ p7_domaindef_ByPosteriorHeuristics(const ESL_SQ *sq, P7_OPROFILE *om,
         }
     }
 
-    p7_oprofile_ReconfigMultihit(om, saveL); /* restore original profile configuration */
+    p7_oprofile_ReconfigMultihit(om, saveL, wholeSeqSz); /* restore original profile configuration */
     return eslOK;
 }
 
@@ -728,7 +728,7 @@ rescore_isolated_domain(P7_DOMAINDEF *ddef, const P7_OPROFILE *om, const ESL_SQ
     float          null2[p7_MAXCODE];
     int            status;
 
-    GB2::TaskStateInfo tmpTi;
+    U2::TaskStateInfo tmpTi;
     p7_Forward (sq->dsq + i-1, Ld, om,      ox1, &envsc, 0, tmpTi );
     p7_Backward(sq->dsq + i-1, Ld, om, ox1, ox2, NULL, 0, tmpTi );
 
@@ -742,8 +742,10 @@ rescore_isolated_domain(P7_DOMAINDEF *ddef, const P7_OPROFILE *om, const ESL_SQ
     */
     if (! null2_is_done) {
         p7_Null2_ByExpectation(om, ox2, null2);
-        for (pos = i; pos <= j; pos++) 
-            ddef->n2sc[pos]  = logf(null2[sq->dsq[pos]]);
+        for (pos = i; pos <= j; pos++) {
+            //ddef->n2sc[pos]  = logf(null2[sq->dsq[pos]]);
+            ddef->n2sc[pos] = log((double)null2[sq->dsq[pos]]);
+        }
     }
 
     for (pos = i; pos <= j; pos++) 
