@@ -294,9 +294,10 @@ p7_hmm_Clone(const P7_HMM *hmm)
     if ((newHMM = p7_hmm_Create(hmm->M, hmm->abc)) == NULL) goto ERROR;
     p7_hmm_CopyParameters(hmm, newHMM);
 
-    if (hmm->name != NULL      && (status = esl_strdup(hmm->name,   -1, &(newHMM->name)))   != eslOK) goto ERROR;
-    if ((hmm->flags & p7H_ACC) && (status = esl_strdup(hmm->acc,    -1, &(newHMM->acc)))    != eslOK) goto ERROR;
-    if ((hmm->flags & p7H_DESC)&& (status = esl_strdup(hmm->desc,   -1, &(newHMM->desc)))   != eslOK) goto ERROR;
+    if ((status = esl_strdup(hmm->name,   -1, &(newHMM->name)))   != eslOK) goto ERROR;
+    if ((status = esl_strdup(hmm->acc,    -1, &(newHMM->acc)))    != eslOK) goto ERROR;
+    if ((status = esl_strdup(hmm->desc,   -1, &(newHMM->desc)))   != eslOK) goto ERROR;
+
     if ((hmm->flags & p7H_RF)  && (status = esl_strdup(hmm->rf,     -1, &(newHMM->rf)))     != eslOK) goto ERROR;
     if ((hmm->flags & p7H_CS)  && (status = esl_strdup(hmm->cs,     -1, &(newHMM->cs)))     != eslOK) goto ERROR;
     if ((hmm->flags & p7H_CA)  && (status = esl_strdup(hmm->ca,     -1, &(newHMM->ca)))     != eslOK) goto ERROR;
@@ -316,8 +317,7 @@ p7_hmm_Clone(const P7_HMM *hmm)
 
     newHMM->offset   = hmm->offset;
     newHMM->flags    = hmm->flags;
-    
-	// ! CODE CHANGED: creating new alphabet, because in ugene hmm need to store its own hmm !
+    // ! CODE CHANGED: creating new alphabet, because in ugene hmm need to store its own hmm !
     newHMM->abc      = esl_alphabet_Create( hmm->abc->type );
     return newHMM;
 
@@ -1069,15 +1069,17 @@ p7_hmm_Compare(P7_HMM *h1, P7_HMM *h2, float tol)
     if (strcmp(h1->name,   h2->name)   != 0) return eslFAIL;
     if (strcmp(h1->comlog, h2->comlog) != 0) return eslFAIL;
     if (strcmp(h1->ctime,  h2->ctime)  != 0) return eslFAIL;
+
     if (h1->nseq     != h2->nseq)            return eslFAIL;
     if (h1->eff_nseq != h2->eff_nseq)        return eslFAIL;
     if (h1->checksum != h2->checksum)        return eslFAIL;
 
-    if ((h1->flags & p7H_ACC)  && strcmp(h1->acc,  h2->acc)  != 0) return eslFAIL;
-    if ((h1->flags & p7H_DESC) && strcmp(h1->desc, h2->desc) != 0) return eslFAIL;
-    if ((h1->flags & p7H_RF)   && strcmp(h1->rf,   h2->rf)   != 0) return eslFAIL;
-    if ((h1->flags & p7H_CS)   && strcmp(h1->cs,   h2->cs)   != 0) return eslFAIL;
-    if ((h1->flags & p7H_CA)   && strcmp(h1->ca,   h2->ca)   != 0) return eslFAIL;
+    if (esl_strcmp(h1->acc,  h2->acc)  != 0) return eslFAIL;
+    if (esl_strcmp(h1->desc, h2->desc) != 0) return eslFAIL;
+
+    if ((h1->flags & p7H_RF)   && esl_strcmp(h1->rf,   h2->rf)                != 0) return eslFAIL;
+    if ((h1->flags & p7H_CS)   && esl_strcmp(h1->cs,   h2->cs)                != 0) return eslFAIL;
+    if ((h1->flags & p7H_CA)   && esl_strcmp(h1->ca,   h2->ca)                != 0) return eslFAIL;
     if ((h1->flags & p7H_MAP)  && esl_vec_ICompare(h1->map, h2->map, h1->M+1) != 0) return eslFAIL;
 
     if (h1->flags & p7H_GA) {
@@ -1139,10 +1141,6 @@ p7_hmm_Validate(P7_HMM *hmm, char *errbuf, float tol)
     if (hmm->t[hmm->M][p7H_DD] != 0.0)                       ESL_XFAIL(eslFAIL, errbuf, "TDD should be 0 for last node");
 
     if (hmm->name == NULL)                                   ESL_XFAIL(eslFAIL, errbuf, "name is NULL: this field is mandatory");
-    if ( (hmm->flags & p7H_ACC)    && hmm->acc  == NULL)     ESL_XFAIL(eslFAIL, errbuf, "accession null but p7H_ACC flag is up");
-    if (!(hmm->flags & p7H_ACC)    && hmm->acc  != NULL)     ESL_XFAIL(eslFAIL, errbuf, "accession present but p7H_ACC flag is down");
-    if ( (hmm->flags & p7H_DESC)   && hmm->desc == NULL)     ESL_XFAIL(eslFAIL, errbuf, "description null but p7H_DESC flag is up");
-    if (!(hmm->flags & p7H_DESC)   && hmm->desc != NULL)     ESL_XFAIL(eslFAIL, errbuf, "description present but p7H_DESC flag is down");
     /* comlog is either NULL or a free text string: hard to validate */
     /* ctime, ditto */
     if ( (hmm->nseq     != -1)     && hmm->nseq     <= 0)    ESL_XFAIL(eslFAIL, errbuf, "invalid nseq");
@@ -1206,16 +1204,16 @@ p7_hmm_CalculateOccupancy(const P7_HMM *hmm, float *mocc, float *iocc)
 {
     int k;
 
-    mocc[0] = 0.;			                    /* no M_0 state */
+    mocc[0] = 0.;			                     /* no M_0 state */
     mocc[1] = hmm->t[0][p7H_MI] + hmm->t[0][p7H_MM];   /* initialize w/ 1 - B->D_1 */
     for (k = 2; k <= hmm->M; k++)
         mocc[k] = mocc[k-1] * (hmm->t[k-1][p7H_MM] + hmm->t[k-1][p7H_MI]) +
         (1.0-mocc[k-1]) * hmm->t[k-1][p7H_DM];  
 
     if (iocc != NULL) {
-        iocc[0] = hmm->t[0][p7H_MI] / hmm->t[0][p7H_II];
+        iocc[0] = hmm->t[0][p7H_MI] / hmm->t[0][p7H_IM];
         for (k = 1; k <= hmm->M; k++)
-            iocc[k] = mocc[k] * hmm->t[k][p7H_MI] / hmm->t[k][p7H_II];
+            iocc[k] = mocc[k] * hmm->t[k][p7H_MI] / hmm->t[k][p7H_IM];
     }
 
     return eslOK;
@@ -1225,8 +1223,8 @@ p7_hmm_CalculateOccupancy(const P7_HMM *hmm, float *mocc, float *iocc)
 
 /************************************************************
 * HMMER - Biological sequence analysis with profile HMMs
- * Version 3.0b3; November 2009
-* Copyright (C) 2009 Howard Hughes Medical Institute.
+* Version 3.0; March 2010
+* Copyright (C) 2010 Howard Hughes Medical Institute.
 * Other copyrights also apply. See the COPYRIGHT file for a full list.
 * 
 * HMMER is distributed under the terms of the GNU General Public License
