@@ -535,7 +535,7 @@ p7_pipeline_Merge(P7_PIPELINE *p1, P7_PIPELINE *p2)
 
 int
 p7_Pipeline(P7_PIPELINE *pli, P7_OPROFILE *om, P7_BG *bg, const ESL_SQ *sq, P7_TOPHITS *hitlist, int percentPerFilters, 
-            GB2::TaskStateInfo & ti )
+            U2::TaskStateInfo & ti, int wholeSeqSz )
 {
     P7_HIT          *hit     = NULL;     /* ptr to the current hit output data      */
     float            usc, vfsc, fwdsc;   /* filter scores                           */
@@ -559,8 +559,10 @@ p7_Pipeline(P7_PIPELINE *pli, P7_OPROFILE *om, P7_BG *bg, const ESL_SQ *sq, P7_T
     p7_omx_GrowTo(pli->oxf, om->M, 0, sq->n);    /* expand the one-row omx if needed */
 
     /* Base null model score (we could calculate this in NewSeq(), for a scan pipeline) */
-    p7_bg_NullOne  (bg, sq->dsq, sq->n, &nullsc);
-
+    // !!! CODE CHANGED !!!
+    //p7_bg_NullOne  (bg, sq->dsq, sq->n, &nullsc);
+    p7_bg_NullOne  (bg, sq->dsq, wholeSeqSz, &nullsc);
+    
     /* First level filter: the MSV filter, multihit with <om> */
     // ! CODE ADDED !
 	status = p7_MSVFilter(sq->dsq, sq->n, om, pli->oxf, &usc, percentPerFilters, ti );
@@ -568,7 +570,7 @@ p7_Pipeline(P7_PIPELINE *pli, P7_OPROFILE *om, P7_BG *bg, const ESL_SQ *sq, P7_T
 
     seq_score = (usc - nullsc) / eslCONST_LOG2;
     P = esl_gumbel_surv(seq_score,  om->evparam[p7_MMU],  om->evparam[p7_MLAMBDA]);
-  if (P > pli->F1) return eslOK;
+    if (P > pli->F1) return eslOK;
     pli->n_past_msv++;
 
     /* biased composition HMM filtering */
@@ -581,13 +583,9 @@ p7_Pipeline(P7_PIPELINE *pli, P7_OPROFILE *om, P7_BG *bg, const ESL_SQ *sq, P7_T
     }
     else filtersc = nullsc;
     pli->n_past_bias++;
-
-    /* In scan mode, if it passes the MSV filter, read the rest of the profile */
-    /*if (pli->hfp) {
-        p7_oprofile_ReadRest(pli->hfp, om);
-        p7_oprofile_ReconfigRestLength(om, sq->n);
-    }*/
-
+    
+    // !!! CODE DELETED !!!
+    
     /* Second level filter: ViterbiFilter(), multihit with <om> */
     if (P > pli->F2) 		
     {
@@ -617,7 +615,7 @@ p7_Pipeline(P7_PIPELINE *pli, P7_OPROFILE *om, P7_BG *bg, const ESL_SQ *sq, P7_T
 	p7_BackwardParser(sq->dsq, sq->n, om, pli->oxf, pli->oxb, NULL, percentPerFilters, ti );
     if( eslCANCELED == status ) { return eslCANCELED; }
 
-    status = p7_domaindef_ByPosteriorHeuristics(sq, om, pli->oxf, pli->oxb, pli->fwd, pli->bck, pli->ddef, percentPerFilters, ti );
+    status = p7_domaindef_ByPosteriorHeuristics(sq, om, pli->oxf, pli->oxb, pli->fwd, pli->bck, pli->ddef, percentPerFilters, ti, wholeSeqSz );
     if( eslCANCELED == status ) { return eslCANCELED; }
     // ! CODE CHANGED: ESL_FAIL was here !
     else if (status != eslOK) ESL_EXCEPTION(status, pli->errbuf, "domain definition workflow failure"); /* eslERANGE can happen */
@@ -630,7 +628,7 @@ p7_Pipeline(P7_PIPELINE *pli, P7_OPROFILE *om, P7_BG *bg, const ESL_SQ *sq, P7_T
     if (pli->do_null2)
     {
         seqbias = esl_vec_FSum(pli->ddef->n2sc, sq->n+1);
-        seqbias = p7_FLogsum(0.0, log(bg->omega) + seqbias);
+        seqbias = p7_FLogsum(0.0, log((double)(bg->omega)) + seqbias);
     }
     else seqbias = 0.0;
     pre_score =  (fwdsc - nullsc) / eslCONST_LOG2; 
@@ -656,7 +654,7 @@ p7_Pipeline(P7_PIPELINE *pli, P7_OPROFILE *om, P7_BG *bg, const ESL_SQ *sq, P7_T
                 seqbias   += pli->ddef->dcl[d].domcorrection;
             }
         }
-        seqbias = p7_FLogsum(0.0, log(bg->omega) + seqbias);
+        seqbias = p7_FLogsum(0.0, log((double)(bg->omega)) + seqbias);
     }
     else 
     {
@@ -670,7 +668,8 @@ p7_Pipeline(P7_PIPELINE *pli, P7_OPROFILE *om, P7_BG *bg, const ESL_SQ *sq, P7_T
         }
         seqbias = 0.0;
     }    
-    sum_score += (sq->n-Ld) * log((float) sq->n / (float) (sq->n+3)); 
+    //sum_score += (sq->n-Ld) * log((double)((float) sq->n / (float) (sq->n+3))); 
+    sum_score += (sq->n-Ld) * log((double)((float) wholeSeqSz / (float) (wholeSeqSz+3))); 
     pre2_score = (sum_score - nullsc) / eslCONST_LOG2;
     sum_score  = (sum_score - (nullsc + seqbias)) / eslCONST_LOG2;
 
@@ -691,13 +690,13 @@ p7_Pipeline(P7_PIPELINE *pli, P7_OPROFILE *om, P7_BG *bg, const ESL_SQ *sq, P7_T
     {
         p7_tophits_CreateNextHit(hitlist, &hit);
         if (pli->mode == p7_SEARCH_SEQS) {
-            if ((status  = esl_strdup(sq->name, -1, &(hit->name)))  != eslOK) esl_fatal("allocation failure");
-            if ((status  = esl_strdup(sq->acc,  -1, &(hit->acc)))   != eslOK) esl_fatal("allocation failure");
-            if ((status  = esl_strdup(sq->desc, -1, &(hit->desc)))  != eslOK) esl_fatal("allocation failure");
+            if (                       (status  = esl_strdup(sq->name, -1, &(hit->name)))  != eslOK) ESL_EXCEPTION(eslEMEM, "allocation failure");
+            if (sq->acc[0]  != '\0' && (status  = esl_strdup(sq->acc,  -1, &(hit->acc)))   != eslOK) ESL_EXCEPTION(eslEMEM, "allocation failure");
+            if (sq->desc[0] != '\0' && (status  = esl_strdup(sq->desc, -1, &(hit->desc)))  != eslOK) ESL_EXCEPTION(eslEMEM, "allocation failure");
         } else {
-            if ((status  = esl_strdup(om->name, -1, &(hit->name)))  != eslOK) esl_fatal("allocation failure");
-            if ((status  = esl_strdup(om->acc,  -1, &(hit->acc)))   != eslOK) esl_fatal("allocation failure");
-            if ((status  = esl_strdup(om->desc, -1, &(hit->desc)))  != eslOK) esl_fatal("allocation failure");
+            if ((status  = esl_strdup(om->name, -1, &(hit->name)))  != eslOK) ESL_EXCEPTION(eslEMEM, "allocation failure");
+            if ((status  = esl_strdup(om->acc,  -1, &(hit->acc)))   != eslOK) ESL_EXCEPTION(eslEMEM, "allocation failure");
+            if ((status  = esl_strdup(om->desc, -1, &(hit->desc)))  != eslOK) ESL_EXCEPTION(eslEMEM, "allocation failure");
         } 
         hit->ndom       = pli->ddef->ndom;
         hit->nexpected  = pli->ddef->nexpected;
@@ -730,11 +729,13 @@ p7_Pipeline(P7_PIPELINE *pli, P7_OPROFILE *om, P7_BG *bg, const ESL_SQ *sq, P7_T
         for (d = 0; d < hit->ndom; d++)
         {
             Ld = hit->dcl[d].jenv - hit->dcl[d].ienv + 1;
-            hit->dcl[d].bitscore = hit->dcl[d].envsc + (sq->n-Ld) * log((float) sq->n / (float) (sq->n+3)); 
-            hit->dcl[d].dombias  = (pli->do_null2 ? p7_FLogsum(0.0, log(bg->omega) + hit->dcl[d].domcorrection) : 0.0);
+            // !!! CODE CHANGED !!!
+            //hit->dcl[d].bitscore = hit->dcl[d].envsc + (sq->n-Ld) * log((float) sq->n / (float) (sq->n+3)); 
+            hit->dcl[d].bitscore = hit->dcl[d].envsc + (wholeSeqSz-Ld) * log((double) wholeSeqSz / (double) (wholeSeqSz+3)); 
+            hit->dcl[d].dombias  = (pli->do_null2 ? p7_FLogsum(0.0, log((double)bg->omega) + hit->dcl[d].domcorrection) : 0.0);
             hit->dcl[d].bitscore = (hit->dcl[d].bitscore - (nullsc + hit->dcl[d].dombias)) / eslCONST_LOG2;
             hit->dcl[d].pvalue   = esl_exp_surv (hit->dcl[d].bitscore,  om->evparam[p7_FTAU], om->evparam[p7_FLAMBDA]);
-
+            
             if (hit->dcl[d].bitscore > hit->dcl[hit->best_domain].bitscore) hit->best_domain = d;
         }
 
@@ -792,12 +793,12 @@ p7_Pipeline(P7_PIPELINE *pli, P7_OPROFILE *om, P7_BG *bg, const ESL_SQ *sq, P7_T
 
 /*------------------- end, pipeline API -------------------------*/
 
-/*****************************************************************
+/************************************************************
 * HMMER - Biological sequence analysis with profile HMMs
- * Version 3.0b3; November 2009
-* Copyright (C) 2009 Howard Hughes Medical Institute.
+* Version 3.0; March 2010
+* Copyright (C) 2010 Howard Hughes Medical Institute.
 * Other copyrights also apply. See the COPYRIGHT file for a full list.
 * 
 * HMMER is distributed under the terms of the GNU General Public License
 * (GPLv3). See the LICENSE file for details.
-*****************************************************************/
+************************************************************/
