@@ -374,27 +374,34 @@ p7_profile_IsMultihit(const P7_PROFILE *gm)
 int
 p7_profile_GetT(const P7_PROFILE *gm, char st1, int k1, char st2, int k2, float *ret_tsc)
 {
-    int   status;
     float tsc = 0.0f;
+    int   status;
 
+    /* Detect transitions that can only come from core traces;
+    * return 0.0 as a special case (this is only done for displaying
+    * "scores" in trace dumps, during debugging.)
+    */
+    if (st1 == p7T_X || st2 == p7T_X) return eslOK;
+    if (st1 == p7T_B && st2 == p7T_I) return eslOK;
+    if (st1 == p7T_B && st2 == p7T_D) return eslOK;
+    if (st1 == p7T_I && st1 == p7T_E) return eslOK;
+
+    /* Now we're sure this is a profile trace, as it should usually be. */
     switch (st1) {
   case p7T_S:  break;
   case p7T_T:  break;
-  case p7T_X:  break; 		/* should only happen on a core trace, with missing data or a fragment. */
-
   case p7T_N:
       switch (st2) {
   case p7T_B: tsc =  gm->xsc[p7P_N][p7P_MOVE]; break;
   case p7T_N: tsc =  gm->xsc[p7P_N][p7P_LOOP]; break;
-  default:     ESL_XEXCEPTION(eslEINVAL, "bad transition %s->%s", p7_hmm_DecodeStatetype(st1), p7_hmm_DecodeStatetype(st2));
+  default:    ESL_XEXCEPTION(eslEINVAL, "bad transition %s->%s", p7_hmm_DecodeStatetype(st1), p7_hmm_DecodeStatetype(st2));
       }
       break;
 
   case p7T_B:
       switch (st2) {
-  case p7T_M:  tsc = p7P_TSC(gm, k2-1, p7P_BM); break; /* remember, B->Mk is stored in [k-1][p7P_BM] */
-    case p7T_X:  tsc = 0.0;                       break; /* should only happen in a core trace, with missing data or fragment */
-  default:     ESL_XEXCEPTION(eslEINVAL, "bad transition %s->%s", p7_hmm_DecodeStatetype(st1), p7_hmm_DecodeStatetype(st2));
+  case p7T_M: tsc = p7P_TSC(gm, k2-1, p7P_BM); break; /* remember, B->Mk is stored in [k-1][p7P_BM] */
+  default:    ESL_XEXCEPTION(eslEINVAL, "bad transition %s->%s", p7_hmm_DecodeStatetype(st1), p7_hmm_DecodeStatetype(st2));
       }
       break;
 
@@ -407,8 +414,7 @@ p7_profile_GetT(const P7_PROFILE *gm, char st1, int k1, char st2, int k2, float
       if (k1 != gm->M && ! p7_profile_IsLocal(gm)) ESL_EXCEPTION(eslEINVAL, "local end transition (M%d of %d) in non-local model", k1, gm->M);
       tsc = 0.0f;		/* by def'n in H3 local alignment */
       break;
-    case p7T_X: tsc = 0.0f; break;
-  default:     ESL_XEXCEPTION(eslEINVAL, "bad transition %s_%d->%s", p7_hmm_DecodeStatetype(st1), k1, p7_hmm_DecodeStatetype(st2));
+  default:    ESL_XEXCEPTION(eslEINVAL, "bad transition %s_%d->%s", p7_hmm_DecodeStatetype(st1), k1, p7_hmm_DecodeStatetype(st2));
       }
       break;
 
@@ -420,8 +426,7 @@ p7_profile_GetT(const P7_PROFILE *gm, char st1, int k1, char st2, int k2, float
       if (k1 != gm->M && ! p7_profile_IsLocal(gm)) ESL_EXCEPTION(eslEINVAL, "local end transition (D%d of %d) in non-local model", k1, gm->M);
       tsc = 0.0f;		/* by def'n in H3 local alignment */
       break;
-    case p7T_X: tsc = 0.0f; break;
-  default:     ESL_XEXCEPTION(eslEINVAL, "bad transition %s_%d->%s", p7_hmm_DecodeStatetype(st1), k1, p7_hmm_DecodeStatetype(st2));
+  default:    ESL_XEXCEPTION(eslEINVAL, "bad transition %s_%d->%s", p7_hmm_DecodeStatetype(st1), k1, p7_hmm_DecodeStatetype(st2));
       }
       break;
 
@@ -429,8 +434,7 @@ p7_profile_GetT(const P7_PROFILE *gm, char st1, int k1, char st2, int k2, float
       switch (st2) {
   case p7T_M: tsc = p7P_TSC(gm, k1, p7P_IM); break;
   case p7T_I: tsc = p7P_TSC(gm, k1, p7P_II); break;
-    case p7T_X: tsc = 0.0f; break;
-  default:     ESL_XEXCEPTION(eslEINVAL, "bad transition %s_%d->%s", p7_hmm_DecodeStatetype(st1), k1, p7_hmm_DecodeStatetype(st2));
+  default:    ESL_XEXCEPTION(eslEINVAL, "bad transition %s_%d->%s", p7_hmm_DecodeStatetype(st1), k1, p7_hmm_DecodeStatetype(st2));
       }
       break;
 
@@ -603,12 +607,12 @@ p7_profile_Compare(P7_PROFILE *gm1, P7_PROFILE *gm2, float tol)
 //    return 0;
 //}
 
-/*****************************************************************
+/************************************************************
 * HMMER - Biological sequence analysis with profile HMMs
- * Version 3.0b3; November 2009
-* Copyright (C) 2009 Howard Hughes Medical Institute.
+* Version 3.0; March 2010
+* Copyright (C) 2010 Howard Hughes Medical Institute.
 * Other copyrights also apply. See the COPYRIGHT file for a full list.
 * 
 * HMMER is distributed under the terms of the GNU General Public License
 * (GPLv3). See the LICENSE file for details.
-*****************************************************************/
+************************************************************/
