@@ -384,9 +384,9 @@ make_digital_msa(ESL_SQ **sq, const ESL_MSA *premsa, P7_TRACE **tr, int nseq, co
     int           idx;
     int           apos;
     int           z;
-    int           status = eslOK;
+    int           status;
 
-    if ((msa = esl_msa_CreateDigital(abc, nseq, alen)) == NULL) goto ERROR; 
+    if ((msa = esl_msa_CreateDigital(abc, nseq, alen)) == NULL) { status = eslEMEM; goto ERROR;  }
 
     for (idx = 0; idx < nseq; idx++)
     {
@@ -404,12 +404,16 @@ make_digital_msa(ESL_SQ **sq, const ESL_MSA *premsa, P7_TRACE **tr, int nseq, co
           break;
 
       case p7T_D:
+          if (matuse[tr[idx]->k[z]]) /* bug h77: if all col is deletes, do nothing; do NOT overwrite a column */
+              msa->ax[idx][matmap[tr[idx]->k[z]]] = esl_abc_XGetGap(abc); /* overwrites ~ in Dk column on X->Dk */
           apos = matmap[tr[idx]->k[z]] + 1;
           break;
 
       case p7T_I:
-          msa->ax[idx][apos] = get_dsq_z(sq, premsa, tr, idx, z);
-          apos++;
+          if ( !(optflags & p7_TRIM) || (tr[idx]->k[z] != 0 && tr[idx]->k[z] != M)) {
+              msa->ax[idx][apos] = get_dsq_z(sq, premsa, tr, idx, z);
+              apos++;
+          }
           break;
 
       case p7T_N:
@@ -424,9 +428,26 @@ make_digital_msa(ESL_SQ **sq, const ESL_MSA *premsa, P7_TRACE **tr, int nseq, co
           apos = matmap[M]+1;	/* set position for C-terminal tail */
           break;
 
-	  case p7T_X:  /* peek at next state for B->X->Ik; superfluous for ->{DM}k; harmless for {MDI}k->X->E  */
-	    apos = matmap[tr[idx]->k[z+1]] + 1; /* this works because all other cases except B->X->Ik set their own apos */
-	    break;
+      case p7T_X: 
+          /* Mark fragments (B->X and X->E containing core traces): 
+          * convert flanks from gaps to ~ 
+          */
+          if (tr[idx]->st[z-1] == p7T_B)
+          { /* B->X leader. This is a core trace and a fragment. Convert leading gaps to ~ */
+              /* to set apos for an initial Ik: peek at next state for B->X->Ik; superfluous for ->{DM}k: */
+              for (apos = 1; apos <= matmap[tr[idx]->k[z+1]]; apos++)
+                  msa->ax[idx][apos] = esl_abc_XGetMissing(abc);
+              /* tricky! apos is now exactly where it needs to be for X->Ik. all other cases except B->X->Ik set their own apos */
+          }
+          else if (tr[idx]->st[z+1] == p7T_E) 
+          { /* X->E trailer. This is a core trace and a fragment. Convert trailing gaps to ~ */
+              /* don't need to set apos for trailer. There can't be any more residues in a core trace once we hit X->E */
+              for (; apos <= alen; apos++)
+                  msa->ax[idx][apos] = esl_abc_XGetMissing(abc);
+          }
+          else ESL_XEXCEPTION(eslECORRUPT, "make_digital_msa(): X state in unexpected position in trace"); 
+
+          break;
 
       default:
           break;
@@ -440,7 +461,7 @@ make_digital_msa(ESL_SQ **sq, const ESL_MSA *premsa, P7_TRACE **tr, int nseq, co
     return eslOK;
 
 ERROR:
-    if (msa != NULL) esl_msa_Destroy(msa);
+    if (msa) esl_msa_Destroy(msa);
     *ret_msa = NULL;
     return status;
 }
@@ -466,9 +487,9 @@ make_text_msa(ESL_SQ **sq, const ESL_MSA *premsa, P7_TRACE **tr, int nseq, const
     int           apos;
     int           z;
     int           k;
-    int           status = eslOK;
+    int           status;
 
-    if ((msa = esl_msa_Create(nseq, alen)) == NULL) goto ERROR;
+    if ((msa = esl_msa_Create(nseq, alen)) == NULL) { status = eslEMEM; goto ERROR; }
 
     for (idx = 0; idx < nseq; idx++)
     {
@@ -482,16 +503,20 @@ make_text_msa(ESL_SQ **sq, const ESL_MSA *premsa, P7_TRACE **tr, int nseq, const
             switch (tr[idx]->st[z]) {
       case p7T_M:
           msa->aseq[idx][-1+matmap[tr[idx]->k[z]]] = toupper(abc->sym[get_dsq_z(sq, premsa, tr, idx, z)]);
-	    apos = matmap[tr[idx]->k[z]]; /* i.e. one past the match column. remember, text mode is 0..alen-1 */
-	    break;
+          apos = matmap[tr[idx]->k[z]]; /* i.e. one past the match column. remember, text mode is 0..alen-1 */
+          break;
 
       case p7T_D:
+          if (matuse[tr[idx]->k[z]]) /* bug #h77: if all column is deletes, do nothing; do NOT overwrite a column */
+              msa->aseq[idx][-1+matmap[tr[idx]->k[z]]] = '-';  /* overwrites ~ in Dk column on X->Dk */
           apos = matmap[tr[idx]->k[z]];
           break;
 
       case p7T_I:
-          msa->aseq[idx][apos] = tolower(abc->sym[get_dsq_z(sq, premsa, tr, idx, z)]);
-          apos++;
+          if ( !(optflags & p7_TRIM) || (tr[idx]->k[z] != 0 && tr[idx]->k[z] != M)) {
+              msa->aseq[idx][apos] = tolower(abc->sym[get_dsq_z(sq, premsa, tr, idx, z)]);
+              apos++;
+          }
           break;
 
       case p7T_N:
@@ -506,9 +531,24 @@ make_text_msa(ESL_SQ **sq, const ESL_MSA *premsa, P7_TRACE **tr, int nseq, const
           apos = matmap[M];	/* set position for C-terminal tail */
           break;
 
-	  case p7T_X: /* see comments in make_digital_msa(); handling of B->X entry and X->E exit is tricky */
-	    apos = matmap[tr[idx]->k[z+1]]; 
-	    break;
+      case p7T_X:
+          /* Mark fragments (B->X and X->E containing core traces): 
+          * convert flanks from gaps to ~ 
+          */
+          if (tr[idx]->st[z-1] == p7T_B)
+          { /* B->X leader. This is a core trace and a fragment. Convert leading gaps to ~ */
+              for (apos = 0; apos < matmap[tr[idx]->k[z+1]]; apos++)
+                  msa->aseq[idx][apos] = '~';
+              /* tricky; apos exactly where it must be for X->Ik; see comments in make_digital_msa() */
+          }
+          else if (tr[idx]->st[z+1] == p7T_E) 
+          { /* X->E trailer. This is a core trace and a fragment. Convert trailing gaps to ~ */
+              for (;  apos < alen; apos++)
+                  msa->aseq[idx][apos] = '~';
+          }
+          else ESL_XEXCEPTION(eslECORRUPT, "make_text_msa(): X state in unexpected position in trace"); 
+
+          break;
 
       default:
           break;
@@ -614,8 +654,10 @@ annotate_posterior_probability(ESL_MSA *msa, P7_TRACE **tr, const int *matmap, i
           break;
 
       case p7T_I:
-          msa->pp[idx][apos] = p7_alidisplay_EncodePostProb(tr[idx]->pp[z]);  
-          apos++;
+          if ( !(optflags & p7_TRIM) || (tr[idx]->k[z] != 0 && tr[idx]->k[z] != M)) {
+              msa->pp[idx][apos] = p7_alidisplay_EncodePostProb(tr[idx]->pp[z]);  
+              apos++;
+          }
           break;
 
       case p7T_N:
@@ -773,12 +815,12 @@ rejustify_insertions_text(const ESL_ALPHABET *abc, ESL_MSA *msa, const int *inse
 
 
 
-/*****************************************************************
+/************************************************************
 * HMMER - Biological sequence analysis with profile HMMs
- * Version 3.0b3; November 2009
-* Copyright (C) 2009 Howard Hughes Medical Institute.
+* Version 3.0; March 2010
+* Copyright (C) 2010 Howard Hughes Medical Institute.
 * Other copyrights also apply. See the COPYRIGHT file for a full list.
 * 
 * HMMER is distributed under the terms of the GNU General Public License
 * (GPLv3). See the LICENSE file for details.
-*****************************************************************/
+************************************************************/
