@@ -8,29 +8,32 @@
 *     for details.
 *****************************************************************/
 
-
 #ifndef _GB2_UHMMER_PHMMER_TASK_H_
 #define _GB2_UHMMER_PHMMER_TASK_H_
 
 #include <QtCore/QList>
 #include <QtCore/QMutex>
 
-#include <core_api/Task.h>
-#include <gobjects/AnnotationTableObject.h>
-#include <datatype/DNASequence.h>
-#include <util_tasks/LoadDocumentTask.h>
-#include <util_tasks/CreateAnnotationTask.h>
+#include <U2Core/Task.h>
+#include <U2Core/AnnotationTableObject.h>
+#include <U2Core/DNASequence.h>
+#include <U2Core/LoadDocumentTask.h>
+#include <U2Core/CreateAnnotationTask.h>
+#include <U2Core/SequenceWalkerTask.h>
 
+#include <search/uHMM3SearchTask.h>
 #include "uhmm3phmmer.h"
 
-namespace GB2 {
+namespace U2 {
 
 /**************************************
-* General hmmer3 phmmer task.
-**************************************/
-
+ * General hmmer3 phmmer task.
+ **************************************/
 class UHMM3PhmmerTask : public Task {
     Q_OBJECT
+public:
+    static DNASequence getSequenceFromDocument( Document * doc, TaskStateInfo & ti );
+    
 public:
     UHMM3PhmmerTask( const DNASequence & query, const DNASequence & db, const UHMM3PhmmerSettings & settings );
     UHMM3PhmmerTask( const QString & queryFilename, const QString & dbFilename, const UHMM3PhmmerSettings & settings );
@@ -44,8 +47,6 @@ public:
     QList< SharedAnnotationData > getResultsAsAnnotations( const QString & name ) const;
     
 private:
-    DNASequence getSequenceFromDocument( Document * doc );
-    
     void addMemResource();
     
 private:
@@ -60,6 +61,50 @@ private:
     
 }; // UHMM3PhmmerTask
 
+/******************************
+ * Sequence walker phmmer
+ ******************************/
+class UHMM3SWPhmmerTask : public Task, SequenceWalkerCallback {
+    Q_OBJECT
+public:
+    static const int DEFAULT_CHUNK_SIZE = 1000000; // 1mb
+    
+public:
+    UHMM3SWPhmmerTask(const QString & queryFilename, const DNASequence & db, 
+                      const UHMM3PhmmerSettings & settings, int chunk = DEFAULT_CHUNK_SIZE);
+    
+    QList<SharedAnnotationData> getResultsAsAnnotations(const QString & name) const;
+    QList<UHMM3SWSearchTaskDomainResult> getResult()const;
+    
+    QList<Task*> onSubTaskFinished(Task* subTask);
+
+    virtual void onRegion(SequenceWalkerSubtask * t, TaskStateInfo & ti);
+    
+    virtual QList<TaskResourceUsage> getResources(SequenceWalkerSubtask * t);
+    
+    ReportResult report();
+
+private:
+    SequenceWalkerTask* getSWSubtask();
+    void checkAlphabets();
+    void setTranslations();
+    
+private:
+    QString             queryFilename;
+    DNASequence         dbSeq;
+    UHMM3PhmmerSettings settings;
+    int                 searchChunkSize;
+    LoadDocumentTask*   loadQueryTask;
+    DNASequence         querySeq;
+    SequenceWalkerTask* swTask;
+    DNATranslation *    complTranslation;
+    DNATranslation *    aminoTranslation;
+    QMutex              writeResultsMtx;
+    QList<UHMM3SWSearchTaskDomainResult> results;
+    QList<UHMM3SWSearchTaskDomainResult> overlaps;
+    
+}; // UHMM3SWPhmmerTask
+
 /*******************************************
 * HMMER3 phmmer search to annotations task.
 ********************************************/
@@ -84,11 +129,11 @@ private:
     QString                             annName;
     UHMM3PhmmerSettings                 settings;
     QPointer< AnnotationTableObject >   annotationObj;
-    UHMM3PhmmerTask *                   phmmerTask;
+    UHMM3SWPhmmerTask *                 phmmerTask;
     CreateAnnotationsTask *             createAnnotationsTask;
     
 }; // UHMM3PhmmerToAnnotationsTask
 
-} // GB2
+} // U2
 
 #endif // _GB2_UHMMER_PHMMER_TASK_H_
