@@ -8,18 +8,17 @@
 *     for details.
 *****************************************************************/
 
-
 #include <QtCore/QByteArray>
 
-#include <core_api/DNAAlphabet.h>
-#include <core_api/DNATranslation.h>
-#include <core_api/AppContext.h>
-#include <core_api/AppResources.h>
-#include <core_api/IOAdapter.h>
-#include <core_api/Counter.h>
-#include <core_api/L10n.h>
-#include <core_api/Log.h>
-#include <gobjects/DNASequenceObject.h>
+#include <U2Core/DNAAlphabet.h>
+#include <U2Core/DNATranslation.h>
+#include <U2Core/AppContext.h>
+#include <U2Core/AppResources.h>
+#include <U2Core/IOAdapter.h>
+#include <U2Core/Counter.h>
+#include <U2Core/L10n.h>
+#include <U2Core/Log.h>
+#include <U2Core/DNASequenceObject.h>
 
 #include <gobject/uHMMObject.h>
 #include <format/uHMMFormat.h>
@@ -30,11 +29,11 @@
 
 #define UHMM3_SEARCH_LOG_CAT "hmm3_search_log_category"
 
-using namespace GB2;
+using namespace U2;
 
-namespace GB2 {
+namespace U2 {
 
-static LogCategory log( UHMM3_SEARCH_LOG_CAT );
+static Logger log( UHMM3_SEARCH_LOG_CAT );
 
 static int countSearchMemInMB( qint64 seqLen, int hmmLen ) {
     return ( ( 77 * seqLen + 10500 * hmmLen ) / ( 1024 * 1024 ) ) + 2;
@@ -60,11 +59,12 @@ static void recountUHMM3SWSearchRegions( UHMM3SearchSeqDomainResult& res, bool i
     recountRegion( res.envRegion, isAmino, isCompl, globalR );
 }
 
-UHMM3SWSearchTask::UHMM3SWSearchTask( const P7_HMM* h, const DNASequence& s, const UHMM3SearchTaskSettings& set )
+UHMM3SWSearchTask::UHMM3SWSearchTask( const P7_HMM* h, const DNASequence& s, const UHMM3SearchTaskSettings& set, int ch )
 : Task( "", TaskFlag_NoRun ), hmm( h ), sequence( s ), settings( set ), 
-  complTranslation( NULL ), aminoTranslation( NULL ), swTask( NULL ), loadHmmTask( NULL ) {
+  complTranslation( NULL ), aminoTranslation( NULL ), swTask( NULL ), loadHmmTask( NULL ), searchChunkSize(ch) {
     GCOUNTER( cvar, tvar, "UHMM3SWSearchTask" );
     
+    assert(searchChunkSize > 0);
     if( NULL == hmm ) {
         setTaskName( tr( "Sequence_walker_HMM_search_task" ) );
         stateInfo.setError( L10N::badArgument( "hmm" ) );
@@ -79,10 +79,11 @@ UHMM3SWSearchTask::UHMM3SWSearchTask( const P7_HMM* h, const DNASequence& s, con
     }
 }
 
-UHMM3SWSearchTask::UHMM3SWSearchTask( const QString& hF, const DNASequence& seq, const UHMM3SearchTaskSettings& s)
+UHMM3SWSearchTask::UHMM3SWSearchTask( const QString& hF, const DNASequence& seq, const UHMM3SearchTaskSettings& s, int ch)
 : Task( "", TaskFlag_NoRun ), hmm( NULL ), sequence( seq ), settings( s ), 
-  complTranslation( NULL ), aminoTranslation( NULL ), swTask( NULL ), loadHmmTask( NULL ), hmmFilename( hF ) {
+  complTranslation( NULL ), aminoTranslation( NULL ), swTask( NULL ), loadHmmTask( NULL ), hmmFilename( hF ), searchChunkSize(ch) {
     
+    assert(searchChunkSize > 0);
     if( hmmFilename.isEmpty() ) {
         setTaskName( tr( "Sequence_walker_HMM_search_task" ) );
         stateInfo.setError( L10N::badArgument( "hmm_filename" ) );
@@ -118,7 +119,7 @@ SequenceWalkerTask* UHMM3SWSearchTask::getSWSubtask() {
     config.strandToWalk         = complTranslation == NULL ? StrandOption_DirectOnly : StrandOption_Both;
     config.aminoTrans           = aminoTranslation;
     /*config.overlapSize          = 2 * hmm->M;
-    config.chunkSize            = qMax( config.overlapSize, SEARCH_CHUNK_SIZE );*/
+    config.chunkSize            = qMax(searchChunkSize, 6 * hmm->M);*/
     config.overlapSize          = 0;
     config.chunkSize            = config.seqSize;
     config.lastChunkExtraLen    = config.chunkSize / 2;
@@ -180,28 +181,50 @@ void UHMM3SWSearchTask::onRegion( SequenceWalkerSubtask* t, TaskStateInfo& ti )
     
     const char* seq = t->getRegionSequence();
     int seqLen      = t->getRegionSequenceLen();
-    bool isComl     = t->isDNAComplemented();
-    bool isAmino    = t->isAminoTranslated();
-    LRegion globalRegion = t->getGlobalRegion();
     
     UHMM3SearchTaskLocalStorage::createTaskContext( t->getTaskId() );
-    UHMM3SearchResult generalRes = UHMM3Search::search( hmm, seq, seqLen, settings.inner, ti );
+    int wholeSeqSz = t->getGlobalConfig().seqSize;
+    wholeSeqSz = t->isAminoTranslated() ? (wholeSeqSz / 3) : wholeSeqSz;
+    UHMM3SearchResult generalRes = UHMM3Search::search( hmm, seq, seqLen, settings.inner, ti, wholeSeqSz );
     if( ti.hasErrors() ) {
         UHMM3SearchTaskLocalStorage::freeTaskContext( t->getTaskId() );
         return;
     }
     
     QMutexLocker locker( &writeResultsMtx );
-    foreach( const UHMM3SearchSeqDomainResult& domainRes, generalRes.domainResList ) {
+    writeResults(generalRes.domainResList, t, results, overlaps, hmm->M);
+    UHMM3SearchTaskLocalStorage::freeTaskContext( t->getTaskId() );
+}
+
+void UHMM3SWSearchTask::writeResults(const QList<UHMM3SearchSeqDomainResult> & domains, SequenceWalkerSubtask * t, 
+        QList<UHMM3SWSearchTaskDomainResult> & results, QList<UHMM3SWSearchTaskDomainResult> & overlaps, int halfOverlap) {
+    bool isCompl     = t->isDNAComplemented();
+    bool isAmino    = t->isAminoTranslated();
+    LRegion globalRegion = t->getGlobalRegion();
+    foreach( const UHMM3SearchSeqDomainResult& domainRes, domains ) {
         UHMM3SWSearchTaskDomainResult res;
         res.generalResult = domainRes;
-        res.onCompl = isComl;
+        res.onCompl = isCompl;
         res.onAmino = isAmino;
-        recountUHMM3SWSearchRegions( res.generalResult, isAmino, isComl, globalRegion );
-        results.append( res );
+        recountUHMM3SWSearchRegions( res.generalResult, isAmino, isCompl, globalRegion );
+        if(t->intersectsWithOverlaps(res.generalResult.seqRegion)) {
+            bool add = true;
+            if(!res.onCompl && t->hasRightOverlap()) { // if it will be found in a next chunk
+                    LRegion nextChunkRegion(globalRegion.endPos() - halfOverlap, halfOverlap);
+                    add = !nextChunkRegion.contains(res.generalResult.seqRegion);
+            } else if(res.onCompl && t->hasLeftOverlap()) { // if it will be found on prev chunk
+                LRegion prevChunkRegion(globalRegion.startPos, halfOverlap);
+                add = !prevChunkRegion.contains(res.generalResult.seqRegion);
+            }
+            if(add) {
+                res.borderResult = (t->hasLeftOverlap() && res.generalResult.seqRegion.startPos == globalRegion.startPos) ||
+                    (t->hasRightOverlap() && res.generalResult.seqRegion.endPos() == globalRegion.endPos());
+                overlaps.append(res);
+            }
+        } else { // no intersections
+         results.append( res );
+        }
     }
-    
-    UHMM3SearchTaskLocalStorage::freeTaskContext( t->getTaskId() );
 }
 
 QList< TaskResourceUsage > UHMM3SWSearchTask::getResources( SequenceWalkerSubtask * t ) {
@@ -211,14 +234,84 @@ QList< TaskResourceUsage > UHMM3SWSearchTask::getResources( SequenceWalkerSubtas
     QList< TaskResourceUsage > res;
     int howManyMem = countSearchMemInMB( t->getRegionSequenceLen(), hmm->M );
     res << TaskResourceUsage( RESOURCE_MEMORY, howManyMem );
-    
     log.trace( QString( "%1 needs %2 of memory" ).arg( getTaskName() ).arg( howManyMem ) );
-    
     return res;
 }
 
+/* Same as in HMMSearchTask */
+void
+UHMM3SWSearchTask::processOverlaps(QList<UHMM3SWSearchTaskDomainResult> & overlaps, 
+                                   QList<UHMM3SWSearchTaskDomainResult> & results, int maxCommonLen) {
+    for(int i = 0; i < overlaps.count(); ++i){
+        UHMM3SWSearchTaskDomainResult & r1 = overlaps[i];
+        if (r1.filtered) {
+            continue;
+        }
+        for(int j = i + 1; j < overlaps.count(); ++j){
+            UHMM3SWSearchTaskDomainResult & r2 = overlaps[j];
+            if (r2.filtered) {
+                continue;
+            }
+            if (r1.onCompl != r2.onCompl) { //check both regions are on the same strand
+                continue;
+            }
+            if (r1.onAmino) { //check both regions have the same amino frame
+                int s1 = r1.onCompl ? r1.generalResult.seqRegion.endPos() % 3 : r1.generalResult.seqRegion.startPos % 3;
+                int s2 = r2.onCompl ? r2.generalResult.seqRegion.endPos() % 3 : r2.generalResult.seqRegion.startPos % 3;
+                if (s1 != s2) {
+                    continue;
+                }
+            }
+            if (r1.generalResult.seqRegion.contains(r2.generalResult.seqRegion) && 
+                r1.generalResult.seqRegion != r2.generalResult.seqRegion) {
+                    r2.filtered = true;
+            } else if (r2.generalResult.seqRegion.contains(r1.generalResult.seqRegion) && 
+                r2.generalResult.seqRegion != r1.generalResult.seqRegion) {
+                    r1.filtered = true;
+                    break;
+            } else if (r1.generalResult.seqRegion.intersect(r2.generalResult.seqRegion).len >= maxCommonLen) {
+                bool useR1 = r2.generalResult.score <= r1.generalResult.score;
+                if (r1.generalResult.score == r2.generalResult.score && r1.generalResult.ival == r2.generalResult.ival
+                    && r1.borderResult && !r2.borderResult) {
+                        useR1 = false;
+                }
+                if (useR1) {
+                    r2.filtered = true;
+                } else {
+                    r1.filtered = true;
+                    break;
+                }
+            }
+        }
+    }
+    
+    foreach(const UHMM3SWSearchTaskDomainResult& r, overlaps) {
+        if (!r.filtered) {
+            results.append(r);
+        }
+    }
+}
+
+bool
+UHMM3SWSearchTask::uhmm3SearchDomainResultLessThan(const UHMM3SWSearchTaskDomainResult & r1, const UHMM3SWSearchTaskDomainResult & r2) {
+    if( r1.generalResult.score == r2.generalResult.score ) {
+        if(r1.generalResult.seqRegion == r2.generalResult.seqRegion) {
+            if( r1.onCompl == r2.onCompl ) {
+                return &r1 < &r2;
+            }
+            return r2.onCompl;
+        }
+        return r1.generalResult.seqRegion < r2.generalResult.seqRegion;
+    }
+    return r1.generalResult.score > r2.generalResult.score;
+}
+
 Task::ReportResult UHMM3SWSearchTask::report() {
-    /* post process overlaps filter here - we don't need it yet */
+    if(hasErrors()) {
+        return ReportResult_Finished;
+    }
+    processOverlaps(overlaps, results, hmm->M / 2);
+    qSort(results.begin(), results.end(), uhmm3SearchDomainResultLessThan);
     return ReportResult_Finished;
 }
 
@@ -273,12 +366,12 @@ bool UHMM3SWSearchTask::setTranslations( int hmmAl, DNAAlphabet* seqAl ) {
     return true;
 }
 
-UHMM3SWSearchTaskResult UHMM3SWSearchTask::getResults() const {
+QList<UHMM3SWSearchTaskDomainResult> UHMM3SWSearchTask::getResults() const {
     return results;
 }
 
-QList< SharedAnnotationData > UHMM3SWSearchTask::getResultsAsAnnotations( const UHMM3SWSearchTaskResult & results, const P7_HMM * hmm,
-                                                                         const QString & name ) {
+QList< SharedAnnotationData >
+UHMM3SWSearchTask::getResultsAsAnnotations( const QList<UHMM3SWSearchTaskDomainResult> & results, const P7_HMM * hmm, const QString & name ) {
     assert( !name.isEmpty() );
     QList< SharedAnnotationData > annotations;
     
@@ -286,7 +379,7 @@ QList< SharedAnnotationData > UHMM3SWSearchTask::getResultsAsAnnotations( const
         AnnotationData * annData = new AnnotationData();
         annData->name = name;
         annData->complement = res.onCompl;
-        annData->aminoStrand = res.onAmino ? TriState_Yes :TriState_No;
+        annData->aminoFrame = res.onAmino ? TriState_Yes :TriState_No;
         annData->location << res.generalResult.seqRegion;
         
         assert( NULL != hmm );
@@ -401,7 +494,7 @@ void UHMM3SearchTask::run() {
     assert( NULL != hmm );
     
     UHMM3SearchTaskLocalStorage::createTaskContext( getTaskId() );
-    result = UHMM3Search::search( hmm, seq, seqLen, settings.inner, stateInfo );
+    result = UHMM3Search::search( hmm, seq, seqLen, settings.inner, stateInfo, seqLen );
     UHMM3SearchTaskLocalStorage::freeTaskContext( getTaskId() );
 }
 
@@ -562,4 +655,4 @@ QList< Task* > UHMM3SWSearchToAnnotationsTask::onSubTaskFinished( Task * subTask
     return res;
 }
 
-} // GB2
+} // U2
