@@ -8,13 +8,12 @@
 *     for details.
 *****************************************************************/
 
-
 #ifndef _GB2_HMMER3_SEARCH_TL_DATA_H_
 #define _GB2_HMMER3_SEARCH_TL_DATA_H_
 
 #include <hmmer3/p7_config.h>
 
-namespace GB2 {
+namespace U2 {
 
 struct UHMM3SearchTaskLocalData {
     float flogsum_lookup[p7_LOGSUM_TBL];
@@ -22,6 +21,6 @@ struct UHMM3SearchTaskLocalData {
     UHMM3SearchTaskLocalData();
 }; // UHMM3SearchTaskLocalData
 
-} // GB2
+} // U2
 
 #endif // _GB2_HMMER3_SEARCH_TL_DATA_H_
