@@ -8,7 +8,6 @@
 *     for details.
 *****************************************************************/
 
-
 #ifndef _GB2_HMMER3_SEARCH_TLS_H_
 #define _GB2_HMMER3_SEARCH_TLS_H_
 
@@ -18,7 +17,7 @@
 
 #include "uHMMSearchTaskLocalData.h"
 
-namespace GB2 {
+namespace U2 {
 
 struct ContextId {
     ContextId( qint64 what ) : id( what ) {}
@@ -41,6 +40,6 @@ private:
     
 }; // UHMMSearchTaskLocalStorage
 
-} // GB2
+} // U2
 
 #endif // _GB2_HMMER3_SEARCH_TLS_H_
