@@ -8,25 +8,19 @@
 *     for details.
 *****************************************************************/
 
+#include "uhmmer3SearchTests.h"
+#include <gobject/uHMMObject.h>
 
-#include <memory>
+#include <U2Core/DocumentModel.h>
+#include <U2Core/IOAdapter.h>
+#include <U2Core/AppContext.h>
+#include <U2Core/DNASequenceObject.h>
+#include <U2Core/TextUtils.h>
 
 #include <QtCore/QList>
+#include <memory>
 
-#include <core_api/DocumentModel.h>
-#include <core_api/IOAdapter.h>
-#include <core_api/AppContext.h>
-#include <gobjects/DNASequenceObject.h>
-#include <gobject/uHMMObject.h>
-#include <util_text/TextUtils.h>
-
-#include <search/uHMM3SearchLocalTask.h>
-#include <distributed_computing/RemoteTask.h>
-#include <distributed_computing/SerializeUtils.h>
-
-#include "uhmmer3SearchTests.h"
-
-namespace GB2 {
+namespace U2 {
 
 /*******************************
 * GTest_GeneralUHMM3Search
@@ -36,6 +30,7 @@ const QString GTest_UHMM3Search::SEQ_DOC_CTX_NAME_TAG        = "seqDoc";
 const QString GTest_UHMM3Search::HMM_FILENAME_TAG            = "hmm";
 const QString GTest_UHMM3Search::HMMSEARCH_TASK_CTX_NAME_TAG = "taskCtxName";
 const QString GTest_UHMM3Search::ALGORITHM_TYPE_OPTION_TAG   = "algo";
+const QString GTest_UHMM3Search::SW_CHUNK_SIZE_OPTION_TAG    = "chunk";
 
 const QString GTest_UHMM3Search::SEQ_E_OPTION_TAG            = "seqE";
 const QString GTest_UHMM3Search::SEQ_T_OPTION_TAG            = "seqT";
@@ -179,12 +174,21 @@ void GTest_UHMM3Search::init( XMLTestFormat *tf, const QDomElement& el ) {
 
     searchTaskToCtx     = NULL;
     hmm = NULL;
-    machine = NULL;
     
     seqDocCtxName = el.attribute( SEQ_DOC_CTX_NAME_TAG );
     setSearchAlgoType( algo, el.attribute( ALGORITHM_TYPE_OPTION_TAG ) );
     setSearchTaskSettings( settings.inner, el, stateInfo );
     
+    swChunk = UHMM3SWSearchTask::DEFAULT_CHUNK_SIZE;
+    QString chunkStr = el.attribute(SW_CHUNK_SIZE_OPTION_TAG);
+    if( !chunkStr.isEmpty() ) {
+        bool ok = false;
+        int candidate = chunkStr.toInt(&ok);
+        if(ok && candidate > 0) {
+            swChunk = candidate;
+        }
+    }
+    
     cleanuped = false;
     ctxAdded = false;
     
@@ -257,7 +261,7 @@ void GTest_UHMM3Search::prepare() {
         break;
     case SEQUENCE_WALKER_SEARCH:
         if( machinePath.isEmpty() ) { /* search task on local machine */
-            searchTaskToCtx = new UHMM3SWSearchTask( hmmFilename, sequence, settings );
+            searchTaskToCtx = new UHMM3SWSearchTask( hmmFilename, sequence, settings, swChunk );
             addSubTask( searchTaskToCtx );
         } else { /* search on remote machine */
             addSubTask( LoadDocumentTask::getDefaultLoadDocTask( hmmFilename ) );
@@ -282,14 +286,6 @@ QList< Task* > GTest_UHMM3Search::onSubTaskFinished( Task * sub ) {
     
     hmm = takeHmmFromDoc( loadHmmTask->getDocument() );
     assert( NULL != hmm );
-    UHMM3SearchLocalTaskSettings localTaskSettings( settings, hmm, sequence );
-    if( !SerializeUtils::deserializeRemoteMachineSettingsFromFile( machinePath, &machine ) ) {
-        assert( NULL == machine );
-        setError( "cannot_create_remote_machine" );
-        return res;
-    }
-    searchTaskToCtx = new RemoteTask( UHMM3SearchLocalTaskFactory::ID, localTaskSettings, machine );
-    res << searchTaskToCtx;
     return res;
 }
 
@@ -315,7 +311,6 @@ void GTest_UHMM3Search::cleanup() {
     if( NULL != hmm ) {
         p7_hmm_Destroy( hmm );
     }
-    delete machine;
     cleanuped = true;
 }
 
@@ -400,24 +395,24 @@ static UHMM3SearchSeqDomainResult getDomainRes( QStringList& tokens ) {
 
     int hmmFrom = (int)getFloat( getNextToken( tokens ) );
     int hmmTo   = (int)getFloat( getNextToken( tokens ) );
-    res.queryRegion = LRegion( hmmFrom, hmmTo - hmmFrom + 1 );
+    res.queryRegion = LRegion( hmmFrom, hmmTo - hmmFrom );
     getNextToken( tokens );
 
     int aliFrom = (int)getFloat( getNextToken( tokens ) );
     int aliTo   = (int)getFloat( getNextToken( tokens ) );
-    res.seqRegion = LRegion( aliFrom, aliTo - aliFrom + 1 );
+    res.seqRegion = LRegion( aliFrom - 1, aliTo - aliFrom + 1 );
     getNextToken( tokens );
 
     int envFrom = (int)getFloat( getNextToken( tokens ) );
     int envTo   = (int)getFloat( getNextToken( tokens ) );
-    res.envRegion = LRegion( envFrom, envTo - envFrom + 1 );
+    res.envRegion = LRegion( envFrom, envTo - envFrom );
     getNextToken( tokens );
 
     res.acc = getDouble( getNextToken( tokens ) );
     return res;
 }
 
-const double COMPARE_PERCENT_BORDER = 0.02; // 2 percents
+const double COMPARE_PERCENT_BORDER = 0.01; // 1 percent
 
 template<class T>
 static bool compareNumbers( T f1, T f2 ) {
@@ -512,30 +507,63 @@ void GTest_UHMM3SearchCompare::generalCompareResults( const UHMM3SearchResult& m
     }
 }
 
-/* we don't compare seq and env regions here - it doesn't make sense */
-static bool findDomainInSWResult( const UHMM3SWSearchTaskResult& res, const UHMM3SearchSeqDomainResult& dRes ) {
-    foreach( const UHMM3SWSearchTaskDomainResult& domainRes, res ) {
-        UHMM3SearchSeqDomainResult dom = domainRes.generalResult;
-        if( !compareNumbers<double>( dom.acc, dRes.acc ) )    { continue; }
-        if( !compareNumbers<float>( dom.bias, dRes.bias ) )   { continue; }
-        if( !compareNumbers<double>( dom.cval, dRes.cval ) )  { continue; }
-        if( !compareNumbers<double>( dom.ival, dRes.ival ) )  { continue; }
-        if( !compareNumbers<float>( dom.score, dRes.score ) ) { continue; }
-        if( dom.queryRegion != dRes.queryRegion ) { continue; }
-        if( dom.isSignificant != dRes.isSignificant ) { continue; }
-        return true;
+static QList<int>
+findEqualDomain(const QList<UHMM3SWSearchTaskDomainResult>& res, const UHMM3SearchSeqDomainResult & dres, bool compareSeqRegion) {
+    QList<int> diff;
+    for(int i = 0; i < res.size(); ++i) {
+        UHMM3SearchSeqDomainResult dom = res.at(i).generalResult;
+        int count = 0;
+        if( !compareNumbers<double>( dom.acc, dres.acc ) )    { count++; }
+        if( !compareNumbers<float>( dom.bias, dres.bias ) )   { count++; }
+        if( !compareNumbers<double>( dom.cval, dres.cval ) )  { count++; }
+        if( !compareNumbers<double>( dom.ival, dres.ival ) )  { count++; }
+        if( !compareNumbers<float>( dom.score, dres.score ) ) { count++; }
+        if( dom.queryRegion != dres.queryRegion ) { count++; }
+        if( compareSeqRegion && dom.seqRegion != dres.seqRegion ) { count++; }
+        if( compareSeqRegion && dom.envRegion != dres.envRegion ) { count++; }
+        if( dom.isSignificant != dres.isSignificant ) { count++; }
+        diff << count;
     }
-    return false;
+    return diff;
+}
+
+static QString seqDomainResult2String(const UHMM3SearchSeqDomainResult & r) {
+    return QString("score=%1, eval=%2, bias=%3, acc=%4, query=%5 seq=%6").arg(r.score).arg(r.ival).arg(r.bias).arg(r.acc).
+        arg(QString("%1..%2").arg(r.queryRegion.startPos).arg(r.queryRegion.endPos())).
+        arg(QString("%1..%2").arg(r.seqRegion.startPos).arg(r.seqRegion.endPos()));
 }
 
 /* we compare here that every domain of trueResult is included in myResult */
-void GTest_UHMM3SearchCompare::swCompareResults( const UHMM3SWSearchTaskResult& myR, const UHMM3SearchResult& trueR, TaskStateInfo& ti ) {
+void
+GTest_UHMM3SearchCompare::swCompareResults( const QList<UHMM3SWSearchTaskDomainResult>& myR, const UHMM3SearchResult& trueR, 
+                                            TaskStateInfo& ti, bool compareSeqRegion ) {
     int sz = trueR.domainResList.size();
     int i = 0;
     for( i = 0; i < sz; ++i ) {
-        bool ok = findDomainInSWResult( myR, trueR.domainResList.at( i ) );
-        if( !ok ) {
-            ti.setError( QString( "cannot_find_#%1_result" ).arg( i ) );
+        const UHMM3SearchSeqDomainResult & trueDom = trueR.domainResList.at(i);
+        if(trueDom.score < 2) {
+            continue;
+        }
+        QList<int> diff = findEqualDomain(myR, trueDom, compareSeqRegion);
+        if(!diff.contains(0)) {
+            int minPos = 0;
+            int min = 1000000;
+            for(int j = 0; j < myR.size(); ++j) {
+                float d = qAbs(myR.at(j).generalResult.score - trueR.domainResList.at(i).score);
+                if( d < min ) {
+                    min = d;
+                    minPos = j;
+                }
+            }
+            if(!myR.isEmpty()) {
+                ti.setError( QString( "Cannot find result #%1: %2, most close result: %3" ).
+                    arg(i).
+                    arg(seqDomainResult2String(trueR.domainResList.at(i))).
+                    arg(seqDomainResult2String(myR.at(minPos).generalResult)));
+            } else {
+                ti.setError( QString( "Cannot find result #%1: %2" ).
+                    arg(i).arg(seqDomainResult2String(trueR.domainResList.at(i))));
+            }
             return;
         }
     }
@@ -573,17 +601,26 @@ void GTest_UHMM3SearchCompare::setAndCheckArgs() {
     
     generalTask = qobject_cast< UHMM3SearchTask*    >( searchTask );
     swTask      = qobject_cast< UHMM3SWSearchTask*  >( searchTask );
-    remoteSearchTask = qobject_cast< RemoteTask* >( searchTask );
     
     if( NULL != generalTask ) {
         algo = GENERAL_SEARCH;
-    } else if( NULL != swTask || NULL != remoteSearchTask ) {
+    } else if (NULL != swTask) {
         algo = SEQUENCE_WALKER_SEARCH;
     } else {
         assert( 0 && "cannot_cast_task_to_search_task" );
     }
 }
 
+bool GTest_UHMM3SearchCompare::searchResultLessThan(const UHMM3SearchSeqDomainResult & r1, const UHMM3SearchSeqDomainResult & r2) {
+    if( r1.score == r2.score ) {
+        if(r1.seqRegion == r2.seqRegion) {
+            return &r1 < &r2;
+        }
+        return r1.seqRegion < r2.seqRegion;
+    }
+    return r1.score > r2.score;
+}
+
 UHMM3SearchResult GTest_UHMM3SearchCompare::getOriginalSearchResult( const QString & filename ) {
     assert( !filename.isEmpty() );
     
@@ -685,18 +722,13 @@ Task::ReportResult GTest_UHMM3SearchCompare::report() {
         break;
     case SEQUENCE_WALKER_SEARCH:
         {
-            UHMM3SWSearchTaskResult result;
+            QList<UHMM3SWSearchTaskDomainResult> result;
             if( NULL != swTask ) {
                 result = swTask->getResults();
-            } else if( NULL != remoteSearchTask ) {
-                LocalTaskResult * ltr = remoteSearchTask->getResult();
-                UHMM3SearchLocalTaskResult * hmmLocalTaskRes = 
-                    dynamic_cast< UHMM3SearchLocalTaskResult* >( ltr );
-                assert( NULL != hmmLocalTaskRes );
-                result = hmmLocalTaskRes->getResult();
             } else {
                 assert( false );
             }
+            qSort(trueRes.domainResList.begin(), trueRes.domainResList.end(), searchResultLessThan);
             swCompareResults( result, trueRes, stateInfo );
         }
         break;
@@ -707,4 +739,4 @@ Task::ReportResult GTest_UHMM3SearchCompare::report() {
     return ReportResult_Finished;
 }
 
-} // GB2
+} // U2
