@@ -8,14 +8,13 @@
 *     for details.
 *****************************************************************/
 
-
 #ifndef _GB2_UHMMER3_TESTS_H_
 #define _GB2_UHMMER3_TESTS_H_
 
-#include <test_framework/xmltest/XMLTestFormat.h>
 #include <QtCore/QList>
+#include <U2Test/XMLTestFormat.h>
 
-namespace GB2 {
+namespace U2 {
 
 class UHMMER3Tests {
 public:
