@@ -8,19 +8,18 @@
 *     for details.
 *****************************************************************/
 
-
 #ifndef _GB2_UHMM3_UTILITIES_H_
 #define _GB2_UHMM3_UTILITIES_H_
 
-#include <core_api/DocumentModel.h>
-#include <core_api/DNAAlphabet.h>
-#include <datatype/MAlignment.h>
+#include <U2Core/DocumentModel.h>
+#include <U2Core/DNAAlphabet.h>
+#include <U2Core/MAlignment.h>
 
 #include <hmmer3/hmmer.h>
 #include <hmmer3/easel/esl_scorematrix.h>
 #include <hmmer3/easel/esl_msa.h>
 
-namespace GB2 {
+namespace U2 {
 
 class SMatrix;
 
@@ -39,6 +38,6 @@ public:
     
 }; // UHMM3Utilities
 
-} // GB2
+} // U2
 
 #endif // _GB2_UHMM3_UTILITIES_H_
