@@ -8,12 +8,12 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_KALIGN_ADAPTER_H_
-#define _GB2_KALIGN_ADAPTER_H_
+#ifndef _U2_KALIGN_ADAPTER_H_
+#define _U2_KALIGN_ADAPTER_H_
 
 #include <QtCore/QObject>
 
-namespace GB2 {
+namespace U2 {
 
 class MAlignment;
 class TaskStateInfo;
