@@ -8,10 +8,8 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_KALIGN_CONSTANTS_H_
-#define _GB2_KALIGN_CONSTANTS_H_
-
-#define ULOG_CAT_KALIGN "Plugin: Kalign"
+#ifndef _U2_KALIGN_CONSTANTS_H_
+#define _U2_KALIGN_CONSTANTS_H_
 
 #endif
 
