@@ -14,10 +14,10 @@
 #include <string.h>
 
 extern "C" void throwKalignException(char *message) {
-	throw GB2::KalignException(message);
+	throw U2::KalignException(message);
 }
 
-namespace GB2 {
+namespace U2 {
 
 KalignException::KalignException(const char* _str) {
 	int len = strlen(_str);
@@ -30,4 +30,4 @@ KalignException::KalignException() {
 	memset(str, 4096, '\0');
 }
 
-} // namespace GB2
+} // namespace U2
