@@ -8,10 +8,10 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_KALIGN_CONTEXT_H_
-#define _GB2_KALIGN_CONTEXT_H_
+#ifndef _U2_KALIGN_CONTEXT_H_
+#define _U2_KALIGN_CONTEXT_H_
 
-namespace GB2 {
+namespace U2 {
 
 struct KalignException {
 	KalignException();
@@ -19,7 +19,7 @@ struct KalignException {
 	char str[4096];
 };
 
-} //namespace GB2
+} //namespace U2
 
-#endif //_GB2_KALIGN_CONTEXT_H_
+#endif //_U2_KALIGN_CONTEXT_H_
 
