@@ -9,7 +9,7 @@
 *****************************************************************/
 
 #include "KalignUtils.h"
-#include "core_api/Task.h"
+#include <U2Core/Task.h>
 
 extern "C" {
 
@@ -27,20 +27,20 @@ char* k_printf(const char *format, ...) {
 	int n = vsprintf(str, format, ArgList);
 	assert(n>=0 && n < 1024);
 	Q_UNUSED(n);
-	GB2::setTaskDesc(get_kalign_context(), str);
+	U2::setTaskDesc(get_kalign_context(), str);
 	return str;
 }
 
 void set_task_progress(int percent) {
-	GB2::setTaskProgress(get_kalign_context(),percent);
+	U2::setTaskProgress(get_kalign_context(),percent);
 }
 
 int check_task_canceled(kalign_context *ctx) {
-	return GB2::isCanceled(ctx);
+	return U2::isCanceled(ctx);
 }
 };
 
-namespace GB2 {
+namespace U2 {
 
 void setTaskProgress(struct kalign_context* ctx, int percent) {
 	((TaskStateInfo*)ctx->ptask_state)->progress = percent;
@@ -55,5 +55,5 @@ bool isCanceled(struct kalign_context* ctx) {
 	return ((TaskStateInfo*)ctx->ptask_state)->cancelFlag;
 }
 
-} //namespace GB2
+} //namespace U2
 
