@@ -13,14 +13,14 @@
 
 struct kalign_context;
 
-namespace GB2 {
+namespace U2 {
 
 void setTaskProgress(struct kalign_context* ctx, int percent);
 
 void setTaskDesc(struct kalign_context* ctx, const char *str);
 
 bool isCanceled(struct kalign_context* ctx);
-} // namespace GB2
+} // namespace U2
 
 #endif // _KALIGN_UTILS_H_
 
