@@ -11,13 +11,13 @@
 #ifndef _DIST_MATRIX_MODEL_WIDGET_H_
 #define _DIST_MATRIX_MODEL_WIDGET_H_
 
+#include <U2View/CreatePhyTreeWidget.h>
 #include "ui/ui_DistMatrixModel.h"
-#include <phyltree/CreatePhyTreeDialogController.h>
-#include <core_api/DNAAlphabet.h>
-#include <datatype/MAlignment.h>
+
+#include <U2Core/MAlignment.h>
 
 
-namespace GB2{
+namespace U2{
 
 class DistMatrixModelWidget : public CreatePhyTreeWidget, Ui_DistMatrixModel {
     Q_OBJECT
