@@ -8,17 +8,17 @@
 *     for details.
 *****************************************************************/
 
-#include <datatype/PhyTree.h>
-
-#ifndef _GB2_NEIGHBORJOIN_ADAPTER_H_
-#define _GB2_NEIGHBORJOIN_ADAPTER_H_
+#ifndef _U2_NEIGHBORJOIN_ADAPTER_H_
+#define _U2_NEIGHBORJOIN_ADAPTER_H_
 
 #include <QtCore/QObject>
-#include <core_api/SubstMatrixRegistry.h>
-#include <phyltree/PhyTreeGenerator.h>
-#include <phyltree/CreatePhyTreeSettings.h>
 
-namespace GB2 { 
+#include <U2Core/PhyTree.h>
+#include <U2Algorithm/SubstMatrixRegistry.h>
+#include <U2View/CreatePhyTreeDialogController.h>
+#include <U2Algorithm/PhyTreeGenerator.h>
+
+namespace U2 { 
 
 	class MAlignment;
 	class TaskStateInfo;
