@@ -11,13 +11,13 @@
 #ifndef  _NEIGHBORJOIN_PLUGIN_H_
 #define  _NEIGHBORJOIN_PLUGIN_H_
 
-#include <core_api/PluginModel.h>
-#include <core_api/AppContext.h>
-#include <core_api/ObjectViewModel.h>
+#include <U2Core/PluginModel.h>
+#include <U2Core/AppContext.h>
+#include <U2Gui/ObjectViewModel.h>
 
 #include <QtGui/QMenu>
 
-namespace GB2 {
+namespace U2 {
 
 
 class PhylipPlugin : public Plugin {
