@@ -10,15 +10,15 @@
 
 #ifndef _NEIGHBORJOINTESTS_H
 #define _NEIGHBORJOINTESTS_H
-#include <test_framework/xmltest/XMLTestUtils.h>
-#include <core_api/GObject.h>
-#include <phyltree/PhyTreeGeneratorTask.h>
+#include <U2Test/XMLTestUtils.h>
+#include <U2Core/GObject.h>
+#include <U2Algorithm/PhyTreeGeneratorTask.h>
 
 #include <QtXml/QDomElement>
 #include <QFileInfo>
 #include <QList>
 
-namespace GB2{
+namespace U2{
 
 class PhyTreeObject;
 class MAlignmentObject;
