@@ -16,22 +16,22 @@
    Permission is granted to copy and use this program provided no fee is
    charged for it and provided that this copyright notice is not removed. */
 
-#include <phyltree/CreatePhyTreeSettings.h>
-#include <core_api/Task.h>
+#include <U2Algorithm/CreatePhyTreeSettings.h>
+#include <U2Core/Task.h>
 
 QString DNADistModelTypes::F84("F84");
 QString DNADistModelTypes::Kimura("Kimura");
 QString DNADistModelTypes::JukesCantor("Jukes-Cantor");
 QString DNADistModelTypes::LogDet("LogDet");
-static GB2::CreatePhyTreeSettings dnaDistSettings;
+static U2::CreatePhyTreeSettings dnaDistSettings;
 
-void GB2::setDNADistSettings( const CreatePhyTreeSettings& settings )
+void U2::setDNADistSettings( const CreatePhyTreeSettings& settings )
 {
     dnaDistSettings = settings;
 
 }
 
-const GB2::CreatePhyTreeSettings& getDNADistSettings()
+const U2::CreatePhyTreeSettings& getDNADistSettings()
 {
     //TODO: use mutex here later
     return dnaDistSettings;
@@ -1280,7 +1280,7 @@ void makedists()
       d[i - 1][j - 1] = v;
       d[j - 1][i - 1] = v;
       
-      GB2::TaskStateInfo* ts = GB2::getTaskInfo();
+      U2::TaskStateInfo* ts = U2::getTaskInfo();
       if (ts->cancelFlag != 0) {
           ugene_exit("Task canceled!");
       } else {
