@@ -24,9 +24,9 @@
 
 #include "phylip.h"
 
-#include <core_api/Task.h>
+#include <U2Core/Task.h>
 
-namespace GB2 {
+namespace U2 {
 
 static TaskStateInfo* ts = NULL;
   
