@@ -41,7 +41,7 @@
 void ugene_exit(const char* message) throw();
 
 
-namespace GB2 {
+namespace U2 {
 
     class TaskStateInfo;
 
