@@ -13,8 +13,8 @@
 #include "protdist.h"
 #include "dnadist.h"
 
-#include <phyltree/CreatePhyTreeSettings.h>
-#include <core_api/Task.h>
+#include <U2Algorithm/CreatePhyTreeSettings.h>
+#include <U2Core/Task.h>
 
 /* version 3.6. (c) Copyright 1993-2004 by the University of Washington.
    Written by Joseph Felsenstein, Akiko Fuseki, Sean Lamont, and Andrew Keeffe.
@@ -511,7 +511,7 @@ void transition()
 }  /* transition */
 
 
-void prot_doinit(const GB2::CreatePhyTreeSettings& settings)
+void prot_doinit(const U2::CreatePhyTreeSettings& settings)
 {
   /* initializes variables */
   protdist_inputnumbers();
@@ -1543,7 +1543,7 @@ void prot_makedists()
       d[i - 1][j] = fracchange * tt;
       d[j][i - 1] = d[i - 1][j];
       
-      GB2::TaskStateInfo* ts = GB2::getTaskInfo();
+      U2::TaskStateInfo* ts = U2::getTaskInfo();
       if (ts->cancelFlag != 0) {
           ugene_exit("Task canceled!");
       } else {
