@@ -11,7 +11,7 @@
 #ifndef PROTDIST_H
 #define PROTDIST_H
 
-#include <phyltree/CreatePhyTreeSettings.h>
+#include <U2Algorithm/CreatePhyTreeSettings.h>
 
 #include <QList>
 #include <QString>
@@ -44,7 +44,7 @@ void   protdist_uppercase(Phylip_Char *);
 void   protdist_inputnumbers(void);
 void   prot_getoptions(const QString& matModel);
 void   transition(void);
-void   prot_doinit(const GB2::CreatePhyTreeSettings& settings);
+void   prot_doinit(const U2::CreatePhyTreeSettings& settings);
 void   prot_printcategories(void);
 void   prot_inputoptions(void);
 void   protdist_inputdata(void);
