@@ -10,11 +10,11 @@
 
 #include <cfloat>
 #include <QtGui/QMessageBox>
-#include <util_ov_annotated_dna/AnnotatedDNAView.h>
-#include <selection/DNASequenceSelection.h>
+#include <U2View/AnnotatedDNAView.h>
+#include <U2Core/DNASequenceSelection.h>
 #include "Primer3Dialog.h"
 
-namespace GB2 {
+namespace U2 {
 
 Primer3Dialog::Primer3Dialog(const Primer3TaskSettings &defaultSettings, ADVSequenceObjectContext *context):
         QDialog(context->getAnnotatedDNAView()->getWidget()),
@@ -94,61 +94,56 @@ void Primer3Dialog::prepareAnnotationObject()
     createAnnotationWidgetController->prepareAnnotationObject();
 }
 
-namespace
-{
-    QString intervalListToString(QList<QPair<int, int> > intervalList, QString delimiter)
+QString Primer3Dialog::intervalListToString(QList<QPair<int, int> > intervalList, QString delimiter) {
+    QString result;
+    bool first = true;
+    QPair<int, int> interval;
+    foreach(interval, intervalList)
     {
-        QString result;
-        bool first = true;
-        QPair<int, int> interval;
-        foreach(interval, intervalList)
+        if(!first)
         {
-            if(!first)
-            {
-                result += " ";
-            }
-            result += QString::number(interval.first);
-            result += delimiter;
-            result += QString::number(interval.second);
-            first = false;
+            result += " ";
         }
-        return result;
+        result += QString::number(interval.first);
+        result += delimiter;
+        result += QString::number(interval.second);
+        first = false;
     }
+    return result;
+}
 
-    bool parseIntervalList(QString inputString, QString delimiter, QList<QPair<int, int> > *outputList)
+bool Primer3Dialog::parseIntervalList(QString inputString, QString delimiter, QList<QPair<int, int> > *outputList) {
+    QList<QPair<int, int> > result;
+    QStringList intervalStringList = inputString.split(QRegExp("\\s+"),QString::SkipEmptyParts);
+    foreach(QString intervalString, intervalStringList)
     {
-        QList<QPair<int, int> > result;
-        QStringList intervalStringList = inputString.split(QRegExp("\\s+"),QString::SkipEmptyParts);
-        foreach(QString intervalString, intervalStringList)
+        QStringList valueStringList = intervalString.split(delimiter);
+        if(2 != valueStringList.size())
         {
-            QStringList valueStringList = intervalString.split(delimiter);
-            if(2 != valueStringList.size())
+            return false;
+        }
+        int firstValue = 0;
+        {
+            bool ok = false;
+            firstValue = valueStringList[0].toInt(&ok);
+            if(!ok)
             {
                 return false;
             }
-            int firstValue = 0;
-            {
-                bool ok = false;
-                firstValue = valueStringList[0].toInt(&ok);
-                if(!ok)
-                {
-                    return false;
-                }
-            }
-            int secondValue = 0;
-            {
-                bool ok = false;
-                secondValue = valueStringList[1].toInt(&ok);
-                if(!ok)
-                {
-                    return false;
-                }
-            }
-            result.append(qMakePair(firstValue, secondValue));
         }
-        *outputList = result;
-        return true;
+        int secondValue = 0;
+        {
+            bool ok = false;
+            secondValue = valueStringList[1].toInt(&ok);
+            if(!ok)
+            {
+                return false;
+            }
+        }
+        result.append(qMakePair(firstValue, secondValue));
     }
+    *outputList = result;
+    return true;
 }
 
 void Primer3Dialog::reset()
@@ -623,4 +618,4 @@ void Primer3Dialog::on_sbRangeEnd_editingFinished()
     }
 }
 
-} // namespace GB2
+} // namespace U2
