@@ -10,13 +10,13 @@
 
 #ifndef _PRIMER3_PLUGIN_H_
 #define _PRIMER3_PLUGIN_H_ 1
-#include <core_api/PluginModel.h>
-#include <core_api/ObjectViewModel.h>
+#include <U2Core/PluginModel.h>
+#include <U2Gui/ObjectViewModel.h>
 
 #include <QtGui/QMenu>
 #include "Primer3Tests.h"
 
-namespace GB2 {
+namespace U2 {
 
 class Primer3ADVContext;
 class XMLTestFactory;
