@@ -9,15 +9,15 @@
 *****************************************************************/
 
 #include <cstdlib>
-#include <core_api/AppContext.h>
-#include <core_api/Counter.h>
-#include <util_tasks/SequenceWalkerTask.h>
-#include <util_tasks/CreateAnnotationTask.h>
+#include <U2Core/AppContext.h>
+#include <U2Core/Counter.h>
+#include <U2Core/SequenceWalkerTask.h>
+#include <U2Core/CreateAnnotationTask.h>
 #include "primer3_main.h"
 #include "boulder_input.h"
 #include "Primer3Task.h"
 
-namespace GB2 {
+namespace U2 {
 
 // Primer
 
@@ -316,7 +316,7 @@ namespace
 }
 
 Primer3Task::Primer3Task(const Primer3TaskSettings &settingsArg):
-    Task(tr("Pick primers task"), TaskFlag_None),
+    Task(tr("Pick primers task"), TaskFlag_ReportingIsEnabled),
     settings(settingsArg)
 {
     GCOUNTER( cvar, tvar, "Primer3Task" );
@@ -445,6 +445,41 @@ Task::ReportResult Primer3Task::report()
     return Task::ReportResult_Finished;
 }
 
+void Primer3Task::sumStat(Primer3TaskSettings *st) {
+    st->getSeqArgs()->left_expl.considered += settings.getSeqArgs()->left_expl.considered;
+    st->getSeqArgs()->left_expl.ns += settings.getSeqArgs()->left_expl.ns;
+    st->getSeqArgs()->left_expl.target += settings.getSeqArgs()->left_expl.target;
+    st->getSeqArgs()->left_expl.excluded += settings.getSeqArgs()->left_expl.excluded;
+    st->getSeqArgs()->left_expl.gc += settings.getSeqArgs()->left_expl.gc;
+    st->getSeqArgs()->left_expl.gc_clamp += settings.getSeqArgs()->left_expl.gc_clamp;
+    st->getSeqArgs()->left_expl.temp_min += settings.getSeqArgs()->left_expl.temp_min;
+    st->getSeqArgs()->left_expl.temp_max += settings.getSeqArgs()->left_expl.temp_max;
+    st->getSeqArgs()->left_expl.compl_any += settings.getSeqArgs()->left_expl.compl_any;
+    st->getSeqArgs()->left_expl.compl_end += settings.getSeqArgs()->left_expl.compl_end;
+    st->getSeqArgs()->left_expl.poly_x += settings.getSeqArgs()->left_expl.poly_x;
+    st->getSeqArgs()->left_expl.stability += settings.getSeqArgs()->left_expl.stability;
+    st->getSeqArgs()->left_expl.ok += settings.getSeqArgs()->left_expl.ok;
+
+    st->getSeqArgs()->right_expl.considered += settings.getSeqArgs()->right_expl.considered;
+    st->getSeqArgs()->right_expl.ns += settings.getSeqArgs()->right_expl.ns;
+    st->getSeqArgs()->right_expl.target += settings.getSeqArgs()->right_expl.target;
+    st->getSeqArgs()->right_expl.excluded += settings.getSeqArgs()->right_expl.excluded;
+    st->getSeqArgs()->right_expl.gc += settings.getSeqArgs()->right_expl.gc;
+    st->getSeqArgs()->right_expl.gc_clamp += settings.getSeqArgs()->right_expl.gc_clamp;
+    st->getSeqArgs()->right_expl.temp_min += settings.getSeqArgs()->right_expl.temp_min;
+    st->getSeqArgs()->right_expl.temp_max += settings.getSeqArgs()->right_expl.temp_max;
+    st->getSeqArgs()->right_expl.compl_any += settings.getSeqArgs()->right_expl.compl_any;
+    st->getSeqArgs()->right_expl.compl_end += settings.getSeqArgs()->right_expl.compl_end;
+    st->getSeqArgs()->right_expl.poly_x += settings.getSeqArgs()->right_expl.poly_x;
+    st->getSeqArgs()->right_expl.stability += settings.getSeqArgs()->right_expl.stability;
+    st->getSeqArgs()->right_expl.ok += settings.getSeqArgs()->right_expl.ok;
+
+    st->getSeqArgs()->pair_expl.considered += settings.getSeqArgs()->pair_expl.considered;
+    st->getSeqArgs()->pair_expl.product += settings.getSeqArgs()->pair_expl.product;
+    st->getSeqArgs()->pair_expl.compl_end += settings.getSeqArgs()->pair_expl.compl_end;
+    st->getSeqArgs()->pair_expl.ok += settings.getSeqArgs()->pair_expl.ok;
+}
+
 QList<PrimerPair> Primer3Task::getBestPairs()const
 {
     return bestPairs;
@@ -513,7 +548,7 @@ QList<PrimerPair> Primer3SWTask::getBestPairs()const
 
 Primer3ToAnnotationsTask::Primer3ToAnnotationsTask( const Primer3TaskSettings &settings,
 AnnotationTableObject * aobj_, const QString & groupName_, const QString & annName_ ) :
-Task(tr("Search primers to annotations"), TaskFlags_NR_FOSCOE), settings(settings), aobj(aobj_), 
+Task(tr("Search primers to annotations"), /*TaskFlags_NR_FOSCOE*/TaskFlags(TaskFlag_NoRun) | TaskFlag_ReportingIsSupported | TaskFlag_ReportingIsEnabled), settings(settings), aobj(aobj_), 
 groupName(groupName_), annName(annName_), searchTask(NULL)
 {
 }
@@ -524,6 +559,49 @@ void Primer3ToAnnotationsTask::prepare()
     addSubTask(searchTask);
 }
 
+QString Primer3ToAnnotationsTask::generateReport() const {
+    QString res;
+
+    foreach(Primer3Task *t, searchTask->regionTasks) {
+        t->sumStat(&searchTask->settings);
+    }
+
+    oligo_stats leftStats = searchTask->settings.getSeqArgs()->left_expl;
+    oligo_stats rightStats = searchTask->settings.getSeqArgs()->right_expl;
+    pair_stats pairStats = searchTask->settings.getSeqArgs()->pair_expl;
+
+    if(!leftStats.considered) {
+        leftStats.considered = leftStats.ns + leftStats.target + leftStats.excluded + leftStats.gc + leftStats.gc_clamp + leftStats.temp_min 
+            + leftStats.temp_max + leftStats.compl_any + leftStats.compl_end + leftStats.poly_x + leftStats.stability + leftStats.ok;
+    }
+
+    if(!rightStats.considered) {
+        rightStats.considered = rightStats.ns + rightStats.target + rightStats.excluded + rightStats.gc + rightStats.gc_clamp + rightStats.temp_min 
+            + rightStats.temp_max + rightStats.compl_any + rightStats.compl_end + rightStats.poly_x + rightStats.stability + rightStats.ok;
+    }
+
+    res+="<table cellspacing='7'>";
+    res += "<tr><th>Statistics</th></tr>\n";
+
+    res += QString("<tr><th></th> <th>con</th> <th>too</th> <th>in</th> <th>in</th> <th></th> <th>no</th> <th>tm</th> <th>tm</th> <th>high</th> <th>high</th> <th></th> <th>high</th> <th></th></tr>");
+    res += QString("<tr><th></th> <th>sid</th> <th>many</th> <th>tar</th> <th>excl</th> <th>bag</th> <th>GC</th> <th>too</th> <th>too</th> <th>any</th> <th>3'</th> <th>poly</th> <th>end</th> <th></th></tr>");
+    res += QString("<tr><th></th> <th>ered</th> <th>Ns</th> <th>get</th> <th>reg</th> <th>GC\%</th> <th>clamp</th> <th>low</th> <th>high</th> <th>compl</th> <th>compl</th> <th>X</th> <th>stab</th> <th>ok</th></tr>");
+
+    res += QString("<tr><th>Left</th><th> %1 </th><th> %2 </th><th> %3 </th><th> %4 </th><th> %5 </th><th> %6 </th><th> %7 </th><th> %8 </th><th> %9 </th><th> %10 </th><th> %11 </th><th> %12 </th><th> %13 </th></tr>")
+        .arg(leftStats.considered).arg(leftStats.ns).arg(leftStats.target).arg(leftStats.excluded).arg(leftStats.gc).arg(leftStats.gc_clamp).arg(leftStats.temp_min).arg(leftStats.temp_max)
+        .arg(leftStats.compl_any).arg(leftStats.compl_end).arg(leftStats.poly_x).arg(leftStats.stability).arg(leftStats.ok);
+    res += QString("<tr><th>Right</th><th> %1 </th><th> %2 </th><th> %3 </th><th> %4 </th><th> %5 </th><th> %6 </th><th> %7 </th><th> %8 </th><th> %9 </th><th> %10 </th><th> %11 </th><th> %12 </th><th> %13 </th></tr>")
+        .arg(rightStats.considered).arg(rightStats.ns).arg(rightStats.target).arg(rightStats.excluded).arg(rightStats.gc).arg(rightStats.gc_clamp).arg(rightStats.temp_min).arg(rightStats.temp_max)
+        .arg(rightStats.compl_any).arg(rightStats.compl_end).arg(rightStats.poly_x).arg(rightStats.stability).arg(rightStats.ok);
+    res+="</table>";
+    res += "<br>Pair stats:<br>";
+    res += QString("considered %1, unacceptable product size %2, high end compl %3, ok %4.")
+        .arg(pairStats.considered).arg(pairStats.product).arg(pairStats.compl_end).arg(pairStats.ok);
+    return res;
+
+    return res;
+}
+
 Task::ReportResult Primer3ToAnnotationsTask::report()
 {
     assert( searchTask );
