@@ -13,7 +13,7 @@
 #include "boulder_input.h"
 #include "Primer3TaskSettings.h"
 
-namespace GB2 {
+namespace U2 {
 
 Primer3TaskSettings::Primer3TaskSettings()
 {
@@ -546,4 +546,4 @@ void Primer3TaskSettings::initMaps()
     doubleProperties.insert("PRIMER_PAIR_WT_TEMPLATE_MISPRIMING",&primerArgs.pr_pair_weights.template_mispriming);
 }
 
-} // namespace GB2
+} // namespace U2
