@@ -11,7 +11,7 @@
 #include "Primer3Tests.h"
 #include "primer3.h"
 
-namespace GB2{
+namespace U2{
 
 #define DBFILEPATH_ATTR "dbfile"
 #define PROTEIN_ATTR "is_protein"
