@@ -1965,7 +1965,7 @@ align(s1, s2, a)
       if (errno == ENOMEM) {
 	OOM_ERROR;
       } else {
-	fprintf(stderr, r.msg);
+	fprintf(stderr, "%s", r.msg);
 	/* Fix this later, when error handling
 	   in "primer_choice" is updated to
 	   no longer exit. */
