@@ -8,14 +8,14 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_PSIPRED_ALG_TASK_H_
-#define _GB2_PSIPRED_ALG_TASK_H_
+#ifndef _U2_PSIPRED_ALG_TASK_H_
+#define _U2_PSIPRED_ALG_TASK_H_
 
 #include <QtCore/QMutex>
-#include <util_sec_struct_predict/SecStructPredictTask.h>
+#include <U2Algorithm/SecStructPredictTask.h>
 
 
-namespace GB2 {
+namespace U2 {
 
 class PsipredAlgTask : public SecStructPredictTask {
     Q_OBJECT
@@ -29,6 +29,6 @@ private:
 
 } //namespace
 
-#endif // _GB2_PSIPRED_ALG_TASK_H_
+#endif // _U2_PSIPRED_ALG_TASK_H_
 
 
