@@ -8,20 +8,18 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_PSIPRED_PLUGIN_H_
-#define _GB2_PSIPRED_PLUGIN_H_
+#ifndef _U2_PSIPRED_PLUGIN_H_
+#define _U2_PSIPRED_PLUGIN_H_
 
-#include <core_api/PluginModel.h>
-#include <core_api/ObjectViewModel.h>
-#include <datatype/AnnotationData.h>
+#include <U2Core/PluginModel.h>
+#include <U2Gui/ObjectViewModel.h>
+#include <U2Core/AnnotationData.h>
 
 
-namespace GB2 {
+namespace U2 {
 
 class XMLTestFactory;
 
-#define ULOG_CAT_PLUGIN_SEC_STRUCT_PREDICT "Plugin: Psipred"
-
 class PsipredPlugin : public Plugin {
 	Q_OBJECT
 public:
@@ -35,6 +33,6 @@ private:
 
 } //namespace
 
-#endif // _GB2_PSIPRED_PLUGIN_H_
+#endif // _U2_PSIPRED_PLUGIN_H_
 
 
