@@ -14,7 +14,7 @@
 #include <algorithm>
 #include <math.h>
 
-namespace GB2 {
+namespace U2 {
 
 static QStringList getStrProperties();
 DinucleotitePropertyRegistry::DinucleotitePropertyRegistry() {
