@@ -8,18 +8,18 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_DI_PROPERTIES_SITECON_H_
-#define _GB2_DI_PROPERTIES_SITECON_H_
+#ifndef _U2_DI_PROPERTIES_SITECON_H_
+#define _U2_DI_PROPERTIES_SITECON_H_
 
 #include <QtCore/QMap>
 #include <QtCore/QList>
 #include <QtCore/QString>
 
-#include <util_weight_matrix/DIProperties.h>
+#include <U2Core/DIProperties.h>
 
 #include <assert.h>
 
-namespace GB2 {
+namespace U2 {
 
 class DiPropertySitecon;
 class DinucleotitePropertyRegistry {
