@@ -10,9 +10,9 @@
 
 #include "DIPropertiesTests.h"
 
-/* TRANSLATOR GB2::GTest */
+/* TRANSLATOR U2::GTest */
 
-namespace GB2 {
+namespace U2 {
 
 #define DI_KEY_ATTR  "key"
 #define DI_VAL_ATTR  "val"
