@@ -8,15 +8,15 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_DIPROPERTIES_TEST_H_
-#define _GB2_DIPROPERTIES_TEST_H_
+#ifndef _U2_DIPROPERTIES_TEST_H_
+#define _U2_DIPROPERTIES_TEST_H_
 
 #include "DIPropertiesSitecon.h"
-#include <test_framework/xmltest/XMLTestUtils.h>
-#include <core_api/GObject.h>
+#include <U2Test/XMLTestUtils.h>
+#include <U2Core/GObject.h>
 #include <QtXml/QDomElement>
 
-namespace GB2 {
+namespace U2 {
 
 class GTest_DiPropertySiteconCheckAttribs : public GTest {
     Q_OBJECT
