@@ -13,19 +13,44 @@
 
 #include "SiteconMath.h"
 
-#include <core_api/DNAAlphabet.h>
-#include <core_api/DNATranslation.h>
-#include <core_api/Log.h>
-#include <datatype/MAlignment.h>
+#include <U2Core/DNAAlphabet.h>
+#include <U2Core/DNATranslation.h>
+#include <U2Core/Log.h>
+#include <U2Core/MAlignment.h>
 
-#include <util_text/TextUtils.h>
+#include <U2Core/TextUtils.h>
 #include <QtCore/QFile>
 
 #include <math.h>
 
-namespace GB2 {
+namespace U2 {
 
-static LogCategory log(ULOG_CAT_SITECON);
+bool SiteconModel::operator !=(const SiteconModel& model) const {
+    bool eq = true;
+    if(matrix.size() != model.matrix.size()) {
+        eq = false;
+    }
+    for(int i = 0; i<matrix.size() && eq;i++) {
+        PositionStats pos = matrix[i];
+        if(pos.size() != model.matrix[i].size()) {
+            eq = false;
+        }
+        for(int j = 0;j < pos.size() && eq;j++) {
+            DiStat ds1 = pos[j];
+            DiStat ds2 = model.matrix[i][j];
+            for(int k = 0; k < 16 && eq; k++) {
+                eq = ds1.prop->original[k] == ds2.prop->original[k] && ds1.prop->normalized[k] == ds2.prop->normalized[k];
+            }
+            eq = eq && ds1.average == ds2.average && ds1.sdeviation == ds2.sdeviation;
+            eq = eq && ds1.weighted == ds2.weighted && ds1.prop->average == ds2.prop->average && ds1.prop->sdeviation == ds2.prop->sdeviation;
+            eq = eq && ds1.prop->keys == ds2.prop->keys;
+        }
+    }
+    for(int i = 0; i < err1.size() && eq; i++) {
+        eq = err1[i] == model.err1[i] && err2[i] == model.err2[i];
+    }
+    return !eq;
+}
 
 QVector<PositionStats> SiteconAlgorithm::calculateDispersionAndAverage(const MAlignment& ma, const SiteconBuildSettings& config, TaskStateInfo& ts) 
 {
@@ -236,9 +261,7 @@ void SiteconAlgorithm::calculateACGTContent(const MAlignment& ma, SiteconBuildSe
 }
 
 
-QByteArray SiteconAlgorithm::generateRandomSequence(const int* acgtContent, int seqLen, TaskStateInfo& ts)  {
-    Q_UNUSED(ts);
-
+QByteArray SiteconAlgorithm::generateRandomSequence(const int* acgtContent, int seqLen, TaskStateInfo&)  {
     QByteArray randomSequence;
     randomSequence.reserve(seqLen);
 
@@ -533,7 +556,7 @@ bool SiteconModel::checkState(bool doAssert) const {
         } else {
             //assert(!doAssert || nWeights <= MAX_WEIGHTS_ALG2);
             if (nWeights > MAX_WEIGHTS_ALG2) {
-                log.trace(QString("Number of Algorithm 2 weights %1, pos %2, model name %3").arg(nWeights).arg(pos).arg(modelName));
+                algoLog.trace(QString("Number of Algorithm 2 weights %1, pos %2, model name %3").arg(nWeights).arg(pos).arg(modelName));
                 //return false;
             }
         }
