@@ -12,24 +12,27 @@
 #include "DIPropertiesSitecon.h"
 #include "SiteconIO.h"
 
-#include <core_api/DocumentModel.h>
-#include <core_api/DocumentFormats.h>
-#include <core_api/AppContext.h>
-#include <core_api/IOAdapter.h>
+#include <U2Core/DocumentModel.h>
+#include <U2Core/BaseDocumentFormats.h>
+#include <U2Core/AppContext.h>
+#include <U2Core/IOAdapter.h>
 
-#include <gobjects/GObjectTypes.h>
-#include <gobjects/DNASequenceObject.h>
-#include <gobjects/GObjectUtils.h>
-#include <gobjects/MAlignmentObject.h>
+#include <U2Core/GObjectTypes.h>
+#include <U2Core/DNASequenceObject.h>
+#include <U2Core/GObjectUtils.h>
+#include <U2Core/MAlignmentObject.h>
 
 #include <QtXml/QDomElement>
 
 
-/* TRANSLATOR GB2::GTest */
+/* TRANSLATOR U2::GTest */
 
-namespace GB2 {
+namespace U2 {
 
 #define DOC_ATTR "doc"
+#define DOC_URL "url"
+#define DOC1_ATTR "model1"
+#define DOC2_ATTR "model2"
 #define SEQNAME_ATTR "sequence"
 #define EXPECTED_RESULTS_ATTR  "expected_results"
 #define DINUCLEOTIDE_POSITIONS "di_positions"
@@ -540,4 +543,41 @@ Task::ReportResult GTest_SiteconSearchTask::report() {
     return ReportResult_Finished;
 }
 
+
+
+void GTest_CompareSiteconModels::init(XMLTestFormat *, const QDomElement& el) {
+    doc1ContextName = el.attribute(DOC1_ATTR);
+    if (doc1ContextName.isEmpty()) {
+        failMissingValue(DOC1_ATTR);
+        return;
+    }
+
+    doc2ContextName = el.attribute(DOC2_ATTR);
+    if (doc2ContextName.isEmpty()) {
+        failMissingValue(DOC2_ATTR);
+        return;
+    }
+}
+
+Task::ReportResult GTest_CompareSiteconModels::report() {
+    //SiteconModel model1 = getContext<SiteconModel>(doc1ContextName);
+    //SiteconModel model2 = getContext<SiteconModel>(doc2ContextName);
+    Document *doc1 = getContext<Document>(this, doc1ContextName);
+    if (doc1 == NULL) {
+        stateInfo.setError(  QString("document not found %1").arg(doc1ContextName) );
+        return ReportResult_Finished;
+    }
+    Document* doc2 = getContext<Document>(this, doc2ContextName);
+    if (doc2 == NULL) {
+        stateInfo.setError(  QString("document not found %1").arg(doc2ContextName) );
+        return ReportResult_Finished;
+    }
+    SiteconModel model1 = SiteconIO::readModel(doc1->getIOAdapterFactory(), doc1->getURLString(), stateInfo);
+    SiteconModel model2 = SiteconIO::readModel(doc2->getIOAdapterFactory(), doc2->getURLString(), stateInfo);
+    if(model1 != model2) {
+        stateInfo.setError(tr("Models not equal"));
+    }
+    return ReportResult_Finished;
+}
+
 }//namespace
