@@ -13,22 +13,22 @@
 #include "SiteconMath.h"
 #include "SiteconPlugin.h"
 
-#include <core_api/AppContext.h>
-#include <core_api/IOAdapter.h>
-#include <core_api/GUrlUtils.h>
-#include <core_api/L10n.h>
+#include <U2Core/AppContext.h>
+#include <U2Core/IOAdapter.h>
+#include <U2Core/GUrlUtils.h>
+#include <U2Core/L10n.h>
 
-#include <util_text/TextUtils.h>
-#include <util_tasks/SaveDocumentTask.h>
+#include <U2Core/TextUtils.h>
+#include <U2Core/SaveDocumentTask.h>
 
-#include <util_gui/DialogUtils.h>
+#include <U2Misc/DialogUtils.h>
 
 #include <QtCore/QVector>
 #include <memory>
 
-/* TRANSLATOR GB2::IOAdapter */
+/* TRANSLATOR U2::IOAdapter */
 
-namespace GB2 {
+namespace U2 {
 
 const QString SiteconIO::SITECON_ID("sitecon");
 const QString SiteconIO::SITECON_EXT = SiteconIO::SITECON_ID;
