@@ -11,29 +11,32 @@
 #include "SiteconIOWorkers.h"
 #include "SiteconWorkers.h"
 #include "SiteconSearchDialogController.h"
-#include <workflow/Datatype.h>
-#include <workflow/IntegralBusModel.h>
-#include <workflow/WorkflowEnv.h>
-#include <workflow/WorkflowRegistry.h>
-#include <workflow_library/BioActorLibrary.h>
-#include <workflow_support/CoreDataTypes.h>
-#include <workflow_support/DelegateEditors.h>
-#include <workflow_support/CoreLibConstants.h>
+#include <U2Lang/Datatype.h>
+#include <U2Lang/IntegralBusModel.h>
+#include <U2Lang/WorkflowEnv.h>
+#include <U2Lang/ActorPrototypeRegistry.h>
+#include <U2Lang/BioActorLibrary.h>
+#include <U2Lang/CoreDataTypes.h>
+#include <U2Designer/DelegateEditors.h>
+#include <U2Lang/CoreLibConstants.h>
 
-#include <core_api/AppContext.h>
-#include <core_api/IOAdapter.h>
-#include <core_api/Log.h>
-#include <core_api/GUrlUtils.h>
-#include <util_tasks/FailTask.h>
+#include <U2Core/AppContext.h>
+#include <U2Core/IOAdapter.h>
+#include <U2Core/Log.h>
+#include <U2Core/GUrlUtils.h>
+#include <U2Core/FailTask.h>
 #include "SiteconIO.h"
 
-/* TRANSLATOR GB2::SiteconIO */
+/* TRANSLATOR U2::SiteconIO */
 
-namespace GB2 {
+namespace U2 {
 namespace LocalWorkflow {
 
-const QString SiteconReader::ACTOR_ID("sitecon.read");
-const QString SiteconWriter::ACTOR_ID("sitecon.write");
+const QString SiteconReader::ACTOR_ID("sitecon-read");
+const QString SiteconWriter::ACTOR_ID("sitecon-write");
+
+static const QString SITECON_OUT_PORT_ID("out-sitecon");
+static const QString SITECON_IN_PORT_ID("in-sitecon");
 
 const QString SiteconWorkerFactory::SITECON_MODEL_TYPE_ID("sitecon.model");
 
@@ -49,12 +52,12 @@ DataTypePtr const SiteconWorkerFactory::SITECON_MODEL_TYPE() {
     return dtr->getById(SITECON_MODEL_TYPE_ID);
 }
 
+const Descriptor SiteconWorkerFactory::SITECON_SLOT("sitecon-model", SiteconIO::tr("Sitecon model"), "");
+
 const Descriptor SiteconWorkerFactory::SITECON_CATEGORY() {return Descriptor("hsitecon", SiteconIO::tr("SITECON"), "");}
 
-static LogCategory log(ULOG_CAT_WD);
-
 SiteconIOProto::SiteconIOProto(const Descriptor& _desc, const QList<PortDescriptor*>& _ports, const QList<Attribute*>& _attrs ) 
-: BusActorPrototype(_desc, _ports, _attrs) {
+: IntegralBusActorPrototype(_desc, _ports, _attrs) {
 }
 
 bool SiteconIOProto::isAcceptableDrop(const QMimeData * md, QVariantMap * params, const QString & urlAttrId ) const {
@@ -80,13 +83,13 @@ ReadSiteconProto::ReadSiteconProto(const Descriptor& _desc, const QList<PortDesc
     
     attrs << new Attribute(CoreLibConstants::URL_IN_ATTR(), CoreDataTypes::STRING_TYPE(), true);
     QMap<QString, PropertyDelegate*> delegateMap;
-    delegateMap[CoreLibConstants::URL_IN_ATTR_ID] = new URLDelegate(SiteconIO::getFileFilter(), SiteconIO::SITECON_ID, true);
+    delegateMap[CoreLibConstants::URL_IN_ATTR().getId()] = new URLDelegate(SiteconIO::getFileFilter(), SiteconIO::SITECON_ID, true);
     setEditor(new DelegateEditor(delegateMap));
     setIconPath(":sitecon/images/sitecon.png");
 }
 
 bool ReadSiteconProto::isAcceptableDrop(const QMimeData * md, QVariantMap * params ) const {
-    return SiteconIOProto::isAcceptableDrop( md, params, CoreLibConstants::URL_IN_ATTR_ID );
+    return SiteconIOProto::isAcceptableDrop( md, params, CoreLibConstants::URL_IN_ATTR().getId() );
 }
 
 WriteSiteconProto::WriteSiteconProto(const Descriptor& _desc, const QList<PortDescriptor*>& _ports, const QList<Attribute*>& _attrs ) 
@@ -95,47 +98,49 @@ WriteSiteconProto::WriteSiteconProto(const Descriptor& _desc, const QList<PortDe
     attrs << new Attribute(BioActorLibrary::FILE_MODE_ATTR(), CoreDataTypes::NUM_TYPE(), false, SaveDoc_Roll);
 
     QMap<QString, PropertyDelegate*> delegateMap;
-    delegateMap[CoreLibConstants::URL_OUT_ATTR_ID] = new URLDelegate(SiteconIO::getFileFilter(), SiteconIO::SITECON_ID, false );
+    delegateMap[CoreLibConstants::URL_OUT_ATTR().getId()] = new URLDelegate(SiteconIO::getFileFilter(), SiteconIO::SITECON_ID, false );
     delegateMap[BioActorLibrary::FILE_MODE_ATTR_ID] = new FileModeDelegate(false);
     
     setEditor(new DelegateEditor(delegateMap));
     setIconPath(":sitecon/images/sitecon.png");
-    setValidator(new ScreenedParamValidator(CoreLibConstants::URL_OUT_ATTR_ID, ports.first()->getId(), CoreLibConstants::URL_SLOT_ID));
-    setPortValidator(CoreLibConstants::IN_PORT_ID, new ScreenedSlotValidator(CoreLibConstants::URL_SLOT_ID));
+    setValidator(new ScreenedParamValidator(CoreLibConstants::URL_OUT_ATTR().getId(), ports.first()->getId(), CoreLibConstants::URL_SLOT().getId()));
+    setPortValidator(SITECON_IN_PORT_ID, new ScreenedSlotValidator(CoreLibConstants::URL_SLOT().getId()));
 }
 
 bool WriteSiteconProto::isAcceptableDrop(const QMimeData * md, QVariantMap * params ) const {
-    return SiteconIOProto::isAcceptableDrop( md, params, CoreLibConstants::URL_OUT_ATTR_ID );
+    return SiteconIOProto::isAcceptableDrop( md, params, CoreLibConstants::URL_OUT_ATTR().getId() );
 }
 
 void SiteconWorkerFactory::init() 
 {
-    WProtoRegistry* r = WorkflowEnv::getProtoRegistry();
+    ActorPrototypeRegistry* r = WorkflowEnv::getProtoRegistry();
     assert(r);
-    DataTypePtr dt = SITECON_MODEL_TYPE();
     {        
         QMap<Descriptor, DataTypePtr> m;
-        Descriptor sd(CoreLibConstants::URL_SLOT_ID, SiteconIO::tr("Location"), SiteconIO::tr("Location hint for the target file."));
-        m[sd] = CoreDataTypes::STRING_TYPE();
-        m[*dt] = dt;
+        m[CoreLibConstants::URL_SLOT()] = CoreDataTypes::STRING_TYPE();
+        m[SiteconWorkerFactory::SITECON_SLOT] = SiteconWorkerFactory::SITECON_MODEL_TYPE();
         DataTypePtr t(new MapDataType(Descriptor("write.sitecon.content"), m));
 
         QList<PortDescriptor*> p; QList<Attribute*> a;
-        Descriptor pd(CoreLibConstants::IN_PORT_ID, SiteconIO::tr("Sitecon model"), SiteconIO::tr("Input Sitecon model"));
+        Descriptor pd(SITECON_IN_PORT_ID, SiteconIO::tr("Sitecon model"), SiteconIO::tr("Input Sitecon model"));
         p << new PortDescriptor(pd, t, true /*input*/);
-        Descriptor desc(SiteconWriter::ACTOR_ID, SiteconIO::tr("Write Sitecon model"), SiteconIO::tr("Saves all input SITECON profiles to specified location."));
-        BusActorPrototype* proto = new WriteSiteconProto(desc, p, a);
+        Descriptor desc(SiteconWriter::ACTOR_ID, SiteconIO::tr("Write SITECON model"), SiteconIO::tr("Saves all input SITECON profiles to specified location."));
+        IntegralBusActorPrototype* proto = new WriteSiteconProto(desc, p, a);
         proto->setPrompter(new SiteconWritePrompter());
-        r->registerProto(SITECON_CATEGORY(), proto);
+        r->registerProto(BioActorLibrary::CATEGORY_TRANSCRIPTION(), proto);
     }
     {
         QList<PortDescriptor*> p; QList<Attribute*> a;
-        Descriptor pd(CoreLibConstants::OUT_PORT_ID, SiteconIO::tr("Sitecon model"), SiteconIO::tr("Loaded SITECON profile data."));
-        p << new PortDescriptor(pd, dt, false /*input*/, true /*multi*/);
-        Descriptor desc(SiteconReader::ACTOR_ID, SiteconIO::tr("Read Sitecon model"), SiteconIO::tr("Reads SITECON profiles from file(s). The files can be local or Internet URLs."));
-        BusActorPrototype* proto = new ReadSiteconProto(desc, p, a);
+        Descriptor pd(SITECON_OUT_PORT_ID, SiteconIO::tr("Sitecon model"), SiteconIO::tr("Loaded SITECON profile data."));
+        
+        QMap<Descriptor, DataTypePtr> outM;
+        outM[SiteconWorkerFactory::SITECON_SLOT] = SiteconWorkerFactory::SITECON_MODEL_TYPE();
+        p << new PortDescriptor(pd, DataTypePtr(new MapDataType("sitecon.read.out", outM)), false /*input*/, true /*multi*/);
+        
+        Descriptor desc(SiteconReader::ACTOR_ID, SiteconIO::tr("Read SITECON model"), SiteconIO::tr("Reads SITECON profiles from file(s). The files can be local or Internet URLs."));
+        IntegralBusActorPrototype* proto = new ReadSiteconProto(desc, p, a);
         proto->setPrompter(new SiteconReadPrompter());
-        r->registerProto(SITECON_CATEGORY(), proto);
+        r->registerProto(BioActorLibrary::CATEGORY_TRANSCRIPTION(), proto);
     }
 
     SiteconBuildWorker::registerProto();
@@ -167,16 +172,16 @@ Worker* SiteconWorkerFactory::createWorker(Actor* a) {
 }
 
 QString SiteconReadPrompter::composeRichDoc() {
-    return tr("Read model(s) from <u>%1</u>").arg(getURL(CoreLibConstants::URL_IN_ATTR_ID));
+    return tr("Read model(s) from <u>%1</u>").arg(getURL(CoreLibConstants::URL_IN_ATTR().getId()));
 }
 
 QString SiteconWritePrompter::composeRichDoc() {
-    BusPort* input = qobject_cast<BusPort*>(target->getPort(CoreLibConstants::IN_PORT_ID));
+    IntegralBusPort* input = qobject_cast<IntegralBusPort*>(target->getPort(SITECON_IN_PORT_ID));
     Actor* producer = input->getProducer(SiteconWorkerFactory::SITECON_MODEL_TYPE_ID);
     if (!producer) {
-        return getURL(CoreLibConstants::URL_OUT_ATTR_ID);
+        return getURL(CoreLibConstants::URL_OUT_ATTR().getId());
     }
-    QString url = getScreenedURL(input, CoreLibConstants::URL_OUT_ATTR_ID, CoreLibConstants::URL_SLOT_ID); 
+    QString url = getScreenedURL(input, CoreLibConstants::URL_OUT_ATTR().getId(), CoreLibConstants::URL_SLOT().getId()); 
     QString doc = tr("Save the profile(s) from <u>%1</u> to %2.")
         .arg(producer->getLabel())
         .arg(url);
@@ -184,8 +189,8 @@ QString SiteconWritePrompter::composeRichDoc() {
 }
 
 void SiteconReader::init() {
-    output = ports.value(CoreLibConstants::OUT_PORT_ID);
-    urls = DesignerUtils::expandToUrls(actor->getParameter(CoreLibConstants::URL_IN_ATTR_ID)->getAttributeValue<QString>());
+    output = ports.value(SITECON_OUT_PORT_ID);
+    urls = WorkflowUtils::expandToUrls(actor->getParameter(CoreLibConstants::URL_IN_ATTR().getId())->getAttributeValue<QString>());
     mtype = SiteconWorkerFactory::SITECON_MODEL_TYPE();
 }
 
@@ -208,33 +213,33 @@ void SiteconReader::sl_taskFinished() {
         if (urls.isEmpty() && tasks.isEmpty()) {
             output->setEnded();
         }
-        log.info(tr("Loaded SITECON model from %1").arg(t->getURL()));
+        algoLog.info(tr("Loaded SITECON model from %1").arg(t->getURL()));
     }
 }
 
 void SiteconWriter::init() {
-    input = ports.value(CoreLibConstants::IN_PORT_ID);
+    input = ports.value(SITECON_IN_PORT_ID);
 }
 
 Task* SiteconWriter::tick() {
     Message inputMessage = getMessageAndSetupScriptValues(input);
-    url = actor->getParameter(CoreLibConstants::URL_OUT_ATTR_ID)->getAttributeValue<QString>();
+    url = actor->getParameter(CoreLibConstants::URL_OUT_ATTR().getId())->getAttributeValue<QString>();
     fileMode = actor->getParameter(BioActorLibrary::FILE_MODE_ATTR_ID)->getAttributeValue<uint>();
     QVariantMap data = inputMessage.getData().toMap();
-    SiteconModel model = data.value(SiteconWorkerFactory::SITECON_MODEL_TYPE_ID).value<SiteconModel>();
+    SiteconModel model = data.value(SiteconWorkerFactory::SITECON_SLOT.getId()).value<SiteconModel>();
     
     QString anUrl = url;
     if (anUrl.isEmpty()) {
-        anUrl = data.value(CoreLibConstants::URL_SLOT_ID).toString();
+        anUrl = data.value(CoreLibConstants::URL_SLOT().getId()).toString();
     }
     if (anUrl.isEmpty()) {
         QString err = tr("Unspecified URL for writing Sitecon");
-        if (failFast) {
+        //if (failFast) {
             return new FailTask(err);
-        } else {
-            log.error(err);
+        /*} else {
+            algoLog.error(err);
             return NULL;
-        }
+        }*/
     }
     assert(!anUrl.isEmpty());
     int count = ++counter[anUrl];
@@ -243,10 +248,10 @@ Task* SiteconWriter::tick() {
     } else {
         anUrl = GUrlUtils::ensureFileExt( anUrl, QStringList("sitecon")).getURLString();
     }
-    log.info(tr("Writing SITECON model to %1").arg(anUrl));
+    ioLog.info(tr("Writing SITECON model to %1").arg(anUrl));
     return new SiteconWriteTask(anUrl, model, fileMode);
 }
 
 } //namespace LocalWorkflow
-} //namespace GB2
+} //namespace U2
 
