@@ -8,21 +8,21 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_SITECON_IO_WORKER_H_
-#define _GB2_SITECON_IO_WORKER_H_
+#ifndef _U2_SITECON_IO_WORKER_H_
+#define _U2_SITECON_IO_WORKER_H_
 
-#include <workflow_library/LocalDomain.h>
-#include <workflow_support/WorkflowUtils.h>
+#include <U2Lang/LocalDomain.h>
+#include <U2Lang/WorkflowUtils.h>
 #include "SiteconAlgorithm.h"
 
-#include <util_tasks/SaveDocumentTask.h>
+#include <U2Core/SaveDocumentTask.h>
 
-Q_DECLARE_METATYPE(GB2::SiteconModel)
+Q_DECLARE_METATYPE(U2::SiteconModel)
 
-namespace GB2 {
+namespace U2 {
 namespace LocalWorkflow {
 
-class SiteconIOProto : public BusActorPrototype {
+class SiteconIOProto : public IntegralBusActorPrototype {
 public:
     SiteconIOProto(const Descriptor& desc, const QList<PortDescriptor*>& ports, 
         const QList<Attribute*>& attrs = QList<Attribute*>());
@@ -100,8 +100,8 @@ protected:
     uint fileMode;
 }; 
 
-}//Workflow namespace
-}//GB2 namespace
+} // Workflow namespace
+} // U2 namespace
 
 #endif
 
