@@ -8,12 +8,12 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_SITECON_MATH_H_
-#define _GB2_SITECON_MATH_H_
+#ifndef _U2_SITECON_MATH_H_
+#define _U2_SITECON_MATH_H_
 
 #include <math.h>
 
-namespace GB2 {
+namespace U2 {
 
 #define     CHI_EPSILON     0.000001    /* accuracy of critchi approximation */
 #define     CHI_MAX     99999.0         /* maximum chi square value */
