@@ -8,17 +8,17 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_SITECON_PLUGIN_H_
-#define _GB2_SITECON_PLUGIN_H_
+#ifndef _U2_SITECON_PLUGIN_H_
+#define _U2_SITECON_PLUGIN_H_
 
 #include "DIPropertiesSitecon.h"
 
-#include <core_api/PluginModel.h>
-#include <core_api/ObjectViewModel.h>
+#include <U2Core/PluginModel.h>
+#include <U2Gui/ObjectViewModel.h>
 
 #include <QtGui/QMenu>
 
-namespace GB2 {
+namespace U2 {
 
 class SiteconADVContext;
 class XMLTestFactory;
