@@ -8,18 +8,18 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_SITECON_SEARCH_TASK_H_
-#define _GB2_SITECON_SEARCH_TASK_H_
+#ifndef _U2_SITECON_SEARCH_TASK_H_
+#define _U2_SITECON_SEARCH_TASK_H_
 
 #include "SiteconAlgorithm.h"
 
-#include <core_api/LRegion.h>
-#include <datatype/AnnotationData.h>
-#include <util_tasks/SequenceWalkerTask.h>
+#include <U2Core/LRegion.h>
+#include <U2Core/AnnotationData.h>
+#include <U2Core/SequenceWalkerTask.h>
 
 #include <QtCore/QMutex>
 
-namespace GB2 {
+namespace U2 {
 
 class SiteconSearchResult {
 public:
@@ -30,7 +30,7 @@ public:
         data = new AnnotationData;
         data->name = name;
         data->location.append(region);
-        data->aminoStrand = TriState_No;
+        data->aminoFrame = TriState_No;
         data->complement = complement;
         if (!modelInfo.isEmpty()) {
             data->qualifiers.append(Qualifier("sitecon_model", modelInfo));
