@@ -12,20 +12,19 @@
 #include "MuscleUtils.h"
 #include "MuscleConstants.h"
 
-#include <core_api/DNAAlphabet.h>
-#include <core_api/Task.h>
-#include <core_api/Log.h>
-#include <util_algorithm/GAutoDeleteList.h>
-#include <datatype/MAlignment.h>
+#include <U2Core/DNAAlphabet.h>
+#include <U2Core/Task.h>
+#include <U2Core/Log.h>
+#include <U2Core/GAutoDeleteList.h>
+#include <U2Core/MAlignment.h>
 
 #include <algorithm>
 #include <QtCore/QVector>
 
 
-namespace GB2 {
+namespace U2 {
 
 //////////////////////////////////////////////////////////////////////////
-static LogCategory log(ULOG_CAT_MUSCLE);
 
 void MuscleAdapter::align(const MAlignment& ma, MAlignment& res, TaskStateInfo& ti, bool mhack) {
     if(ti.cancelFlag)  {
@@ -156,7 +155,7 @@ void MuscleAdapter::alignUnsafe(const MAlignment& ma, MAlignment& res, TaskState
     } else {
         RefineHoriz(msa, GuideTree, ctx->params.g_uMaxIters - 2, false, false);
     }
-    log.trace(QString("Serial refine stage complete. Elapsed %1 ms").arg(timer.elapsed()));
+    perfLog.trace(QString("Serial refine stage complete. Elapsed %1 ms").arg(timer.elapsed()));
     if (ti.cancelFlag) {
         return;
     }
@@ -180,7 +179,7 @@ void MuscleAdapter::refine(const MAlignment& ma, MAlignment& res, TaskStateInfo&
         QTime timer;
         timer.start();
         refineUnsafe(ma, res, ti);
-        log.trace(QString("Serial refine stage complete. Elapsed %1 ms").arg(timer.elapsed()));
+        algoLog.trace(QString("Serial refine stage complete. Elapsed %1 ms").arg(timer.elapsed()));
     } catch (MuscleException e) {
         if (!ti.cancelFlag) {
             ti.setError(  tr("Internal MUSCLE error: %1").arg(e.str) );
