@@ -8,23 +8,20 @@
 *     for details.
 *****************************************************************/
 
-
-#include <QtGui/QMessageBox>
-
-#include <core_api/AppContext.h>
-#include <distributed_computing/RemoteMachineMonitor.h>
-#include <distributed_computing/DistributedComputingUtil.h>
-#include <util_gui/RemoteMachineMonitorDialogImpl.h>
-
-#include <muscle_local_task/MuscleLocalTask.h>
 #include "MuscleAlignDialogController.h"
 
-/* TRANSLATOR GB2::MuscleAlignDialogController */    
+#include <U2Core/AppContext.h>
 
-namespace GB2 {
+#include <QtGui/QMessageBox>
+#include <QtGui/QToolButton>
+
+
+/* TRANSLATOR U2::MuscleAlignDialogController */    
+
+namespace U2 {
 
 MuscleAlignDialogController::MuscleAlignDialogController(QWidget* w, const MAlignment& _ma, MuscleTaskSettings& _settings) 
-: QDialog(w), ma(_ma), settings(_settings)
+    : QDialog(w), ma(_ma), settings(_settings)
 {
     setupUi(this);
 
@@ -41,8 +38,7 @@ MuscleAlignDialogController::MuscleAlignDialogController(QWidget* w, const MAlig
     foreach(const MuscleAlignPreset* p, presets.qlist) {
         confBox->addItem(p->name);
     }
-    
-    connect( remoteRunPushButton, SIGNAL( clicked() ), SLOT( sl_remoteRunButtonClicked() ) );
+   
 }
 
 void MuscleAlignDialogController::accept() {
@@ -55,6 +51,87 @@ void MuscleAlignDialogController::accept() {
     if (wholeRangeRB->isChecked()) {
         settings.regionToAlign = LRegion(0, ma.getLength());
         settings.alignRegion = false;
+    } else {
+        int startPos = rangeStartSB->value() - 1;
+        int endPos = rangeEndSB->value() - 1;
+        if (endPos - startPos < 2) {
+            QMessageBox::critical(NULL, tr("Error"), tr("Illegal alignment region"));
+            rangeStartSB->setFocus();
+            return;
+        }
+        settings.alignRegion = true;
+        settings.regionToAlign = LRegion(startPos,  endPos - startPos + 1);
+    }
+
+    if (maxItersCheckBox->isChecked()) {
+        settings.maxIterations = maxItersSpinBox->value();
+        assert(settings.maxIterations >= 2);
+    }
+    if (maxMinutesCheckBox->isChecked()) {
+        settings.maxSecs = maxMinutesSpinBox->value() * 60; 
+        assert(settings.maxSecs > 0);
+    }
+    QDialog::accept();
+}
+
+void MuscleAlignDialogController::sl_onPresetChanged(int newPreset) {
+    assert(newPreset>=0 && newPreset < presets.qlist.size());
+    const MuscleAlignPreset* p = presets.qlist[newPreset];
+    confEdit->setText(p->desc);
+}
+
+////////////////////////////////////////
+//MuscleAlignWithExtFileSpecifyDialogController
+MuscleAlignWithExtFileSpecifyDialogController::MuscleAlignWithExtFileSpecifyDialogController(QWidget* w, MuscleTaskSettings& _settings)
+: QDialog(w), settings(_settings)
+{
+    setupUi(this);
+    //add input file line edit
+    QWidget * widget = new QWidget(w);
+    inputFileLineEdit= new FileLineEdit(DialogUtils::prepareDocumentsFileFilterByObjType(GObjectTypes::MULTIPLE_ALIGNMENT, true),
+        "", false, widget);
+    inputFileLineEdit->setText("");
+    QToolButton * selectToolPathButton = new QToolButton(widget);
+    selectToolPathButton->setVisible(true);
+    selectToolPathButton->setText("...");
+    connect(selectToolPathButton, SIGNAL(clicked()), inputFileLineEdit, SLOT(sl_onBrowse()));
+    connect(inputFileLineEdit,SIGNAL(textChanged(QString)),this, SLOT(sl_inputFileLineEditChanged(QString)));
+
+    QHBoxLayout* layout = new QHBoxLayout(widget);
+    layout->addWidget(inputFileLineEdit);
+    layout->addWidget(selectToolPathButton);
+
+    QGroupBox* inputFileGroupBox=new QGroupBox(tr("Select input file"),widget);
+    inputFileGroupBox->setLayout(layout);
+    QBoxLayout* parentLayout = qobject_cast<QBoxLayout*>(this->layout());
+    assert(parentLayout);
+    parentLayout->insertWidget(0, inputFileGroupBox);
+    alignButton->setEnabled(false);
+
+    //we don`t know length of MA, need check this at task
+    rangeStartSB->setValue(0);
+    rangeEndSB->setValue(500);
+
+    connect(confBox, SIGNAL(currentIndexChanged(int)), SLOT(sl_onPresetChanged(int)));
+    initPresets();
+    foreach(const MuscleAlignPreset* p, presets.qlist) {
+        confBox->addItem(p->name);
+    }
+}
+
+void MuscleAlignWithExtFileSpecifyDialogController::sl_inputFileLineEditChanged(const QString& str){
+    alignButton->setEnabled(!str.isEmpty());
+}
+
+void MuscleAlignWithExtFileSpecifyDialogController::accept() {
+    int n = confBox->currentIndex();
+    assert(n >=0 && n < presets.qlist.size());
+    const MuscleAlignPreset* p = presets.qlist[n];
+    p->apply(settings);
+    settings.stableMode = stableCB->isChecked();
+
+    if (wholeRangeRB->isChecked()) {
+        settings.alignRegion = false;
     } else {
         int startPos = rangeStartSB->value() - 1;
         int endPos = rangeEndSB->value();
@@ -72,54 +149,28 @@ void MuscleAlignDialogController::accept() {
         assert(settings.maxIterations >= 2);
     }
     if (maxMinutesCheckBox->isChecked()) {
-        settings.maxSecs = maxMinutesSpinBox->value() * 60; 
+        settings.maxSecs = maxMinutesSpinBox->value() * 60;
         assert(settings.maxSecs > 0);
     }
+    if(!inputFileLineEdit->text().isEmpty()){
+        settings.inputFilePath=inputFileLineEdit->text();
+    }else{
+        assert(NULL);
+        reject();
+    }
     QDialog::accept();
 }
 
-void MuscleAlignDialogController::sl_remoteRunButtonClicked() {
-    int rc = 0;
-    do{
-        RemoteMachineMonitor * rmm = AppContext::getRemoteMachineMonitor();
-        assert( NULL != rmm );
-        RemoteMachineMonitorDialogImpl dlg( QApplication::activeWindow(), rmm->getRemoteMachineMonitorItems(), 
-            MuscleLocalTaskFactory::ID );
-        rc = dlg.exec();
-        if( QDialog::Rejected == rc ) {
-            return;
-        }
-        assert( QDialog::Accepted == rc );
-        
-        QList< RemoteMachineMonitorDialogItem > dlgModel = dlg.getModel();
-        DistributedComputingUtil::applyChangesForRemoteMachineMonitor( rmm, dlgModel );
-        QList< RemoteMachineSettings* > selectedMachines = rmm->getSelectedMachines();
-        int howManyMachines = selectedMachines.size();
-        if( 0 == howManyMachines ) {
-            QMessageBox::critical( this, tr( "Selecting machines error!" ), tr( "You didn't select a machine to run remote task!" ) );
-            continue;
-        } else if( 1 != howManyMachines ) {
-            QMessageBox::critical( this, tr( "Selecting machines error!" ), 
-                tr( "Distributed run on many machines is not supported yet. Select 1 machine" ) );
-            continue;
-        }
-        machines << selectedMachines.first();
-        break;
-    } while( QDialog::Accepted == rc );
-    
-    accept();
-}
-
-QList< RemoteMachineSettings* > MuscleAlignDialogController::getSelectedMachines() const {
-    return machines;
-}
-
-void MuscleAlignDialogController::sl_onPresetChanged(int newPreset) {
+void MuscleAlignWithExtFileSpecifyDialogController::sl_onPresetChanged(int newPreset) {//???
     assert(newPreset>=0 && newPreset < presets.qlist.size());
     const MuscleAlignPreset* p = presets.qlist[newPreset];
     confEdit->setText(p->desc);
 }
-
+void MuscleAlignWithExtFileSpecifyDialogController::initPresets() {
+    presets.qlist.append(new DefaultModePreset());
+    presets.qlist.append(new LargeModePreset());
+    presets.qlist.append(new RefineModePreset());
+}
 
 //////////////////////////////////////////////////////////////////////////
 // presets
