@@ -8,18 +8,19 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_MUSCLE_ALIGN_DIALOG_CONTROLLER_H_
-#define _GB2_MUSCLE_ALIGN_DIALOG_CONTROLLER_H_
+#ifndef _U2_MUSCLE_ALIGN_DIALOG_CONTROLLER_H_
+#define _U2_MUSCLE_ALIGN_DIALOG_CONTROLLER_H_
+
+#include "MuscleTask.h"
+
+#include <U2Core/GAutoDeleteList.h>
+#include <U2Misc/DialogUtils.h>
+
+#include <ui/ui_MuscleAlignDialog.h>
 
 #include <QtGui/QDialog>
 
-#include <util_algorithm/GAutoDeleteList.h>
-#include <distributed_computing/RemoteMachine.h>
-
-#include <ui/ui_MuscleAlignDialog.h>
-#include "MuscleTask.h"
-
-namespace GB2 {
+namespace U2 {
 
 class MuscleAlignPreset {
 public:
@@ -65,14 +66,11 @@ class MuscleAlignDialogController : public QDialog, public Ui_MuscleAlignmentDia
 public:
     MuscleAlignDialogController(QWidget* w, const MAlignment& ma, MuscleTaskSettings& settings);
     
-    QList< RemoteMachineSettings* > getSelectedMachines() const;
-    
 public slots:
     void accept();
 
 private slots:
     void sl_onPresetChanged(int current);
-    void sl_remoteRunButtonClicked();
     
 private:
     void initPresets();
@@ -80,10 +78,26 @@ private:
     MAlignment                          ma;
     MuscleTaskSettings&                 settings;
     GAutoDeleteList<MuscleAlignPreset>  presets;
-    
-    QList< RemoteMachineSettings* >     machines; /* not empty if remote run was chosen */
 };
 
+class MuscleAlignWithExtFileSpecifyDialogController : public QDialog, public Ui_MuscleAlignmentDialog {
+    Q_OBJECT
+
+public:
+    MuscleAlignWithExtFileSpecifyDialogController(QWidget* w, MuscleTaskSettings& settings);
+    
+public slots:
+    void accept();
+
+private slots:
+    void sl_onPresetChanged(int current);
+    void sl_inputFileLineEditChanged(const QString& str);
+private:
+    void initPresets();
+    MuscleTaskSettings&                 settings;
+    GAutoDeleteList<MuscleAlignPreset>  presets;
+    FileLineEdit*                       inputFileLineEdit;
+};
 
 
 }//namespace
