@@ -14,10 +14,10 @@
 #include "MuscleWorkPool.h"
 #include "TaskLocalStorage.h"
 
-#include <core_api/DNAAlphabet.h>
-#include <core_api/DocumentModel.h>
-#include <core_api/Log.h>
-#include <core_api/AppResources.h>
+#include <U2Core/DNAAlphabet.h>
+#include <U2Core/DocumentModel.h>
+#include <U2Core/Log.h>
+#include <U2Core/AppResources.h>
 
 #include <QtCore/QMutex>
 #include <QtCore/QMutexLocker>
@@ -25,11 +25,9 @@
 
 #include "muscle/scorehistory.h"
 
-namespace GB2 {
+namespace U2 {
 
-static LogCategory log(ULOG_CAT_MUSCLE);
-struct Range
-{
+struct Range {
     unsigned m_uBestColLeft;
     unsigned m_uBestColRight;
 };
@@ -531,7 +529,7 @@ void RefineTask::run() {
         _run(); 
         workpool->refineDone = true;
         workpool->mainSem.release(workpool->nThreads);
-        log.trace(QString("Parallel muscle refine stage complete. Elapsed %1 ms").arg(timer.elapsed()));
+        perfLog.trace(QString("Parallel muscle refine stage complete. Elapsed %1 ms").arg(timer.elapsed()));
     }
     catch (MuscleException e) {
         if (!isCanceled()) {
