@@ -8,17 +8,18 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_MUSCLE_TASK_H_
-#define _GB2_MUSCLE_TASK_H_
+#ifndef _U2_MUSCLE_TASK_H_
+#define _U2_MUSCLE_TASK_H_
 
-#include <core_api/Task.h>
-#include <gobjects/MAlignmentObject.h>
+#include <U2Core/Task.h>
+#include <U2Core/MAlignmentObject.h>
+#include <U2Core/SaveDocumentTask.h>
 
 #include <QtCore/QPointer>
 
 class MuscleContext;
 
-namespace GB2 {
+namespace U2 {
 
 class StateLock;
 class MAlignmentObject;
@@ -52,6 +53,7 @@ public:
 
     //number of threads: 0 - auto, 1 - serial
     int nThreads;
+    QString         inputFilePath;
 
 };
 
@@ -109,5 +111,23 @@ public:
     MuscleTask*                 muscleTask;
     MuscleTaskSettings          config;
 };
+
+class MuscleWithExtFileSpecifySupportTask : public Task {
+public:
+    MuscleWithExtFileSpecifySupportTask(const MuscleTaskSettings& config);
+    void prepare();
+    Task::ReportResult report();
+
+    QList<Task*> onSubTaskFinished(Task* subTask);
+private:
+    MAlignmentObject*   mAObject;
+    Document*           currentDocument;
+
+    SaveDocumentTask*   saveDocumentTask;
+    LoadDocumentTask*   loadDocumentTask;
+    MuscleGObjectTask*  muscleGObjectTask;
+    MuscleTaskSettings  config;
+};
+
 }//namespace
 #endif
