@@ -9,11 +9,11 @@
 *****************************************************************/
 
 #include "MuscleWorkPool.h"
-#include <core_api/Log.h>
+#include <U2Core/Log.h>
 
-namespace GB2 {
+namespace U2 {
 
-    extern LogCategory log;
+    extern Logger log;
 
     MuscleWorkPool::MuscleWorkPool(MuscleContext *_ctx, const MuscleTaskSettings  &_config, TaskStateInfo& _ti, int _nThreads, const MAlignment& _ma, MAlignment& _res, bool _mhack)
         :ctx(_ctx), config(_config), ma(_ma), res(_res), mhack(_mhack), Weights(NULL), ProgNodes(NULL), ph(NULL), ti(_ti),
