@@ -15,7 +15,7 @@
 
 class MuscleContext;
 
-namespace GB2 {
+namespace U2 {
 
 class MuscleContextTLSRef {
 public:
