@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -12,6 +12,7 @@
 #include "msa.h"
 #include "profile.h"
 #include "pwpath.h"
+#include "muscle_context.h"
 
 SCORE GlobalAlign4(ProfPos *PA, unsigned uLengthA, ProfPos *PB,
   unsigned uLengthB, PWPath &Path);
@@ -21,8 +22,10 @@ SCORE AlignTwoProfs(
   const ProfPos *PB, unsigned uLengthB, WEIGHT wB,
   PWPath &Path, ProfPos **ptrPout, unsigned *ptruLengthOut)
 	{
-	assert(uLengthA < 100000);
-	assert(uLengthB < 100000);
+	if(uLengthA >= 100000 || uLengthB >= 100000)
+		throw MuscleException("Can't align sequence longer 100000");
+	//assert(uLengthA < 100000);
+	//assert(uLengthB < 100000);
 
 	float r = (float) uLengthA/ (float) (uLengthB + 1); // +1 to prevent div 0
 	if (r < 1)
