@@ -1,6 +1,6 @@
 /*****************************************************************
 * Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
+* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
@@ -18,8 +18,8 @@ static char szOnExceptionMessage[] =
 
 void OnException()
 	{
-	fprintf(stderr, szOnExceptionMessage);
-	Log(szOnExceptionMessage);
-	Log("Finished %s\n", GetTimeAsStr());
+	fprintf(stderr, "%s", szOnExceptionMessage);
+	//Log(szOnExceptionMessage);
+        //Log("Finished %s\n", GetTimeAsStr());
 	exit(EXIT_Except);
 	}
