@@ -12,34 +12,28 @@
 #include "MuscleConstants.h"
 #include "MuscleTask.h"
 #include "MuscleParallel.h"
-#include <muscle_local_task/MuscleLocalTask.h>
 
-#include <util_tasks/LoadDocumentTask.h>
-#include <util_tasks/SaveDocumentTask.h>
+#include <U2Core/LoadDocumentTask.h>
+#include <U2Core/SaveDocumentTask.h>
 
-#include <core_api/DocumentModel.h>
-#include <core_api/DocumentFormats.h>
-#include <core_api/AppContext.h>
-#include <core_api/IOAdapter.h>
-#include <core_api/Log.h>
+#include <U2Core/DocumentModel.h>
+#include <U2Core/BaseDocumentFormats.h>
+#include <U2Core/AppContext.h>
+#include <U2Core/IOAdapter.h>
+#include <U2Core/Log.h>
 
-#include <gobjects/GObjectTypes.h>
-#include <gobjects/MAlignmentObject.h>
-#include <gobjects/DNASequenceObject.h>
+#include <U2Core/GObjectTypes.h>
+#include <U2Core/MAlignmentObject.h>
+#include <U2Core/DNASequenceObject.h>
 
 #include <QtCore/QDir>
 
-#include <distributed_computing/RemoteTask.h>
-#include <distributed_computing/SerializeUtils.h>
+/* TRANSLATOR U2::GTest*/
 
-/* TRANSLATOR GB2::GTest*/
-
-namespace GB2 {
+namespace U2 {
 
 extern double QScore(const MAlignment& maTest, const MAlignment& maRef, TaskStateInfo& ti);
 
-static LogCategory log(ULOG_CAT_MUSCLE);
-
 #define OUT_FILE_NAME_ATTR "out"
 #define IN_FILE_NAME_ATTR "in"
 #define QSCORE_ATTR "qscr"
@@ -422,10 +416,8 @@ void GTest_Muscle_Load_Align_QScore::init(XMLTestFormat *tf, const QDomElement&
     muscleTask = NULL;
     ma1 = NULL;
     ma2 = NULL;
-    machine = NULL;
-    machinePath = env->getVar( MACHINE_PATH );
-
-    if(inFileURL.isEmpty()) {
+    
+    if (inFileURL.isEmpty()) {
         failMissingValue(IN_FILE_NAME_ATTR); 
         return;
     }
@@ -480,15 +472,6 @@ void GTest_Muscle_Load_Align_QScore::prepare() {
         return;
     }
 
-    if( !machinePath.isEmpty() ) {
-        machinePath = env->getVar( "COMMON_DATA_DIR" ) + "/" + machinePath;
-        if( !SerializeUtils::deserializeRemoteMachineSettingsFromFile( machinePath, &machine ) ) {
-            assert( NULL == machine );
-            setError( "cannot_create_remote_machine" );
-            return;
-        }
-    }
-
     IOAdapterFactory* iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::url2io(env->getVar("COMMON_DATA_DIR")+"/"+inFileURL));
     loadTask1 = new LoadDocumentTask(BaseDocumentFormats::PLAIN_FASTA,env->getVar("COMMON_DATA_DIR")+"/"+inFileURL,iof);
     loadTask1->setSubtaskProgressWeight(0);
@@ -551,13 +534,7 @@ QList<Task*> GTest_Muscle_Load_Align_QScore::onSubTaskFinished(Task* subTask) {
             return res;
         }
 
-        if( NULL != machine ) { /* run task on remote machine */
-            MuscleLocalTaskSettings localTaskSettings( ma1->getMAlignment(), config );
-            muscleTask = new RemoteTask( MuscleLocalTaskFactory::ID, localTaskSettings, machine );
-        } else { /* ordinary task on local machine */
-            muscleTask = new MuscleTask(ma1->getMAlignment(),config);
-        }
-
+        
         res << muscleTask;
         this->connect(muscleTask,SIGNAL(si_progressChanged()),SLOT(sl_muscleProgressChg()));
     }
@@ -566,17 +543,11 @@ QList<Task*> GTest_Muscle_Load_Align_QScore::onSubTaskFinished(Task* subTask) {
             setError( muscleTask->getError() );
             return res;
         }
-        if( NULL != machine ) {
-            RemoteTask * remoteTask = qobject_cast< RemoteTask* >( subTask );
-            assert( NULL != remoteTask );
-            MuscleLocalTaskResult * result = dynamic_cast< MuscleLocalTaskResult* >( remoteTask->getResult() );
-            assert( NULL != result );
-            ma1->setMAlignment( result->getMa() );
-        } else {
-            MuscleTask * localMuscle = qobject_cast<MuscleTask*>( subTask );
-            assert( NULL != localMuscle );
-            ma1->setMAlignment( localMuscle->resultMA );
-        }
+        
+        MuscleTask * localMuscle = qobject_cast<MuscleTask*>( subTask );
+        assert( NULL != localMuscle );
+        ma1->setMAlignment( localMuscle->resultMA );
+        
     }
     else if (subTask == loadTask2) {
         if (loadTask2->hasErrors()) {
@@ -630,15 +601,11 @@ Task::ReportResult GTest_Muscle_Load_Align_QScore::report() {
 }
 
 GTest_Muscle_Load_Align_QScore::~GTest_Muscle_Load_Align_QScore() {
-    if( NULL != machine ) {
-        delete machine;
-        machine = NULL;
-    }
 }
 
 Muscle_Load_Align_Compare_Task::Muscle_Load_Align_Compare_Task( QString inFileURL, QString patFileURL, 
-                                                                MuscleTaskSettings& _config, QString _name, RemoteMachine * m)
-: Task(_name, TaskFlags_FOSCOE), str_inFileURL(inFileURL), str_patFileURL(patFileURL),muscleTask(NULL), config(_config), machine( m )
+                                                                MuscleTaskSettings& _config, QString _name)
+: Task(_name, TaskFlags_FOSCOE), str_inFileURL(inFileURL), str_patFileURL(patFileURL),muscleTask(NULL), config(_config)
 {
     //QFileInfo fInf(inFileURL);
     //setTaskName("Muscle_Load_Align_Compare_Task: " + fInf.fileName());
@@ -680,7 +647,6 @@ MAlignment Muscle_Load_Align_Compare_Task::dna_to_ma(QList<GObject*> dnaSeqs) {
 }
 
 QList<Task*> Muscle_Load_Align_Compare_Task::onSubTaskFinished(Task* subTask) {
-    Q_UNUSED(subTask);
     QList<Task*> res;
     if (hasErrors() || isCanceled()) {
         return res;
@@ -712,12 +678,7 @@ QList<Task*> Muscle_Load_Align_Compare_Task::onSubTaskFinished(Task* subTask) {
             return res;
         }
         
-        if( NULL != machine ) { /* run task on remote machine */
-            MuscleLocalTaskSettings localTaskSettings( ma1->getMAlignment(), config );
-            muscleTask = new RemoteTask( MuscleLocalTaskFactory::ID, localTaskSettings, machine );
-        } else { /* ordinary task on local machine */
-            muscleTask = new MuscleTask(ma1->getMAlignment(),config);
-        }
+        muscleTask = new MuscleTask(ma1->getMAlignment(),config);
         
         res << muscleTask;
         this->connect(muscleTask,SIGNAL(si_progressChanged()),SLOT(sl_muscleProgressChg()));
@@ -727,17 +688,10 @@ QList<Task*> Muscle_Load_Align_Compare_Task::onSubTaskFinished(Task* subTask) {
             setError( muscleTask->getError() );
             return res;
         }
-        if( NULL != machine ) {
-            RemoteTask * remoteTask = qobject_cast< RemoteTask* >( subTask );
-            assert( NULL != remoteTask );
-            MuscleLocalTaskResult * result = dynamic_cast< MuscleLocalTaskResult* >( remoteTask->getResult() );
-            assert( NULL != result );
-            ma1->setMAlignment( result->getMa() );
-        } else {
-            MuscleTask * localMuscle = qobject_cast<MuscleTask*>( subTask );
-            assert( NULL != localMuscle );
-            ma1->setMAlignment( localMuscle->resultMA );
-        }
+        MuscleTask * localMuscle = qobject_cast<MuscleTask*>( subTask );
+        assert( NULL != localMuscle );
+        ma1->setMAlignment( localMuscle->resultMA );
+
     }
     else if (subTask == loadTask2) {
         if (loadTask2->hasErrors()) {
@@ -814,12 +768,8 @@ Task::ReportResult Muscle_Load_Align_Compare_Task::report() {
     return ReportResult_Finished;
 }
 
-void GTest_Muscle_Load_Align_Compare::init(XMLTestFormat *tf, const QDomElement& el) {
-    Q_UNUSED(tf);
+void GTest_Muscle_Load_Align_Compare::init(XMLTestFormat *, const QDomElement& el) {
     inFileURL = el.attribute(IN_FILE_NAME_ATTR);
-    machinePath = env->getVar( MACHINE_PATH );
-    machine = NULL;
-
     if (inFileURL.isEmpty()) {
         failMissingValue(IN_FILE_NAME_ATTR); 
         return;
@@ -853,18 +803,6 @@ void GTest_Muscle_Load_Align_Compare::prepare() {
         return;
     }
     
-    if( !machinePath.isEmpty() ) {
-        machinePath = env->getVar( "COMMON_DATA_DIR" ) + "/" + machinePath;
-        if( !SerializeUtils::deserializeRemoteMachineSettingsFromFile( machinePath, &machine ) ) {
-            assert( NULL == machine );
-            setError( "cannot_create_remote_machine" );
-            return;
-        }
-        worker = new Muscle_Load_Align_Compare_Task(inFile.absoluteFilePath(),patFile.absoluteFilePath(),mSettings,inFile.fileName(), machine);
-        addSubTask(worker);
-        return;
-    }
-    
     worker = new Muscle_Load_Align_Compare_Task(inFile.absoluteFilePath(),patFile.absoluteFilePath(),mSettings,inFile.fileName());
     addSubTask(worker);
 }
@@ -875,13 +813,9 @@ Task::ReportResult GTest_Muscle_Load_Align_Compare::report() {
 }
 
 GTest_Muscle_Load_Align_Compare::~GTest_Muscle_Load_Align_Compare() {
-    if( NULL != machine ) {
-        delete machine;
-        machine = NULL;
-    }
 }
 
-void GTest_uMusclePacketTest::init(GB2::XMLTestFormat *tf, const QDomElement &el) {
+void GTest_uMusclePacketTest::init(U2::XMLTestFormat *tf, const QDomElement &el) {
     Q_UNUSED(tf);
     int nThread = qMax(0, getEnv()->getVar("NUM_THREADS").toInt());
     setMaxParallelSubtasks(nThread);
@@ -944,8 +878,9 @@ void GTest_uMusclePacketTest::prepare() {
 
 Task::ReportResult GTest_uMusclePacketTest::report() {
     propagateSubtaskError();
-    if(!hasErrors())
-        log.trace(QString("uMusclePacketTest: \"%1\" accomplished. Time elapsed: %2 ms").arg(inDirName).arg(timer.elapsed()));
+    if (!hasErrors()) {
+        algoLog.trace(QString("uMusclePacketTest: \"%1\" accomplished. Time elapsed: %2 ms").arg(inDirName).arg(timer.elapsed()));
+    }
     return ReportResult_Finished;
 }
 
