@@ -8,19 +8,19 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_MUSCLE_TESTS_H_
-#define _GB2_MUSCLE_TESTS_H_
+#ifndef _U2_MUSCLE_TESTS_H_
+#define _U2_MUSCLE_TESTS_H_
+
+#include <U2Core/GObject.h>
+#include <U2Test/XMLTestUtils.h>
 
-#include <test_framework/xmltest/XMLTestUtils.h>
-#include <core_api/GObject.h>
 #include <QtXml/QDomElement>
-#include <QFileInfo>
+#include <QtCore/QFileInfo>
 
-#include <distributed_computing/RemoteMachine.h>
 
 #include "MuscleTask.h"
 
-namespace GB2 {
+namespace U2 {
 
 class MuscleGObjectTask;
 class MAlignmentObject;
@@ -102,21 +102,17 @@ private:
 	double dqscore;
 	LoadDocumentTask*           loadTask1;
 	LoadDocumentTask*           loadTask2;
-	Task*                       muscleTask; /* MuscleTask or RemoteTask */
+	Task*                       muscleTask; 
 	MuscleTaskSettings          config;
 	MAlignmentObject*           ma1;
 	MAlignmentObject*           ma2;
-    
-    RemoteMachine * machine; /* for remote suite tests */
-    QString         machinePath;
-    
 };
 
 class  Muscle_Load_Align_Compare_Task : public Task {
     Q_OBJECT
 public:
     Muscle_Load_Align_Compare_Task(QString inFileURL, QString patFileURL, MuscleTaskSettings& config, 
-        QString _name = QString("Muscle_Load_Align_Compare_Task"), RemoteMachine * machine = NULL );
+        QString _name = QString("Muscle_Load_Align_Compare_Task"));
     ~Muscle_Load_Align_Compare_Task() {cleanup();}
     void prepare();
     void run();
@@ -133,13 +129,10 @@ private:
     QString str_patFileURL;
     LoadDocumentTask*           loadTask1;
     LoadDocumentTask*           loadTask2;
-    Task*                       muscleTask; /* MuscleTask or RemoteTask */
+    Task*                       muscleTask; 
     MuscleTaskSettings          config;
     MAlignmentObject*           ma1;
     MAlignmentObject*           ma2;
-    
-    RemoteMachine *             machine;
-    
 };
 
 class GTest_Muscle_Load_Align_Compare: public GTest {
@@ -153,10 +146,6 @@ private:
     QString inFileURL;
     QString patFileURL;
     Muscle_Load_Align_Compare_Task *worker;
-    
-    RemoteMachine * machine; /* for remote suite tests */
-    QString         machinePath;
-    
 };
 
 class GTest_uMusclePacketTest: public GTest {
