@@ -11,15 +11,15 @@
 
 #include <QtCore/QEventLoop>
 
-#include <core_api/Log.h>
+#include <U2Core/Log.h>
 
 #include "ForeverTask.h"
 
 #define FOREVER_TASK_LOG_CAT "Forever task"
 
-namespace GB2 {
+namespace U2 {
 
-LogCategory log( FOREVER_TASK_LOG_CAT );
+Logger log( FOREVER_TASK_LOG_CAT );
 
 ForeverTask::ForeverTask() : Task( "Forever task", TaskFlag_None ) {
     log.trace( tr( "Forever task created" ) );
@@ -33,4 +33,4 @@ void ForeverTask::run() {
     loop.exec();
 }
 
-} // GB2
+} // U2
