@@ -9,12 +9,12 @@
 *****************************************************************/
 
 
-#ifndef _GB2_FOREVER_TASK_H_
-#define _GB2_FOREVER_TASK_H_
+#ifndef _U2_FOREVER_TASK_H_
+#define _U2_FOREVER_TASK_H_
 
-#include <core_api/Task.h>
+#include <U2Core/Task.h>
 
-namespace GB2 {
+namespace U2 {
 
 /* need for congene not to die */
 class ForeverTask : public Task {
@@ -27,6 +27,6 @@ public:
     
 }; // ForeverTask
 
-} // GB2
+} // U2
 
-#endif // _GB2_FOREVER_TASK_H_
+#endif // _U2_FOREVER_TASK_H_
