@@ -11,9 +11,9 @@
 #ifndef _TASK_STATUS_BAR_CON_H_
 #define _TASK_STATUS_BAR_CON_H_
 
-#include <core_api/Task.h>
+#include <U2Core/Task.h>
 #define TSB_SETTINGS_ROOT QString("task_status_bar_settings/")
-namespace GB2 {
+namespace U2 {
 
 
 class TaskStatusBarCon : public QObject {
