@@ -8,80 +8,87 @@
 *     for details.
 *****************************************************************/
 
-#include <core_services/AppContextImpl.h>
-#include <core_services/SettingsImpl.h>
-#include <core_services/DocumentFormatRegistryImpl.h>
-#include <core_services/IOAdapterRegistryImpl.h>
+#include <AppContextImpl.h>
+#include <SettingsImpl.h>
+#include <DocumentFormatRegistryImpl.h>
+#include <IOAdapterRegistryImpl.h>
+#include <PluginSupportImpl.h>
+#include <ServiceRegistryImpl.h>
+#include <TaskSchedulerImpl.h>
+#include <AppSettingsImpl.h>
+
+#include "app_settings/AppSettingsGUIImpl.h"
+#include "app_settings/logview_settings/LogSettingsGUIController.h"
 
-#include "plugin_support/PluginSupportImpl.h"
-#include "plugin_support/ServiceRegistryImpl.h"
 #include "plugin_viewer/PluginViewerImpl.h"
 #include "project_support/ProjectLoaderImpl.h"
 #include "main_window/MainWindowImpl.h"
 #include "project_view/ProjectViewImpl.h"
-#include "logview/LogCache.h"
-#include "logview/LogView.h"
-#include <task_scheduler/TaskSchedulerImpl.h>
+
 #include "task_view/TaskViewController.h"
-#include <core_services/AppSettingsImpl.h>
-#include "app_settings/AppSettingsGUIImpl.h"
 #include "shtirlitz/Shtirlitz.h"
-#include <util_msa_consensus/MSAConsensusAlgorithmRegistry.h>
-#include <util_weight_matrix/PWMConversionAlgorithmRegistry.h>
+#include <U2Algorithm/MSAConsensusAlgorithmRegistry.h>
+#include <U2Algorithm/MSADistanceAlgorithmRegistry.h>
+#include <U2Algorithm/PWMConversionAlgorithmRegistry.h>
 
-#include <core_api/Log.h>
-#include <core_api/Timer.h>
-#include <core_api/GUrlUtils.h>
-#include <core_api/DNATranslation.h>
-#include <core_api/ObjectViewModel.h>
-#include <core_api/ResourceTracker.h>
-#include <core_api/DocumentFormatConfigurators.h>
-#include <core_api/DBXRefRegistry.h>
-#include <core_api/UserApplicationsSettings.h>
-#include <core_api/SecStructPredictAlgRegistry.h>
-#include <core_api/CudaGpuRegistry.h>
-#include <core_api/AtiStreamGpuRegistry.h>
-#include <core_api/VirtualFileSystem.h>
+#include <U2Core/Log.h>
+#include <U2Core/Timer.h>
+#include <U2Core/GUrlUtils.h>
+#include <U2Core/DNATranslation.h>
+#include <U2Gui/ObjectViewModel.h>
+#include <U2Core/ResourceTracker.h>
+#include <U2Core/DocumentFormatConfigurators.h>
+#include <U2Core/DBXRefRegistry.h>
+#include <U2Core/UserApplicationsSettings.h>
+#include <U2Algorithm/SecStructPredictAlgRegistry.h>
+#include <U2Algorithm/CudaGpuRegistry.h>
+#include <U2Algorithm/OpenCLGpuRegistry.h>
+//#include <U2Core/VirtualFileSystem.h>
+#include <CrashHandler.h>
 
-#include <core_api/SubstMatrixRegistry.h>
-#include <core_api/SWResultFilterRegistry.h>
-#include <core_api/SmithWatermanTaskFactoryRegistry.h>
-#include <core_api/DnaAssemblyAlgRegistry.h>
-#include <core_api/DataBaseRegistry.h>
-#include <core_api/RepeatFinderTaskFactoryRegistry.h>
+#include <U2Algorithm/SubstMatrixRegistry.h>
+#include <U2Algorithm/SWResultFilterRegistry.h>
+#include <U2Algorithm/SmithWatermanTaskFactoryRegistry.h>
+#include <U2Algorithm/DnaAssemblyAlgRegistry.h>
+#include <U2Algorithm/MSAAlignAlgRegistry.h>
+#include <U2Core/DataBaseRegistry.h>
+#include <U2Algorithm/RepeatFinderTaskFactoryRegistry.h>
+#include <U2Core/ExternalToolRegistry.h>
 
-#include <cmdline/CMDLineRegistry.h>
-#include <cmdline/CMDLineUtils.h>
-#include <cmdline/CMDLineCoreOptions.h>
+#include <U2Core/CMDLineRegistry.h>
+#include <U2Core/CMDLineUtils.h>
+#include <U2Core/CMDLineCoreOptions.h>
 
-#include <molecular_geometry/MolecularSurfaceFactoryRegistry.h>
-#include <phyltree/PhyTreeGeneratorRegistry.h>
+#include <U2Algorithm/MolecularSurfaceFactoryRegistry.h>
+#include <U2Algorithm/PhyTreeGeneratorRegistry.h>
 
-#include <document_format/DNAAlphabetRegistryImpl.h>
-#include <gobjects/AnnotationSettings.h>
-#include <gobjects/GObjectTypes.h>
-#include <test_framework/GTestFrameworkComponents.h>
-#include <util_gui/BaseDocumentFormatConfigurators.h>
-#include <util_ov_msaedit/MSAColorScheme.h>
+#include <U2Core/DNAAlphabetRegistryImpl.h>
+#include <U2Core/AnnotationSettings.h>
+#include <U2Core/GObjectTypes.h>
+#include <U2Test/GTestFrameworkComponents.h>
+#include <U2Gui/BaseDocumentFormatConfigurators.h>
+#include <U2View/MSAColorScheme.h>
 
-#include <workflow_support/WorkflowEnvImpl.h>
-#include <workflow_library/BioActorLibrary.h>
-#include <util_tasks/TaskStarter.h>
-#include <util_tasks/LoadRemoteDocumentTask.h>
-#include <util_index_support/UIndexSupport.h>
-#include <util_dna_assembly/DnaAssemblyUtils.h>
+#include <U2Lang/WorkflowEnvImpl.h>
+#include <U2Lang/BioActorLibrary.h>
+#include <U2Core/TaskStarter.h>
+#include <U2Core/LoadRemoteDocumentTask.h>
+#include <U2View/UIndexSupport.h>
+#include <U2View/DnaAssemblyUtils.h>
+#include <U2View/MSAAlignUtils.h>
+#include <U2Lang/QueryDesignerRegistry.h>
+#include <U2Core/LogCache.h>
+#include <U2Gui/LogView.h>
 
 #include <QtGui/QApplication>
 #include <QtGui/QIcon>
 
-#include <distributed_computing/DistributedComputingUtil.h>
-
-#include <test_framework/xmltest/XMLTestFormat.h>
+#include <U2Remote/DistributedComputingUtil.h>
+#include <U2Formats/DocumentFormatUtils.h>
+#include <U2Test/XMLTestFormat.h>
 #include <project_support/ProjectTasksGui.h>
 
-static GB2::LogCategory logCat(ULOG_CAT_USER_INTERFACE);
-
-/* TRANSLATOR GB2::AppContextImpl */
+/* TRANSLATOR U2::AppContextImpl */
 
 #if defined(Q_WS_WIN) || defined(Q_WS_MAC)
 QT_BEGIN_NAMESPACE
@@ -89,7 +96,11 @@ extern Q_GUI_EXPORT bool qt_use_native_dialogs;
 QT_END_NAMESPACE
 #endif
 
-namespace GB2 {
+#ifdef _DEBUG //force no crash handler mode in debug build
+#undef USE_CRASHHANDLER
+#endif
+
+namespace U2 {
 
 static void registerCoreServices() {
     ServiceRegistry* sr = AppContext::getServiceRegistry();
@@ -101,7 +112,7 @@ static void registerCoreServices() {
 
 }//namespace
 
-using namespace GB2;
+using namespace U2;
 
 static void updateStaticTranslations() {
     GObjectTypes::initTypeTranslations();
@@ -112,7 +123,7 @@ static void setDataSearchPaths() {
     //set search paths for data files
     QStringList dataSearchPaths;
 #if (defined(Q_OS_LINUX) || defined(Q_OS_UNIX)) && defined( UGENE_DATA_DIR )
-    //using directory which is set during installation process on linux
+    //using directory which is set during installation process on Linux
     QString ugene_data_dir( UGENE_DATA_DIR );
     if( QDir(ugene_data_dir).exists() ) {
         dataSearchPaths.push_back( QString(UGENE_DATA_DIR) );
@@ -138,13 +149,56 @@ static void setSearchPaths() {
     setDataSearchPaths();
 }
 
+
+static void initLogsCache(LogCacheExt& logsCache, const QStringList& envList) {
+#ifdef _DEBUG
+    logsCache.setConsoleOutputEnabled(true);
+#else
+    QString consoleOutVal = qgetenv("UGENE_PRINT_TO_CONSOLE");
+    logsCache.setConsoleOutputEnabled(consoleOutVal == "true" || consoleOutVal == "1");
+#endif
+    QString file = qgetenv("UGENE_PRINT_TO_FILE");
+    if (!file.isEmpty()) {
+        logsCache.setFileOutputEnabled(file);
+    }
+}
+
+class GApplication: public QApplication {
+public:
+    GApplication(int & argc, char ** argv): QApplication(argc, argv) {}
+    virtual bool notify(QObject * receiver, QEvent * event ) {
+        bool res;
+#if defined(USE_CRASHHANDLER)
+        try {
+            res = QApplication::notify(receiver, event);
+        } catch(...) {
+            if(CrashHandler::buffer) {
+                CrashHandler::releaseReserve();
+            }
+
+            CrashHandler::runMonitorProcess("C++ exception|Unhandled exception");
+        }
+#else
+        res = QApplication::notify(receiver, event);
+#endif
+        return res;
+    }
+
+};
+
 int main(int argc, char **argv) 
 {
+#if defined(USE_CRASHHANDLER)
+    CrashHandler::setupHandler();
+    CrashHandler::allocateReserve();
+#endif
+
     QT_REQUIRE_VERSION( argc, argv, QT_VERSION_STR );
 
     GTIMER(c1, t1, "main()->QApp::exec");
-
-    QApplication app(argc, argv);
+    
+    //QApplication app(argc, argv);
+    GApplication app(argc, argv);
     QCoreApplication::addLibraryPath(QCoreApplication::applicationDirPath());
 
 // add some extra paths used during development
@@ -160,6 +214,7 @@ int main(int argc, char **argv)
     setSearchPaths();
 
     AppContextImpl* appContext = AppContextImpl::getApplicationContext();
+    appContext->setGUIMode(true);
 
     // parse all cmdline arguments
     CMDLineRegistry* cmdLineRegistry = new CMDLineRegistry(app.arguments()); 
@@ -170,7 +225,6 @@ int main(int argc, char **argv)
     appContext->setGlobalSettings(globalSettings);
 
     SettingsImpl* settings = new SettingsImpl(QSettings::UserScope);
-    settings->setValue(GLOBAL_SETTINGS + "drawIcons", true);
     appContext->setSettings(settings);
 
     AppSettings* appSettings = new AppSettingsImpl();
@@ -205,17 +259,21 @@ int main(int argc, char **argv)
     // 3 create functional components of ugene
     QStringList envList = QProcess::systemEnvironment();
 
-    LogCache logsCache;
-#ifdef _DEBUG
-    logsCache.print_to_console=true;
-#else
-    logsCache.print_to_console = envList.indexOf("UGENE_PRINT_TO_CONSOLE=true") >= 0 || envList.indexOf("UGENE_PRINT_TO_CONSOLE=1") >= 0;
-#endif
+    LogCacheExt logsCache;
+    initLogsCache(logsCache, envList);
+    LogCache::setAppGlobalInstance(&logsCache);
+    coreLog.details(AppContextImpl::tr("UGENE initialization started"));
+
+    coreLog.trace(QString("UGENE run at dir %1 with parameters %2").arg(app.applicationDirPath()).arg(app.arguments().join(" ")));
+
+    //print some settings info, can't do it earlier than logging is initialized
+    coreLog.trace(QString("Active UGENE.ini file : %1").arg(AppContext::getSettings()->fileName()));
+//    logCat.trace(QString("INI-var: %1").arg(AppContext::getCMDLineRegistry()->getParameterValue( CMDLineCoreOptions::INI_FILE)));
 
-    logCat.details(AppContextImpl::tr("UGENE initialization started"));
 
 #if defined(Q_WS_WIN) || defined(Q_WS_MAC)
-    qt_use_native_dialogs = envList.indexOf("UGENE_USE_NATIVE_DIALOGS=false") < 0 && envList.indexOf("UGENE_USE_NATIVE_DIALOGS=0") < 0;
+    bool useNative = envList.indexOf("UGENE_USE_NATIVE_DIALOGS=false") < 0 && envList.indexOf("UGENE_USE_NATIVE_DIALOGS=0") < 0;
+    qt_use_native_dialogs = useNative; //using local here for debugger
 #endif
 
     QString style = userAppSettings->getVisualStyle();
@@ -224,7 +282,7 @@ int main(int argc, char **argv)
         if (qstyle!=NULL) {
             app.setStyle(qstyle);
         } else {
-            logCat.details(AppContextImpl::tr("Style not available %1").arg(style));
+            uiLog.details(AppContextImpl::tr("Style not available %1").arg(style));
         }
     } 
     
@@ -234,7 +292,7 @@ int main(int argc, char **argv)
     TaskSchedulerImpl* ts = new TaskSchedulerImpl(appSettings->getAppResourcePool());
     appContext->setTaskScheduler(ts);
 
-    AnnotationSettingsRegistry* asr = new AnnotationSettingsRegistry();
+    AnnotationSettingsRegistry* asr = new AnnotationSettingsRegistry(DocumentFormatUtils::predefinedSettings());
     appContext->setAnnotationSettingsRegistry(asr);
 
     TestFramework* tf = new TestFramework();
@@ -256,7 +314,13 @@ int main(int argc, char **argv)
     appContext->setAppSettingsGUI(appSettingsGUI);
 
     AppContext::getMainWindow()->getDockManager()->registerDock(MWDockArea_Bottom, new TaskViewDockWidget(), QKeySequence(Qt::ALT | Qt::Key_2));
-    AppContext::getMainWindow()->getDockManager()->registerDock(MWDockArea_Bottom, new LogViewDockWidget(&logsCache), QKeySequence(Qt::ALT | Qt::Key_3));
+    
+    // Initialize logged log view
+    LogViewWidget* logView = new LogViewWidget(&logsCache);
+    logView->setObjectName(DOCK_LOG_VIEW);
+    AppContext::getAppSettingsGUI()->registerPage(new LogSettingsPageController(logView));
+    AppContext::getMainWindow()->getDockManager()->registerDock(MWDockArea_Bottom, logView, QKeySequence(Qt::ALT | Qt::Key_3));
+    
     
     GObjectViewFactoryRegistry* ovfr = new GObjectViewFactoryRegistry();
     appContext->setObjectViewFactoryRegistry(ovfr);
@@ -295,6 +359,9 @@ int main(int argc, char **argv)
     MSAConsensusAlgorithmRegistry* msaConsReg = new MSAConsensusAlgorithmRegistry();
     appContext->setMSAConsensusAlgorithmRegistry(msaConsReg);
 
+    MSADistanceAlgorithmRegistry* msaDistReg = new MSADistanceAlgorithmRegistry();
+    appContext->setMSADistanceAlgorithmRegistry(msaDistReg);
+
     PWMConversionAlgorithmRegistry* pwmConvReg = new PWMConversionAlgorithmRegistry();
     appContext->setPWMConversionAlgorithmRegistry(pwmConvReg);
 
@@ -307,6 +374,12 @@ int main(int argc, char **argv)
     RepeatFinderTaskFactoryRegistry* rfr = new RepeatFinderTaskFactoryRegistry();
     appContext->setRepeatFinderTaskFactoryRegistry(rfr);
 
+    ExternalToolRegistry* etr = new ExternalToolRegistry();
+    appContext->setExternalToolRegistry(etr);
+
+    QDActorPrototypeRegistry* qpr = new QDActorPrototypeRegistry();
+    appContext->setQDActorFactoryRegistry(qpr);
+
     CMDLineUtils::init();
     
     PhyTreeGeneratorRegistry* genRegistry = new PhyTreeGeneratorRegistry();
@@ -324,8 +397,8 @@ int main(int argc, char **argv)
     CudaGpuRegistry * cgr = new CudaGpuRegistry();
     appContext->setCudaGpuRegistry(cgr); 
 
-    AtiStreamGpuRegistry * asgr = new AtiStreamGpuRegistry ();
-    appContext->setAtiStreamGpuRegistry( asgr ); 
+    OpenCLGpuRegistry * oclgr = new OpenCLGpuRegistry();
+    appContext->setOpenCLGpuRegistry( oclgr );
 
     RecentlyDownloadedCache* rdc = new RecentlyDownloadedCache();
     appContext->setRecentlyDownloadedCache(rdc);
@@ -344,6 +417,9 @@ int main(int argc, char **argv)
     appContext->setDnaAssemblyAlgRegistry(assemblyReg);
     DnaAssemblySupport assemblySupport;
 
+    MSAAlignAlgRegistry* alignReg = new MSAAlignAlgRegistry();
+    appContext->setMSAAlignAlgRegistry(alignReg);
+
     DataBaseRegistry *dbr = new DataBaseRegistry();
     appContext->setDataBaseRegistry(dbr);
 
@@ -376,7 +452,7 @@ int main(int argc, char **argv)
 
     //3 run QT GUI
     t1.stop();
-    logCat.info(AppContextImpl::tr("UGENE started"));
+    coreLog.info(AppContextImpl::tr("UGENE started"));
     int rc = app.exec();
 
     //4 deallocate resources
@@ -421,6 +497,9 @@ int main(int argc, char **argv)
     appContext->setPluginSupport(NULL);
     delete psp;
 
+    appContext->setExternalToolRegistry(NULL);
+    delete etr;
+
     appContext->setMainWindow(NULL);
     delete mw;
 
@@ -457,8 +536,35 @@ int main(int argc, char **argv)
     appContext->setCudaGpuRegistry(NULL);
     delete cgr;
 
-    appContext->setAtiStreamGpuRegistry(NULL);
-    delete asgr;
+    delete oclgr;
+    appContext->setOpenCLGpuRegistry(NULL);
+
+    delete cmdLineRegistry;
+    appContext->setCMDLineRegistry(NULL);
+
+    appContext->setSecStructPedictAlgRegistry(NULL);
+    delete sspar;
+
+    appContext->setMSAConsensusAlgorithmRegistry(NULL);
+    delete msaConsReg;
+    
+    appContext->setMSADistanceAlgorithmRegistry(NULL);
+    delete msaDistReg;
+
+    appContext->setPWMConversionAlgorithmRegistry(NULL);
+    delete pwmConvReg;
+
+    appContext->setDnaAssemblyAlgRegistry(NULL);
+    delete assemblyReg;
+
+    appContext->setMSAAlignAlgRegistry(NULL);
+    delete alignReg;
+    
+    appContext->setDataBaseRegistry(NULL);
+    delete dbr;
+
+    appContext->setQDActorFactoryRegistry(NULL);
+    delete qpr;
 
     appContext->setAppSettingsGUI(NULL);
     delete appSettingsGUI;
@@ -471,25 +577,7 @@ int main(int argc, char **argv)
 
     appContext->setGlobalSettings(NULL);
     delete globalSettings;
-    
-    delete cmdLineRegistry;
-    appContext->setCMDLineRegistry(NULL);
 
-    appContext->setSecStructPedictAlgRegistry(NULL);
-    delete sspar;
-
-    appContext->setMSAConsensusAlgorithmRegistry(NULL);
-    delete msaConsReg;
-
-    appContext->setPWMConversionAlgorithmRegistry(NULL);
-    delete pwmConvReg;
-
-    appContext->setDnaAssemblyAlgRegistry(NULL);
-    delete assemblyReg;
-    
-    appContext->setDataBaseRegistry(NULL);
-    delete dbr;
-
-    return rc;
+    return rc;   
 }
 
