@@ -8,12 +8,12 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_APPSETTINGS_GUI_IMPL_H_
-#define _GB2_APPSETTINGS_GUI_IMPL_H_
+#ifndef _U2_APPSETTINGS_GUI_IMPL_H_
+#define _U2_APPSETTINGS_GUI_IMPL_H_
 
-#include <core_api/AppSettingsGUI.h>
+#include <U2Gui/AppSettingsGUI.h>
 
-namespace GB2 {
+namespace U2 {
 
 class AppSettingsGUIImpl : public AppSettingsGUI {
     Q_OBJECT
