@@ -10,10 +10,10 @@
 
 #include "AboutDialogController.h"
 
-#include <core_api/AppGlobals.h>
+#include <U2Core/Version.h>
 
-#include <core_api/AppContext.h>
-#include <core_api/Settings.h>
+#include <U2Core/AppContext.h>
+#include <U2Core/Settings.h>
 
 #include <QtGui/QHBoxLayout>
 #include <QtGui/QPainter>
@@ -22,7 +22,7 @@
 #include <QtGui/QStyle>
 #include <assert.h>
 
-namespace GB2 {
+namespace U2 {
 
 AboutDialogController::AboutDialogController(QAction* visitWebAction, QWidget *p):QDialog(p) {
     setupUi(this);
@@ -142,8 +142,9 @@ AWidget::AWidget() {
     QImage image(":ugene/images/about.png");
     QPainter p(&image);
     p.setPen(Qt::lightGray);
-    QString version = QString::number(UGENE_VERSION_1) + "." + QString::number(UGENE_VERSION_2) + "." + QString::number(UGENE_VERSION_3);
-    QString text = "Unipro UGENE v"+version + "\n" + __DATE__;
+    Version v = Version::ugeneVersion();
+    QString version = v.text;
+    QString text = "Unipro UGENE v" + version + "\n" + __DATE__;
     p.drawText(QRect(10, 20, width()-10, 60), text);
     p.end();
 
