@@ -8,12 +8,12 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_CHECK_UPDATES_TASKS_H_
-#define _GB2_CHECK_UPDATES_TASKS_H_
+#ifndef _U2_CHECK_UPDATES_TASKS_H_
+#define _U2_CHECK_UPDATES_TASKS_H_
 
-#include <core_api/Task.h>
+#include <U2Core/Task.h>
 
-namespace GB2 {
+namespace U2 {
 
 class CheckUpdatesTask : public Task {
     Q_OBJECT
