@@ -8,15 +8,15 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_MWTOOLBAR_IMPL_H_
-#define _GB2_MWTOOLBAR_IMPL_H_
+#ifndef _U2_MWTOOLBAR_IMPL_H_
+#define _U2_MWTOOLBAR_IMPL_H_
 
-#include <core_api/MainWindow.h>
+#include <U2Gui/MainWindow.h>
 
 #include <QtGui/QToolBar>
 #include <QtGui/QMainWindow>
 
-namespace GB2 {
+namespace U2 {
 
 class MWToolBarManagerImpl : public MWToolBarManager {
 public:	
