@@ -8,14 +8,14 @@
 *     for details.
 *****************************************************************/
 
-#ifndef _GB2_EXPORT_PROJECT_DIALOG_CONTROLLER_
-#define _GB2_EXPORT_PROJECT_DIALOG_CONTROLLER_
+#ifndef _U2_EXPORT_PROJECT_DIALOG_CONTROLLER_
+#define _U2_EXPORT_PROJECT_DIALOG_CONTROLLER_
 
 #include <ui/ui_ExportProjectDialog.h>
 
-#include <core_api/AppContext.h>
+#include <U2Core/AppContext.h>
 
-namespace GB2 {
+namespace U2 {
 
 class ExportProjectDialogController : public QDialog, public Ui_ExportProjectDialog {
 	Q_OBJECT
