@@ -14,40 +14,42 @@
 #include "ProjectImpl.h"
 #include "ProjectLoaderImpl.h"
 
-#include <core_services/AppContextImpl.h>
+#include <AppContextImpl.h>
 
-#include <util_tasks/SaveDocumentTask.h>
-#include <util_tasks/AddDocumentTask.h>
-#include <util_tasks/LoadDocumentTask.h>
-#include <util_tasks/RemoveDocumentTask.h>
+#include <U2Core/SaveDocumentTask.h>
+#include <U2Core/AddDocumentTask.h>
+#include <U2Core/LoadDocumentTask.h>
+#include <U2Core/RemoveDocumentTask.h>
+#include <U2Gui/OpenViewTask.h>
+#include <U2Gui/UnloadDocumentTask.h>
 
-#include <document_format/DocumentFormatUtils.h>
+#include <U2Core/DocumentUtils.h>
 
-#include <core_api/IOAdapter.h>
-#include <core_api/Log.h>
-#include <core_api/GUrlUtils.h>
-#include <core_api/ObjectViewModel.h>
-#include <core_api/DocumentModel.h>
-#include <core_api/DocumentFormats.h>
-#include <core_api/GHints.h>
-#include <core_api/ProjectView.h>
-#include <core_api/GObject.h>
-#include <core_api/AppSettings.h>
-#include <core_api/L10n.h>
+#include <U2Core/IOAdapter.h>
+#include <U2Core/Log.h>
+#include <U2Core/GUrlUtils.h>
+#include <U2Gui/ObjectViewModel.h>
+#include <U2Core/DocumentModel.h>
+#include <U2Core/BaseDocumentFormats.h>
+#include <U2Core/GHints.h>
+#include <U2Gui/ProjectView.h>
+#include <U2Core/GObject.h>
+#include <U2Core/AppSettings.h>
+#include <U2Core/L10n.h>
 
-#include <gobjects/UnloadedObject.h>
-#include <gobjects/GObjectUtils.h>
+#include <U2Core/CMDLineUtils.h>
 
-#include <util_project/ProjectParsing.h>
+#include <U2Core/UnloadedObject.h>
+#include <U2Core/GObjectUtils.h>
+
+#include <U2Gui/ProjectParsing.h>
 
 #include <QtXml/QDomDocument>
 #include <QtGui/QMessageBox>
 
 #include <QtCore/QMutex>
 
-namespace GB2 {
-
-static LogCategory log(ULOG_CAT_CORE_SERVICES);
+namespace U2 {
 
 //////////////////////////////////////////////////////////////////////////
 ///Close project
@@ -109,12 +111,37 @@ void OpenProjectTask::prepare() {
 
         // close current
         if (AppContext::getProject()!=NULL) {
-            if (!closeActiveProject) {
-                stateInfo.cancelFlag = true;
-                log.info(tr("Stopped loading project: %1. Reason: active project found").arg(url));
-                return;
+            if(url == AppContext::getProject()->getProjectURL()) {
+                coreLog.info(tr("Project already opened"));
+                QMessageBox::critical(AppContext::getMainWindow()->getQMainWindow(),"UGENE", tr("Project already opened"));
+                return ;
             }
-            addSubTask(new CloseProjectTask());
+
+            QMessageBox msgBox(AppContext::getMainWindow()->getQMainWindow());
+            msgBox.setWindowTitle(tr("UGENE"));
+            msgBox.setText(tr("New project can either be opened in a new window or replace the project in the existing. How would you like to open the project?"));
+            QPushButton *newWindow = msgBox.addButton(tr("New Window"), QMessageBox::ActionRole);
+            QPushButton *oldWindow = msgBox.addButton(tr("This Window"), QMessageBox::ActionRole);
+            QPushButton *abort = msgBox.addButton(QMessageBox::Abort);
+            msgBox.exec();
+
+            if(msgBox.clickedButton() == newWindow) {
+                QStringList params =  CMDLineRegistryUtils::getPureValues(0);
+                bool b = QProcess::startDetached(params.first(), QStringList() << url);
+                if(!b) {
+                    coreLog.error(tr("Failed to open new instance of UGENE"));
+                }
+                return;
+            } else if(msgBox.clickedButton() == oldWindow) {
+                if (!closeActiveProject) {
+                    stateInfo.cancelFlag = true;
+                    coreLog.info(tr("Stopped loading project: %1. Reason: active project found").arg(url));
+                    return;
+                }
+                addSubTask(new CloseProjectTask());
+            } else {
+                return;
+            }        
         }
 
         if (f.exists()) {
@@ -132,7 +159,7 @@ void OpenProjectTask::prepare() {
         Project* p = AppContext::getProject();
         if (!p) {
             // create anonymous project
-            log.info(tr("Creating new project"));
+            coreLog.info(tr("Creating new project"));
             p = new ProjectImpl("", "");
             Task* rpt = new RegisterProjectServiceTask(p);
             rpt->setSubtaskProgressWeight(0);
@@ -145,24 +172,30 @@ void OpenProjectTask::prepare() {
                 stateInfo.setError(  tr("ignore %1").arg(url) );
                 continue;
             }
-            Document * doc = p->findDocumentByURL(url);
+            Document * doc = p->findDocumentByURL(_url);
             if (!doc) {
-                QList<DocumentFormat*> fs = DocumentFormatUtils::detectFormat(url);
+                QList<DocumentFormat*> fs = DocumentUtils::detectFormat(_url);
                 if (fs.isEmpty()) {
-                    stateInfo.setError(  tr("unsupported_document%1").arg(url) );
+                    stateInfo.setError(  tr("unsupported_document%1").arg(_url.fileName()) );
                     continue;
                 }
 
                 DocumentFormat* format = fs.first();
                 assert(format);
-                IOAdapterFactory* iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::url2io(url));
-                doc = new Document(format, iof, url);
-                Task * adt = new AddDocumentTask(doc);
-                adt->setSubtaskProgressWeight(0);
-                addSubTask(adt);
+                IOAdapterFactory* iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::url2io(_url));
+                doc = new Document(format, iof, _url);
+                GObjectType t = format->getSupportedObjectTypes().toList().first();
+                if(GObjectTypes::getTypeInfo(t).type != GObjectTypes::UNKNOWN) {
+                    Task * adt = new AddDocumentTask(doc);
+                    adt->setSubtaskProgressWeight(0);
+                    addSubTask(adt);
+                }
+                else {
+                    coreLog.info(tr("Document wasn't added to project: unsupported format"));
+                }
             } else{
                 QWidget *p = AppContextImpl::getMainWindow()->getQMainWindow();
-                log.details("The document already in the project");
+                coreLog.details("The document already in the project");
                 QMessageBox::warning(p, tr("warning"), tr("The document already in the project"));
                 if (doc->isLoaded()) {
                     const QList<GObject*>& docObjects = doc->getObjects();
@@ -172,7 +205,7 @@ void OpenProjectTask::prepare() {
                     }else{
                         AppContext::getProjectView()->highlightItem(doc);
                     }
-                    log.info(tr("The document is already opened: %1").arg(url));
+                    coreLog.info(tr("The document is already opened: %1").arg(_url.fileName()));
                     continue;
                 }else if(!doc->isLoaded() && AppContext::getProjectView()){
                     AppContext::getProjectView()->highlightItem(doc);
@@ -189,6 +222,16 @@ void OpenProjectTask::prepare() {
 
 QList<Task*> OpenProjectTask::onSubTaskFinished(Task* subTask) {
     QList<Task*> res;
+    if(subTask->hasErrors()) {
+        if (subTask == loadProjectTask) {
+            return res;
+        }
+        Project *p = AppContext::getProject();
+        Document * doc = p->findDocumentByURL(url);
+        if(doc) {
+            p->removeDocument(doc);
+        }
+    } 
     if (!isCanceled() && subTask == loadProjectTask && !loadProjectTask->hasErrors()) {
         Project* p =  loadProjectTask->detachProject();
         res.append(new RegisterProjectServiceTask(p));
@@ -311,7 +354,7 @@ void SaveOnlyProjectTask::_run(){
     lock = new StateLock(getTaskName(), StateLockFlag_LiveLock);
     proj->lockState(lock);
 
-    log.info(tr("Saving project %1").arg(url));
+    coreLog.info(tr("Saving project %1").arg(url));
     ProjectFileUtils::saveProjectFile(stateInfo, proj, url);
 }
 
@@ -339,7 +382,7 @@ LoadProjectTask::~LoadProjectTask() {
 }
 
 void LoadProjectTask::run() {
-    log.details(tr("Loading project from: %1").arg(url));
+    coreLog.details(tr("Loading project from: %1").arg(url));
     ProjectFileUtils::loadXMLProjectModel(url, stateInfo, *xmlDoc, version);
 }
 
@@ -348,13 +391,14 @@ Task::ReportResult LoadProjectTask::report() {
         ProjectParserRegistry *ppr = ProjectParserRegistry::instance();
         ProjectParser *parser = ppr->getProjectParserByVersion(version);
         if(parser == NULL){
-            log.info(tr("Unable to detect parser for project"));
+            coreLog.info(tr("Unable to detect parser for project"));
+            setError(tr("failed to parse project file %1").arg(url));
         }else{
             proj = parser->createProjectFromXMLModel(url, *xmlDoc, stateInfo);
         }
         if (proj!=NULL) {
-            log.info(tr("Project loaded: %1").arg(url));
-        }
+            coreLog.info(tr("Project loaded: %1").arg(url));
+        } 
     }
     return Task::ReportResult_Finished;
 }
@@ -372,20 +416,6 @@ void RegisterProjectServiceTask::prepare() {
     addSubTask(AppContext::getServiceRegistry()->registerServiceTask(ps));
 }
 
-OpenProjectTaskAndExecDialog::OpenProjectTaskAndExecDialog(QDialog *_dialog)
-    :OpenProjectTask(QString(), true)
-    , dialog(_dialog){
-
-};
-
-Task::ReportResult OpenProjectTaskAndExecDialog::report(){
-    dialog->exec();
-    delete dialog;
-    return ReportResult_Finished;
-}
-
-
-
 ExportProjectTask::ExportProjectTask(const QString& _destinationDir, const QString& _file, bool _compress):
 Task(tr("Export project task"), TaskFlags_NR_FOSCOE), compress(_compress), destinationDir(_destinationDir), projectFile(_file)
 {
@@ -399,7 +429,7 @@ void ExportProjectTask::prepare(){
     QList<Document*> docList = pr->getDocuments();
     foreach(Document* doc, docList){
         if(doc->getURL().isEmpty()){
-            log.error(tr("One of the documents has empty URL"));
+            coreLog.error(tr("One of the documents has empty URL"));
             return;
         }
     }
@@ -407,13 +437,13 @@ void ExportProjectTask::prepare(){
     QString error;
     QDir dDir(GUrlUtils::prepareDirLocation(destinationDir, error));
     if (!error.isEmpty()){
-        log.error(error);
+        coreLog.error(error);
         setError(error);
         return;
     }
 
     QMap<QString, QString> urlRemap;
-    foreach(Document* doc, docList){
+    /*foreach(Document* doc, docList){
         QString origPath = doc->getURLString();
         IOAdapterId id = doc->getIOAdapterFactory()->getAdapterId();
         if (id == BaseIOAdapters::LOCAL_FILE || id == BaseIOAdapters::GZIPPED_LOCAL_FILE){
@@ -426,7 +456,7 @@ void ExportProjectTask::prepare(){
             }
             urlRemap[origPath] = resultPath;
         }
-    }
+    }*/
     if(pr->getProjectName().isEmpty()){
         QFileInfo fi(projectFile);
         pr->setProjectName(fi.baseName());
@@ -547,7 +577,7 @@ void GTest_ExportProject::cleanup(){
     QDir qd(url);
     if(qd.exists(url)){
         if(!removeDir(QDir(url))){
-            log.info(tr("GTest_ExportProject::cleanup unable to delete exported files"));
+            coreLog.info(tr("GTest_ExportProject::cleanup unable to delete exported files"));
         }
     }
 }
