@@ -10,43 +10,48 @@
 
 #include "ProjectViewImpl.h"
 
-#include <core_services/AppContextImpl.h>
+#include <AppContextImpl.h>
 
-#include <core_api/ProjectModel.h>
-#include <core_api/Settings.h>
-#include <core_api/ObjectViewModel.h>
-#include <core_api/IOAdapter.h>
-#include <core_api/Log.h>
-#include <core_api/GObject.h>
-#include <core_api/GUrl.h>
+#include <U2Core/ProjectService.h>
+#include <U2Core/ProjectModel.h>
+#include <U2Core/Settings.h>
+#include <U2Gui/ObjectViewModel.h>
+#include <U2Core/IOAdapter.h>
+#include <U2Core/Log.h>
+#include <U2Core/GObject.h>
+#include <U2Core/GUrl.h>
 
-#include <gobjects/GObjectTypes.h>
-#include <gobjects/GObjectUtils.h>
+#include <U2Core/GObjectTypes.h>
+#include <U2Core/GObjectUtils.h>
+#include <U2Core/DNASequenceObject.h>
 
-#include <util_tasks/SaveDocumentTask.h>
-#include <util_tasks/LoadDocumentTask.h>
-#include <util_tasks/MultiTask.h>
-#include <util_tasks/CopyDataTask.h>
-#include <util_tasks/AddDocumentTask.h>
-#include <util_tasks/SaveDocumentTask.h>
+#include <U2Core/SaveDocumentTask.h>
+#include <U2Core/LoadDocumentTask.h>
+#include <U2Core/MultiTask.h>
+#include <U2Core/CopyDataTask.h>
+#include <U2Core/AddDocumentTask.h>
+#include <U2Core/SaveDocumentTask.h>
+#include <U2Gui/OpenViewTask.h>
 
-#include <util_gui/AddNewDocumentDialogImpl.h>
-#include <util_gui/AddExistingDocumentDialogImpl.h>
-#include <util_gui/GUIUtils.h>
-#include <util_gui/DialogUtils.h>
-#include <util_gui/CopyDocumentDialogController.h>
-#include <selection/SelectionUtils.h>
+#include <U2Gui/AddNewDocumentDialogController.h>
+#include <U2Gui/AddExistingDocumentDialogController.h>
+#include <U2Gui/GUIUtils.h>
+#include <U2Misc/DialogUtils.h>
+#include <U2Gui/CopyDocumentDialogController.h>
+#include <U2Core/SelectionUtils.h>
+
+#include <U2View/AnnotatedDNAView.h>
+#include <U2View/ADVSequenceWidget.h>
+#include <U2View/ADVSingleSequenceWidget.h>
 
 #include <QtGui/QtGui>
 #include <memory>
 
-namespace GB2 {
+namespace U2 {
 
 
-/* TRANSLATOR GB2::ProjectViewImpl */
-/* TRANSLATOR GB2::ProjectTreeController */
-
-static LogCategory log(ULOG_CAT_CORE_SERVICES);
+/* TRANSLATOR U2::ProjectViewImpl */
+/* TRANSLATOR U2::ProjectTreeController */
 
 #define SETTINGS_ROOT QString("projecview/")
 
@@ -121,7 +126,7 @@ void ProjectViewImpl::enable() {
     w = new ProjectViewWidget();
     
     assert(addExistingDocumentAction == NULL);
-    addExistingDocumentAction = new QAction(QIcon(":ugene/images/advanced_open.png"), tr("open_as"), w);
+    addExistingDocumentAction = new QAction(QIcon(":ugene/images/advanced_open.png"), tr("Open as..."), w);
     addExistingDocumentAction->setShortcut(QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_O));
     addExistingDocumentAction->setShortcutContext(Qt::ApplicationShortcut);
     connect(addExistingDocumentAction, SIGNAL(triggered()), SLOT(sl_onAddExistingDocument()));
@@ -201,6 +206,7 @@ void ProjectViewImpl::disable() {
     mw->setWindowTitle("");
 }
 
+
 void ProjectViewImpl::saveWidgetState(ProjectViewWidget* w) {
     QByteArray splitState = w->splitter->saveState();
     AppContext::getSettings()->setValue(SETTINGS_ROOT + "splitterState", splitState);
@@ -221,10 +227,13 @@ void ProjectViewImpl::initView() {
     ProjectTreeControllerModeSettings s;
     s.groupMode = getLastGroupMode();
     s.loadTaskProvider = this;
+    s.markActive = true;
+    s.activeFont.setWeight(QFont::DemiBold);
     projectTreeController = new ProjectTreeController(w, w->documentTreeWidget, s);
     projectTreeController->setObjectName("document_Filter_Tree_Controller");
     connect(projectTreeController, SIGNAL(si_onPopupMenuRequested(QMenu&)), SLOT(sl_onDocTreePopupMenuRequested(QMenu&)));
     connect(projectTreeController, SIGNAL(si_doubleClicked(GObject*)), SLOT(sl_onDoubleClicked(GObject*)));
+    connect(projectTreeController, SIGNAL(si_nameChanged(GObject *)), SLOT(sl_onNameChanged(GObject *)));
 
     w->groupModeMenu->addAction(projectTreeController->getGroupByDocumentAction());
     w->groupModeMenu->addAction(projectTreeController->getGroupByTypeAction());
@@ -239,6 +248,7 @@ void ProjectViewImpl::initView() {
     restoreWidgetState(w);	
 }
 
+
 bool ProjectViewImpl::eventFilter(QObject *obj, QEvent *event) {
     if (event->type() == QEvent::Close) {
         GObjectViewWindow* ov = qobject_cast<GObjectViewWindow*>(obj);
@@ -291,11 +301,11 @@ void ProjectViewImpl::sl_onAddNewDocument() {
     DocumentFormatConstraints c;
     c.supportedObjectTypes+=GObjectTypes::ANNOTATION_TABLE; //TODO: we can't create other data types on the fly..
     c.addFlagToSupport(DocumentFormatFlag_SupportWriting);
-    AddNewDocumentDialogImpl::run(NULL, m, c);
+    AddNewDocumentDialogController::run(NULL, m, c);
     if (m.successful) {
         DocumentFormat* format = AppContext::getDocumentFormatRegistry()->getFormatById(m.format);
         IOAdapterFactory* iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(m.io);
-        log.info(tr("creating_new_document_lm %1").arg(m.url));
+        coreLog.info(tr("Creating new document %1").arg(m.url));
         Document* doc = format->createNewDocument(iof, m.url);
         doc->setModified(true);
         AppContext::getProject()->addDocument(doc);
@@ -349,7 +359,7 @@ void ProjectViewImpl::sl_onViewPersistentStateChanged(GObjectViewWindow* v) {
 
 void ProjectViewImpl::sl_onAddExistingDocument() {
     AddExistingDocumentDialogModel m;
-	AddExistingDocumentDialogImpl::run(NULL, m, false);
+	AddExistingDocumentDialogController::run(NULL, m, false);
 	if (!m.successful) {
         return;
     }
@@ -357,13 +367,13 @@ void ProjectViewImpl::sl_onAddExistingDocument() {
     DocumentFormat* format = AppContext::getDocumentFormatRegistry()->getFormatById(m.format);
     IOAdapterFactory* iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(m.io);
 
-    log.info(tr("adding_existing_document %1").arg(m.url));
+    coreLog.info(tr("Adding existing document %1").arg(m.url));
 
     QList<Task *> tasks;
     Document * newdoc = 0;
     QString multiTaskName;
     if( !m.dwnldPath.isEmpty() ) {
-        IOAdapterFactory * iow = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById("local_file");
+        IOAdapterFactory * iow = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::LOCAL_FILE);
         QString url_w = m.dwnldPath;
         tasks.push_back( new CopyDataTask(iof, m.url, iow, url_w) );
         multiTaskName += "download_";
@@ -378,7 +388,7 @@ void ProjectViewImpl::sl_onAddExistingDocument() {
     adt->setSubtaskProgressWeight(0);
     tasks.append(adt);
     tasks.append(new LoadUnloadedDocumentAndOpenViewTask(newdoc));
-    multiTaskName += "add_load_document_task";
+    multiTaskName += tr("Add and load document");
     AppContext::getTaskScheduler()->registerTopLevelTask( new MultiTask(multiTaskName, tasks) );
 
 }
@@ -614,6 +624,7 @@ void ProjectViewImpl::buildViewMenu(QMenu& m) {
             break;
         }
     }
+
     buildRelocateMenu(&m);
 
     saveSelectedDocsAction->setEnabled(hasModifiedDocs);
@@ -674,6 +685,36 @@ void ProjectViewImpl::sl_openStateView() {
     }
 }
 
+void ProjectViewImpl::sl_onNameChanged(GObject *obj) {
+    QList<GObjectViewWindow*> wList = GObjectViewUtils::findViewsWithObject(obj);
+    //GObjectViewFactory* f = wList.first()->getViewFactory();
+    foreach(GObjectViewWindow* w, wList) {
+        OVTViewItem* bookmark = objectViewController->findViewItem(w->getWindowName());
+        QString newName = GObjectViewUtils::genUniqueViewName(obj->getDocument(),obj);
+        w->setWindowName(newName);
+        bookmark->viewName = newName;
+        bookmark->setText(0,newName);
+
+        if(obj->getGObjectType() == GObjectTypes::SEQUENCE) {
+            AnnotatedDNAView* objView = qobject_cast<AnnotatedDNAView*>(w->getObjectView());
+            foreach(ADVSequenceWidget * seqWidget, objView->getSequenceWidgets()) {
+                if(seqWidget->isWidgetOnlyObject(obj)) {
+                    ADVSingleSequenceWidget *sSeqWidget = qobject_cast<ADVSingleSequenceWidget*>(seqWidget);
+                    sSeqWidget->setTitle(obj->getGObjectName());
+                    break;
+                }
+            }
+        }
+    }
+
+    /*w->closeView();
+    GObjectSelection os; os.addToSelection(obj);
+    MultiGSelection ms; ms.addSelection(&os);
+    OpenViewContext* c = new OpenViewContext(this,ms,f);
+    assert(c->factory->canCreateView(c->selection));
+    AppContext::getTaskScheduler()->registerTopLevelTask(c->factory->createViewTask(c->selection));*/
+}
+
 void ProjectViewImpl::sl_onDocumentAdded(Document* d) {
     connect(d, SIGNAL(si_loadedStateChanged()), SLOT(sl_onDocumentLoadedStateChanged()));
 }
@@ -746,17 +787,18 @@ void ProjectViewImpl::sl_saveCopy() {
             GObjectUtils::updateRelationsURL(o, d->getURL(), h.url);
         }
         Task* t = NULL;
+        t = new SaveDocumentTask(dd, iof, h.url); //TODO: memory leak here! Create wrapper-like task that cleans resources on finish
+        AppContext::getTaskScheduler()->registerTopLevelTask(t);
+
         if (addToProject) {
             Project *p = AppContext::getProject(); //TODO: add to project only if save was successful!
             dd->setModified(true);
             p->addDocument(dd);
-        } else {
-            t = new SaveDocumentTask(dd, iof, h.url); //TODO: memory leak here! Create wrapper-like task that cleans resources on finish
-            AppContext::getTaskScheduler()->registerTopLevelTask(t);
-        }
+        } 
     }
 }
 
+
 void ProjectViewImpl::highlightItem(Document* doc){
     assert(doc);
     projectTreeController->highlightItem(doc);
