@@ -10,23 +10,21 @@
 
 #include "TaskViewController.h"
 
-#include <core_api/Task.h>
-#include <core_api/Settings.h>
-#include <core_api/AppContext.h>
-#include <core_api/Log.h>
-#include <core_api/Timer.h>
+#include <U2Core/Task.h>
+#include <U2Core/Settings.h>
+#include <U2Core/AppContext.h>
+#include <U2Core/Log.h>
+#include <U2Core/Timer.h>
 
 #include <QtGui/QVBoxLayout>
 #include <QtGui/QHeaderView>
 #include <QtGui/QMenu>
 
-/* TRANSLATOR GB2::TaskViewDockWidget */
+/* TRANSLATOR U2::TaskViewDockWidget */
 
 //TODO: do not create subtask items until not expanded
 
-namespace GB2 {
-
-static LogCategory log(ULOG_CAT_TASKS);
+namespace U2 {
 
 #define SETTINGS_ROOT QString("task_view/")
 
@@ -223,7 +221,7 @@ void TaskViewDockWidget::sl_onTopLevelTaskUnregistered(Task* t) {
     TVTreeItem* ti = findItem(t, true);
     assert(ti!=NULL);
 
-    if (t->isReportingEnabled()) {
+    /*if (t->isReportingEnabled()) {
         log.info(tr("New report available from task: %1").arg(t->getTaskName()));
         
         ti->detachFromTask();
@@ -240,9 +238,9 @@ void TaskViewDockWidget::sl_onTopLevelTaskUnregistered(Task* t) {
         ti->cancelButton->setIcon(removeReportAction->icon());
 
         emit si_reportsCountChanged();
-    } else {
+    } else {*/
         delete ti;
-    }
+    //}
 }
 
 void TaskViewDockWidget::sl_activateReportByButton() {
@@ -283,7 +281,7 @@ void TaskViewDockWidget::sl_onRemoveTaskReport() {
 
 void TaskViewDockWidget::activateReport(TVTreeItem* ti) {
     assert(ti->reportButton!=NULL);
-    log.trace(tr("Activating task report: %1").arg(ti->taskName));
+    uiLog.details(tr("Activating task report: %1").arg(ti->taskName));
 
     MWMDIManager* mdi = AppContext::getMainWindow()->getMDIManager();
     MWMDIWindow* w = ti->reportWindowId!=-1 ? NULL : mdi->getWindowById(ti->reportWindowId);
@@ -418,6 +416,8 @@ TVReportWindow::TVReportWindow(const QString& taskName, qint64 tid, const QStrin
     textEdit->setText(report);
     
     l->addWidget(textEdit);
+    textEdit->viewport()->installEventFilter(this);
+    textEdit->viewport()->setMouseTracking(true);
 }
 
 QString TVReportWindow::genWindowName(const QString& taskName) {
@@ -453,6 +453,26 @@ QString TVReportWindow::prepareReportHTML(Task* t) {
     return report;
 }
 
+bool TVReportWindow::eventFilter(QObject *o, QEvent *e) {
+    if(e->type() == QEvent::MouseButtonPress) {
+        QMouseEvent *me = static_cast<QMouseEvent*>(e);
+        if(me->button() == Qt::LeftButton) {
+            QString url = textEdit->anchorAt(me->pos());
+            if(!url.isEmpty()) {
+                Task *t = AppContext::getProjectLoader()->openProjectTask(url, false);
+                AppContext::getTaskScheduler()->registerTopLevelTask(t);
+            }
+        }
+    } else if(e->type() == QEvent::MouseMove) {
+        QMouseEvent *me = static_cast<QMouseEvent*>(e);
+        if(!textEdit->anchorAt(me->pos()).isEmpty()) {
+            textEdit->viewport()->setCursor(Qt::PointingHandCursor);
+        } else {
+            textEdit->viewport()->setCursor(Qt::IBeamCursor);
+        }
+    }
+    return false;
+}
 
 
 //////////////////////////////////////////////////////////////////////////
